package com.goodix.cap.fingerprint.ext;

import android.content.Context;
import android.graphics.Bitmap;
import android.os.CancellationSignal;
import android.support.v4.os.EnvironmentCompat;
import android.support.v4.view.MotionEventCompat;
import android.util.Log;
import com.goodix.cap.fingerprint.Constants;
import com.goodix.cap.fingerprint.sec.GoodixFpCaptureInfo;
import com.goodix.cap.fingerprint.sec.GoodixFpEnrollStatus;
import com.goodix.cap.fingerprint.sec.GoodixFpIdentifyResult;
import com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt;
import com.goodix.cap.fingerprint.utils.TestParamEncoder;
import com.google.common.primitives.UnsignedBytes;
import egis.client.api.EgisFingerprint;
import java.util.HashMap;
import java.util.List;

public class ExtGoodixFpManager {
    private static final int ENROLL_STATE_PAUSE = 1;
    private static final int ENROLL_STATE_RESUME = 0;
    private static final int STATE_ENROLL = 1;
    private static final int STATE_IDENTIFY = 2;
    private static final int STATE_IDLE = 0;
    private static final String TAG = "ExtGoodixFpManager";
    private static HashMap<Integer, String> mChipInfo;
    private static int mCurState = 0;
    private static int mEnrollBadTrial = 0;
    private static int mEnrollProgress = 0;
    private static int mEnrollState = 0;
    private static int mEnrollSuccessTrial = 0;
    private static int mEnrollingGroupId = -1;
    private static int mEnrollingIndex = -1;
    private static String mEnrollingUserId = null;
    private GoodixFingerprintManagerExt.UntrustedAuthenticationCallback mAuthenticateCallback = new GoodixFingerprintManagerExt.UntrustedAuthenticationCallback() {
        /* class com.goodix.cap.fingerprint.ext.ExtGoodixFpManager.AnonymousClass3 */

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedAuthenticationCallback
        public void onAuthenticationError(int errorCode, CharSequence errString) {
            Log.d(ExtGoodixFpManager.TAG, "onAuthenticationError errorCode=" + errorCode);
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedAuthenticationCallback
        public void onAuthenticationHelp(int helpCode, CharSequence helpString) {
            Log.d(ExtGoodixFpManager.TAG, "onAuthenticationHelp helpCode=" + helpCode);
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedAuthenticationCallback
        public void onAuthenticationSucceeded(int fingerId) {
            Log.d(ExtGoodixFpManager.TAG, "onAuthenticationSucceeded fingerId=" + fingerId);
            ExtGoodixFpManager.this.mIndentifyResult = new GoodixFpIdentifyResult();
            ExtGoodixFpManager.this.mIndentifyResult.userId = ExtGoodixFpManager.this.mIdentifyUserID;
            ExtGoodixFpManager.this.mFpUserState.loadFingerprintsForUser(ExtGoodixFpManager.this.mIndentifyResult.userId);
            ExtGoodixFpManager.this.mIndentifyResult.index = ExtGoodixFpManager.this.mFpUserState.getIndexByFingerID(fingerId);
            ExtGoodixFpManager.this.mIndentifyResult.indexes = new int[1];
            ExtGoodixFpManager.this.mIndentifyResult.indexes[0] = ExtGoodixFpManager.this.mIndentifyResult.index;
            ExtGoodixFpManager.this.mFpEventListener.onEvent(6001, ExtGoodixFpManager.this.mIndentifyResult);
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedAuthenticationCallback
        public void onAuthenticationFailed() {
            Log.d(ExtGoodixFpManager.TAG, "onAuthenticationFailed");
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedAuthenticationCallback
        public void onAuthenticationCaptureBmpResult(GoodixImageInfo captureInfo) {
            Log.d(ExtGoodixFpManager.TAG, "onAuthenticationCaptureBmpResult CaptureSuccess ..... ");
            ExtGoodixFpManager.this.mAuthenticateCaptureInfo = new GoodixFpCaptureInfo();
            ExtGoodixFpManager.this.mAuthenticateCaptureInfo.bitmap = captureInfo.bmp;
            ExtGoodixFpManager.this.mAuthenticateCaptureInfo.rawbitmap = captureInfo.rawBmp;
            ExtGoodixFpManager.this.mAuthenticateCaptureInfo.width = captureInfo.width;
            ExtGoodixFpManager.this.mAuthenticateCaptureInfo.height = captureInfo.height;
            ExtGoodixFpManager.this.mAuthenticateCaptureInfo.quality = captureInfo.imgQuality;
            if (ExtGoodixFpManager.this.mIdentifySuccess) {
                ExtGoodixFpManager.this.mIdentifySuccess = false;
            }
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedAuthenticationCallback
        public void onAuthenticationAcquired(int acquireInfo) {
            switch (acquireInfo) {
                case 4001:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_READY = " + acquireInfo);
                    ExtGoodixFpManager.this.mCaptureSuccess = false;
                    ExtGoodixFpManager.this.mCaptureFail = false;
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4001, null);
                    return;
                case 4002:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_STARTED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4002, null);
                    return;
                case 4003:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_COMPLETED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4003, null);
                    return;
                case 4004:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_SUCCESS = " + acquireInfo);
                    ExtGoodixFpManager.access$208();
                    ExtGoodixFpManager.this.mCaptureSuccess = true;
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4004, ExtGoodixFpManager.this.mAuthenticateCaptureInfo);
                    return;
                case 4005:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_FAILED = " + acquireInfo);
                    ExtGoodixFpManager.access$108();
                    ExtGoodixFpManager.this.mCaptureSuccess = false;
                    ExtGoodixFpManager.this.mCaptureFail = true;
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4005, ExtGoodixFpManager.this.mAuthenticateCaptureInfo);
                    return;
                case 4006:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_FINGER_LEAVED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4006, null);
                    if (GoodixSharePref.getInstance().getBoolean("enable_mt_flag", false)) {
                        ExtGoodixFpManager.this.controlDevice(0);
                        return;
                    }
                    return;
                case 6001:
                    ExtGoodixFpManager.this.mIdentifySuccess = true;
                    return;
                case 6002:
                case 6103:
                case 6104:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired IDENTIFY_FAILED = " + acquireInfo);
                    ExtGoodixFpManager.this.mIdentifySuccess = false;
                    ExtGoodixFpManager.this.mIndentifyResult = new GoodixFpIdentifyResult();
                    ExtGoodixFpManager.this.mIndentifyResult.userId = ExtGoodixFpManager.this.mIdentifyUserID;
                    ExtGoodixFpManager.this.mIndentifyResult.index = -1;
                    ExtGoodixFpManager.this.mIndentifyResult.indexes = new int[1];
                    ExtGoodixFpManager.this.mIndentifyResult.indexes[0] = ExtGoodixFpManager.this.mIndentifyResult.index;
                    if (acquireInfo == 6002) {
                        ExtGoodixFpManager.this.mIndentifyResult.result = 6103;
                        ExtGoodixFpManager.this.mFpEventListener.onEvent(6002, ExtGoodixFpManager.this.mIndentifyResult);
                        return;
                    }
                    ExtGoodixFpManager.this.mIndentifyResult.result = acquireInfo;
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(6002, ExtGoodixFpManager.this.mIndentifyResult);
                    return;
                default:
                    return;
            }
        }
    };
    private GoodixFpCaptureInfo mAuthenticateCaptureInfo;
    private CancellationSignal mAuthenticationCancel;
    private boolean mCaptureDone = false;
    private boolean mCaptureFail = false;
    private boolean mCaptureSuccess = false;
    private Context mContext;
    private GoodixFpCaptureInfo mEnrollCaptureInfo;
    private GoodixFingerprintManagerExt.UntrustedEnrollmentCallback mEnrollmentCallback = new GoodixFingerprintManagerExt.UntrustedEnrollmentCallback() {
        /* class com.goodix.cap.fingerprint.ext.ExtGoodixFpManager.AnonymousClass1 */

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedEnrollmentCallback
        public void onEnrollmentProgress(int fingerId, int progress) {
            Log.d(ExtGoodixFpManager.TAG, "onEnrollmentProgress fingerId = " + fingerId + "  progress=" + progress);
            int unused = ExtGoodixFpManager.mEnrollProgress = progress;
            GoodixFpEnrollStatus enrollStatus = new GoodixFpEnrollStatus();
            enrollStatus.progress = progress;
            enrollStatus.badTrial = ExtGoodixFpManager.mEnrollBadTrial;
            enrollStatus.successTrial = ExtGoodixFpManager.mEnrollSuccessTrial;
            enrollStatus.totalTrial = ExtGoodixFpManager.mEnrollBadTrial + ExtGoodixFpManager.mEnrollSuccessTrial;
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedEnrollmentCallback
        public void onEnrollmentProgress(int fingerId, int progress, byte[] result) {
            int unused = ExtGoodixFpManager.mEnrollProgress = progress;
            Log.d(ExtGoodixFpManager.TAG, "onEnrollmentProgress : " + ExtGoodixFpManager.mEnrollProgress);
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedEnrollmentCallback
        public void onEnrollmentResultInfo(GoodixEnrollInfo enrollInfo) {
            int unused = ExtGoodixFpManager.mEnrollProgress = enrollInfo.remaining;
            Log.d(ExtGoodixFpManager.TAG, "onEnrollmentResultInfo : " + ExtGoodixFpManager.mEnrollProgress);
            GoodixFpEnrollStatus enrollStatus = new GoodixFpEnrollStatus();
            enrollStatus.progress = 100 - ((enrollInfo.remaining * 100) / ExtGoodixFpManager.this.getEnrollCountMin());
            enrollStatus.badTrial = ExtGoodixFpManager.mEnrollBadTrial;
            enrollStatus.successTrial = ExtGoodixFpManager.mEnrollSuccessTrial;
            enrollStatus.totalTrial = ExtGoodixFpManager.mEnrollBadTrial + ExtGoodixFpManager.mEnrollSuccessTrial;
            enrollStatus.coverageBitmap = enrollInfo.bitmap;
            Log.d(ExtGoodixFpManager.TAG, "onEnrollmentResultInfo fingerId = " + enrollInfo.fingerId + "  progress=" + enrollStatus.progress + "% enrollStatus.badTrial = " + enrollStatus.badTrial + " enrollStatus.successTrial = " + enrollStatus.successTrial);
            ExtGoodixFpManager.this.mFpEventListener.onEvent(5001, enrollStatus);
            if (enrollInfo.remaining == 0) {
                ExtGoodixFpManager.this.mFpEventListener.onEvent(5002, enrollStatus);
                ExtGoodixFpManager.this.mFpUserState.addFingerprint(ExtGoodixFpManager.mEnrollingUserId, ExtGoodixFpManager.mEnrollingIndex, enrollInfo.fingerId, ExtGoodixFpManager.mEnrollingGroupId);
                if (!GoodixSharePref.getInstance().getBoolean("enable_mt_flag", false)) {
                    ExtGoodixFpManager.this.controlDevice(0);
                }
            }
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedEnrollmentCallback
        public void onEnrollmentCaptureBmpResult(GoodixImageInfo captureInfo) {
            Log.d(ExtGoodixFpManager.TAG, "onEnrollmentCaptureBmpResult  ....... ");
            ExtGoodixFpManager.this.mEnrollCaptureInfo = new GoodixFpCaptureInfo();
            ExtGoodixFpManager.this.mEnrollCaptureInfo.bitmap = captureInfo.bmp;
            ExtGoodixFpManager.this.mEnrollCaptureInfo.rawbitmap = captureInfo.rawBmp;
            ExtGoodixFpManager.this.mEnrollCaptureInfo.width = captureInfo.width;
            ExtGoodixFpManager.this.mEnrollCaptureInfo.height = captureInfo.height;
            ExtGoodixFpManager.this.mEnrollCaptureInfo.quality = captureInfo.imgQuality;
            if (!ExtGoodixFpManager.this.mCaptureFail && ExtGoodixFpManager.this.mCaptureSuccess) {
                ExtGoodixFpManager.this.mCaptureSuccess = false;
            }
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedEnrollmentCallback
        public void onEnrollmentHelp(int helpMsgId, String helpString) {
            Log.d(ExtGoodixFpManager.TAG, "onEnrollmentHelp helpMsgId = " + helpMsgId);
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedEnrollmentCallback
        public void onEnrollmentError(int errMsgId, String errString) {
            Log.d(ExtGoodixFpManager.TAG, "onEnrollmentError errMsgId = " + errMsgId);
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedEnrollmentCallback
        public void onEnrollmentAcquired(int acquireInfo) {
            Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired acquireInfo = " + acquireInfo);
            switch (acquireInfo) {
                case 4001:
                    Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired CAPTURE_READY = " + acquireInfo);
                    ExtGoodixFpManager.this.mCaptureSuccess = false;
                    ExtGoodixFpManager.this.mCaptureFail = false;
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4001, null);
                    return;
                case 4002:
                    Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired CAPTURE_STARTED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4002, null);
                    return;
                case 4003:
                    Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired CAPTURE_COMPLETED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4003, null);
                    return;
                case 4004:
                    Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired CAPTURE_SUCCESS = " + acquireInfo);
                    ExtGoodixFpManager.access$208();
                    ExtGoodixFpManager.this.mCaptureSuccess = true;
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4004, ExtGoodixFpManager.this.mEnrollCaptureInfo);
                    return;
                case 4005:
                    Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired CAPTURE_FAILED = " + acquireInfo);
                    ExtGoodixFpManager.access$108();
                    ExtGoodixFpManager.this.mCaptureSuccess = false;
                    ExtGoodixFpManager.this.mCaptureFail = true;
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4005, ExtGoodixFpManager.this.mEnrollCaptureInfo);
                    return;
                case 4006:
                    Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired CAPTURE_FINGER_LEAVED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4006, null);
                    if (GoodixSharePref.getInstance().getBoolean("enable_mt_flag", false)) {
                        ExtGoodixFpManager.this.controlDevice(0);
                        return;
                    }
                    return;
                default:
                    return;
            }
        }
    };
    private CancellationSignal mEnrollmentCancel;
    private GoodixEventListener mFpEventListener = null;
    private GoodixFpsUserState mFpUserState;
    private GoodixFingerprintManagerExt mGoodixFingerprintManager = null;
    private boolean mIdentifySuccess = false;
    private String mIdentifyUserID = null;
    private GoodixFpIdentifyResult mIndentifyResult;
    private GoodixFingerprintManagerExt.UntrustedRemovalCallback mRemoveCallback = new GoodixFingerprintManagerExt.UntrustedRemovalCallback() {
        /* class com.goodix.cap.fingerprint.ext.ExtGoodixFpManager.AnonymousClass2 */

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedRemovalCallback
        public void onRemovalSucceeded(int fingerId) {
            Log.d(ExtGoodixFpManager.TAG, "onRemovalSucceeded fingerId = " + fingerId);
            ExtGoodixFpManager.this.mFpEventListener.onEvent(9005, null);
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.UntrustedRemovalCallback
        public void onRemovalError(int errMsgId, CharSequence errString) {
            Log.d(ExtGoodixFpManager.TAG, "onRemovalFailed");
            Log.d(ExtGoodixFpManager.TAG, "onRemovalFailed errMsgId = " + errMsgId + " errString = " + ((Object) errString));
        }
    };

    static /* synthetic */ int access$108() {
        int i = mEnrollBadTrial;
        mEnrollBadTrial = i + 1;
        return i;
    }

    static /* synthetic */ int access$208() {
        int i = mEnrollSuccessTrial;
        mEnrollSuccessTrial = i + 1;
        return i;
    }

    static {
        HashMap<Integer, String> hashMap = new HashMap<>();
        mChipInfo = hashMap;
        hashMap.put(13, "gw32j1");
        mChipInfo.put(10, "gw32k");
    }

    public ExtGoodixFpManager(Context context) {
        this.mContext = context;
        Log.d(TAG, "mContext=" + this.mContext);
        this.mGoodixFingerprintManager = GoodixFingerprintManagerExt.getGoodixManager(this.mContext);
        this.mFpUserState = new GoodixFpsUserState(this.mContext);
        GoodixSharePref.getInstance().init(context);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void controlDevice(int flag) {
    }

    public String[] getUserIdList() {
        Log.d(TAG, "getUserIdList");
        String[] userId = null;
        List<GoodixUserInfo> uis = this.mFpUserState.getUserInfo();
        Log.d(TAG, "getUserIdList uis.size()=" + uis.size());
        if (uis.size() > 0) {
            userId = new String[uis.size()];
            for (int i = 0; i < uis.size(); i++) {
                userId[i] = uis.get(i).getUserId().toString();
                Log.d(TAG, "getUserIdList userId[" + i + "]=" + userId[i]);
            }
        }
        return userId;
    }

    public int enroll(String userId, int index) {
        Log.d(TAG, "enroll");
        mCurState = 1;
        mEnrollState = 0;
        mEnrollingIndex = index;
        mEnrollBadTrial = 0;
        mEnrollSuccessTrial = 0;
        mEnrollingUserId = userId;
        controlDevice(1);
        if (GoodixSharePref.getInstance().getBoolean("enable_mt_flag", false)) {
            mEnrollingGroupId = this.mFpUserState.addUserInfo(userId);
            Log.d(TAG, "MT enroll mEnrollingGroupId=" + mEnrollingGroupId);
            setActiveGroup(10000);
        } else {
            if (this.mFpUserState.isUserIdExist(userId)) {
                mEnrollingGroupId = this.mFpUserState.getGroupIdForUser(userId);
            } else {
                mEnrollingGroupId = this.mFpUserState.addUserInfo(userId);
            }
            Log.d(TAG, "enroll mEnrollingGroupId=" + mEnrollingGroupId);
            int i = mEnrollingGroupId;
            if (i >= 0) {
                setActiveGroup(i);
            }
            Log.d(TAG, "after setActiveGroup");
        }
        CancellationSignal cancellationSignal = new CancellationSignal();
        this.mEnrollmentCancel = cancellationSignal;
        this.mGoodixFingerprintManager.untrustedEnroll(cancellationSignal, this.mEnrollmentCallback);
        return 0;
    }

    public int identify(String userId) {
        int groupId;
        Log.d(TAG, "identify");
        mCurState = 2;
        this.mIdentifyUserID = userId;
        this.mFpUserState.getFingerprints(userId);
        controlDevice(1);
        if (GoodixSharePref.getInstance().getBoolean("enable_mt_flag", false)) {
            int groupId2 = this.mFpUserState.addUserInfo(userId);
            Log.d(TAG, "MT identify groupId=" + groupId2);
            setActiveGroup(10000);
        } else {
            if (this.mFpUserState.isUserIdExist(userId)) {
                groupId = this.mFpUserState.getGroupIdForUser(userId);
            } else {
                groupId = this.mFpUserState.addUserInfo(userId);
            }
            Log.d(TAG, "identify groupId=" + groupId);
            if (groupId >= 0) {
                setActiveGroup(groupId);
            }
        }
        CancellationSignal cancellationSignal = new CancellationSignal();
        this.mAuthenticationCancel = cancellationSignal;
        this.mGoodixFingerprintManager.untrustedAuthenticate(cancellationSignal, this.mAuthenticateCallback);
        return 0;
    }

    public int cancel() {
        CancellationSignal cancellationSignal;
        Log.d(TAG, "cancel");
        int i = mCurState;
        if (i == 1) {
            CancellationSignal cancellationSignal2 = this.mEnrollmentCancel;
            if (cancellationSignal2 != null && !cancellationSignal2.isCanceled()) {
                Log.d(TAG, "cancel enrollment");
                this.mEnrollmentCancel.cancel();
                this.mFpEventListener.onEvent(5003, 5101);
                this.mEnrollmentCancel = null;
            }
            mEnrollState = 0;
        } else if (i == 2 && (cancellationSignal = this.mAuthenticationCancel) != null && !cancellationSignal.isCanceled()) {
            Log.d(TAG, "cancel identification");
            this.mAuthenticationCancel.cancel();
            GoodixFpIdentifyResult identifyResult = new GoodixFpIdentifyResult();
            identifyResult.userId = this.mIdentifyUserID;
            identifyResult.index = -1;
            identifyResult.indexes = new int[1];
            identifyResult.indexes[0] = -1;
            identifyResult.result = 6101;
            this.mFpEventListener.onEvent(6002, identifyResult);
            this.mAuthenticationCancel = null;
        }
        this.mIdentifyUserID = null;
        mCurState = 0;
        controlDevice(0);
        return 0;
    }

    public void enableMT(boolean enable) {
        GoodixSharePref.getInstance().init(this.mContext);
        GoodixSharePref.getInstance().putBoolean("enable_mt_flag", enable);
    }

    private void setActiveGroup(int groupId) {
        byte[] byteArray = new byte[8];
        this.mGoodixFingerprintManager.initGroupIdValue(groupId);
        TestParamEncoder.encodeInt32(byteArray, 0, 1420, groupId);
        this.mGoodixFingerprintManager.testCmd(53, byteArray);
    }

    public void setEventListener(GoodixEventListener listener) {
        Log.d(TAG, "setEventListener");
        this.mFpEventListener = listener;
    }

    public String getVersion() {
        return Constants.RELEASE_VERSION;
    }

    public int setEnrollSession(boolean flag) {
        this.mGoodixFingerprintManager.setEnrollSession(flag);
        return this.mGoodixFingerprintManager.setEnrollSession(flag);
    }

    public int release() {
        return 0;
    }

    public int setAccuracyLevel(int level) {
        return 0;
    }

    public int[] getFingerprintIndexList(String userId) {
        Log.d(TAG, "getFingerprintIndexList");
        List<GoodixFpInfo> fps = this.mFpUserState.getFingerprints(userId);
        int[] fpIndex = null;
        Log.d(TAG, "getFingerprintIndexList fps.size()=" + fps.size());
        if (fps.size() > 0) {
            fpIndex = new int[fps.size()];
            for (int i = 0; i < fps.size(); i++) {
                fpIndex[i] = fps.get(i).getFingerIndex();
                Log.d(TAG, "getFingerprintIndexList fpIndex[" + i + "]=" + fpIndex[i]);
            }
        }
        return fpIndex;
    }

    public int getEnrollRepeatCount() {
        Log.d(TAG, "getEnrollRepeatCount");
        return 20;
    }

    public byte[] getFingerprintId(String userId, int index) {
        Log.d(TAG, "getFingerprintId");
        List<GoodixFpInfo> fps = this.mFpUserState.getFingerprints(userId);
        byte[] fid = null;
        if (fps.size() > 0) {
            for (int i = 0; i < fps.size(); i++) {
                if (index == fps.get(i).getFingerIndex()) {
                    int fingerId = fps.get(i).getFingerId();
                    Log.d(TAG, "getFingerprintId fingerId = " + fingerId);
                    fid = int2bytes(fingerId);
                }
            }
        }
        return fid;
    }

    public void remove(String userId, int index) {
        Log.d(TAG, "remove userId=" + userId + " index =" + index);
        byte[] fid = getFingerprintId(userId, index);
        if (fid != null) {
            int fingerId = byte2int(fid);
            int groupId = this.mFpUserState.getGroupIdForUser(userId);
            Log.d(TAG, "remove userId=" + userId);
            Log.d(TAG, "remove index=" + index);
            Log.d(TAG, "remove fid=" + fid);
            Log.d(TAG, "remove fingerId=" + fingerId);
            Log.d(TAG, "remove groupId=" + groupId);
            this.mGoodixFingerprintManager.untrustedRemoveForSec(groupId, fingerId, this.mRemoveCallback);
            this.mFpUserState.removeFingerprint(userId, index);
            return;
        }
        this.mFpEventListener.onEvent(9006, null);
    }

    private static byte[] int2bytes(int res) {
        return new byte[]{(byte) (res & 255), (byte) ((res >> 8) & 255), (byte) ((res >> 16) & 255), (byte) (res >>> 24)};
    }

    private static int byte2int(byte[] res) {
        return (res[0] & UnsignedBytes.MAX_VALUE) | ((res[1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK) | ((res[2] << 24) >>> 8) | (res[3] << 24);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int getEnrollCountMin() {
        if (getProperty("gf.debug.open_swipe_enroll", "0").equals(EgisFingerprint.MAJOR_VERSION)) {
            return 3;
        }
        return 20;
    }

    private String getProperty(String key, String defaultValue) {
        try {
            Class<?> c = Class.forName("android.os.SystemProperties");
            return (String) c.getMethod("get", String.class, String.class).invoke(c, key, EnvironmentCompat.MEDIA_UNKNOWN);
        } catch (Exception e) {
            e.printStackTrace();
            return defaultValue;
        } catch (Throwable th) {
            return defaultValue;
        }
    }

    public int request(int code, Object data) {
        Log.d(TAG, "request() code = " + code);
        switch (code) {
            case 2001:
                this.mGoodixFingerprintManager.untrustedPauseEnroll();
                mEnrollState = 1;
                break;
            case 2002:
                this.mGoodixFingerprintManager.untrustedResumeEnroll();
                mEnrollState = 0;
                break;
        }
        return 0;
    }

    public void setPassword(String userId, byte[] pwdHash) {
        Log.d(TAG, "setPassword");
        new String(pwdHash);
    }

    public void verifyPassword(String userId, byte[] pwdHash) {
        Log.d(TAG, "VerifyPassword");
        new String(pwdHash);
    }

    public String getSensorInfo() {
        Log.d(TAG, "mChipType info =  " + this.mGoodixFingerprintManager.getConfig().mChipType + "  " + mChipInfo.get(Integer.valueOf(this.mGoodixFingerprintManager.getConfig().mChipType)));
        return "gf-cap-" + this.mGoodixFingerprintManager.getConfig().mChipSeries + "-" + mChipInfo.get(Integer.valueOf(this.mGoodixFingerprintManager.getConfig().mChipType));
    }

    public int getSensorStatus() {
        return -1;
    }

    private Bitmap convertDataToBmp(byte[] data, int width, int height) {
        Log.d(TAG, "convertDataToBmp start");
        Log.d(TAG, "convertToBitmap width=" + width + ",height=" + height + " data=" + data);
        int length = width * height;
        int[] display = new int[length];
        for (int i = 0; i < length; i++) {
            int pixel = data[i] & UnsignedBytes.MAX_VALUE;
            display[i] = -16777216 | (pixel << 16) | (pixel << 8) | pixel;
        }
        return Bitmap.createBitmap(display, width, height, Bitmap.Config.ARGB_8888);
    }
}
