package com.goodix.cap.fingerprint.ext;

import android.content.Context;
import android.os.AsyncTask;
import android.util.AtomicFile;
import android.util.Log;
import android.util.Xml;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlSerializer;

public class GoodixFpsUserState {
    private static final String ATTR_FINGER_ID = "fingerId";
    private static final String ATTR_GROUP_ID = "groupId";
    private static final String ATTR_INDEX = "index";
    private static final String ATTR_PASSWORD = "password";
    private static final String ATTR_USER_ID = "userId";
    private static final String FINGERPRINT_FILE = "fingerprint_info.xml";
    private static final String TAG = "GoodixFpsUserState";
    private static final String TAG_FINGERPRINT = "fingerprint";
    private static final String TAG_FINGERPRINTS = "fingerprints";
    private static final String TAG_USER_INFO = "user_info";
    private static final String TAG_USER_INFOS = "user_infos";
    private static final String USER_INFO_FILE = "user_info.xml";
    private final Context mCtx;
    private String mCurUserId = "";
    private File mFingerprintFile;
    private final ArrayList<GoodixFpInfo> mFingerprints = new ArrayList<>();
    private final ArrayList<GoodixUserInfo> mUserInfo = new ArrayList<>();
    private final File mUserInfoFile;
    private final Runnable mWriteFpStateRunnable = new Runnable() {
        /* class com.goodix.cap.fingerprint.ext.GoodixFpsUserState.AnonymousClass2 */

        public void run() {
            GoodixFpsUserState.this.doWriteFpState();
        }
    };
    private final Runnable mWriteUserInfoRunnable = new Runnable() {
        /* class com.goodix.cap.fingerprint.ext.GoodixFpsUserState.AnonymousClass1 */

        public void run() {
            GoodixFpsUserState.this.doWriteUserInfo();
        }
    };

    public GoodixFpsUserState(Context ctx) {
        this.mCtx = ctx;
        this.mUserInfoFile = getUserInfoFile();
        Log.d(TAG, "mCtx = " + ctx);
        GoodixSharePref.getInstance().init(ctx);
        synchronized (this) {
            readUserInfoSyncLocked();
        }
    }

    public int addUserInfo(String userId) {
        Log.d(TAG, "addUserInfo userId = " + userId);
        int groupId = -1;
        synchronized (this) {
            if (!isUserIdExist(userId)) {
                groupId = getUniqueGroupId();
                Log.d(TAG, "addUserInfo groupId = " + groupId);
                this.mUserInfo.add(new GoodixUserInfo(userId, groupId));
                scheduleWriteUserInfoLocked();
            }
            if (GoodixSharePref.getInstance().getBoolean("enable_mt_flag", false)) {
                groupId = 10000;
            }
        }
        return groupId;
    }

    public boolean setUserPwd(String userId, String pwd) {
        Log.d(TAG, "setUserPwd userId = " + userId + ", pwd=" + pwd);
        for (int i = 0; i < this.mUserInfo.size(); i++) {
            if (userId.equals(this.mUserInfo.get(i).getUserId().toString())) {
                this.mUserInfo.get(i).setPwd(pwd);
                scheduleWriteUserInfoLocked();
                this.mCurUserId = userId;
                return true;
            }
        }
        return false;
    }

    public boolean verifyUserPwd(String userId, String pwd) {
        Log.d(TAG, "verifyUserPwd userId = " + userId + ", pwd=" + pwd);
        if (this.mUserInfo == null) {
            return false;
        }
        for (int i = 0; i < this.mUserInfo.size(); i++) {
            if (this.mUserInfo.get(i) != null && userId.equals(this.mUserInfo.get(i).getUserId().toString()) && pwd.equals(this.mUserInfo.get(i).getPwd().toString())) {
                return true;
            }
        }
        return false;
    }

    public int getIndexByFingerID(int fingerID) {
        for (int i = 0; i < this.mFingerprints.size(); i++) {
            if (fingerID == this.mFingerprints.get(i).getFingerId()) {
                return this.mFingerprints.get(i).getFingerIndex();
            }
        }
        return -1;
    }

    public boolean isUserIdExist(String userId) {
        Log.d(TAG, "isUserIdExist userId = " + userId);
        for (int i = 0; i < this.mUserInfo.size(); i++) {
            if (userId.equals(this.mUserInfo.get(i).getUserId().toString())) {
                return true;
            }
        }
        return false;
    }

    private boolean isGroupIdExist(int groupId) {
        Log.d(TAG, "isGroupIdExist groupId = " + groupId);
        for (int i = 0; i < this.mUserInfo.size(); i++) {
            if (groupId == this.mUserInfo.get(i).getGroupId()) {
                return true;
            }
        }
        return false;
    }

    private int getUniqueGroupId() {
        int groupId = -1;
        while (true) {
            if (!GoodixSharePref.getInstance().getBoolean("enable_mt_flag", false)) {
                groupId++;
                if (!isGroupIdExist(groupId)) {
                    break;
                }
            } else {
                groupId = 10000;
                break;
            }
        }
        Log.d(TAG, "getUniqueGroupId groupId = " + groupId);
        return groupId;
    }

    public void addFingerprint(String userId, int index, int fingerId, int groupId) {
        Log.d(TAG, "addFingerprint userId = " + userId);
        Log.d(TAG, "addFingerprint mCurUserId = " + this.mCurUserId);
        Log.d(TAG, "addFingerprint index = " + index);
        Log.d(TAG, "addFingerprint fingerId = " + fingerId);
        Log.d(TAG, "addFingerprint groupId = " + groupId);
        synchronized (this) {
            if (!this.mCurUserId.equals(userId)) {
                this.mCurUserId = userId;
                Log.d(TAG, "addFingerprint loadFingerprintsForUser ");
                loadFingerprintsForUser(userId);
            }
            this.mFingerprints.add(new GoodixFpInfo(index, groupId, fingerId));
            scheduleWriteFpLocked(userId);
        }
    }

    public void removeFingerprint(String userId, int index) {
        Log.d(TAG, "removeFingerprint userId = " + userId);
        Log.d(TAG, "removeFingerprint index = " + index);
        synchronized (this) {
            String str = this.mCurUserId;
            if (str != null && !str.equals(userId)) {
                this.mCurUserId = userId;
                loadFingerprintsForUser(userId);
            }
            int i = 0;
            while (true) {
                if (i >= this.mFingerprints.size()) {
                    break;
                } else if (index == this.mFingerprints.get(i).getFingerIndex()) {
                    this.mFingerprints.remove(i);
                    scheduleWriteFpLocked(userId);
                    if (this.mFingerprints.size() == 0) {
                        getFingerprintFile(userId).delete();
                        int j = 0;
                        while (true) {
                            if (j >= this.mUserInfo.size()) {
                                break;
                            } else if (userId.equals(this.mUserInfo.get(j).getUserId())) {
                                this.mUserInfo.remove(j);
                                scheduleWriteUserInfoLocked();
                                break;
                            } else {
                                j++;
                            }
                        }
                    }
                } else {
                    i++;
                }
            }
        }
    }

    public List<GoodixUserInfo> getUserInfo() {
        ArrayList<GoodixUserInfo> userInfoCopy;
        synchronized (this) {
            userInfoCopy = getUserInfoCopy(this.mUserInfo);
        }
        return userInfoCopy;
    }

    public void loadFingerprintsForUser(String userId) {
        synchronized (this) {
            this.mFingerprintFile = getFingerprintFile(userId);
            readFpSyncLocked();
        }
    }

    public List<GoodixFpInfo> getFingerprints(String userId) {
        ArrayList<GoodixFpInfo> fpInfoCopy;
        synchronized (this) {
            this.mFingerprintFile = getFingerprintFile(userId);
            readFpSyncLocked();
            fpInfoCopy = getFpInfoCopy(this.mFingerprints);
        }
        return fpInfoCopy;
    }

    private File getUserInfoFile() {
        return new File(this.mCtx.getFilesDir(), USER_INFO_FILE);
    }

    private File getFingerprintFile(String userId) {
        Log.d(TAG, "getFingerprintFile  = " + this.mCtx.getFilesDir() + "/" + String.valueOf(getGroupIdForUser(userId)) + "/" + FINGERPRINT_FILE);
        return new File(this.mCtx.getFilesDir() + "/" + String.valueOf(getGroupIdForUser(userId)) + "/", FINGERPRINT_FILE);
    }

    private void createFpInfoDir(String userId) {
        Log.d(TAG, "createFpInfoDir userId = " + userId);
        File dir = new File(this.mCtx.getFilesDir() + "/" + String.valueOf(getGroupIdForUser(userId)));
        if (!dir.exists()) {
            dir.mkdirs();
            loadFingerprintsForUser(userId);
        }
    }

    public int getGroupIdForUser(String userId) {
        Log.d(TAG, "getGroupIdForUser userId = " + userId);
        for (int i = 0; i < this.mUserInfo.size(); i++) {
            if (userId.equals(this.mUserInfo.get(i).getUserId())) {
                return this.mUserInfo.get(i).getGroupId();
            }
        }
        return -1;
    }

    private void scheduleWriteUserInfoLocked() {
        AsyncTask.execute(this.mWriteUserInfoRunnable);
    }

    private ArrayList<GoodixUserInfo> getUserInfoCopy(ArrayList<GoodixUserInfo> array) {
        ArrayList<GoodixUserInfo> result = new ArrayList<>(array.size());
        for (int i = 0; i < array.size(); i++) {
            GoodixUserInfo ui = array.get(i);
            result.add(new GoodixUserInfo(ui.getUserId(), ui.getGroupId(), ui.getPwd()));
        }
        return result;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void doWriteUserInfo() {
        ArrayList<GoodixUserInfo> userInfo;
        AtomicFile destination = new AtomicFile(this.mUserInfoFile);
        synchronized (this) {
            userInfo = getUserInfoCopy(this.mUserInfo);
        }
        FileOutputStream out = null;
        try {
            FileOutputStream out2 = destination.startWrite();
            XmlSerializer serializer = Xml.newSerializer();
            serializer.setOutput(out2, "utf-8");
            serializer.setFeature("http://xmlpull.org/v1/doc/features.html#indent-output", true);
            serializer.startDocument(null, true);
            serializer.startTag(null, TAG_USER_INFOS);
            int count = userInfo.size();
            for (int i = 0; i < count; i++) {
                GoodixUserInfo ui = userInfo.get(i);
                serializer.startTag(null, TAG_USER_INFO);
                serializer.attribute(null, ATTR_USER_ID, ui.getUserId().toString());
                serializer.attribute(null, ATTR_GROUP_ID, Integer.toString(ui.getGroupId()));
                if (ui.getPwd() != null) {
                    serializer.attribute(null, ATTR_PASSWORD, ui.getPwd().toString());
                }
                serializer.endTag(null, TAG_USER_INFO);
            }
            serializer.endTag(null, TAG_USER_INFOS);
            serializer.endDocument();
            destination.finishWrite(out2);
            if (out2 != null) {
                try {
                    out2.close();
                } catch (IOException e) {
                }
            }
        } catch (Throwable t) {
            if (0 != 0) {
                try {
                    out.close();
                } catch (IOException e2) {
                }
            }
            throw t;
        }
    }

    private void readUserInfoSyncLocked() {
        Log.d(TAG, "readUserInfoSyncLocked");
        if (this.mUserInfoFile.exists()) {
            try {
                FileInputStream in = new FileInputStream(this.mUserInfoFile);
                try {
                    XmlPullParser parser = Xml.newPullParser();
                    parser.setInput(in, null);
                    parseUserInfoLocked(parser);
                    try {
                        in.close();
                    } catch (IOException e) {
                    }
                } catch (Exception e2) {
                    throw new IllegalStateException("Failed parsing user info file: " + this.mUserInfoFile, e2);
                } catch (Throwable th) {
                    try {
                        in.close();
                    } catch (IOException e3) {
                    }
                    throw th;
                }
            } catch (FileNotFoundException e4) {
                Log.i(TAG, "No fingerprint state");
            }
        }
    }

    private void parseUserInfoLocked(XmlPullParser parser) throws IOException, XmlPullParserException {
        Log.d(TAG, "parseUserInfoLocked");
        int outerDepth = parser.getDepth();
        while (true) {
            int type = parser.next();
            if (type == 1) {
                return;
            }
            if (type == 3 && parser.getDepth() <= outerDepth) {
                return;
            }
            if (!(type == 3 || type == 4 || !parser.getName().equals(TAG_USER_INFOS))) {
                parseUserInformationLocked(parser);
            }
        }
    }

    private void parseUserInformationLocked(XmlPullParser parser) throws IOException, XmlPullParserException {
        int outerDepth = parser.getDepth();
        while (true) {
            int type = parser.next();
            if (type == 1) {
                return;
            }
            if (type == 3 && parser.getDepth() <= outerDepth) {
                return;
            }
            if (!(type == 3 || type == 4 || !parser.getName().equals(TAG_USER_INFO))) {
                String userId = parser.getAttributeValue(null, ATTR_USER_ID);
                String groupId = parser.getAttributeValue(null, ATTR_GROUP_ID);
                String password = parser.getAttributeValue(null, ATTR_PASSWORD);
                Log.d(TAG, "parseUserInformationLocked userId=" + userId + ",groupId=" + groupId + ",password=" + password);
                this.mUserInfo.add(new GoodixUserInfo(userId, Integer.parseInt(groupId), password));
            }
        }
    }

    private void scheduleWriteFpLocked(String userId) {
        Log.e(TAG, "scheduleWriteFpLocked");
        createFpInfoDir(userId);
        this.mFingerprintFile = getFingerprintFile(userId);
        doWriteFpState();
    }

    private ArrayList<GoodixFpInfo> getFpInfoCopy(ArrayList<GoodixFpInfo> array) {
        ArrayList<GoodixFpInfo> result = new ArrayList<>(array.size());
        for (int i = 0; i < array.size(); i++) {
            GoodixFpInfo fp = array.get(i);
            result.add(new GoodixFpInfo(fp.getFingerIndex(), fp.getGroupId(), fp.getFingerId()));
        }
        return result;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void doWriteFpState() {
        ArrayList<GoodixFpInfo> fingerprints;
        Log.e(TAG, "doWriteFpState mFingerprintFile = " + this.mFingerprintFile.getAbsolutePath());
        AtomicFile destination = new AtomicFile(this.mFingerprintFile);
        Log.e(TAG, "doWriteFpState mFingerprints getGroupIdForUser= " + getGroupIdForUser(this.mCurUserId));
        Log.e(TAG, "doWriteFpState mFingerprints size= " + this.mFingerprints.size());
        for (int i = 0; i < this.mFingerprints.size(); i++) {
            Log.e(TAG, "doWriteFpState mFingerprints getGroupId= " + this.mFingerprints.get(i).getGroupId());
            Log.e(TAG, "doWriteFpState mFingerprints getFingerId= " + this.mFingerprints.get(i).getFingerId());
            Log.e(TAG, "doWriteFpState mFingerprints getFingerIndex= " + this.mFingerprints.get(i).getFingerIndex());
        }
        synchronized (this) {
            fingerprints = getFpInfoCopy(this.mFingerprints);
        }
        FileOutputStream out = null;
        try {
            FileOutputStream out2 = destination.startWrite();
            XmlSerializer serializer = Xml.newSerializer();
            serializer.setOutput(out2, "utf-8");
            serializer.setFeature("http://xmlpull.org/v1/doc/features.html#indent-output", true);
            serializer.startDocument(null, true);
            serializer.startTag(null, TAG_FINGERPRINTS);
            int count = fingerprints.size();
            int currGroupId = getGroupIdForUser(this.mCurUserId);
            for (int i2 = 0; i2 < count; i2++) {
                GoodixFpInfo fp = fingerprints.get(i2);
                if (currGroupId == fp.getGroupId()) {
                    serializer.startTag(null, TAG_FINGERPRINT);
                    serializer.attribute(null, ATTR_INDEX, Integer.toString(fp.getFingerIndex()));
                    serializer.attribute(null, ATTR_GROUP_ID, Integer.toString(fp.getGroupId()));
                    serializer.attribute(null, ATTR_FINGER_ID, Integer.toString(fp.getFingerId()));
                    serializer.endTag(null, TAG_FINGERPRINT);
                }
            }
            serializer.endTag(null, TAG_FINGERPRINTS);
            serializer.endDocument();
            destination.finishWrite(out2);
            if (out2 != null) {
                try {
                    out2.close();
                } catch (IOException e) {
                }
            }
        } catch (Throwable t) {
            if (0 != 0) {
                try {
                    out.close();
                } catch (IOException e2) {
                }
            }
            throw t;
        }
    }

    private void readFpSyncLocked() {
        if (!this.mFingerprintFile.exists()) {
            Log.i(TAG, "readFpSyncLocked No mFingerprintFile");
            return;
        }
        try {
            Log.i(TAG, "FingerprintFile = " + this.mFingerprintFile.getAbsolutePath());
            FileInputStream in = new FileInputStream(this.mFingerprintFile);
            try {
                XmlPullParser parser = Xml.newPullParser();
                parser.setInput(in, null);
                parseFpLocked(parser);
                try {
                    in.close();
                } catch (IOException e) {
                }
            } catch (Exception e2) {
                throw new IllegalStateException("Failed parsing fingerprint file: " + this.mFingerprintFile, e2);
            } catch (Throwable th) {
                try {
                    in.close();
                } catch (IOException e3) {
                }
                throw th;
            }
        } catch (FileNotFoundException e4) {
            Log.i(TAG, "No fingerprint state");
        }
    }

    private void parseFpLocked(XmlPullParser parser) throws IOException, XmlPullParserException {
        int outerDepth = parser.getDepth();
        while (true) {
            int type = parser.next();
            if (type == 1) {
                return;
            }
            if (type == 3 && parser.getDepth() <= outerDepth) {
                return;
            }
            if (!(type == 3 || type == 4 || !parser.getName().equals(TAG_FINGERPRINTS))) {
                parseFingerprintsLocked(parser);
            }
        }
    }

    private void parseFingerprintsLocked(XmlPullParser parser) throws IOException, XmlPullParserException {
        Log.i(TAG, "parseFingerprintsLocked");
        int outerDepth = parser.getDepth();
        this.mFingerprints.clear();
        while (true) {
            int type = parser.next();
            if (type == 1) {
                return;
            }
            if (type == 3 && parser.getDepth() <= outerDepth) {
                return;
            }
            if (!(type == 3 || type == 4 || !parser.getName().equals(TAG_FINGERPRINT))) {
                this.mFingerprints.add(new GoodixFpInfo(Integer.parseInt(parser.getAttributeValue(null, ATTR_INDEX)), Integer.parseInt(parser.getAttributeValue(null, ATTR_GROUP_ID)), Integer.parseInt(parser.getAttributeValue(null, ATTR_FINGER_ID))));
            }
        }
    }
}
