package com.goodix.cap.fingerprint.proxy;

import android.os.IHwBinder;
import android.os.RemoteException;
import android.util.Log;
import com.goodix.cap.fingerprint.proxy.DaemonProxyBase;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.NoSuchElementException;
import vendor.goodix.hardware.biometrics.fingerprint.V2_1.IGoodixFingerprintDaemon;
import vendor.goodix.hardware.biometrics.fingerprint.V2_1.IGoodixFingerprintDaemonCallback;

public class DaemonProxy extends DaemonProxyBase {
    private static final String TAG = "HwBinderDaemonProxy";
    private static GFDaemonImp mGFDaemonImp = null;

    /* access modifiers changed from: protected */
    @Override // com.goodix.cap.fingerprint.proxy.DaemonProxyBase
    public DaemonProxyBase.Daemon getGFDaemonImp(IGFDaemonCallback callback) {
        GFDaemonImp gFDaemonImp = mGFDaemonImp;
        if (gFDaemonImp != null) {
            return gFDaemonImp;
        }
        GFDaemonImp gFDaemonImp2 = new GFDaemonImp(callback);
        mGFDaemonImp = gFDaemonImp2;
        return gFDaemonImp2;
    }

    private abstract class HwBinderDaemon extends DaemonProxyBase.Daemon implements IHwBinder.DeathRecipient {
        IDaemonDiedCallback mDaemonCallback;

        /* access modifiers changed from: package-private */
        public abstract void handleServiceDied();

        private HwBinderDaemon() {
            super();
            this.mDaemonCallback = null;
        }

        public void serviceDied(long cookie) {
            handleServiceDied();
            IDaemonDiedCallback iDaemonDiedCallback = this.mDaemonCallback;
            if (iDaemonDiedCallback != null) {
                iDaemonDiedCallback.onDaemonDied();
            }
        }

        /* access modifiers changed from: package-private */
        public ArrayList<Byte> toArrayList(byte[] param) {
            if (param == null || param.length == 0) {
                return new ArrayList<>();
            }
            Byte[] p = new Byte[param.length];
            for (int i = 0; i < param.length; i++) {
                p[i] = Byte.valueOf(param[i]);
            }
            return new ArrayList<>(Arrays.asList(p));
        }

        /* access modifiers changed from: package-private */
        public byte[] toByteArray(ArrayList<Byte> list) {
            if (list == null || list.size() == 0) {
                return null;
            }
            Byte[] tmp = new Byte[list.size()];
            list.toArray(tmp);
            byte[] ret = new byte[tmp.length];
            for (int i = 0; i < tmp.length; i++) {
                ret[i] = tmp[i].byteValue();
            }
            return ret;
        }

        /* access modifiers changed from: package-private */
        public int[] toIntArray(ArrayList<Integer> list) {
            if (list == null || list.size() == 0) {
                return null;
            }
            Integer[] tmp = new Integer[list.size()];
            list.toArray(tmp);
            int[] ret = new int[tmp.length];
            for (int i = 0; i < tmp.length; i++) {
                ret[i] = tmp[i].byteValue();
            }
            return ret;
        }
    }

    private class GFDaemonImp extends HwBinderDaemon implements IGFDaemon {
        private IGoodixFingerprintDaemon mDaemon = null;
        private IGoodixFingerprintDaemonCallback mGFDaemonCallback = new IGoodixFingerprintDaemonCallback.Stub() {
            /* class com.goodix.cap.fingerprint.proxy.DaemonProxy.GFDaemonImp.AnonymousClass1 */

            @Override // vendor.goodix.hardware.biometrics.fingerprint.V2_1.IGoodixFingerprintDaemonCallback
            public void onEnrollResult(long devId, int fpId, int gpId, int rem) throws RemoteException {
                if (GFDaemonImp.this.mDaemonCallback != null) {
                    ((IGFDaemonCallback) GFDaemonImp.this.mDaemonCallback).onEnrollResult(devId, fpId, gpId, rem);
                }
            }

            @Override // vendor.goodix.hardware.biometrics.fingerprint.V2_1.IGoodixFingerprintDaemonCallback
            public void onAcquired(long devId, int acquiredInfo) throws RemoteException {
                if (GFDaemonImp.this.mDaemonCallback != null) {
                    ((IGFDaemonCallback) GFDaemonImp.this.mDaemonCallback).onAcquired(devId, acquiredInfo);
                }
            }

            @Override // vendor.goodix.hardware.biometrics.fingerprint.V2_1.IGoodixFingerprintDaemonCallback
            public void onAuthenticated(long devId, int fingerId, int groupId, ArrayList<Byte> arrayList) throws RemoteException {
                if (GFDaemonImp.this.mDaemonCallback != null) {
                    ((IGFDaemonCallback) GFDaemonImp.this.mDaemonCallback).onAuthenticated(devId, fingerId, groupId, GFDaemonImp.this.toByteArray(arrayList));
                }
            }

            @Override // vendor.goodix.hardware.biometrics.fingerprint.V2_1.IGoodixFingerprintDaemonCallback
            public void onError(long devId, int error) throws RemoteException {
                if (GFDaemonImp.this.mDaemonCallback != null) {
                    ((IGFDaemonCallback) GFDaemonImp.this.mDaemonCallback).onError(devId, error);
                }
            }

            @Override // vendor.goodix.hardware.biometrics.fingerprint.V2_1.IGoodixFingerprintDaemonCallback
            public void onRemoved(long devId, int fingerId, int groupId) throws RemoteException {
                if (GFDaemonImp.this.mDaemonCallback != null) {
                    ((IGFDaemonCallback) GFDaemonImp.this.mDaemonCallback).onRemoved(devId, fingerId, groupId);
                }
            }

            @Override // vendor.goodix.hardware.biometrics.fingerprint.V2_1.IGoodixFingerprintDaemonCallback
            public void onTestCmd(long devId, int cmdId, ArrayList<Byte> arrayList) throws RemoteException {
                if (GFDaemonImp.this.mDaemonCallback != null) {
                    ((IGFDaemonCallback) GFDaemonImp.this.mDaemonCallback).onTestCmd(devId, cmdId, GFDaemonImp.this.toByteArray(arrayList));
                }
            }

            @Override // vendor.goodix.hardware.biometrics.fingerprint.V2_1.IGoodixFingerprintDaemonCallback
            public void onHbdData(long devId, int heartBeatRate, int status, ArrayList<Byte> arrayList) throws RemoteException {
                if (GFDaemonImp.this.mDaemonCallback != null) {
                    ((IGFDaemonCallback) GFDaemonImp.this.mDaemonCallback).onHbdData(devId, heartBeatRate, status, GFDaemonImp.this.toByteArray(arrayList));
                }
            }

            @Override // vendor.goodix.hardware.biometrics.fingerprint.V2_1.IGoodixFingerprintDaemonCallback
            public void onEnrollSecResult(long devId, int fpId, int gpId, int remaining, int width, int height, ArrayList<Byte> arrayList) throws RemoteException {
                if (GFDaemonImp.this.mDaemonCallback != null) {
                    ((IGFDaemonCallback) GFDaemonImp.this.mDaemonCallback).onEnrollSecResult(devId, fpId, gpId, remaining, width, height, GFDaemonImp.this.toByteArray(arrayList));
                }
            }

            @Override // vendor.goodix.hardware.biometrics.fingerprint.V2_1.IGoodixFingerprintDaemonCallback
            public void onCaptureInfo(long devId, int width, int height, int imgQuality, int score, ArrayList<Byte> rawData, ArrayList<Byte> bmpData) throws RemoteException {
                if (GFDaemonImp.this.mDaemonCallback != null) {
                    ((IGFDaemonCallback) GFDaemonImp.this.mDaemonCallback).onCaptureInfo(devId, width, height, imgQuality, score, GFDaemonImp.this.toByteArray(rawData), GFDaemonImp.this.toByteArray(bmpData));
                }
            }

            @Override // vendor.goodix.hardware.biometrics.fingerprint.V2_1.IGoodixFingerprintDaemonCallback
            public void onEventInfo(int eventId, ArrayList<Byte> arrayList) throws RemoteException {
                if (GFDaemonImp.this.mDaemonCallback != null) {
                    ((IGFDaemonCallback) GFDaemonImp.this.mDaemonCallback).onEventInfo(eventId, GFDaemonImp.this.toByteArray(arrayList));
                }
            }
        };
        private byte[] version;

        public GFDaemonImp(IGFDaemonCallback callback) {
            super();
            this.mDaemonCallback = callback;
            this.mDaemon = (IGoodixFingerprintDaemon) getService();
        }

        public void preGetVersion() {
        }

        @Override // com.goodix.cap.fingerprint.proxy.DaemonProxyBase.Daemon
        public Object getService() {
            if (this.mDaemon == null) {
                try {
                    this.mDaemon = IGoodixFingerprintDaemon.getService();
                } catch (NoSuchElementException e) {
                } catch (RemoteException e2) {
                    Log.e(DaemonProxy.TAG, "Failed to get IGoodixFingerprintDaemon");
                }
                IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
                if (iGoodixFingerprintDaemon != null) {
                    try {
                        iGoodixFingerprintDaemon.asBinder().linkToDeath(this, 0);
                        this.mDaemon.initCallback(this.mGFDaemonCallback);
                    } catch (RemoteException e3) {
                        this.mDaemon = null;
                    }
                }
            }
            return this.mDaemon;
        }

        /* access modifiers changed from: package-private */
        @Override // com.goodix.cap.fingerprint.proxy.DaemonProxy.HwBinderDaemon
        public void handleServiceDied() {
            this.mDaemon = null;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int initCallback(IGFDaemonCallback callback) {
            this.mDaemonCallback = callback;
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int setSafeClass(int safeClass) throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.setSafeClass(safeClass);
            }
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int navigate(int navMode) throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.navigate(navMode);
            }
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int stopNavigation() throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.stopNavigation();
            }
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int testInit(IGFDaemonCallback callback) {
            this.mDaemonCallback = callback;
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int testCmd(int cmdId, byte[] param) throws RemoteException {
            if (this.mDaemon == null) {
                return 0;
            }
            return this.mDaemon.testCmd(cmdId, toArrayList(param));
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int enumerate() throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.enumerate();
            }
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int[] getIdList(int groupId) throws RemoteException {
            return new int[0];
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int pauseEnroll() throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.pauseEnroll();
            }
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int resumeEnroll() throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.resumeEnroll();
            }
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int openHal() throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.openHal();
            }
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int closeHal() throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.closeHal();
            }
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int startUntouchTest() throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.startUntouchTest();
            }
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int startTouchPrepareTest() throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.startTouchPrepareTest();
            }
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int startTouchTest() throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.startTouchTest();
            }
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int startOtpTest() throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.startOtpTest();
            }
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public int startSensorInfoTest() throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.startSensorInfoTest();
            }
            return 0;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemon
        public String getVersion() throws RemoteException {
            IGoodixFingerprintDaemon iGoodixFingerprintDaemon = this.mDaemon;
            if (iGoodixFingerprintDaemon != null) {
                return iGoodixFingerprintDaemon.getVersion();
            }
            return "";
        }
    }
}
