package com.goodix.cap.fingerprint.sec.mt;

import android.content.Context;
import com.goodix.cap.fingerprint.sec.GoodixFpCaptureInfo;
import com.goodix.cap.fingerprint.sec.GoodixFpEnrollStatus;
import com.goodix.cap.fingerprint.sec.GoodixFpIdentifyResult;

public class GFTestManager implements TestStatusListener {
    private static final String TAG = "GFTestManager";
    public static final int TEST_FINGER_INDEX = 1;
    public static final String TEST_USER_ID = "Test";
    private Context mContext;
    private TestResultNotify mResultNotify;
    private TestTask mTestTask;

    public GFTestManager(Context context) {
        Common.LOG_D(TAG, "GFTestManager init ,thread Id = " + Thread.currentThread().getId());
        this.mContext = context;
        TestTask testTask = new TestTask(context);
        this.mTestTask = testTask;
        testTask.setTestStatusListener(this);
    }

    public String getVersion() {
        Common.LOG_D(TAG, "getVersion");
        String version = this.mTestTask.getSoftwareVersion();
        Common.LOG_D(TAG, "getVersion : " + version);
        return version;
    }

    public void cancelTest() {
        Common.LOG_D(TAG, "cancelTest");
        this.mTestTask.removeTestStatusListener();
    }

    public void cancelCMD() {
        Common.LOG_D(TAG, "cancelTest");
        this.mTestTask.cancel();
    }

    public void resumeTest() {
        Common.LOG_D(TAG, "resumeTest");
        TestTask testTask = new TestTask(this.mContext);
        this.mTestTask = testTask;
        testTask.setTestStatusListener(this);
    }

    public void registerResultNotify(TestResultNotify notify) {
        Common.LOG_D(TAG, "registerResultNotify");
        this.mResultNotify = notify;
    }

    public void startUnTouchTest() {
        Common.LOG_D(TAG, "startUnTouchTest");
        this.mTestTask.startUnTouchTest();
    }

    public void startTouchIntRstTest() {
        Common.LOG_D(TAG, "startTouchIntRstTest");
        this.mTestTask.startTouchIntRstTest();
    }

    public void startTouchTest() {
        Common.LOG_D(TAG, "startTouchTest");
        this.mTestTask.startTouchTest();
    }

    public void startGetSensorInfo() {
        Common.LOG_D(TAG, "startGetSensorInfo");
        this.mTestTask.startGetSensorInfoTest();
    }

    public void enroll() {
        Common.LOG_D(TAG, "enroll");
        this.mTestTask.startEnrollTest("Test", 1);
    }

    public void identify() {
        Common.LOG_D(TAG, "identify");
        this.mTestTask.startAuthenticateTest("Test");
    }

    public void startOTPCheckTest() {
        Common.LOG_D(TAG, "startOTPCheckTest");
        this.mTestTask.startOtpCheckTest();
    }

    @Override // com.goodix.cap.fingerprint.sec.mt.TestStatusListener
    public void onUnTouchTestStatus(int cmdId, Object result) {
        Common.LOG_D(TAG, "onUnTouchTestStatus mResultNotify = " + this.mResultNotify + " cmdId = " + cmdId);
        TestResultNotify testResultNotify = this.mResultNotify;
        if (testResultNotify != null) {
            testResultNotify.onUnTouchResultNotify(cmdId, result);
        }
    }

    @Override // com.goodix.cap.fingerprint.sec.mt.TestStatusListener
    public void onTouchTestStatus(int cmdId, Object result) {
        Common.LOG_D(TAG, "onTouchTestStatus mResultNotify = " + this.mResultNotify + " cmdId = " + cmdId);
        TestResultNotify testResultNotify = this.mResultNotify;
        if (testResultNotify != null) {
            testResultNotify.onTouchResultNotify(cmdId, result);
        }
    }

    @Override // com.goodix.cap.fingerprint.sec.mt.TestStatusListener
    public void onCaptureStatus(int cmdId, Object result) {
        Common.LOG_D(TAG, "onCaptureStatus mResultNotify = " + this.mResultNotify + " cmdId = " + cmdId);
        TestResultNotify testResultNotify = this.mResultNotify;
        if (testResultNotify != null) {
            testResultNotify.onCaptureNotify(cmdId, (GoodixFpCaptureInfo) result);
        }
    }

    @Override // com.goodix.cap.fingerprint.sec.mt.TestStatusListener
    public void onCaptureFingerLeaved(int cmdId, Object result) {
        TestResultNotify testResultNotify = this.mResultNotify;
        if (testResultNotify != null) {
            testResultNotify.onCaptureFingerLeaved(cmdId, result);
        }
    }

    @Override // com.goodix.cap.fingerprint.sec.mt.TestStatusListener
    public void onEnrollTestStatus(int cmdId, Object result) {
        Common.LOG_D(TAG, "onEnrollTestStatus mResultNotify = " + this.mResultNotify + " cmdId = " + cmdId);
        TestResultNotify testResultNotify = this.mResultNotify;
        if (testResultNotify != null) {
            testResultNotify.onEnrollStatus(cmdId, (GoodixFpEnrollStatus) result);
        }
    }

    @Override // com.goodix.cap.fingerprint.sec.mt.TestStatusListener
    public void onAuthenticateStatus(int cmdId, Object result) {
        Common.LOG_D(TAG, "onAuthenticateStatus mResultNotify = " + this.mResultNotify + " cmdId = " + cmdId);
        TestResultNotify testResultNotify = this.mResultNotify;
        if (testResultNotify != null) {
            testResultNotify.onIdentifyStatus(cmdId, (GoodixFpIdentifyResult) result);
        }
    }

    @Override // com.goodix.cap.fingerprint.sec.mt.TestStatusListener
    public void onOTPCheckTestStatus(int cmdId, Object result) {
        Common.LOG_D(TAG, "onOTPCheckTestStatus mResultNotify = " + this.mResultNotify + " cmdId = " + cmdId);
        TestResultNotify testResultNotify = this.mResultNotify;
        if (testResultNotify != null) {
            testResultNotify.onOTPCheckNotify(cmdId, result);
        }
    }

    @Override // com.goodix.cap.fingerprint.sec.mt.TestStatusListener
    public void onGetSensorInfoStatus(int cmdId, Object result) {
        Common.LOG_D(TAG, "onGetSensorInfoStatus mResultNotify = " + this.mResultNotify + " cmdId = " + cmdId);
        TestResultNotify testResultNotify = this.mResultNotify;
        if (testResultNotify != null) {
            testResultNotify.onGetSensorInfoNotify(cmdId, result);
        }
    }
}
