package com.goodix.cap.fingerprint.sec.mt;

import android.content.Context;
import com.goodix.cap.fingerprint.ext.ExtGoodixFpManager;
import com.goodix.cap.fingerprint.ext.GoodixEventListener;
import com.goodix.cap.fingerprint.sec.GoodixFpEnrollStatus;
import com.goodix.cap.fingerprint.sec.GoodixFpIdentifyResult;
import com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt;
import com.goodix.cap.fingerprint.utils.TestResultParser;
import com.google.common.primitives.UnsignedBytes;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.math.BigInteger;
import java.util.HashMap;

public class TestTask implements GoodixFingerprintManagerExt.TestCmdCallback {
    private static final int DISABLE_DEVICE_FLAG = 0;
    private static final int ENABLE_DEVICE_FLAG = 1;
    private static final String TAG = "TestTask";
    private static final int TASK_TIME_OUT = 10000;
    private static final int[] UNTOUCH_TEST_ITEMS_1 = {8, 2};
    private static final int[] UNTOUCH_TEST_ITEMS_2 = {24, 23};
    private static final String mAuthenticateResultFile = "/data/log/gf_authenticate_test.txt";
    private static final String mEnrollResultFile = "/data/log/gf_enroll_test.txt";
    private static final String mGetSensorInfoFile = "/data/log/gf_get_sensor_info_test.txt";
    private static NormalScanData mNormalScanData = null;
    private static NormalScanDataSub mNormalScanDataSub = null;
    private static final String mOtpCheckResultFile = "/data/log/gf_otp_check_test.txt";
    private static final String mResultBaseFile = "/data/log";
    private static SnrData mSnrData = null;
    private static SnrDataSub mSnrDataSub = null;
    private static SnrThreshold mSnrThreshold = null;
    private static SnrThresholdSub mSnrThresholdSub = null;
    private static NormalScanThreshold mThreshold = null;
    private static NormalScanThresholdSub mThresholdSub = null;
    private static final String mTimeFormat = "yyyy/MM/dd HH:mm:ss SSS";
    private static final String mTouchResultFile = "/data/log/gf_touch_test.txt";
    private static final String mUnTouchResultFile = "/data/log/gf_un_touch_test.txt";
    private static TestTask sTestTask;
    private GoodixEventListener listener = new GoodixEventListener() {
        /* class com.goodix.cap.fingerprint.sec.mt.TestTask.AnonymousClass9 */

        @Override // com.goodix.cap.fingerprint.ext.GoodixEventListener
        public void onEvent(int eventId, Object eventData) {
            switch (eventId) {
                case 4002:
                case 4003:
                case 9005:
                case 9006:
                default:
                    return;
                case 4004:
                    StringBuffer stringBuffer = TestTask.this.mEnrollResult;
                    stringBuffer.append("Capture Status:" + TestTask.this.parseResult(true) + "\r\n");
                    StringBuilder sb = new StringBuilder();
                    sb.append("Capture Status:");
                    sb.append(TestTask.this.parseResult(true));
                    Common.LOG_D(TestTask.TAG, sb.toString());
                    if (TestTask.this.mTestStatusListener != null) {
                        TestTask.this.mTestStatusListener.onCaptureStatus(4004, eventData);
                        return;
                    } else {
                        Common.LOG_D(TestTask.TAG, "mTestStatusListener is not initialized.");
                        return;
                    }
                case 4005:
                    StringBuffer stringBuffer2 = TestTask.this.mEnrollResult;
                    stringBuffer2.append("Capture Status:" + TestTask.this.parseResult(false) + "\r\n");
                    StringBuilder sb2 = new StringBuilder();
                    sb2.append("Capture Status:");
                    sb2.append(TestTask.this.parseResult(false));
                    Common.LOG_D(TestTask.TAG, sb2.toString());
                    if (TestTask.this.mTestStatusListener != null) {
                        TestTask.this.mTestStatusListener.onCaptureStatus(4005, eventData);
                    } else {
                        Common.LOG_D(TestTask.TAG, "mTestStatusListener is not initialized.");
                    }
                    synchronized (TestTask.this.mTaskThread) {
                        TestTask.this.mTaskThread.notify();
                    }
                    return;
                case 4006:
                    if (TestTask.this.mTestStatusListener != null) {
                        TestTask.this.mTestStatusListener.onCaptureFingerLeaved(4006, null);
                        TestTask.this.mGoodixFpManager.cancel();
                        return;
                    }
                    Common.LOG_D(TestTask.TAG, "mTestStatusListener is not initialized.");
                    return;
                case 5001:
                    Common.LOG_D(TestTask.TAG, "Enroll Image:" + ((GoodixFpEnrollStatus) eventData).coverageBitmap);
                    if (TestTask.this.mTestStatusListener != null) {
                        TestTask.this.mTestStatusListener.onEnrollTestStatus(5001, eventData);
                        return;
                    } else {
                        Common.LOG_D(TestTask.TAG, "mTestStatusListener is not initialized.");
                        return;
                    }
                case 5002:
                    StringBuffer stringBuffer3 = TestTask.this.mEnrollResult;
                    stringBuffer3.append("Enroll Result:" + TestTask.this.parseResult(true) + "\r\n");
                    StringBuilder sb3 = new StringBuilder();
                    sb3.append("Enroll Result:");
                    sb3.append(TestTask.this.parseResult(true));
                    Common.LOG_D(TestTask.TAG, sb3.toString());
                    if (TestTask.this.mTestStatusListener != null) {
                        TestTask.this.mTestStatusListener.onEnrollTestStatus(5002, eventData);
                    } else {
                        Common.LOG_D(TestTask.TAG, "mTestStatusListener is not initialized.");
                    }
                    synchronized (TestTask.this.mTaskThread) {
                        TestTask.this.mTaskThread.notify();
                    }
                    return;
                case 6001:
                    StringBuffer stringBuffer4 = TestTask.this.mAuthenticateResult;
                    stringBuffer4.append("Authenticate Result:" + TestTask.this.parseResult(true) + "\r\n");
                    StringBuilder sb4 = new StringBuilder();
                    sb4.append("Authenticate Result:");
                    sb4.append(TestTask.this.parseResult(true));
                    Common.LOG_D(TestTask.TAG, sb4.toString());
                    if (TestTask.this.mTestStatusListener != null) {
                        TestTask.this.mTestStatusListener.onAuthenticateStatus(6001, eventData);
                    } else {
                        Common.LOG_D(TestTask.TAG, "mTestStatusListener is not initialized.");
                    }
                    synchronized (TestTask.this.mTaskThread) {
                        TestTask.this.mGoodixFpManager.remove("Test", 1);
                        TestTask.this.mTaskThread.notify();
                    }
                    return;
                case 6002:
                    if (((GoodixFpIdentifyResult) eventData).result == 6101) {
                        synchronized (TestTask.this.mTaskThread) {
                            TestTask.this.mTaskThread.notify();
                        }
                        return;
                    }
                    if (TestTask.this.mTestStatusListener != null) {
                        TestTask.this.mTestStatusListener.onAuthenticateStatus(6002, eventData);
                    } else {
                        Common.LOG_D(TestTask.TAG, "mTestStatusListener is not initialized.");
                    }
                    StringBuffer stringBuffer5 = TestTask.this.mAuthenticateResult;
                    stringBuffer5.append("Authenticate Result:" + TestTask.this.parseResult(false) + "\r\n");
                    StringBuilder sb5 = new StringBuilder();
                    sb5.append("Authenticate Result:");
                    sb5.append(TestTask.this.parseResult(false));
                    Common.LOG_D(TestTask.TAG, sb5.toString());
                    TestTask.this.mGoodixFpManager.remove("Test", 1);
                    synchronized (TestTask.this.mTaskThread) {
                        TestTask.this.mTaskThread.notify();
                    }
                    return;
            }
        }
    };
    private StringBuffer mAuthenticateResult;
    private StringBuffer mEnrollResult;
    private int mFalseTrigger = 1;
    private GoodixFingerprintManagerExt mGoodixFingerprintManager;
    private ExtGoodixFpManager mGoodixFpManager;
    private HashMap<Integer, Object> mIntResult;
    private int mOtpResult = 1;
    private HashMap<Integer, Object> mRstResult;
    private TaskThread mTaskThread;
    private TestStatusListener mTestStatusListener;
    private Runnable mTimeout = new Runnable() {
        /* class com.goodix.cap.fingerprint.sec.mt.TestTask.AnonymousClass1 */

        public void run() {
            synchronized (TestTask.this.mTaskThread) {
                TestTask.this.mGoodixFingerprintManager.testCmd(25);
                TestTask.this.mTaskThread.notifyAll();
            }
        }
    };

    /* access modifiers changed from: package-private */
    public static class NormalScanData {
        String BadPixelSteak;
        String Local;
        String OTP;
        String SPI;
        String Total;
        String Zone_8_1;
        String Zone_8_7;

        NormalScanData() {
        }
    }

    static class NormalScanThreshold {
        String MaxLocal;
        String MaxStreak;
        String MaxTotal;
        String MaxZone_8_1;
        String MaxZone_8_7;
        String MinLocal;
        String MinStreak;
        String MinTotal;
        String MinZone_8_1;
        String MinZone_8_7;

        NormalScanThreshold() {
        }
    }

    /* access modifiers changed from: package-private */
    public static class NormalScanDataSub {
        String BadPixelSteak;
        String Local;
        String OTP;
        String SPI;
        String Total;
        String Zone_8_1;
        String Zone_8_7;

        NormalScanDataSub() {
        }
    }

    static class NormalScanThresholdSub {
        String MaxLocal;
        String MaxStreak;
        String MaxTotal;
        String MaxZone_8_1;
        String MaxZone_8_7;
        String MinLocal;
        String MinStreak;
        String MinTotal;
        String MinZone_8_1;
        String MinZone_8_7;

        NormalScanThresholdSub() {
        }
    }

    /* access modifiers changed from: package-private */
    public static class SnrData {
        String DataDiff;
        String DeltaPixelLocal;
        String DeltaPixelTotal;
        String INT;
        String Noise;
        String Performance;
        String PixelDown;
        String RST;
        String RubberPlacement;
        String SNR;
        String SaturationMaxUp;
        String SaturationMinDown;

        SnrData() {
        }
    }

    static class SnrThreshold {
        String MaxDataDiff;
        String MaxDeltaPixelLocal;
        String MaxDeltaPixelTotal;
        String MaxNoise;
        String MaxPerformance;
        String MaxRubberPlacement;
        String MaxSNR;
        String MaxSaturationMaxUp;
        String MaxSaturationMinDown;
        String MinDataDiff;
        String MinDeltaPixelLocal;
        String MinDeltaPixelTotal;
        String MinNoise;
        String MinPerformance;
        String MinRubberPlacement;
        String MinSNR;
        String MinSaturationMaxUp;
        String MinSaturationMinDown;

        SnrThreshold() {
        }
    }

    /* access modifiers changed from: package-private */
    public static class SnrDataSub {
        String DataDiff;
        String DeltaPixelLocal;
        String DeltaPixelTotal;
        String INT;
        String Noise;
        String Performance;
        String PixelDown;
        String RST;
        String RubberPlacement;
        String SNR;
        String SaturationMaxUp;
        String SaturationMinDown;

        SnrDataSub() {
        }
    }

    static class SnrThresholdSub {
        String MaxDataDiff;
        String MaxDeltaPixelLocal;
        String MaxDeltaPixelTotal;
        String MaxNoise;
        String MaxPerformance;
        String MaxRubberPlacement;
        String MaxSNR;
        String MaxSaturationMaxUp;
        String MaxSaturationMinDown;
        String MinDataDiff;
        String MinDeltaPixelLocal;
        String MinDeltaPixelTotal;
        String MinNoise;
        String MinPerformance;
        String MinRubberPlacement;
        String MinSNR;
        String MinSaturationMaxUp;
        String MinSaturationMinDown;

        SnrThresholdSub() {
        }
    }

    public TestTask(Context context) {
        Common.LOG_D(TAG, "TestTask create,thread Id = " + Thread.currentThread().getId());
        GoodixFingerprintManagerExt goodixManager = GoodixFingerprintManagerExt.getGoodixManager(context);
        this.mGoodixFingerprintManager = goodixManager;
        goodixManager.registerTestCmdCallback(this);
        this.mEnrollResult = new StringBuffer();
        this.mAuthenticateResult = new StringBuffer();
        ExtGoodixFpManager extGoodixFpManager = new ExtGoodixFpManager(context);
        this.mGoodixFpManager = extGoodixFpManager;
        extGoodixFpManager.setEventListener(this.listener);
        this.mTaskThread = new TaskThread();
        mNormalScanData = new NormalScanData();
        mThreshold = new NormalScanThreshold();
        mNormalScanDataSub = new NormalScanDataSub();
        mThresholdSub = new NormalScanThresholdSub();
        mSnrData = new SnrData();
        mSnrThreshold = new SnrThreshold();
        mSnrDataSub = new SnrDataSub();
        mSnrThresholdSub = new SnrThresholdSub();
    }

    public synchronized void cancel() {
        Common.LOG_D(TAG, "cancel.");
        this.mGoodixFingerprintManager.testCmd(25);
    }

    public static synchronized TestTask getTestTask(Context context) {
        TestTask testTask;
        synchronized (TestTask.class) {
            if (sTestTask == null) {
                synchronized (TestTask.class) {
                    if (sTestTask == null) {
                        sTestTask = new TestTask(context);
                    }
                }
            }
            testTask = sTestTask;
        }
        return testTask;
    }

    public synchronized void setTestStatusListener(TestStatusListener listener2) {
        Common.LOG_D(TAG, "setTestStatusListener");
        this.mTestStatusListener = listener2;
        this.mGoodixFingerprintManager.registerTestCmdCallback(this);
    }

    public synchronized void removeTestStatusListener() {
        Common.LOG_D(TAG, "removeTestStatusListener");
        stopTest();
    }

    private void resumeTask() {
        Common.LOG_D(TAG, "TaskThread.isShutdown ");
        this.mTaskThread.resumeThreadPool();
    }

    public synchronized void startUnTouchTest() {
        Common.LOG_D(TAG, "startUnTouchTest ");
        this.mGoodixFingerprintManager.registerTestCmdCallback(this);
        if (this.mTaskThread.isShutdown()) {
            resumeTask();
        }
        this.mTaskThread.runTestThread(new TaskCommon() {
            /* class com.goodix.cap.fingerprint.sec.mt.TestTask.AnonymousClass2 */

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onStart() {
                Common.LOG_D(TestTask.TAG, "startUnTouchTest onStart ");
                TestTask.this.mGoodixFingerprintManager.startUntouchTest();
            }

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onDone() {
                Common.LOG_D(TestTask.TAG, "startUnTouchTest onDone ");
                TestTask.this.stopTask();
            }
        });
    }

    public synchronized void testCmd(int cmd) {
        this.mGoodixFingerprintManager.testCmd(cmd);
    }

    public synchronized void startTouchIntRstTest() {
        Common.LOG_D(TAG, "startTouchIntRstTest");
        this.mGoodixFingerprintManager.registerTestCmdCallback(this);
        if (this.mTaskThread.isShutdown()) {
            resumeTask();
        }
        this.mTaskThread.runTestThread(new TaskCommon() {
            /* class com.goodix.cap.fingerprint.sec.mt.TestTask.AnonymousClass3 */

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onStart() {
                Common.LOG_D(TestTask.TAG, "startTouchIntRstTest onStart ");
                Common.LOG_D(TestTask.TAG, "startTouchTest CMD_TEST_SENSOR_TOUCH_PREPARE start ");
                TestTask.this.mGoodixFingerprintManager.startTouchPrepareTest();
            }

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onDone() {
                Common.LOG_D(TestTask.TAG, "startTouchIntRstTest  done ");
            }
        });
    }

    public synchronized void startTouchTest() {
        Common.LOG_D(TAG, "startTouchTest ");
        this.mGoodixFingerprintManager.registerTestCmdCallback(this);
        if (this.mTaskThread.isShutdown()) {
            resumeTask();
        }
        this.mTaskThread.runTestThread(new TaskCommon() {
            /* class com.goodix.cap.fingerprint.sec.mt.TestTask.AnonymousClass4 */

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onStart() {
                Common.LOG_D(TestTask.TAG, "startTouchTest onStart ");
                TestTask.this.mGoodixFingerprintManager.startTouchTest();
            }

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onDone() {
                Common.LOG_D(TestTask.TAG, "startTouchTest onDone ");
            }
        });
    }

    public synchronized void startGetSensorInfoTest() {
        Common.LOG_D(TAG, "startGetSensorInfoTest ");
        this.mGoodixFingerprintManager.registerTestCmdCallback(this);
        if (this.mTaskThread.isShutdown()) {
            resumeTask();
        }
        this.mTaskThread.runTestThread(new TaskCommon() {
            /* class com.goodix.cap.fingerprint.sec.mt.TestTask.AnonymousClass5 */

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onStart() {
                Common.LOG_D(TestTask.TAG, "startGetSensorInfoTest onStart ");
                TestTask.this.mGoodixFingerprintManager.startSensorInfoTest();
                Common.LOG_D(TestTask.TAG, "startGetSensorInfoTest CMD_TEST_GET_SENSOR_INFO ");
            }

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onDone() {
                Common.LOG_D(TestTask.TAG, "startGetSensorInfoTest onDone ");
                TestTask.this.stopTask();
            }
        });
    }

    public synchronized void startEnrollTest(final String userId, final int index) {
        Common.LOG_D(TAG, "startEnrollTest ");
        if (this.mTaskThread.isShutdown()) {
            resumeTask();
        }
        this.mTaskThread.runTestThread(new TaskCommon() {
            /* class com.goodix.cap.fingerprint.sec.mt.TestTask.AnonymousClass6 */

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onStart() {
                Common.LOG_D(TestTask.TAG, "enroll onStart ");
                TestTask.this.mEnrollResult.append("Enroll Test start\r\n");
                StringBuffer stringBuffer = TestTask.this.mEnrollResult;
                stringBuffer.append("Time       : " + Common.longToString(System.currentTimeMillis(), TestTask.mTimeFormat) + "\r\n");
                synchronized (TestTask.this.mTaskThread) {
                    try {
                        TestTask.this.mGoodixFpManager.enableMT(true);
                        TestTask.this.mGoodixFpManager.remove("Test", 1);
                        TestTask.this.mGoodixFpManager.enroll(userId, index);
                        TestTask.this.mTaskThread.wait();
                    } catch (InterruptedException e) {
                        e.printStackTrace();
                    }
                }
            }

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onDone() {
                Common.LOG_D(TestTask.TAG, "enroll end ");
                TestTask.this.mEnrollResult.append("Enroll Test end\r\n");
                TestTask testTask = TestTask.this;
                testTask.logResult(TestTask.mEnrollResultFile, testTask.mEnrollResult.toString());
                TestTask.this.mEnrollResult.delete(0, TestTask.this.mEnrollResult.length());
                TestTask.this.stopTask();
            }
        });
    }

    public synchronized void startAuthenticateTest(final String userId) {
        Common.LOG_D(TAG, "startAuthenticateTest");
        if (this.mTaskThread.isShutdown()) {
            resumeTask();
        }
        this.mTaskThread.runTestThread(new TaskCommon() {
            /* class com.goodix.cap.fingerprint.sec.mt.TestTask.AnonymousClass7 */

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onStart() {
                Common.LOG_D(TestTask.TAG, "identify onStart ");
                TestTask.this.mAuthenticateResult.append("Authenticate Test start\r\n");
                StringBuffer stringBuffer = TestTask.this.mAuthenticateResult;
                stringBuffer.append("Time       : " + Common.longToString(System.currentTimeMillis(), TestTask.mTimeFormat) + "\r\n");
                synchronized (TestTask.this.mTaskThread) {
                    try {
                        TestTask.this.mGoodixFpManager.enableMT(true);
                        TestTask.this.mGoodixFpManager.identify(userId);
                        TestTask.this.mTaskThread.wait();
                    } catch (InterruptedException e) {
                        e.printStackTrace();
                    }
                }
            }

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onDone() {
                Common.LOG_D(TestTask.TAG, "identify end ");
                TestTask.this.mAuthenticateResult.append("Authenticate Test end\r\n");
                TestTask testTask = TestTask.this;
                testTask.logResult(TestTask.mAuthenticateResultFile, testTask.mAuthenticateResult.toString());
                TestTask.this.mAuthenticateResult.delete(0, TestTask.this.mAuthenticateResult.length());
                TestTask.this.stopTask();
            }
        });
    }

    public synchronized void startOtpCheckTest() {
        Common.LOG_D(TAG, "startOtpCheckTest");
        this.mGoodixFingerprintManager.registerTestCmdCallback(this);
        if (this.mTaskThread.isShutdown()) {
            resumeTask();
        }
        this.mTaskThread.runTestThread(new TaskCommon() {
            /* class com.goodix.cap.fingerprint.sec.mt.TestTask.AnonymousClass8 */

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onStart() {
                Common.LOG_D(TestTask.TAG, "startOtpCheckTest onStart");
                TestTask.this.mGoodixFingerprintManager.startOtpCheckTest();
            }

            @Override // com.goodix.cap.fingerprint.sec.mt.TaskCommon
            public void onDone() {
                Common.LOG_D(TestTask.TAG, "startOtpCheckTest onDone");
                TestTask.this.stopTask();
            }
        });
    }

    public synchronized void stopTest() {
        Common.LOG_D(TAG, "stopTest");
        synchronized (this.mTaskThread) {
            this.mTaskThread.notifyAll();
        }
        cancel();
        this.mTaskThread.stopTask();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void stopTask() {
        Common.LOG_D(TAG, "stopTask");
        synchronized (this.mTaskThread) {
            this.mTaskThread.notifyAll();
        }
        this.mTaskThread.stopTask();
    }

    private static String toHexString(byte[] byteArray) {
        if (byteArray == null || byteArray.length < 1) {
            throw new IllegalArgumentException("this byteArray must not be null or empty");
        }
        StringBuilder hexString = new StringBuilder();
        for (int i = 0; i < byteArray.length; i++) {
            if ((byteArray[i] & UnsignedBytes.MAX_VALUE) < 16) {
                hexString.append("0");
            }
            hexString.append(Integer.toHexString(byteArray[i] & UnsignedBytes.MAX_VALUE));
        }
        return hexString.toString().toLowerCase();
    }

    public String bytes2Hex(byte[] bytes) {
        return new BigInteger(1, bytes).toString(16);
    }

    public static String bytes2hex02(byte[] bytes) {
        StringBuilder sb = new StringBuilder();
        for (byte b : bytes) {
            String tmp = Integer.toHexString(b & UnsignedBytes.MAX_VALUE);
            if (tmp.length() == 1) {
                tmp = "0" + tmp;
            }
            sb.append(tmp);
        }
        return sb.toString();
    }

    @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.TestCmdCallback
    public void onTestCmd(int cmd, HashMap<Integer, Object> result) {
        Common.LOG_D(TAG, "onTestCmd cmd =  " + cmd);
        if (result != null) {
            if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_UNTOUCH_TEST_START))) {
                Common.LOG_D(TAG, "TEST_TOKEN_UNTOUCH_TEST_START");
                TestStatusListener testStatusListener = this.mTestStatusListener;
                if (testStatusListener != null) {
                    testStatusListener.onUnTouchTestStatus(917, 1);
                } else {
                    Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                }
            } else if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_UNTOUCH_TEST_END))) {
                if (this.mTestStatusListener != null) {
                    mThreshold.MinTotal = "null";
                    mThreshold.MaxTotal = "null";
                    mThreshold.MinLocal = "null";
                    mThreshold.MaxLocal = "null";
                    mThreshold.MinZone_8_1 = "null";
                    mThreshold.MaxZone_8_1 = "null";
                    mThreshold.MinZone_8_7 = "null";
                    mThreshold.MaxZone_8_7 = "null";
                    mThreshold.MinStreak = "null";
                    mThreshold.MaxStreak = "null";
                    if (result.containsKey(6000)) {
                        mThreshold.MinTotal = result.get(6000).toString();
                    }
                    if (result.containsKey(6001)) {
                        mThreshold.MaxTotal = result.get(6001).toString();
                    }
                    if (result.containsKey(6002)) {
                        mThreshold.MinLocal = result.get(6002).toString();
                    }
                    if (result.containsKey(6003)) {
                        mThreshold.MaxLocal = result.get(6003).toString();
                    }
                    if (result.containsKey(6004)) {
                        mThreshold.MinZone_8_1 = result.get(6004).toString();
                    }
                    if (result.containsKey(6005)) {
                        mThreshold.MaxZone_8_1 = result.get(6005).toString();
                    }
                    if (result.containsKey(6006)) {
                        mThreshold.MinZone_8_7 = result.get(6006).toString();
                    }
                    if (result.containsKey(6007)) {
                        mThreshold.MaxZone_8_7 = result.get(6007).toString();
                    }
                    if (result.containsKey(6008)) {
                        mThreshold.MinStreak = result.get(6006).toString();
                    }
                    if (result.containsKey(6009)) {
                        mThreshold.MaxStreak = result.get(6009).toString();
                    }
                    String normalScan = ((((((("" + "Date:Not support\n") + "OTP;0;0;" + mNormalScanData.OTP + "\n") + "Pin Open Short SPI;0;0;" + mNormalScanData.SPI + "\n") + "Pixel Open Short Total;" + mThreshold.MinTotal + ";" + mThreshold.MaxTotal + ";" + mNormalScanData.Total + "\n") + "Pixel Open Short Local;" + mThreshold.MinLocal + ";" + mThreshold.MaxLocal + ";" + mNormalScanData.Local + "\n") + "FDT Pixel Open Short 8x1 FDT Zone;" + mThreshold.MinZone_8_1 + ";" + mThreshold.MaxZone_8_1 + ";" + mNormalScanData.Zone_8_1 + "\n") + "FDT Pixel Open Short 8x7 FDT Zone;" + mThreshold.MinZone_8_7 + ";" + mThreshold.MaxZone_8_7 + ";" + mNormalScanData.Zone_8_7 + "\n") + "Bad Pixel Streak;" + mThreshold.MinStreak + ";" + mThreshold.MaxStreak + ";" + mNormalScanData.BadPixelSteak + "\n";
                    Common.LOG_D(TAG, "##### normalScan result #####\n");
                    Common.LOG_D(TAG, normalScan + "\n");
                    Common.LOG_D(TAG, "GOODIX TEST_TOKEN_UNTOUCH_TEST_END\n");
                    this.mTestStatusListener.onUnTouchTestStatus(918, normalScan);
                    mThresholdSub.MinTotal = "null";
                    mThresholdSub.MaxTotal = "null";
                    mThresholdSub.MinLocal = "null";
                    mThresholdSub.MaxLocal = "null";
                    mThresholdSub.MinZone_8_1 = "null";
                    mThresholdSub.MaxZone_8_1 = "null";
                    mThresholdSub.MinZone_8_7 = "null";
                    mThresholdSub.MaxZone_8_7 = "null";
                    mThresholdSub.MinStreak = "null";
                    mThresholdSub.MaxStreak = "null";
                    if (result.containsKey(6010)) {
                        mThresholdSub.MinTotal = result.get(6010).toString();
                    }
                    if (result.containsKey(6011)) {
                        mThresholdSub.MaxTotal = result.get(6011).toString();
                    }
                    if (result.containsKey(6012)) {
                        mThresholdSub.MinLocal = result.get(6012).toString();
                    }
                    if (result.containsKey(6013)) {
                        mThresholdSub.MaxLocal = result.get(6013).toString();
                    }
                    if (result.containsKey(6014)) {
                        mThresholdSub.MinZone_8_1 = result.get(6014).toString();
                    }
                    if (result.containsKey(6015)) {
                        mThresholdSub.MaxZone_8_1 = result.get(6015).toString();
                    }
                    if (result.containsKey(6016)) {
                        mThresholdSub.MinZone_8_7 = result.get(6016).toString();
                    }
                    if (result.containsKey(6017)) {
                        mThresholdSub.MaxZone_8_7 = result.get(6017).toString();
                    }
                    if (result.containsKey(6018)) {
                        mThresholdSub.MinStreak = result.get(6016).toString();
                    }
                    if (result.containsKey(6019)) {
                        mThresholdSub.MaxStreak = result.get(6019).toString();
                    }
                    String normalScanSub = ((((((("" + "Date:Not support\n") + "OTP;0;0;" + mNormalScanDataSub.OTP + "\n") + "Pin Open Short SPI;0;0;" + mNormalScanDataSub.SPI + "\n") + "Pixel Open Short Total;" + mThresholdSub.MinTotal + ";" + mThresholdSub.MaxTotal + ";" + mNormalScanDataSub.Total + "\n") + "Pixel Open Short Local;" + mThresholdSub.MinLocal + ";" + mThresholdSub.MaxLocal + ";" + mNormalScanDataSub.Local + "\n") + "FDT Pixel Open Short 8x1 FDT Zone;" + mThresholdSub.MinZone_8_1 + ";" + mThresholdSub.MaxZone_8_1 + ";" + mNormalScanDataSub.Zone_8_1 + "\n") + "FDT Pixel Open Short 8x7 FDT Zone;" + mThresholdSub.MinZone_8_7 + ";" + mThresholdSub.MaxZone_8_7 + ";" + mNormalScanDataSub.Zone_8_7 + "\n") + "Bad Pixel Streak;" + mThresholdSub.MinStreak + ";" + mThresholdSub.MaxStreak + ";" + mNormalScanDataSub.BadPixelSteak + "\n";
                    Common.LOG_D(TAG, "##### normalScan subline result #####\n");
                    Common.LOG_D(TAG, normalScanSub + "\n");
                    Common.LOG_D(TAG, "GOODIX TEST_TOKEN_UNTOUCH_TEST_END_SUB\n");
                    this.mTestStatusListener.onUnTouchTestStatus(898, normalScanSub);
                    return;
                }
                Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
            } else if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_TEST_START))) {
                Common.LOG_D(TAG, "TEST_TOKEN_TOUCH_TEST_START");
                TestStatusListener testStatusListener2 = this.mTestStatusListener;
                if (testStatusListener2 != null) {
                    testStatusListener2.onTouchTestStatus(919, 1);
                } else {
                    Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                }
            } else if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_TEST_END))) {
                if (this.mTestStatusListener != null) {
                    mSnrThreshold.MinDeltaPixelTotal = "null";
                    mSnrThreshold.MaxDeltaPixelTotal = "null";
                    mSnrThreshold.MinDeltaPixelLocal = "null";
                    mSnrThreshold.MaxDeltaPixelLocal = "null";
                    mSnrThreshold.MinNoise = "null";
                    mSnrThreshold.MaxNoise = "null";
                    mSnrThreshold.MinSNR = "null";
                    mSnrThreshold.MaxSNR = "null";
                    mSnrThreshold.MinPerformance = "null";
                    mSnrThreshold.MaxPerformance = "null";
                    mSnrThreshold.MinDataDiff = "null";
                    mSnrThreshold.MaxDataDiff = "null";
                    mSnrThreshold.MinRubberPlacement = "null";
                    mSnrThreshold.MaxRubberPlacement = "null";
                    mSnrThreshold.MinSaturationMaxUp = "null";
                    mSnrThreshold.MaxSaturationMaxUp = "null";
                    mSnrThreshold.MinSaturationMinDown = "null";
                    mSnrThreshold.MaxSaturationMinDown = "null";
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_DELTA_MIN))) {
                        mSnrThreshold.MinDeltaPixelTotal = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_DELTA_MIN)).toString();
                    }
                    if (result.containsKey(6101)) {
                        mSnrThreshold.MaxDeltaPixelTotal = result.get(6101).toString();
                    }
                    if (result.containsKey(6102)) {
                        mSnrThreshold.MinDeltaPixelLocal = result.get(6102).toString();
                    }
                    if (result.containsKey(6103)) {
                        mSnrThreshold.MaxDeltaPixelLocal = result.get(6103).toString();
                    }
                    if (result.containsKey(6104)) {
                        mSnrThreshold.MinNoise = result.get(6104).toString();
                    }
                    if (result.containsKey(6105)) {
                        mSnrThreshold.MaxNoise = result.get(6105).toString();
                    }
                    if (result.containsKey(6106)) {
                        mSnrThreshold.MinSNR = result.get(6106).toString();
                    }
                    if (result.containsKey(6107)) {
                        mSnrThreshold.MaxSNR = result.get(6107).toString();
                    }
                    if (result.containsKey(6108)) {
                        mSnrThreshold.MinPerformance = result.get(6108).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_PERF_MAX))) {
                        mSnrThreshold.MaxPerformance = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_PERF_MAX)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_DIFF_MIN))) {
                        mSnrThreshold.MinDataDiff = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_DIFF_MIN)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_DIFF_MAX))) {
                        mSnrThreshold.MaxDataDiff = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_DIFF_MAX)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_RUBBER_MIN))) {
                        mSnrThreshold.MinRubberPlacement = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_RUBBER_MIN)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_RUBBER_MAX))) {
                        mSnrThreshold.MaxRubberPlacement = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_RUBBER_MAX)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_SATURATION_UP_MIN))) {
                        mSnrThreshold.MinSaturationMaxUp = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_SATURATION_UP_MIN)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_SATURATION_UP_MAX))) {
                        mSnrThreshold.MaxSaturationMaxUp = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_SATURATION_UP_MAX)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_SATURATION_DOWN_MIN))) {
                        mSnrThreshold.MinSaturationMinDown = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_SATURATION_DOWN_MIN)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_SATURATION_DOWN_MAX))) {
                        mSnrThreshold.MaxSaturationMinDown = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_MAIN_TEST_SPEC_SATURATION_DOWN_MAX)).toString();
                    }
                    String snrTest = (((((((((((("" + "Date:Not support\n") + "Delta Pixel Total;" + mSnrThreshold.MinDeltaPixelTotal + ";" + mSnrThreshold.MaxDeltaPixelTotal + ";" + mSnrData.DeltaPixelTotal + "\n") + "Delta Pixel Local;" + mSnrThreshold.MinDeltaPixelLocal + ";" + mSnrThreshold.MaxDeltaPixelLocal + ";" + mSnrData.DeltaPixelLocal + "\n") + "Noise;" + mSnrThreshold.MinNoise + ";" + mSnrThreshold.MaxNoise + ";" + mSnrData.Noise + "\n") + "Pin Open Short INT;0;0;" + mSnrData.INT + "\n") + "Pin Open Short RST;0;0;" + mSnrData.RST + "\n") + "SNR;" + mSnrThreshold.MinSNR + ";" + mSnrThreshold.MaxSNR + ";" + mSnrData.SNR + "\n") + "Pixel Down;0;0;" + mSnrData.PixelDown + "\n") + "Performance;" + mSnrThreshold.MinPerformance + ";" + mSnrThreshold.MaxPerformance + ";" + mSnrData.Performance + "\n") + "Data Difference;" + mSnrThreshold.MinDataDiff + ";" + mSnrThreshold.MaxDataDiff + ";" + mSnrData.DataDiff + "\n") + "Rubber Placement;" + mSnrThreshold.MinRubberPlacement + ";" + mSnrThreshold.MaxRubberPlacement + ";" + mSnrData.RubberPlacement + "\n") + "Saturation Max Up;" + mSnrThreshold.MinSaturationMaxUp + ";" + mSnrThreshold.MaxSaturationMaxUp + ";" + mSnrData.SaturationMaxUp + "\n") + "Saturation Min Down;" + mSnrThreshold.MinSaturationMinDown + ";" + mSnrThreshold.MaxSaturationMinDown + ";" + mSnrData.SaturationMinDown + "\n";
                    Common.LOG_D(TAG, "##### snrTest result #####\n");
                    Common.LOG_D(TAG, snrTest + "\n");
                    Common.LOG_D(TAG, "GOODIX TEST_TOKEN_TOUCH_TEST_END\n");
                    this.mTestStatusListener.onTouchTestStatus(920, snrTest);
                    mSnrThresholdSub.MinDeltaPixelTotal = "null";
                    mSnrThresholdSub.MaxDeltaPixelTotal = "null";
                    mSnrThresholdSub.MinDeltaPixelLocal = "null";
                    mSnrThresholdSub.MaxDeltaPixelLocal = "null";
                    mSnrThresholdSub.MinNoise = "null";
                    mSnrThresholdSub.MaxNoise = "null";
                    mSnrThresholdSub.MinSNR = "null";
                    mSnrThresholdSub.MaxSNR = "null";
                    mSnrThresholdSub.MinPerformance = "null";
                    mSnrThresholdSub.MaxPerformance = "null";
                    mSnrThresholdSub.MinDataDiff = "null";
                    mSnrThresholdSub.MaxDataDiff = "null";
                    mSnrThresholdSub.MinRubberPlacement = "null";
                    mSnrThresholdSub.MaxRubberPlacement = "null";
                    mSnrThresholdSub.MinSaturationMaxUp = "null";
                    mSnrThresholdSub.MaxSaturationMaxUp = "null";
                    mSnrThresholdSub.MinSaturationMinDown = "null";
                    mSnrThresholdSub.MaxSaturationMinDown = "null";
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_DELTA_MIN))) {
                        mSnrThresholdSub.MinDeltaPixelTotal = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_DELTA_MIN)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_DELTA_MAX))) {
                        mSnrThresholdSub.MaxDeltaPixelTotal = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_DELTA_MAX)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_LOCAL_MIN))) {
                        mSnrThresholdSub.MinDeltaPixelLocal = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_LOCAL_MIN)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_LOCAL_MAX))) {
                        mSnrThresholdSub.MaxDeltaPixelLocal = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_LOCAL_MAX)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_NOISE_MIN))) {
                        mSnrThresholdSub.MinNoise = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_NOISE_MIN)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_NOISE_MAX))) {
                        mSnrThresholdSub.MaxNoise = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_NOISE_MAX)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_SNR_MIN))) {
                        mSnrThresholdSub.MinSNR = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_SNR_MIN)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_SNR_MAX))) {
                        mSnrThresholdSub.MaxSNR = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_SNR_MAX)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_PERF_MIN))) {
                        mSnrThresholdSub.MinPerformance = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_PERF_MIN)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_PERF_MAX))) {
                        mSnrThresholdSub.MaxPerformance = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_PERF_MAX)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_DIFF_MIN))) {
                        mSnrThresholdSub.MinDataDiff = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_DIFF_MIN)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_DIFF_MAX))) {
                        mSnrThresholdSub.MaxDataDiff = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_DIFF_MAX)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_RUBBER_MIN))) {
                        mSnrThresholdSub.MinRubberPlacement = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_RUBBER_MIN)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_RUBBER_MAX))) {
                        mSnrThresholdSub.MaxRubberPlacement = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_RUBBER_MAX)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_SATURATION_UP_MIN))) {
                        mSnrThresholdSub.MinSaturationMaxUp = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_SATURATION_UP_MIN)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_SATURATION_UP_MAX))) {
                        mSnrThresholdSub.MaxSaturationMaxUp = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_SATURATION_UP_MAX)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_SATURATION_DOWN_MIN))) {
                        mSnrThresholdSub.MinSaturationMinDown = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_SATURATION_DOWN_MIN)).toString();
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_SATURATION_DOWN_MAX))) {
                        mSnrThresholdSub.MaxSaturationMinDown = result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_TOUCH_SUB_TEST_SPEC_SATURATION_DOWN_MAX)).toString();
                    }
                    String snrTestSub = (((((((((((("" + "Date:Not support\n") + "Delta Pixel Total;" + mSnrThresholdSub.MinDeltaPixelTotal + ";" + mSnrThresholdSub.MaxDeltaPixelTotal + ";" + mSnrDataSub.DeltaPixelTotal + "\n") + "Delta Pixel Local;" + mSnrThresholdSub.MinDeltaPixelLocal + ";" + mSnrThresholdSub.MaxDeltaPixelLocal + ";" + mSnrDataSub.DeltaPixelLocal + "\n") + "Noise;" + mSnrThresholdSub.MinNoise + ";" + mSnrThresholdSub.MaxNoise + ";" + mSnrDataSub.Noise + "\n") + "Pin Open Short INT;0;0;" + mSnrDataSub.INT + "\n") + "Pin Open Short RST;0;0;" + mSnrDataSub.RST + "\n") + "SNR;" + mSnrThresholdSub.MinSNR + ";" + mSnrThresholdSub.MaxSNR + ";" + mSnrDataSub.SNR + "\n") + "Pixel Down;0;0;" + mSnrDataSub.PixelDown + "\n") + "Performance;" + mSnrThresholdSub.MinPerformance + ";" + mSnrThresholdSub.MaxPerformance + ";" + mSnrDataSub.Performance + "\n") + "Data Difference;" + mSnrThresholdSub.MinDataDiff + ";" + mSnrThresholdSub.MaxDataDiff + ";" + mSnrDataSub.DataDiff + "\n") + "Rubber Placement;" + mSnrThresholdSub.MinRubberPlacement + ";" + mSnrThresholdSub.MaxRubberPlacement + ";" + mSnrDataSub.RubberPlacement + "\n") + "Saturation Max Up;" + mSnrThresholdSub.MinSaturationMaxUp + ";" + mSnrThresholdSub.MaxSaturationMaxUp + ";" + mSnrDataSub.SaturationMaxUp + "\n") + "Saturation Min Down;" + mSnrThresholdSub.MinSaturationMinDown + ";" + mSnrThresholdSub.MaxSaturationMinDown + ";" + mSnrDataSub.SaturationMinDown + "\n";
                    Common.LOG_D(TAG, "##### snrTestSub result #####\n");
                    Common.LOG_D(TAG, snrTestSub + "\n");
                    Common.LOG_D(TAG, "GOODIX TEST_TOKEN_TOUCH_TEST_END_SUB\n");
                    this.mTestStatusListener.onTouchTestStatus(899, snrTestSub);
                    stopTask();
                    return;
                }
                Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
            } else if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_OTPCHECK_TEST_START))) {
                Common.LOG_D(TAG, "TEST_TOKEN_OTPCHECK_TEST_START");
                TestStatusListener testStatusListener3 = this.mTestStatusListener;
                if (testStatusListener3 != null) {
                    testStatusListener3.onOTPCheckTestStatus(921, 1);
                } else {
                    Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                }
            } else if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_OTPCHECK_TEST_END))) {
                Common.LOG_D(TAG, "TEST_TOKEN_OTPCHECK_TEST_END");
                TestStatusListener testStatusListener4 = this.mTestStatusListener;
                if (testStatusListener4 != null) {
                    testStatusListener4.onOTPCheckTestStatus(922, 1);
                } else {
                    Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                }
            } else if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_GET_SENSOR_INFO_TEST_START))) {
                Common.LOG_D(TAG, "TEST_TOKEN_GET_SENSOR_INFO_TEST_START");
                TestStatusListener testStatusListener5 = this.mTestStatusListener;
                if (testStatusListener5 != null) {
                    testStatusListener5.onGetSensorInfoStatus(923, 1);
                } else {
                    Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                }
            } else if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_GET_SENSOR_INFO_TEST_END))) {
                Common.LOG_D(TAG, "TEST_TOKEN_GET_SENSOR_INFO_TEST_END");
                TestStatusListener testStatusListener6 = this.mTestStatusListener;
                if (testStatusListener6 != null) {
                    testStatusListener6.onGetSensorInfoStatus(924, 1);
                } else {
                    Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                }
            } else if (cmd == 8) {
                onTestSpi(result);
            } else if (cmd == 24) {
                this.mIntResult = result;
            } else if (cmd == 23) {
                this.mRstResult = result;
            } else if (cmd == 2) {
                onTestPixel(result);
            } else if (cmd == 72) {
                if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_PIXEL_SHORT_NUM))) {
                    int pixelShort = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_PIXEL_SHORT_NUM))).intValue();
                    if (this.mTestStatusListener != null) {
                        mNormalScanData.BadPixelSteak = String.valueOf(pixelShort);
                        mNormalScanDataSub.BadPixelSteak = String.valueOf(pixelShort);
                        return;
                    }
                    Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                }
            } else if (cmd == 32) {
                if (result.containsKey(900)) {
                    this.mOtpResult = ((Integer) result.get(900)).intValue();
                    Common.LOG_D(TAG, "sensorValidity = " + this.mOtpResult);
                    if (this.mTestStatusListener != null) {
                        mNormalScanData.OTP = String.valueOf(this.mOtpResult);
                        mNormalScanDataSub.OTP = String.valueOf(this.mOtpResult);
                        return;
                    }
                    Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                }
            } else if (cmd != 63 || !result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_FALSE_TRIGGER_STATUS))) {
                if (cmd == 60) {
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_SENSOR_AVAILABLE_STATUS))) {
                        int sensorAvailable = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_SENSOR_AVAILABLE_STATUS))).intValue();
                        Common.LOG_D(TAG, "sensorAvailable = " + sensorAvailable);
                        TestStatusListener testStatusListener7 = this.mTestStatusListener;
                        if (testStatusListener7 != null) {
                            testStatusListener7.onTouchTestStatus(933, Integer.valueOf(sensorAvailable));
                        } else {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    int isPrepare = -1;
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_IS_TOUCH_TEST_PREPARE))) {
                        isPrepare = ((Short) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_IS_TOUCH_TEST_PREPARE))).shortValue();
                    }
                    Common.LOG_D(TAG, "isPrepare = " + isPrepare);
                    if (isPrepare == 1) {
                        TestStatusListener testStatusListener8 = this.mTestStatusListener;
                        if (testStatusListener8 != null) {
                            testStatusListener8.onTouchTestStatus(902, parseResult(true));
                        } else {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    } else {
                        TestStatusListener testStatusListener9 = this.mTestStatusListener;
                        if (testStatusListener9 != null) {
                            testStatusListener9.onTouchTestStatus(903, parseResult(false));
                        } else {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                } else if (cmd == 59) {
                    Common.LOG_D(TAG, "CMD_TEST_SENSOR_TOUCH   ");
                    HashMap<Integer, Object> hashMap = this.mIntResult;
                    if (hashMap != null) {
                        onTestInt(hashMap);
                    }
                    HashMap<Integer, Object> hashMap2 = this.mRstResult;
                    if (hashMap2 != null) {
                        onTestReset(hashMap2);
                    }
                    int sensorAvailable2 = 1;
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_SENSOR_AVAILABLE_STATUS))) {
                        sensorAvailable2 = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_SENSOR_AVAILABLE_STATUS))).intValue();
                        Common.LOG_D(TAG, "sensorAvailable = " + sensorAvailable2);
                        TestStatusListener testStatusListener10 = this.mTestStatusListener;
                        if (testStatusListener10 != null) {
                            testStatusListener10.onTouchTestStatus(933, Integer.valueOf(sensorAvailable2));
                        } else {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    if (this.mTestStatusListener == null) {
                        Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                    }
                    int errorCode = 1000;
                    if (result.containsKey(100)) {
                        errorCode = ((Integer) result.get(100)).intValue();
                        Common.LOG_D(TAG, "errorCode = " + errorCode);
                    }
                    float noise = 0.0f;
                    if (result.containsKey(301)) {
                        noise = ((Float) result.get(301)).floatValue();
                        mSnrData.Noise = Float.toString(noise);
                        mSnrDataSub.Noise = Float.toString(noise);
                        Common.LOG_D(TAG, "noise = " + noise);
                        if (this.mTestStatusListener == null) {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    if (result.containsKey(303)) {
                        float snr = ((Float) result.get(303)).floatValue();
                        mSnrData.SNR = Float.toString(snr);
                        mSnrDataSub.SNR = Float.toString(snr);
                        Common.LOG_D(TAG, "snr = " + snr);
                        if (this.mTestStatusListener == null) {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    if (result.containsKey(305)) {
                        int totalPixelNum = ((Integer) result.get(305)).intValue();
                        Common.LOG_D(TAG, "Delta Pixel Total = " + totalPixelNum);
                        mSnrData.DeltaPixelTotal = Float.toString((float) totalPixelNum);
                        mSnrDataSub.DeltaPixelTotal = Float.toString((float) totalPixelNum);
                        if (this.mTestStatusListener == null) {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    if (result.containsKey(307)) {
                        int localPixelNum = ((Integer) result.get(307)).intValue();
                        Common.LOG_D(TAG, "Delta Pixel Local = " + localPixelNum);
                        mSnrData.DeltaPixelLocal = Float.toString((float) localPixelNum);
                        mSnrDataSub.DeltaPixelLocal = Float.toString((float) localPixelNum);
                        if (this.mTestStatusListener == null) {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_DATA_DIFFERENCE))) {
                        int dataDifference = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_DATA_DIFFERENCE))).intValue();
                        Common.LOG_D(TAG, "Data Difference = " + dataDifference);
                        mSnrData.DataDiff = Float.toString((float) dataDifference);
                        mSnrDataSub.DataDiff = Float.toString((float) dataDifference);
                        if (this.mTestStatusListener == null) {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_SNR_TEST_IS_TOUCH_STABLE))) {
                        float rubberPlacement = ((Float) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_SNR_TEST_IS_TOUCH_STABLE))).floatValue();
                        Common.LOG_D(TAG, "Rubber Placement = " + rubberPlacement);
                        mSnrData.RubberPlacement = Float.toString(rubberPlacement);
                        mSnrDataSub.RubberPlacement = Float.toString(rubberPlacement);
                        if (this.mTestStatusListener == null) {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    if (result.containsKey(1423)) {
                        int performance = ((Integer) result.get(1423)).intValue();
                        Common.LOG_D(TAG, "Performance = " + performance);
                        mSnrData.Performance = Float.toString((float) performance);
                        mSnrDataSub.Performance = Float.toString((float) performance);
                        if (this.mTestStatusListener == null) {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_IS_PIXEL_DOWN_PASS))) {
                        int pixelDown = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_IS_PIXEL_DOWN_PASS))).intValue();
                        Common.LOG_D(TAG, "Pixel Key Pixel Down = " + pixelDown);
                        mSnrData.PixelDown = String.valueOf(pixelDown);
                        mSnrDataSub.PixelDown = String.valueOf(pixelDown);
                        if (this.mTestStatusListener == null) {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    int falseIrq = 0;
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_IS_RECV_FALSE_IRQ))) {
                        falseIrq = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_IS_RECV_FALSE_IRQ))).intValue();
                        Common.LOG_D(TAG, "falseIrq = " + falseIrq);
                        TestStatusListener testStatusListener11 = this.mTestStatusListener;
                        if (testStatusListener11 != null) {
                            testStatusListener11.onTouchTestStatus(911, Integer.valueOf(falseIrq));
                        } else {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    int saturateMin = 0;
                    if (result.containsKey(1304)) {
                        saturateMin = ((Integer) result.get(1304)).intValue();
                        Common.LOG_D(TAG, "Saturation Min Down = " + saturateMin);
                        mSnrData.SaturationMinDown = Float.toString((float) saturateMin);
                        mSnrDataSub.SaturationMinDown = Float.toString((float) saturateMin);
                        if (this.mTestStatusListener == null) {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    if (result.containsKey(1303)) {
                        int saturateMax = ((Integer) result.get(1303)).intValue();
                        Common.LOG_D(TAG, "Saturation Max Up = " + saturateMax);
                        mSnrData.SaturationMaxUp = Float.toString((float) saturateMax);
                        mSnrDataSub.SaturationMaxUp = Float.toString((float) saturateMax);
                        if (this.mTestStatusListener == null) {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    this.mIntResult = null;
                    this.mRstResult = null;
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_IS_PIXEL_UP_PASS))) {
                        int pixelUp = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_IS_PIXEL_UP_PASS))).intValue();
                        Common.LOG_D(TAG, "pixelUp = " + pixelUp);
                        TestStatusListener testStatusListener12 = this.mTestStatusListener;
                        if (testStatusListener12 != null) {
                            testStatusListener12.onTouchTestStatus(910, Integer.valueOf(pixelUp));
                        } else {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                } else if (cmd == 61) {
                    int sensorAvailable3 = 1;
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_SENSOR_AVAILABLE_STATUS))) {
                        sensorAvailable3 = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_SENSOR_AVAILABLE_STATUS))).intValue();
                        Common.LOG_D(TAG, "sensorAvailable = " + sensorAvailable3);
                    }
                    TestStatusListener testStatusListener13 = this.mTestStatusListener;
                    if (testStatusListener13 != null) {
                        testStatusListener13.onGetSensorInfoStatus(933, Integer.valueOf(sensorAvailable3));
                    } else {
                        Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                    }
                    byte[] bArr = new byte[0];
                    if (result.containsKey(207)) {
                        String sensorIdStr = toHexString((byte[]) result.get(207));
                        Common.LOG_D(TAG, "sensorId = " + sensorIdStr);
                        TestStatusListener testStatusListener14 = this.mTestStatusListener;
                        if (testStatusListener14 != null) {
                            testStatusListener14.onGetSensorInfoStatus(928, sensorIdStr);
                        } else {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    byte[] bArr2 = new byte[0];
                    if (result.containsKey(211)) {
                        byte[] productId = (byte[]) result.get(211);
                        String productIdStr = "";
                        for (byte ch : productId) {
                            productIdStr = productIdStr + ((char) ch);
                        }
                        Common.LOG_D(TAG, "productId = " + productIdStr);
                        TestStatusListener testStatusListener15 = this.mTestStatusListener;
                        if (testStatusListener15 != null) {
                            testStatusListener15.onGetSensorInfoStatus(927, productIdStr);
                        } else {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_IS_MODULE_TEST_PASS))) {
                        int isModuleTestPass = ((Short) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_IS_MODULE_TEST_PASS))).shortValue();
                        Common.LOG_D(TAG, "isModuleTestPass = " + isModuleTestPass);
                        TestStatusListener testStatusListener16 = this.mTestStatusListener;
                        if (testStatusListener16 != null) {
                            testStatusListener16.onGetSensorInfoStatus(914, Integer.valueOf(isModuleTestPass));
                        } else {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                    if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_CALIBRATION_STATUS))) {
                        int calibration = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_CALIBRATION_STATUS))).intValue();
                        TestStatusListener testStatusListener17 = this.mTestStatusListener;
                        if (testStatusListener17 != null) {
                            testStatusListener17.onGetSensorInfoStatus(929, Integer.valueOf(calibration));
                        } else {
                            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                        }
                    }
                }
            } else {
                this.mFalseTrigger = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_FALSE_TRIGGER_STATUS))).intValue();
                Common.LOG_D(TAG, "falseTrigger = " + this.mFalseTrigger);
                TestStatusListener testStatusListener18 = this.mTestStatusListener;
                if (testStatusListener18 != null) {
                    testStatusListener18.onTouchTestStatus(932, Integer.valueOf(this.mFalseTrigger));
                } else {
                    Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
                }
            }
        }
    }

    private void onTestSpi(HashMap<Integer, Object> result) {
        byte[] chip;
        int errorCode = 1000;
        int chipID = 0;
        if (result.containsKey(100)) {
            errorCode = ((Integer) result.get(100)).intValue();
        }
        int sensorAvailable = 1;
        if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_SENSOR_AVAILABLE_STATUS))) {
            sensorAvailable = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_SENSOR_AVAILABLE_STATUS))).intValue();
            Common.LOG_D(TAG, "sensorAvailable = " + sensorAvailable);
        }
        TestStatusListener testStatusListener = this.mTestStatusListener;
        if (testStatusListener != null) {
            testStatusListener.onUnTouchTestStatus(933, Integer.valueOf(sensorAvailable));
        } else {
            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
        }
        if (result.containsKey(205) && (chip = (byte[]) result.get(205)) != null && chip.length >= 4) {
            chipID = TestResultParser.decodeInt32(chip, 0) >> 8;
        }
        Common.LOG_D(TAG, "onTestSpi errorCode = " + errorCode + " , chipID = 0x" + Integer.toHexString(chipID));
        if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_SPI_PASS_STATUS))) {
            int spiPass = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_SPI_PASS_STATUS))).intValue();
            mNormalScanData.SPI = String.valueOf(spiPass);
            mNormalScanDataSub.SPI = String.valueOf(spiPass);
        }
        if (this.mTestStatusListener == null) {
            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
        }
    }

    private void onTestInt(HashMap<Integer, Object> result) {
        int errorCode = 1000;
        if (result.containsKey(100)) {
            errorCode = ((Integer) result.get(100)).intValue();
        }
        Common.LOG_D(TAG, "onTestInt errorCode = " + errorCode);
        if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_INT_PASS_STATUS))) {
            int intPass = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_INT_PASS_STATUS))).intValue();
            mSnrData.INT = String.valueOf(intPass);
            mSnrDataSub.INT = String.valueOf(intPass);
        }
        if (this.mTestStatusListener == null) {
            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
        }
    }

    private void onTestReset(HashMap<Integer, Object> result) {
        int errorCode = 1000;
        if (result.containsKey(100)) {
            errorCode = ((Integer) result.get(100)).intValue();
        }
        int resetFlag = 0;
        if (result.containsKey(600)) {
            resetFlag = ((Integer) result.get(600)).intValue();
        }
        Common.LOG_D(TAG, "onTestReset errorCode = " + errorCode + " , resetFlag =" + resetFlag);
        if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_RESET_PASS_STATUS))) {
            int rstPass = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_RESET_PASS_STATUS))).intValue();
            mSnrData.RST = String.valueOf(rstPass);
            mSnrDataSub.RST = String.valueOf(rstPass);
        }
        if (this.mTestStatusListener == null) {
            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
        }
    }

    private void onTestPixel(HashMap<Integer, Object> result) {
        int errorCode = 1000;
        if (result.containsKey(100)) {
            errorCode = ((Integer) result.get(100)).intValue();
        }
        int badPixelNum = 0;
        if (result.containsKey(305)) {
            badPixelNum = ((Integer) result.get(305)).intValue();
        }
        int localBadPixelNum = 0;
        if (result.containsKey(307)) {
            localBadPixelNum = ((Integer) result.get(307)).intValue();
        }
        int fdtZone8x1 = 0;
        if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_FDT_USED_OPEN_PIXEL_NUM))) {
            fdtZone8x1 = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_FDT_USED_OPEN_PIXEL_NUM))).intValue();
        }
        int fdtZone8x7 = 0;
        if (result.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_FDT_EXTRA_OPEN_PIXEL_NUM))) {
            fdtZone8x7 = ((Integer) result.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_FDT_EXTRA_OPEN_PIXEL_NUM))).intValue();
        }
        Common.LOG_D(TAG, "onTestPixel errorCode = " + errorCode + " , badPixelNum =" + badPixelNum + ", localBadPixelNum = " + localBadPixelNum + ", fdtZone8x1 = " + fdtZone8x1 + ", fdtZone8x7 = " + fdtZone8x7);
        mNormalScanData.Total = String.valueOf(badPixelNum);
        mNormalScanDataSub.Total = String.valueOf(badPixelNum);
        mNormalScanData.Local = String.valueOf(localBadPixelNum);
        mNormalScanDataSub.Local = String.valueOf(localBadPixelNum);
        mNormalScanData.Zone_8_1 = String.valueOf(fdtZone8x1);
        mNormalScanDataSub.Zone_8_1 = String.valueOf(fdtZone8x1);
        mNormalScanData.Zone_8_7 = String.valueOf(fdtZone8x7);
        mNormalScanDataSub.Zone_8_7 = String.valueOf(fdtZone8x7);
        if (this.mTestStatusListener == null) {
            Common.LOG_D(TAG, "mTestStatusListener is not initialized.");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void logResult(String file, String content) {
        BufferedWriter out = null;
        try {
            File parentDir = new File(mResultBaseFile);
            if (!parentDir.exists()) {
                parentDir.mkdirs();
            }
            File logFile = new File(file);
            if (logFile.exists()) {
                logFile.delete();
            }
            if (logFile.createNewFile()) {
                Common.LOG_D(TAG, "Test log file created.");
            }
            BufferedWriter out2 = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file, true)));
            out2.newLine();
            out2.write(content);
            try {
                out2.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        } catch (FileNotFoundException e2) {
            e2.printStackTrace();
            if (0 != 0) {
                out.close();
            }
        } catch (IOException e3) {
            e3.printStackTrace();
            if (0 != 0) {
                out.close();
            }
        } catch (Exception e4) {
            e4.printStackTrace();
            if (0 != 0) {
                out.close();
            }
        } catch (Throwable th) {
            if (0 != 0) {
                try {
                    out.close();
                } catch (IOException e5) {
                    e5.printStackTrace();
                }
            }
            throw th;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Integer parseResult(boolean result) {
        int i = 1;
        if (result) {
            i = 0;
        }
        return Integer.valueOf(i);
    }

    public synchronized String getSoftwareVersion() {
        return this.mGoodixFingerprintManager.startGetVersion();
    }
}
