package com.goodix.cap.fingerprint.service;

import android.app.AppOpsManager;
import android.content.Context;
import android.graphics.Bitmap;
import android.os.Binder;
import android.os.Handler;
import android.os.RemoteException;
import android.util.Log;
import com.goodix.cap.fingerprint.GFConfig;
import com.goodix.cap.fingerprint.GFDevice;
import com.goodix.cap.fingerprint.proxy.DaemonManager;
import com.goodix.cap.fingerprint.proxy.IGFDaemon;
import com.goodix.cap.fingerprint.proxy.IGFDaemonCallback;
import com.goodix.cap.fingerprint.utils.FingerprintUtils;
import com.goodix.cap.fingerprint.utils.TestParamEncoder;
import com.goodix.cap.fingerprint.utils.TestResultParser;
import com.google.common.primitives.UnsignedBytes;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;

public class GFService {
    public static final boolean DEBUG = true;
    protected static final int ERROR_CLIENT_DEFINED = 100;
    protected static final int ERROR_ESRCH = 3;
    public static final String MANAGE_FINGERPRINT = "android.permission.MANAGE_FINGERPRINT";
    private static final String TAG = "GFService";
    private static final int TEST_GET_CONFIG_MAX_RETRY_TIMES = 20;
    public static final String USE_FINGERPRINT = "android.permission.USE_FINGERPRINT";
    private AppOpsManager mAppOps;
    private GFConfig mConfig = new GFConfig();
    private Context mContext;
    private IGFDaemonCallback mDaemonCallback = new IGFDaemonCallback() {
        /* class com.goodix.cap.fingerprint.service.GFService.AnonymousClass2 */

        @Override // com.goodix.cap.fingerprint.proxy.IDaemonDiedCallback
        public void onDaemonDied() {
            if (GFService.this.mFingerprintCallback != null) {
                GFService.this.mFingerprintCallback.onError(1);
            }
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemonCallback
        public void onEnrollResult(long devId, int fpId, int gpId, int rem) {
            if (GFService.this.mFingerprintCallback != null) {
                GFService.this.mFingerprintCallback.onEnrollResult(fpId, rem);
            }
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemonCallback
        public void onAcquired(long devId, int acquiredInfo) {
            if (GFService.this.mFingerprintCallback != null) {
                GFService.this.mFingerprintCallback.onAcquired(acquiredInfo);
            }
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemonCallback
        public void onAuthenticated(long devId, int fingerId, int groupId, byte[] token) {
            if (GFService.this.mFingerprintCallback != null) {
                if (fingerId != 0) {
                    GFService.this.mFingerprintCallback.onAuthenticationSucceeded(fingerId);
                    FingerprintUtils.vibrateFingerprintSuccess(GFService.this.mContext);
                    return;
                }
                GFService.this.mFingerprintCallback.onAuthenticationFailed();
                FingerprintUtils.vibrateFingerprintError(GFService.this.mContext);
            }
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemonCallback
        public void onError(long devId, int error) {
            if (GFService.this.mFingerprintCallback != null) {
                GFService.this.mFingerprintCallback.onError(error);
            }
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemonCallback
        public void onRemoved(long devId, int fingerId, int groupId) {
            if (GFService.this.mFingerprintCallback != null) {
                GFService.this.mFingerprintCallback.onRemoved(fingerId);
            }
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemonCallback
        public void onTestCmd(long devId, int cmdId, byte[] result) {
            if (GFService.this.mFingerprintCallback != null) {
                if (26 == cmdId || 27 == cmdId) {
                    GFService.this.onConfigCmd(result);
                    if (26 == cmdId) {
                        return;
                    }
                }
                GFService.this.mFingerprintCallback.onTestCmd(cmdId, result);
            }
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemonCallback
        public void onHbdData(long devId, int heartBeatRate, int status, byte[] displayData) {
            GoodixFingerprintCallbackExt unused = GFService.this.mFingerprintCallback;
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemonCallback
        public void onEnrollSecResult(long devId, int fpId, int gpId, int remaining, int width, int height, byte[] result) {
            if (GFService.this.mFingerprintCallback != null) {
                GFService.this.mFingerprintCallback.onEnrollSecResult(fpId, remaining, width, height, GFService.this.convertToBitmap(result, width, height), width * height);
            }
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemonCallback
        public void onCaptureInfo(long devId, int width, int height, int imgQuality, int score, byte[] rawData, byte[] bmpData) {
            if (GFService.this.mFingerprintCallback != null) {
                Bitmap rawBmp = GFService.this.convertToBitmap(rawData, width, height);
                Bitmap bmp = GFService.this.convertToBitmap(bmpData, width, height);
                FingerprintUtils.vibrateFingerprintSuccess(GFService.this.mContext);
                GFService.this.mFingerprintCallback.onCaptureInfo(devId, rawBmp, rawData, width, height, bmp, bmpData, imgQuality, score);
            }
        }

        @Override // com.goodix.cap.fingerprint.proxy.IGFDaemonCallback
        public void onEventInfo(int eventId, byte[] eventData) {
        }
    };
    private DaemonManager mDaemonMgr;
    private GFDevice mDevice = new GFDevice();
    private GoodixFingerprintCallbackExt mFingerprintCallback;
    private int mGetConfigRetryCount = 0;
    private Handler mHandler = null;
    private String mOpPackageName;
    private int mOpUseFingerprint = -1;
    private int mTestResult = -1;
    private int mUserId;

    static /* synthetic */ int access$108(GFService x0) {
        int i = x0.mGetConfigRetryCount;
        x0.mGetConfigRetryCount = i + 1;
        return i;
    }

    public GFService(Context context) {
        this.mContext = context;
        this.mHandler = new Handler(context.getMainLooper());
        this.mAppOps = (AppOpsManager) context.getSystemService("appops");
        this.mUserId = getMyUserId();
        this.mOpPackageName = getAppOpPackageName();
        this.mOpUseFingerprint = getOpUseFingerprint();
        this.mDaemonMgr = DaemonManager.getInstance();
    }

    public void registerFingerprintCallback(GoodixFingerprintCallbackExt fingerprintCallback) {
        this.mFingerprintCallback = fingerprintCallback;
    }

    public void unRegisterFingerprintCallback() {
        this.mFingerprintCallback = null;
    }

    public void openHal() {
        IGFDaemon daemon = getFingerprintDaemon();
        if (daemon == null) {
            Log.e(TAG, "pauseEnroll: service not found!");
            return;
        }
        Log.e(TAG, " daemon.openHal();");
        try {
            daemon.openHal();
        } catch (RemoteException e) {
            Log.e(TAG, "pauseEnroll RemoteException");
        }
    }

    public void closeHal() {
        IGFDaemon daemon = getFingerprintDaemon();
        if (daemon == null) {
            Log.e(TAG, "closeHal: service not found!");
            return;
        }
        try {
            daemon.closeHal();
        } catch (RemoteException e) {
            Log.e(TAG, "pauseEnroll RemoteException");
        }
    }

    private IGFDaemon getFingerprintDaemon() {
        Log.d(TAG, "getFingerprintDaemon()");
        return this.mDaemonMgr.getGoodixFingerprintDaemon(this.mDaemonCallback);
    }

    public void testCmd(int cmdId, byte[] param, String opPackageName) {
        Log.d(TAG, "testCmd " + cmdId);
        if (!canUseFingerprint(opPackageName)) {
            Log.w(TAG, "Calling not granted permission to use fingerprint");
            return;
        }
        final IGFDaemon daemon = getFingerprintDaemon();
        if (daemon == null) {
            Log.w(TAG, "stopTestCmd: no goodixfingeprintd!");
            return;
        }
        while (this.mTestResult != 0 && 26 == cmdId && this.mGetConfigRetryCount < 20) {
            try {
                this.mHandler.postDelayed(new Runnable() {
                    /* class com.goodix.cap.fingerprint.service.GFService.AnonymousClass1 */

                    public void run() {
                        try {
                            GFService.this.mTestResult = daemon.testCmd(26, null);
                        } catch (RemoteException e) {
                            e.printStackTrace();
                        }
                        GFService.access$108(GFService.this);
                        Log.i(GFService.TAG, "CMD_TEST_GET_CONFIG retry count : " + GFService.this.mGetConfigRetryCount);
                    }
                }, 1000);
            } catch (RemoteException e) {
                e.printStackTrace();
                return;
            }
        }
        this.mTestResult = daemon.testCmd(cmdId, param);
    }

    public void untrustedAuthenticate(String opPackageName) {
        Log.e(TAG, "untrustedAuthenticate:" + opPackageName);
        testCmd(35, null, opPackageName);
    }

    public void cancelUntrustedAuthentication(String opPackageName) {
        cancelTestCmd(opPackageName);
    }

    public void untrustedEnroll(String opPackageName) {
        Log.e(TAG, "untrustedEnroll:" + opPackageName);
        testCmd(34, null, opPackageName);
    }

    public void untrustedRemoveForSec(String opPackageName, int groupId, int fingerId) {
        if (!canUseFingerprint(opPackageName)) {
            Log.w(TAG, "Calling not granted permission to use fingerprint");
            return;
        }
        byte[] byteArray = new byte[16];
        TestParamEncoder.encodeInt32(byteArray, TestParamEncoder.encodeInt32(byteArray, 0, 1421, groupId), 1422, fingerId);
        testCmd(54, byteArray, opPackageName);
    }

    public void untrustedRemove(String opPackageName) {
        testCmd(36, null, this.mOpPackageName);
    }

    public void pauseEnroll(String opPackageName) {
        Log.d(TAG, "pauseEnroll");
        if (canUseFingerprint(opPackageName)) {
            IGFDaemon daemon = getFingerprintDaemon();
            if (daemon == null) {
                Log.e(TAG, "pauseEnroll: service not found!");
                return;
            }
            try {
                daemon.pauseEnroll();
            } catch (RemoteException e) {
                Log.e(TAG, "pauseEnroll RemoteException");
            }
        }
    }

    public void resumeEnroll(String opPackageName) {
        Log.d(TAG, "resumeEnroll");
        if (canUseFingerprint(opPackageName)) {
            IGFDaemon daemon = getFingerprintDaemon();
            if (daemon == null) {
                Log.e(TAG, "resumeEnroll: service not found!");
                return;
            }
            try {
                daemon.resumeEnroll();
            } catch (RemoteException e) {
                Log.e(TAG, "resumeEnroll RemoteException");
            }
        }
    }

    public void cancelUntrustedEnrollment(String opPackageName) {
        cancelTestCmd(opPackageName);
    }

    public void untrustedPauseEnroll(GoodixFingerprintCallbackExt receiver, String opPackageName) {
        Log.d(TAG, "untrustedPauseEnroll");
        testCmd(55, null, opPackageName);
    }

    public void untrustedResumeEnroll(GoodixFingerprintCallbackExt receiver, String opPackageName) {
        Log.d(TAG, "untrustedResumeEnroll");
        testCmd(56, null, opPackageName);
    }

    public void cancelTestCmd(String opPackageName) {
        testCmd(25, null, opPackageName);
    }

    public void navigate(int navMode, String opPackageName) {
        Log.d(TAG, "navigate");
        if (canUseFingerprint(opPackageName)) {
            IGFDaemon daemon = getFingerprintDaemon();
            if (daemon == null) {
                Log.e(TAG, "navigate: service not found!");
                return;
            }
            try {
                daemon.navigate(navMode);
            } catch (RemoteException e) {
                Log.e(TAG, "navigate RemoteException");
            }
        }
    }

    public void stopNavigation(String opPackageName) {
        Log.d(TAG, "stopNavigation");
        if (canUseFingerprint(opPackageName)) {
            IGFDaemon daemon = getFingerprintDaemon();
            if (daemon == null) {
                Log.e(TAG, "stopNavigation: service not found!");
                return;
            }
            try {
                daemon.stopNavigation();
            } catch (RemoteException e) {
                Log.e(TAG, "stopNavigation RemoteException");
            }
        }
    }

    public void startUntouchTest() {
        Log.d(TAG, "startUntouchTest");
        IGFDaemon daemon = getFingerprintDaemon();
        if (daemon == null) {
            Log.e(TAG, "startUntouchTest: service not found!");
            return;
        }
        try {
            daemon.startUntouchTest();
        } catch (RemoteException e) {
            Log.e(TAG, "startUntouchTest RemoteException");
        }
    }

    public void startTouchPrepareTest() {
        Log.d(TAG, "startTouchPrepareTest");
        IGFDaemon daemon = getFingerprintDaemon();
        if (daemon == null) {
            Log.e(TAG, "startTouchPrepareTest: service not found!");
            return;
        }
        try {
            daemon.startTouchPrepareTest();
        } catch (RemoteException e) {
            Log.e(TAG, "startTouchPrepareTest RemoteException");
        }
    }

    public void startTouchTest() {
        Log.d(TAG, "startTouchTest");
        IGFDaemon daemon = getFingerprintDaemon();
        if (daemon == null) {
            Log.e(TAG, "startTouchTest: service not found!");
            return;
        }
        try {
            daemon.startTouchTest();
        } catch (RemoteException e) {
            Log.e(TAG, "startTouchTest RemoteException");
        }
    }

    public void startOtpCheckTest() {
        Log.d(TAG, "startOtpCheckTest");
        IGFDaemon daemon = getFingerprintDaemon();
        if (daemon == null) {
            Log.e(TAG, "startOtpCheckTest: service not found!");
            return;
        }
        try {
            daemon.startOtpTest();
        } catch (RemoteException e) {
            Log.e(TAG, "startOtpCheckTest RemoteException");
        }
    }

    public void startSensorInfoTest() {
        Log.d(TAG, "startSensorInfoTest");
        IGFDaemon daemon = getFingerprintDaemon();
        if (daemon == null) {
            Log.e(TAG, "startSensorInfoTest: service not found!");
            return;
        }
        try {
            daemon.startSensorInfoTest();
        } catch (RemoteException e) {
            Log.e(TAG, "startSensorInfoTest RemoteException");
        }
    }

    public String startGetVersion() {
        Log.d(TAG, "startGetVersion from Daemon.");
        IGFDaemon daemon = getFingerprintDaemon();
        if (daemon == null) {
            Log.e(TAG, "startGetVersion: service not found!");
            return "";
        }
        try {
            return daemon.getVersion();
        } catch (RemoteException e) {
            Log.e(TAG, "startGetVersion RemoteException");
            return "";
        }
    }

    public GFConfig getConfig(String opPackageName) {
        if (!canUseFingerprint(opPackageName)) {
            return null;
        }
        return new GFConfig(this.mConfig);
    }

    public GFDevice getDevice(String opPackageName) {
        if (!canUseFingerprint(opPackageName)) {
            return null;
        }
        return new GFDevice(this.mDevice);
    }

    private int getMyUserId() {
        try {
            return ((Integer) Class.forName("android.os.UserHandle").getMethod("myUserId", new Class[0]).invoke(null, new Object[0])).intValue();
        } catch (ClassNotFoundException e) {
            Log.e(TAG, "getMyUserId ClassNotFoundException: ", e);
            return 0;
        } catch (NoSuchMethodException e2) {
            Log.e(TAG, "getMyUserId NoSuchMethodException: ", e2);
            return 0;
        } catch (IllegalAccessException e3) {
            Log.e(TAG, "getMyUserId IllegalAccessException: ", e3);
            return 0;
        } catch (InvocationTargetException e4) {
            Log.e(TAG, "getMyUserId InvocationTargetException: ", e4);
            return 0;
        } catch (IllegalArgumentException e5) {
            Log.e(TAG, "getMyUserId IllegalArgumentException: ", e5);
            return 0;
        }
    }

    private void checkPermission(String permission) {
        Context context = this.mContext;
        context.enforceCallingOrSelfPermission(permission, "Must have " + permission + " permission.");
    }

    private boolean canUseFingerprint(String opPackageName) {
        checkPermission("android.permission.USE_FINGERPRINT");
        try {
            Method noteOp = this.mAppOps.getClass().getMethod("noteOp", Integer.TYPE, Integer.TYPE, String.class);
            noteOp.setAccessible(true);
            return ((Integer) noteOp.invoke(this.mAppOps, new Object[]{Integer.valueOf(this.mOpUseFingerprint), Integer.valueOf(Binder.getCallingUid()), opPackageName})).intValue() == 0;
        } catch (NoSuchMethodException e) {
            Log.e(TAG, "canUseFingerprint NoSuchMethodException: ", e);
            return false;
        } catch (InvocationTargetException e2) {
            Log.e(TAG, "canUseFingerprint InvocationTargetException: ", e2);
            return false;
        } catch (IllegalAccessException e3) {
            Log.e(TAG, "canUseFingerprint IllegalAccessException: ", e3);
            return false;
        }
    }

    private String getAppOpPackageName() {
        Context context = this.mContext;
        if (context == null) {
            return null;
        }
        try {
            Method getOpPackageName = context.getClass().getMethod("getOpPackageName", new Class[0]);
            getOpPackageName.setAccessible(true);
            return (String) getOpPackageName.invoke(this.mContext, new Object[0]);
        } catch (NoSuchMethodException e) {
            Log.e(TAG, "getAppOpPackageName NoSuchMethodException: ", e);
            return null;
        } catch (IllegalAccessException e2) {
            Log.e(TAG, "getAppOpPackageName IllegalAccessException: ", e2);
            return null;
        } catch (IllegalArgumentException e3) {
            Log.e(TAG, "getAppOpPackageName IllegalArgumentException: ", e3);
            return null;
        } catch (InvocationTargetException e4) {
            Log.e(TAG, "getAppOpPackageName InvocationTargetException: ", e4);
            return null;
        }
    }

    private int getOpUseFingerprint() {
        try {
            return AppOpsManager.class.getDeclaredField("OP_USE_FINGERPRINT").getInt(null);
        } catch (NoSuchFieldException e) {
            Log.e(TAG, "getOpUseFingerprint NoSuchFieldException: ", e);
            return -1;
        } catch (IllegalAccessException e2) {
            Log.e(TAG, "getOpUseFingerprint IllegalAccessException: ", e2);
            return -1;
        } catch (IllegalArgumentException e3) {
            Log.e(TAG, "getOpUseFingerprint IllegalArgumentException: ", e3);
            return -1;
        }
    }

    public void onConfigCmd(byte[] result) {
        HashMap<Integer, Object> testResult = TestResultParser.parser(result);
        if (testResult != null) {
            if (!testResult.containsKey(100) || ((Integer) testResult.get(100)).intValue() <= 0) {
                if (testResult.containsKey(101)) {
                    this.mConfig.mChipType = ((Integer) testResult.get(101)).intValue();
                }
                if (testResult.containsKey(102)) {
                    this.mConfig.mChipSeries = ((Integer) testResult.get(102)).intValue();
                }
                if (testResult.containsKey(800)) {
                    this.mConfig.mMaxFingers = ((Integer) testResult.get(800)).intValue();
                }
                if (testResult.containsKey(801)) {
                    this.mConfig.mMaxFingersPerUser = ((Integer) testResult.get(801)).intValue();
                }
                if (testResult.containsKey(802)) {
                    this.mConfig.mSupportKeyMode = ((Integer) testResult.get(802)).intValue();
                }
                if (testResult.containsKey(803)) {
                    this.mConfig.mSupportFFMode = ((Integer) testResult.get(803)).intValue();
                }
                if (testResult.containsKey(804)) {
                    this.mConfig.mSupportPowerKeyFeature = ((Integer) testResult.get(804)).intValue();
                }
                if (testResult.containsKey(805)) {
                    this.mConfig.mForbiddenUntrustedEnroll = ((Integer) testResult.get(805)).intValue();
                }
                if (testResult.containsKey(806)) {
                    this.mConfig.mForbiddenEnrollDuplicateFingers = ((Integer) testResult.get(806)).intValue();
                }
                if (testResult.containsKey(807)) {
                    this.mConfig.mSupportBioAssay = ((Integer) testResult.get(807)).intValue();
                }
                if (testResult.containsKey(808)) {
                    this.mConfig.mSupportPerformanceDump = ((Integer) testResult.get(808)).intValue();
                }
                if (testResult.containsKey(809)) {
                    this.mConfig.mSupportNavMode = ((Integer) testResult.get(809)).intValue();
                }
                if (testResult.containsKey(810)) {
                    this.mConfig.mNavDoubleClickTime = ((Integer) testResult.get(810)).intValue();
                }
                if (testResult.containsKey(811)) {
                    this.mConfig.mNavLongPressTime = ((Integer) testResult.get(811)).intValue();
                }
                if (testResult.containsKey(812)) {
                    this.mConfig.mEnrollingMinTemplates = ((Integer) testResult.get(812)).intValue();
                }
                if (testResult.containsKey(813)) {
                    this.mConfig.mValidImageQualityThreshold = ((Integer) testResult.get(813)).intValue();
                }
                if (testResult.containsKey(814)) {
                    this.mConfig.mValidImageAreaThreshold = ((Integer) testResult.get(814)).intValue();
                }
                if (testResult.containsKey(815)) {
                    this.mConfig.mDuplicateFingerOverlayScore = ((Integer) testResult.get(815)).intValue();
                }
                if (testResult.containsKey(816)) {
                    this.mConfig.mIncreaseRateBetweenStitchInfo = ((Integer) testResult.get(816)).intValue();
                }
                if (testResult.containsKey(817)) {
                    this.mConfig.mScreenOnAuthenticateFailRetryCount = ((Integer) testResult.get(817)).intValue();
                }
                if (testResult.containsKey(818)) {
                    this.mConfig.mScreenOffAuthenticateFailRetryCount = ((Integer) testResult.get(818)).intValue();
                }
                if (testResult.containsKey(819)) {
                    this.mConfig.mScreenOnValidTouchFrameThreshold = ((Integer) testResult.get(819)).intValue();
                }
                if (testResult.containsKey(820)) {
                    this.mConfig.mScreenOffValidTouchFrameThreshold = ((Integer) testResult.get(820)).intValue();
                }
                if (testResult.containsKey(821)) {
                    this.mConfig.mImageQualityThresholdForMistakeTouch = ((Integer) testResult.get(821)).intValue();
                }
                if (testResult.containsKey(822)) {
                    this.mConfig.mAuthenticateOrder = ((Integer) testResult.get(822)).intValue();
                }
                if (testResult.containsKey(823)) {
                    this.mConfig.mReissueKeyDownWhenEntryFfMode = ((Integer) testResult.get(823)).intValue();
                }
                if (testResult.containsKey(824)) {
                    this.mConfig.mReissueKeyDownWhenEntryImageMode = ((Integer) testResult.get(824)).intValue();
                }
                if (testResult.containsKey(825)) {
                    this.mConfig.mSupportSensorBrokenCheck = ((Integer) testResult.get(825)).intValue();
                }
                if (testResult.containsKey(826)) {
                    this.mConfig.mBrokenPixelThresholdForDisableSensor = ((Integer) testResult.get(826)).intValue();
                }
                if (testResult.containsKey(827)) {
                    this.mConfig.mBrokenPixelThresholdForDisableStudy = ((Integer) testResult.get(827)).intValue();
                }
                if (testResult.containsKey(828)) {
                    this.mConfig.mBadPointTestMaxFrameNumber = ((Integer) testResult.get(828)).intValue();
                }
                if (testResult.containsKey(829)) {
                    this.mConfig.mReportKeyEventOnlyEnrollAuthenticate = ((Integer) testResult.get(829)).intValue();
                }
                if (testResult.containsKey(830)) {
                    this.mConfig.mRequireDownAndUpInPairsForImageMode = ((Integer) testResult.get(830)).intValue();
                }
                if (testResult.containsKey(831)) {
                    this.mConfig.mRequireDownAndUpInPairsForFFMode = ((Integer) testResult.get(831)).intValue();
                }
                if (testResult.containsKey(832)) {
                    this.mConfig.mRequireDownAndUpInPairsForKeyMode = ((Integer) testResult.get(832)).intValue();
                }
                if (testResult.containsKey(833)) {
                    this.mConfig.mRequireDownAndUpInPairsForNavMode = ((Integer) testResult.get(833)).intValue();
                }
                if (testResult.containsKey(834)) {
                    this.mConfig.mSupportSetSpiSpeedInTEE = ((Integer) testResult.get(834)).intValue();
                }
                if (testResult.containsKey(835)) {
                    this.mConfig.mSupportFrrAnalysis = ((Integer) testResult.get(835)).intValue();
                }
                if (testResult.containsKey(5200)) {
                    this.mConfig.mTemplateUpateSaveThreshold = ((Integer) testResult.get(5200)).intValue();
                }
                if (this.mConfig.mMaxFingers < this.mConfig.mMaxFingersPerUser) {
                    GFConfig gFConfig = this.mConfig;
                    gFConfig.mMaxFingers = gFConfig.mMaxFingersPerUser;
                }
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Bitmap convertToBitmap(byte[] result, int width, int height) {
        Log.d(TAG, "convertToBitmap width=" + width + ",height=" + height + " data=" + result);
        int length = width * height;
        int[] display = new int[length];
        for (int i = 0; i < length; i++) {
            int pixel = result[i] & UnsignedBytes.MAX_VALUE;
            display[i] = -16777216 | (pixel << 16) | (pixel << 8) | pixel;
        }
        return Bitmap.createBitmap(display, width, height, Bitmap.Config.ARGB_8888);
    }
}
