package com.goodix.cap.fingerprint.service;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.os.AsyncTask;
import android.os.Binder;
import android.os.CancellationSignal;
import android.os.Environment;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.support.v4.app.NotificationManagerCompat;
import android.support.v4.view.MotionEventCompat;
import android.util.Log;
import com.goodix.cap.fingerprint.Constants;
import com.goodix.cap.fingerprint.GFConfig;
import com.goodix.cap.fingerprint.GFDevice;
import com.goodix.cap.fingerprint.GFResource;
import com.goodix.cap.fingerprint.ext.GoodixEnrollInfo;
import com.goodix.cap.fingerprint.ext.GoodixImageInfo;
import com.goodix.cap.fingerprint.ext.GoodixSharePref;
import com.goodix.cap.fingerprint.service.IGoodixFingerprintDumpCallback;
import com.goodix.cap.fingerprint.utils.TestResultParser;
import com.google.common.primitives.UnsignedBytes;
import com.sec.factory.app.factorytest.FactoryTestManager;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;

public class GoodixFingerprintManagerExt {
    public static final int FINGERPRINT_ACQUIRED_GOOD = 0;
    public static final int FINGERPRINT_ACQUIRED_IMAGER_DIRTY = 3;
    public static final int FINGERPRINT_ACQUIRED_INSUFFICIENT = 2;
    public static final int FINGERPRINT_ACQUIRED_PARTIAL = 1;
    public static final int FINGERPRINT_ACQUIRED_TOO_FAST = 5;
    public static final int FINGERPRINT_ACQUIRED_TOO_SLOW = 4;
    public static final int FINGERPRINT_ACQUIRED_VENDOR_BASE = 1000;
    public static final int FINGERPRINT_ERROR_CANCELED = 5;
    public static final int FINGERPRINT_ERROR_HW_UNAVAILABLE = 1;
    public static final int FINGERPRINT_ERROR_LOCKOUT = 7;
    public static final int FINGERPRINT_ERROR_NO_SPACE = 4;
    public static final int FINGERPRINT_ERROR_TIMEOUT = 3;
    public static final int FINGERPRINT_ERROR_UNABLE_TO_PROCESS = 2;
    public static final int FINGERPRINT_ERROR_UNABLE_TO_REMOVE = 6;
    public static final int FINGERPRINT_ERROR_VENDOR_BASE = 1000;
    private static final int MSG_ACQUIRED = 101;
    private static final int MSG_AUTHENTICATED_FIDO = 1003;
    public static final int MSG_AUTHENTICATED_FIDO_CANCELED = 102;
    public static final int MSG_AUTHENTICATED_FIDO_LOCKOUT = 107;
    public static final int MSG_AUTHENTICATED_FIDO_NO_MATCH = 103;
    public static final int MSG_AUTHENTICATED_FIDO_SUCCESS = 100;
    public static final int MSG_AUTHENTICATED_FIDO_TIMEOUT = 113;
    private static final int MSG_AUTHENTICATION_FAILED = 103;
    private static final int MSG_AUTHENTICATION_SUCCEEDED = 102;
    private static final int MSG_DUMP = 1002;
    private static final int MSG_ENROLL_RESULT = 100;
    private static final int MSG_ENROLL_SEC_BMP_RESULT = 108;
    private static final int MSG_ENROLL_SEC_RAW_BMP_RESULT = 107;
    private static final int MSG_ENROLL_SEC_RESULT = 106;
    private static final int MSG_ERROR = 104;
    private static final int MSG_HBD = 1001;
    private static final int MSG_REMOVED = 105;
    private static final int MSG_TEST = 1000;
    private static final String TAG = "GoodixFingerprintManagerExt";
    private static TestCmdCallback mTestCallback;
    private static GoodixFingerprintManagerExt sGoodixManager;
    private static int sGroupId = 0;
    private SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd-HH-mm-ss-SSS");
    GoodixImageInfo gImageInfo;
    private AuthenticateFidoCallback mAuthenticateFidoCallback = null;
    private Context mContext = null;
    private DumpCallback mDumpCallback = null;
    private GoodixFingerprintCallbackExt mGoodixFingerprintCallback = new GoodixFingerprintCallbackExt() {
        /* class com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.AnonymousClass2 */

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintCallbackExt
        public void onEnrollResult(int fingerId, int remaining) {
            Log.d(GoodixFingerprintManagerExt.TAG, "onEnrollResult fingerId = " + fingerId + " remaining = " + remaining);
            GoodixFingerprintManagerExt.this.mHandler.obtainMessage(100, fingerId, remaining).sendToTarget();
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintCallbackExt
        public void onEnrollSecResult(int fingerId, int remaining, int width, int height, Bitmap bitmap, int length) {
            GoodixEnrollInfo enrollInfo = new GoodixEnrollInfo();
            enrollInfo.fingerId = fingerId;
            enrollInfo.remaining = remaining;
            enrollInfo.width = width;
            enrollInfo.height = height;
            enrollInfo.bitmap = bitmap;
            Log.d(GoodixFingerprintManagerExt.TAG, "onEnrollSecResult fingerId = " + fingerId + " remaining = " + remaining + " width = " + width + " height =" + height + " bitmap=" + bitmap);
            GoodixFingerprintManagerExt.this.mHandler.obtainMessage(106, enrollInfo).sendToTarget();
            GoodixFingerprintManagerExt.this.saveDumpImage(GoodixFingerprintManagerExt.sGroupId, GoodixFingerprintManagerExt.this.gImageInfo.bmpScore, "enroll", fingerId, GoodixFingerprintManagerExt.this.gImageInfo.width, GoodixFingerprintManagerExt.this.gImageInfo.height, GoodixFingerprintManagerExt.this.gImageInfo.bmpData, GoodixFingerprintManagerExt.this.gImageInfo.rawBmpData);
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintCallbackExt
        public void onCaptureInfo(long devId, Bitmap rawBmp, byte[] rawBmpData, int bWidth, int bHeight, Bitmap bmp, byte[] bmpData, int imgQuality, int bmpScore) {
            GoodixImageInfo captureInfo = new GoodixImageInfo();
            captureInfo.rawBmp = rawBmp;
            captureInfo.rawBmpData = rawBmpData;
            captureInfo.width = bWidth;
            captureInfo.height = bHeight;
            captureInfo.bmp = bmp;
            captureInfo.bmpData = bmpData;
            captureInfo.imgQuality = imgQuality;
            captureInfo.bmpScore = bmpScore;
            GoodixFingerprintManagerExt.this.mHandler.obtainMessage(108, captureInfo).sendToTarget();
            GoodixFingerprintManagerExt.this.gImageInfo = captureInfo;
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintCallbackExt
        public void onEventInfo(int eventId, byte[] eventData) {
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintCallbackExt
        public void onAcquired(int acquireInfo) {
            GoodixFingerprintManagerExt.this.mHandler.obtainMessage(101, acquireInfo, 0).sendToTarget();
            switch (acquireInfo) {
                case 6002:
                case 6103:
                case 6104:
                    GoodixFingerprintManagerExt.this.saveDumpImage(GoodixFingerprintManagerExt.sGroupId, GoodixFingerprintManagerExt.this.gImageInfo.bmpScore, "authentication", -1, GoodixFingerprintManagerExt.this.gImageInfo.width, GoodixFingerprintManagerExt.this.gImageInfo.height, GoodixFingerprintManagerExt.this.gImageInfo.bmpData, GoodixFingerprintManagerExt.this.gImageInfo.rawBmpData);
                    return;
                default:
                    return;
            }
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintCallbackExt
        public void onAuthenticationSucceeded(int fingerId) {
            GoodixFingerprintManagerExt.this.mHandler.obtainMessage(102, fingerId, 0).sendToTarget();
            GoodixFingerprintManagerExt.this.saveDumpImage(GoodixFingerprintManagerExt.sGroupId, GoodixFingerprintManagerExt.this.gImageInfo.bmpScore, "authentication", fingerId, GoodixFingerprintManagerExt.this.gImageInfo.width, GoodixFingerprintManagerExt.this.gImageInfo.height, GoodixFingerprintManagerExt.this.gImageInfo.bmpData, GoodixFingerprintManagerExt.this.gImageInfo.rawBmpData);
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintCallbackExt
        public void onAuthenticationFailed() {
            GoodixFingerprintManagerExt.this.mHandler.obtainMessage(103).sendToTarget();
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintCallbackExt
        public void onError(int error) {
            GoodixFingerprintManagerExt.this.mHandler.obtainMessage(104, error, 0).sendToTarget();
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintCallbackExt
        public void onRemoved(int fingerId) {
            GoodixFingerprintManagerExt.this.mHandler.obtainMessage(105, fingerId, 0).sendToTarget();
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintCallbackExt
        public void onTestCmd(int cmdId, byte[] result) {
            Log.d(GoodixFingerprintManagerExt.TAG, "onTestCmd " + ((Object) Constants.testCmdIdToString(cmdId)));
            GoodixFingerprintManagerExt.this.mHandler.obtainMessage(1000, cmdId, 0, result).sendToTarget();
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintCallbackExt
        public void onHbdData(final int heartBeatRate, final int status, final int[] displayData, final int[] rawData) {
            Log.d(GoodixFingerprintManagerExt.TAG, "onHbdData");
            GoodixFingerprintManagerExt.this.mHandler.post(new Runnable() {
                /* class com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.AnonymousClass2.AnonymousClass1 */

                public void run() {
                    if (GoodixFingerprintManagerExt.this.mHbdCallback != null) {
                        GoodixFingerprintManagerExt.this.mHbdCallback.onHbdData(heartBeatRate, status, displayData, rawData);
                    }
                }
            });
        }

        @Override // com.goodix.cap.fingerprint.service.GoodixFingerprintCallbackExt
        public void onAuthenticateFido(int fingerId, byte[] uvt) {
            Log.d(GoodixFingerprintManagerExt.TAG, "onAuthenticateFido, fingerId:" + fingerId);
            Message msg = GoodixFingerprintManagerExt.this.mHandler.obtainMessage(1003);
            msg.arg1 = fingerId;
            msg.obj = uvt;
            msg.sendToTarget();
        }
    };
    private IGoodixFingerprintDumpCallback.Stub mGoodixFingerprintDumpCallback = new IGoodixFingerprintDumpCallback.Stub() {
        /* class com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.AnonymousClass3 */

        @Override // com.goodix.cap.fingerprint.service.IGoodixFingerprintDumpCallback
        public void onDump(int cmdId, byte[] data) {
            Log.d(GoodixFingerprintManagerExt.TAG, "onDump");
            GoodixFingerprintManagerExt.this.mHandler.obtainMessage(1002, cmdId, 0, data).sendToTarget();
        }
    };
    private Handler mHandler = null;
    private HbdCallback mHbdCallback = null;
    private GFService mIGoodixFingerprintInterface = null;
    private String mOpPackageName = null;
    private TimeOutRunnable mTimeOutRunnable = null;
    private IBinder mToken;
    private UntrustedAuthenticationCallback mUntrustedAuthenticationCallback = null;
    private UntrustedEnrollmentCallback mUntrustedEnrollmentCallback = null;
    private UntrustedRemovalCallback mUntrustedRemovalCallback = null;

    public interface AuthenticateFidoCallback {
        void onResult(int i, byte[] bArr, byte[] bArr2);
    }

    public interface DumpCallback {
        void onDump(int i, HashMap<Integer, Object> hashMap);
    }

    public interface HbdCallback {
        void onHbdData(int i, int i2, int[] iArr, int[] iArr2);
    }

    public interface TestCmdCallback {
        void onTestCmd(int i, HashMap<Integer, Object> hashMap);
    }

    /* access modifiers changed from: private */
    public class OnUntrustedEnrollCancelListener implements CancellationSignal.OnCancelListener {
        private OnUntrustedEnrollCancelListener() {
        }

        public void onCancel() {
            GoodixFingerprintManagerExt.this.cancelUntrustedEnrollment();
        }
    }

    /* access modifiers changed from: private */
    public class OnUntrustedAuthenticationCancelListener implements CancellationSignal.OnCancelListener {
        private OnUntrustedAuthenticationCancelListener() {
        }

        public void onCancel() {
            GoodixFingerprintManagerExt.this.cancelUntrustedAuthentication();
        }
    }

    public static abstract class UntrustedEnrollmentCallback {
        public void onEnrollmentError(int errMsgId, String errString) {
        }

        public void onEnrollmentHelp(int helpMsgId, String helpString) {
        }

        public void onEnrollmentProgress(int fingerId, int remaining) {
        }

        public void onEnrollmentProgress(int fingerId, int remaining, byte[] result) {
        }

        public void onEnrollmentAcquired(int acquireInfo) {
        }

        public void onEnrollmentResultInfo(GoodixEnrollInfo enrollInfo) {
        }

        public void onEnrollmentCaptureBmpInfo(int imageQuality, int length, Bitmap bmp) {
        }

        public void onEnrollmentCaptureRawBmpInfo(int imageQuality, int length, Bitmap rawBmp) {
        }

        public void onEnrollmentCaptureBmpResult(GoodixImageInfo captureInfo) {
        }
    }

    public static abstract class UntrustedAuthenticationCallback {
        public void onAuthenticationError(int errorCode, CharSequence errString) {
        }

        public void onAuthenticationHelp(int helpCode, CharSequence helpString) {
        }

        public void onAuthenticationSucceeded(int fingerId) {
        }

        public void onAuthenticationFailed() {
        }

        public void onAuthenticationAcquired(int acquireInfo) {
        }

        public void onAuthenticationCaptureBmpResult(GoodixImageInfo captureInfo) {
        }
    }

    public static abstract class UntrustedRemovalCallback {
        public void onRemovalError(int errMsgId, CharSequence errString) {
        }

        public void onRemovalSucceeded(int fingerId) {
        }
    }

    public static GoodixFingerprintManagerExt getGoodixManager(Context context) {
        Log.e(TAG, "getFingerprintManager = " + sGoodixManager);
        if (sGoodixManager == null) {
            sGoodixManager = new GoodixFingerprintManagerExt(context);
            Log.e(TAG, "getFingerprintManager create = " + sGoodixManager);
        }
        return sGoodixManager;
    }

    private String getAppOpPackageName() {
        Context context = this.mContext;
        if (context == null) {
            return null;
        }
        try {
            Method getOpPackageName = context.getClass().getMethod("getOpPackageName", new Class[0]);
            getOpPackageName.setAccessible(true);
            return (String) getOpPackageName.invoke(this.mContext, new Object[0]);
        } catch (IllegalAccessException | IllegalArgumentException | NoSuchMethodException | InvocationTargetException e) {
            return null;
        }
    }

    private void resetFidoAuthenticateTimeOut(long timeout) {
        Handler handler = this.mHandler;
        if (handler != null) {
            handler.postDelayed(this.mTimeOutRunnable, timeout);
        }
    }

    private class TimeOutRunnable implements Runnable {
        private TimeOutRunnable() {
        }

        public void run() {
            if (GoodixFingerprintManagerExt.this.mAuthenticateFidoCallback != null) {
                GoodixFingerprintManagerExt.this.mAuthenticateFidoCallback.onResult(113, null, null);
            }
        }
    }

    public int setEnrollSession(boolean flag) {
        return 0;
    }

    public void startFpManager(Context context) {
        Intent intent = new Intent("android.intent.action.MAIN");
        intent.setComponent(new ComponentName("com.android.settings", "com.android.settings.Settings$FingerPrintSettingsActivity"));
        intent.addFlags(268435456);
        intent.putExtra(":settings:show_fragment", "com.android.settings.FingerPrintSettingsActivity");
        context.startActivity(intent);
    }

    public GoodixFingerprintManagerExt(Context context) {
        this.mContext = context;
        this.mHandler = new MyHandler(context);
        this.mOpPackageName = getAppOpPackageName();
        this.mToken = new Binder();
        GoodixSharePref.getInstance().init(context);
        GFService gFService = new GFService(context);
        this.mIGoodixFingerprintInterface = gFService;
        gFService.registerFingerprintCallback(this.mGoodixFingerprintCallback);
        sGoodixManager = this;
        Log.d(TAG, "mOpPackageName = " + this.mOpPackageName + " mGoodixFingerprintCallback = " + this.mGoodixFingerprintCallback);
    }

    public void registerTestCmdCallback(TestCmdCallback callback) {
        Log.d(TAG, "registerTestCmdCallback " + callback);
        mTestCallback = callback;
    }

    public void unregisterTestCmdCallback(TestCmdCallback callback) {
        Log.d(TAG, "unregisterTestCmdCallback");
        mTestCallback = null;
        cancelUntrustedEnrollment();
        cancelUntrustedAuthentication();
    }

    public void testCmd(int cmdId) {
        testCmd(cmdId, null);
    }

    public void initGroupIdValue(int groupId) {
        Log.d(TAG, "initGroupIdValue  groupId" + groupId);
        sGroupId = groupId;
    }

    public void testCmd(int cmdId, byte[] param) {
        Log.d(TAG, "testCmd " + ((Object) Constants.testCmdIdToString(cmdId)));
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "testCmd no com.goodix.FingerprintService");
        } else {
            gFService.testCmd(cmdId, param, this.mOpPackageName);
        }
    }

    public void navigate(int navMode) {
        Log.d(TAG, "navigate");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "navigate no com.goodix.FingerprintService");
        } else {
            gFService.navigate(navMode, this.mOpPackageName);
        }
    }

    public void stopNavigation() {
        Log.d(TAG, "stopNavigation");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "stopNavigation no com.goodix.FingerprintService");
        } else {
            gFService.stopNavigation(this.mOpPackageName);
        }
    }

    public GFConfig getConfig() {
        Log.d(TAG, "getConfig");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService != null) {
            return gFService.getConfig(this.mOpPackageName);
        }
        Log.e(TAG, "getConfig null interface com.goodix.FingerprintService");
        return null;
    }

    public GFDevice getDevice() {
        Log.d(TAG, "getDevice");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService != null) {
            return gFService.getDevice(this.mOpPackageName);
        }
        Log.e(TAG, "getDevice null interface com.goodix.FingerprintService");
        return null;
    }

    public void untrustedAuthenticate(CancellationSignal cancel, UntrustedAuthenticationCallback callback) {
        if (callback != null) {
            if (this.mUntrustedEnrollmentCallback != null) {
                this.mUntrustedEnrollmentCallback = null;
            }
            if (cancel != null) {
                if (cancel.isCanceled()) {
                    Log.w(TAG, "untrusted authentication already canceled");
                    return;
                }
                cancel.setOnCancelListener(new OnUntrustedAuthenticationCancelListener());
            }
            GFService gFService = this.mIGoodixFingerprintInterface;
            if (gFService != null) {
                this.mUntrustedAuthenticationCallback = callback;
                gFService.untrustedAuthenticate(getAppOpPackageName());
                return;
            }
            return;
        }
        throw new IllegalArgumentException("Must supply an untrusted authentication callback");
    }

    public void cancelUntrustedAuthentication() {
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService != null) {
            gFService.cancelUntrustedAuthentication(getAppOpPackageName());
            this.mUntrustedAuthenticationCallback = null;
        }
    }

    public void untrustedEnroll(CancellationSignal cancel, UntrustedEnrollmentCallback callback) {
        if (callback != null) {
            if (this.mUntrustedAuthenticationCallback != null) {
                this.mUntrustedAuthenticationCallback = null;
            }
            if (cancel != null) {
                if (cancel.isCanceled()) {
                    Log.w(TAG, "untrusted enrollment already canceled");
                    return;
                }
                cancel.setOnCancelListener(new OnUntrustedEnrollCancelListener());
            }
            GFService gFService = this.mIGoodixFingerprintInterface;
            if (gFService != null) {
                this.mUntrustedEnrollmentCallback = callback;
                gFService.untrustedEnroll(getAppOpPackageName());
                return;
            }
            return;
        }
        throw new IllegalArgumentException("Must supply an untrusted enrollment callback");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void cancelUntrustedEnrollment() {
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService != null) {
            gFService.cancelUntrustedEnrollment(getAppOpPackageName());
        }
    }

    public void untrustedRemove(UntrustedRemovalCallback callback) {
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService != null) {
            this.mUntrustedRemovalCallback = callback;
            gFService.untrustedRemove(getAppOpPackageName());
        }
    }

    public void untrustedRemoveForSec(int groupId, int fingerId, UntrustedRemovalCallback callback) {
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService != null) {
            this.mUntrustedRemovalCallback = callback;
            gFService.untrustedRemoveForSec(getAppOpPackageName(), groupId, fingerId);
        }
    }

    public void pauseEnroll() {
        Log.d(TAG, "pauseEnroll");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "pauseEnroll no com.goodix.FingerprintService");
        } else {
            gFService.pauseEnroll(this.mOpPackageName);
        }
    }

    public void resumeEnroll() {
        Log.d(TAG, "resumeEnroll");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "resumeEnroll no com.goodix.FingerprintService");
        } else {
            gFService.resumeEnroll(this.mOpPackageName);
        }
    }

    public void untrustedPauseEnroll() {
        Log.d(TAG, "untrustedPauseEnroll");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "untrustedPauseEnroll no com.goodix.FingerprintService");
        } else {
            gFService.untrustedPauseEnroll(this.mGoodixFingerprintCallback, this.mOpPackageName);
        }
    }

    public void untrustedResumeEnroll() {
        Log.d(TAG, "untrustedResumeEnroll");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "untrustedResumeEnroll no com.goodix.FingerprintService");
        } else {
            gFService.untrustedResumeEnroll(this.mGoodixFingerprintCallback, this.mOpPackageName);
        }
    }

    public void openHal() {
        Log.d(TAG, "openHal");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "openHal no com.goodix.FingerprintService");
        } else {
            gFService.openHal();
        }
    }

    public void closeHal() {
        Log.d(TAG, "closeHal");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "closeHal no com.goodix.FingerprintService");
        } else {
            gFService.closeHal();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getErrorString(int errMsg) {
        switch (errMsg) {
            case 1:
                return GFResource.R_String.fingerprint_error_hw_not_available;
            case 2:
                return GFResource.R_String.fingerprint_error_unable_to_process;
            case 3:
                return GFResource.R_String.fingerprint_error_timeout;
            case 4:
                return GFResource.R_String.fingerprint_error_no_space;
            case 5:
                return GFResource.R_String.fingerprint_error_canceled;
            case 6:
            default:
                if (errMsg < 1000) {
                    return null;
                }
                int msgNumber = errMsg + NotificationManagerCompat.IMPORTANCE_UNSPECIFIED;
                String[] msgArray = GFResource.R_String_Array.fingerprint_error_vendor;
                if (msgNumber < msgArray.length) {
                    return msgArray[msgNumber];
                }
                return null;
            case 7:
                return GFResource.R_String.fingerprint_error_lockout;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getAcquiredString(int acquireInfo) {
        switch (acquireInfo) {
            case 0:
                return "";
            case 1:
                return GFResource.R_String.fingerprint_acquired_partial;
            case 2:
                return GFResource.R_String.fingerprint_acquired_insufficient;
            case 3:
                return GFResource.R_String.fingerprint_acquired_imager_dirty;
            case 4:
                return GFResource.R_String.fingerprint_acquired_too_slow;
            case 5:
                return GFResource.R_String.fingerprint_acquired_too_fast;
            default:
                if (acquireInfo >= 1000) {
                    int msgNumber = acquireInfo + NotificationManagerCompat.IMPORTANCE_UNSPECIFIED;
                    String[] msgArray = {"goodix base", "", "", "", "", "", "Duplicate area", "Duplicate finger"};
                    if (msgNumber < msgArray.length) {
                        return msgArray[msgNumber];
                    }
                }
                return "";
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void saveDumpImage(final int groupId, final int score, final String opType, final int fingerId, final int width, final int height, final byte[] bmpData, byte[] rawBmpData) {
        AsyncTask.execute(new Runnable() {
            /* class com.goodix.cap.fingerprint.service.GoodixFingerprintManagerExt.AnonymousClass1 */

            public void run() {
                String savePath;
                Log.d(GoodixFingerprintManagerExt.TAG, "saveDumpImage");
                if (fingerId != 0) {
                    savePath = Environment.getExternalStorageDirectory().getAbsolutePath() + "/gf_data/" + groupId + "/" + fingerId + "/" + opType + "/";
                } else {
                    savePath = Environment.getExternalStorageDirectory().getAbsolutePath() + "/gf_data/" + groupId + "/fail/" + opType + "/";
                }
                Log.d(GoodixFingerprintManagerExt.TAG, "saveDumpImage savePath = " + savePath);
                File file = new File(savePath);
                if (!file.exists()) {
                    Log.d(GoodixFingerprintManagerExt.TAG, "saveDumpImage file.mkdirs = " + savePath);
                    file.mkdirs();
                }
                GoodixFingerprintManagerExt goodixFingerprintManagerExt = GoodixFingerprintManagerExt.this;
                byte[] bArr = bmpData;
                goodixFingerprintManagerExt.saveGrayBitmap(savePath, bArr, bArr.length, height, width, score);
            }
        });
    }

    public int saveGrayBitmap(String FilePath, byte[] pData, int length, int row, int colume, int score) {
        FileNotFoundException e;
        IOException e2;
        byte[] grayBitmapHeader = new byte[1078];
        int colume_t = (colume + 3) & 252;
        int i = (row + 3) & 252;
        grayBitmapHeader[0] = FactoryTestManager.TEST_LOOPBACK2_SPK;
        grayBitmapHeader[1] = 77;
        grayBitmapHeader[2] = FactoryTestManager.TEST_DMB3;
        grayBitmapHeader[3] = FactoryTestManager.TEST_FELICA;
        grayBitmapHeader[4] = 0;
        grayBitmapHeader[5] = 0;
        grayBitmapHeader[6] = 0;
        grayBitmapHeader[7] = 0;
        grayBitmapHeader[8] = 0;
        grayBitmapHeader[9] = 0;
        grayBitmapHeader[10] = FactoryTestManager.TEST_DMB3;
        grayBitmapHeader[11] = 4;
        grayBitmapHeader[12] = 0;
        grayBitmapHeader[13] = 0;
        grayBitmapHeader[14] = FactoryTestManager.TEST_FELICA;
        grayBitmapHeader[15] = 0;
        grayBitmapHeader[16] = 0;
        grayBitmapHeader[17] = 0;
        grayBitmapHeader[18] = (byte) (colume & 255);
        grayBitmapHeader[19] = (byte) ((colume >> 8) & 255);
        grayBitmapHeader[20] = (byte) ((colume >> 16) & 255);
        grayBitmapHeader[21] = (byte) ((colume >> 24) & 255);
        grayBitmapHeader[22] = (byte) (row & 255);
        grayBitmapHeader[23] = (byte) ((row >> 8) & 255);
        grayBitmapHeader[24] = (byte) ((row >> 16) & 255);
        grayBitmapHeader[25] = (byte) ((row >> 24) & 255);
        grayBitmapHeader[26] = 1;
        grayBitmapHeader[27] = 0;
        grayBitmapHeader[28] = 8;
        grayBitmapHeader[29] = 0;
        for (int i2 = 0; i2 < 256; i2++) {
            grayBitmapHeader[(i2 * 4) + 54] = (byte) i2;
            grayBitmapHeader[(i2 * 4) + 54 + 1] = (byte) i2;
            grayBitmapHeader[(i2 * 4) + 54 + 2] = (byte) i2;
        }
        byte[] pad = new byte[4];
        try {
            StringBuilder sb = new StringBuilder();
            try {
                sb.append(FilePath);
            } catch (FileNotFoundException e3) {
                e = e3;
                e.printStackTrace();
                return 0;
            } catch (IOException e4) {
                e2 = e4;
                e2.printStackTrace();
                return 0;
            }
            try {
                sb.append(this.formatter.format(new Date()));
                sb.append("-<");
                sb.append(score & 255);
                sb.append("-");
                sb.append((score >> 8) & 255);
                sb.append("-");
                sb.append((score >> 16) & 255);
                sb.append(">.bmp");
                FileOutputStream fileOutStream = new FileOutputStream(new File(sb.toString()));
                fileOutStream.write(grayBitmapHeader);
                for (int i3 = 0; i3 < row; i3++) {
                    try {
                        fileOutStream.write(pData, ((row - i3) - 1) * colume, colume);
                        if (colume_t > colume) {
                            fileOutStream.write(pad, 0, colume_t - colume);
                        }
                    } catch (FileNotFoundException e5) {
                        e = e5;
                        e.printStackTrace();
                        return 0;
                    } catch (IOException e6) {
                        e2 = e6;
                        e2.printStackTrace();
                        return 0;
                    }
                }
                fileOutStream.close();
            } catch (FileNotFoundException e7) {
                e = e7;
                e.printStackTrace();
                return 0;
            } catch (IOException e8) {
                e2 = e8;
                e2.printStackTrace();
                return 0;
            }
        } catch (FileNotFoundException e9) {
            e = e9;
            e.printStackTrace();
            return 0;
        } catch (IOException e10) {
            e2 = e10;
            e2.printStackTrace();
            return 0;
        }
        return 0;
    }

    private class MyHandler extends Handler {
        private MyHandler(Context context) {
            super(context.getMainLooper());
        }

        private Bitmap convertToBitmap(byte[] result, int width, int height) {
            Log.d(GoodixFingerprintManagerExt.TAG, "convertToBitmap width=" + width + ",height=" + height + " data=" + result);
            int length = width * height;
            int[] display = new int[length];
            for (int i = 0; i < length; i++) {
                int pixel = result[i] & UnsignedBytes.MAX_VALUE;
                display[i] = -16777216 | (pixel << 16) | (pixel << 8) | pixel;
            }
            return Bitmap.createBitmap(display, width, height, Bitmap.Config.ARGB_8888);
        }

        public void handleMessage(Message msg) {
            int result;
            switch (msg.what) {
                case 100:
                    if (GoodixFingerprintManagerExt.this.mUntrustedEnrollmentCallback != null) {
                        GoodixFingerprintManagerExt.this.mUntrustedEnrollmentCallback.onEnrollmentProgress(msg.arg1, msg.arg2);
                        return;
                    } else {
                        Log.d(GoodixFingerprintManagerExt.TAG, "MSG_ENROLL_RESULT no callback");
                        return;
                    }
                case 101:
                    Log.d(GoodixFingerprintManagerExt.TAG, "MSG_ACQUIRED sGoodixManager = " + GoodixFingerprintManagerExt.sGoodixManager);
                    if (GoodixFingerprintManagerExt.this.mUntrustedEnrollmentCallback != null) {
                        GoodixFingerprintManagerExt.this.mUntrustedEnrollmentCallback.onEnrollmentAcquired(msg.arg1);
                        GoodixFingerprintManagerExt.this.getAcquiredString(msg.arg1);
                        return;
                    } else if (GoodixFingerprintManagerExt.this.mUntrustedAuthenticationCallback != null) {
                        GoodixFingerprintManagerExt.this.mUntrustedAuthenticationCallback.onAuthenticationAcquired(msg.arg1);
                        return;
                    } else {
                        Log.d(GoodixFingerprintManagerExt.TAG, "MSG_ACQUIRED no callback");
                        return;
                    }
                case 102:
                    if (GoodixFingerprintManagerExt.this.mUntrustedAuthenticationCallback != null) {
                        GoodixFingerprintManagerExt.this.mUntrustedAuthenticationCallback.onAuthenticationSucceeded(msg.arg1);
                        return;
                    } else {
                        Log.d(GoodixFingerprintManagerExt.TAG, "MSG_AUTHENTICATION_SUCCEEDED no callback");
                        return;
                    }
                case 103:
                    if (GoodixFingerprintManagerExt.this.mUntrustedAuthenticationCallback != null) {
                        GoodixFingerprintManagerExt.this.mUntrustedAuthenticationCallback.onAuthenticationFailed();
                        return;
                    } else {
                        Log.d(GoodixFingerprintManagerExt.TAG, "mUntrustedAuthenticationCallback no callback");
                        return;
                    }
                case 104:
                    if (GoodixFingerprintManagerExt.this.mUntrustedEnrollmentCallback != null) {
                        GoodixFingerprintManagerExt.this.mUntrustedEnrollmentCallback.onEnrollmentError(msg.arg1, GoodixFingerprintManagerExt.this.getErrorString(msg.arg1));
                        return;
                    } else if (GoodixFingerprintManagerExt.this.mUntrustedAuthenticationCallback != null) {
                        GoodixFingerprintManagerExt.this.mUntrustedAuthenticationCallback.onAuthenticationError(msg.arg1, GoodixFingerprintManagerExt.this.getErrorString(msg.arg1));
                        return;
                    } else if (GoodixFingerprintManagerExt.this.mUntrustedRemovalCallback != null) {
                        GoodixFingerprintManagerExt.this.mUntrustedRemovalCallback.onRemovalError(msg.arg1, GoodixFingerprintManagerExt.this.getErrorString(msg.arg1));
                        return;
                    } else {
                        Log.d(GoodixFingerprintManagerExt.TAG, "MSG_ACQUIRED no callback");
                        return;
                    }
                case 105:
                    if (GoodixFingerprintManagerExt.this.mUntrustedRemovalCallback != null) {
                        GoodixFingerprintManagerExt.this.mUntrustedRemovalCallback.onRemovalSucceeded(msg.arg1);
                        return;
                    }
                    return;
                case 106:
                    if (GoodixFingerprintManagerExt.this.mUntrustedEnrollmentCallback != null) {
                        GoodixFingerprintManagerExt.this.mUntrustedEnrollmentCallback.onEnrollmentResultInfo((GoodixEnrollInfo) msg.obj);
                        return;
                    } else {
                        Log.d(GoodixFingerprintManagerExt.TAG, "MSG_ENROLL_RESULT no callback");
                        return;
                    }
                case 107:
                    if (GoodixFingerprintManagerExt.this.mUntrustedEnrollmentCallback != null) {
                        Log.d(GoodixFingerprintManagerExt.TAG, "MSG_ENROLL_SEC_RAW_BMP_RESULT  callback");
                        GoodixFingerprintManagerExt.this.mUntrustedEnrollmentCallback.onEnrollmentCaptureRawBmpInfo(msg.arg1, msg.arg2, (Bitmap) msg.obj);
                        return;
                    }
                    Log.d(GoodixFingerprintManagerExt.TAG, "MSG_ENROLL_SEC_RAW_BMP_RESULT no callback");
                    return;
                case 108:
                    GoodixImageInfo captureInfo = (GoodixImageInfo) msg.obj;
                    if (GoodixFingerprintManagerExt.this.mUntrustedEnrollmentCallback != null) {
                        Log.d(GoodixFingerprintManagerExt.TAG, "MSG_ENROLL_SEC_BMP_RESULT  callback");
                        GoodixFingerprintManagerExt.this.mUntrustedEnrollmentCallback.onEnrollmentCaptureBmpResult(captureInfo);
                        return;
                    } else if (GoodixFingerprintManagerExt.this.mUntrustedAuthenticationCallback != null) {
                        GoodixFingerprintManagerExt.this.mUntrustedAuthenticationCallback.onAuthenticationCaptureBmpResult(captureInfo);
                        return;
                    } else {
                        Log.d(GoodixFingerprintManagerExt.TAG, "MSG_ENROLL_SEC_BMP_RESULT no callback");
                        return;
                    }
                case 1000:
                    Log.d(GoodixFingerprintManagerExt.TAG, "MSG_TEST sGoodixManager = " + GoodixFingerprintManagerExt.sGoodixManager);
                    Log.e(GoodixFingerprintManagerExt.TAG, "MSG_TEST, mTestCallback = " + GoodixFingerprintManagerExt.mTestCallback);
                    if (GoodixFingerprintManagerExt.mTestCallback != null) {
                        HashMap<Integer, Object> testResult = TestResultParser.parser((byte[]) msg.obj);
                        if (testResult.containsKey(200)) {
                            String algoVersion = (String) testResult.get(200);
                            GoodixSharePref.getInstance().init(GoodixFingerprintManagerExt.this.mContext);
                            GoodixSharePref.getInstance().putString("200", algoVersion);
                        }
                        GoodixFingerprintManagerExt.mTestCallback.onTestCmd(msg.arg1, testResult);
                        return;
                    }
                    return;
                case 1002:
                    if (GoodixFingerprintManagerExt.this.mDumpCallback != null) {
                        GoodixFingerprintManagerExt.this.mDumpCallback.onDump(msg.arg1, TestResultParser.parser((byte[]) msg.obj));
                        return;
                    }
                    return;
                case 1003:
                    if (GoodixFingerprintManagerExt.this.mAuthenticateFidoCallback != null) {
                        int fingerId = msg.arg1;
                        byte[] uvtData = (byte[]) msg.obj;
                        if (fingerId != 0 && uvtData != null && uvtData.length > 0) {
                            result = 100;
                        } else if (fingerId == 0) {
                            result = 103;
                        } else if (fingerId == 0 || !(uvtData == null || uvtData.length == 0)) {
                            result = 113;
                        } else {
                            result = 102;
                        }
                        GoodixFingerprintManagerExt.this.mAuthenticateFidoCallback.onResult(result, uvtData, GoodixFingerprintManagerExt.int2bytes(fingerId));
                        return;
                    }
                    Log.e(GoodixFingerprintManagerExt.TAG, "handleMessage, mAuthenticateFidoCallback is null");
                    return;
                default:
                    return;
            }
        }
    }

    private static int byte2int(byte[] res) {
        return (res[0] & UnsignedBytes.MAX_VALUE) | ((res[1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK) | ((res[2] << 24) >>> 8) | (res[3] << 24);
    }

    public static byte[] int2bytes(int res) {
        return new byte[]{(byte) (res & 255), (byte) ((res >> 8) & 255), (byte) ((res >> 16) & 255), (byte) (res >>> 24)};
    }

    public static int bytes2int(byte[] res) {
        return (res[0] & UnsignedBytes.MAX_VALUE) | ((res[1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK) | ((res[2] << 24) >>> 8) | (res[3] << 24);
    }

    public void startUntouchTest() {
        Log.d(TAG, "startUntouchTest");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService != null) {
            gFService.startUntouchTest();
        }
    }

    public void startTouchPrepareTest() {
        Log.d(TAG, "startTouchPrepareTest");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService != null) {
            gFService.startTouchPrepareTest();
        }
    }

    public void startTouchTest() {
        Log.d(TAG, "startTouchTest");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService != null) {
            gFService.startTouchTest();
        }
    }

    public void startOtpCheckTest() {
        Log.d(TAG, "startOtpCheckTest");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService != null) {
            gFService.startOtpCheckTest();
        }
    }

    public void startSensorInfoTest() {
        Log.d(TAG, "startSensorInfoTest");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService != null) {
            gFService.startSensorInfoTest();
        }
    }

    public String startGetVersion() {
        Log.d(TAG, "startGetVersion");
        GFService gFService = this.mIGoodixFingerprintInterface;
        if (gFService != null) {
            return gFService.startGetVersion();
        }
        return "";
    }
}
