package com.goodix.display.fingerprint.ext;

import android.content.Context;
import android.graphics.Bitmap;
import android.os.CancellationSignal;
import android.os.Handler;
import android.support.v4.os.EnvironmentCompat;
import android.support.v4.view.MotionEventCompat;
import android.util.Log;
import com.goodix.display.fingerprint.sec.GoodixFpCaptureInfo;
import com.goodix.display.fingerprint.sec.GoodixFpEnrollStatus;
import com.goodix.display.fingerprint.sec.GoodixFpIdentifyResult;
import com.goodix.display.fingerprint.sec.GoodixFpRemoveInfo;
import com.goodix.fingerprint.GFDelmarConfig;
import com.goodix.fingerprint.ShenzhenConstants;
import com.goodix.fingerprint.service.EventData;
import com.goodix.fingerprint.service.GoodixFingerprintManager;
import com.goodix.fingerprint.utils.TestParamEncoder;
import com.google.common.primitives.UnsignedBytes;
import java.util.HashMap;
import java.util.List;

public class ExtGoodixFpManager {
    private static final int ENROLL_STATE_PAUSE = 1;
    private static final int ENROLL_STATE_RESUME = 0;
    private static final int GF_FINGERPRINT_HIDE_PREVIEW = 2;
    private static final int GF_FINGERPRINT_PREVIEW_WINDOW_SIZE = 3;
    private static final int GF_FINGERPRINT_SHOW_PREVIEW = 1;
    private static final int STATE_ENROLL = 1;
    private static final int STATE_IDENTIFY = 2;
    private static final int STATE_IDLE = 0;
    private static final String TAG = "ExtGoodixFpManager";
    private static HashMap<Integer, String> mChipInfo = new HashMap<>();
    private static int mCurState = 0;
    private static int mEnrollBadTrial = 0;
    private static int mEnrollFingerId;
    private static int mEnrollProgress = 0;
    private static int mEnrollState = 0;
    private static int mEnrollSuccessTrial = 0;
    private static int mEnrollingGroupId = -1;
    private static int mEnrollingIndex = -1;
    private static String mEnrollingUserId = null;
    private int MAX_ENROLL_TEMPLATE;
    private GoodixFingerprintManager.UntrustedAuthenticationCallback mAuthenticateCallback = new GoodixFingerprintManager.UntrustedAuthenticationCallback() {
        /* class com.goodix.display.fingerprint.ext.ExtGoodixFpManager.AnonymousClass4 */

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedAuthenticationCallback
        public void onAuthenticationError(int errorCode, CharSequence errString) {
            Log.d(ExtGoodixFpManager.TAG, "onAuthenticationError errorCode=" + errorCode);
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedAuthenticationCallback
        public void onAuthenticationHelp(int helpCode, CharSequence helpString) {
            Log.d(ExtGoodixFpManager.TAG, "onAuthenticationHelp helpCode=" + helpCode);
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedAuthenticationCallback
        public void onAuthenticationSucceeded(int fingerId) {
            Log.d(ExtGoodixFpManager.TAG, "onAuthenticationSucceeded fingerId=" + fingerId);
            ExtGoodixFpManager.this.mIndentifyResult = new GoodixFpIdentifyResult();
            ExtGoodixFpManager.this.mIndentifyResult.userId = ExtGoodixFpManager.this.mIdentifyUserID;
            ExtGoodixFpManager.this.mFpUserState.loadFingerprintsForUser(ExtGoodixFpManager.this.mIndentifyResult.userId);
            ExtGoodixFpManager.this.mIndentifyResult.index = ExtGoodixFpManager.this.mFpUserState.getIndexByFingerID(fingerId);
            ExtGoodixFpManager.this.mIndentifyResult.indexes = new int[1];
            ExtGoodixFpManager.this.mIndentifyResult.indexes[0] = fingerId;
            ExtGoodixFpManager.this.mFpEventListener.onEvent(6001, ExtGoodixFpManager.this.mIndentifyResult);
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedAuthenticationCallback
        public void onAuthenticationFailed() {
            Log.d(ExtGoodixFpManager.TAG, "onAuthenticationFailed");
        }

        public void onAuthenticationCaptureBmpResult(GoodixImageInfo captureInfo) {
            Log.d(ExtGoodixFpManager.TAG, "onAuthenticationCaptureBmpResult CaptureSuccess ..... ");
            ExtGoodixFpManager.this.mAuthenticateCaptureInfo = new GoodixFpCaptureInfo();
            ExtGoodixFpManager.this.mAuthenticateCaptureInfo.bitmap = captureInfo.bmp;
            ExtGoodixFpManager.this.mAuthenticateCaptureInfo.rawbitmap = captureInfo.rawBmp;
            ExtGoodixFpManager.this.mAuthenticateCaptureInfo.width = captureInfo.width;
            ExtGoodixFpManager.this.mAuthenticateCaptureInfo.height = captureInfo.height;
            ExtGoodixFpManager.this.mAuthenticateCaptureInfo.quality = captureInfo.imgQuality;
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedAuthenticationCallback
        public void onAuthenticationAcquired(int acquireInfo) {
            switch (acquireInfo) {
                case 4001:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_READY = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4001, null);
                    return;
                case 4002:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_STARTED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4002, null);
                    return;
                case 4003:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_COMPLETED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4003, null);
                    return;
                case 4004:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_SUCCESS = " + acquireInfo);
                    ExtGoodixFpManager.access$508();
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4004, ExtGoodixFpManager.this.mAuthenticateCaptureInfo);
                    return;
                case 4005:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_FAILED = " + acquireInfo);
                    ExtGoodixFpManager.access$408();
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4005, ExtGoodixFpManager.this.mAuthenticateCaptureInfo);
                    return;
                case 4006:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_FINGER_LEAVED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4006, null);
                    if (GoodixSharePref.getInstance().getBoolean("enable_mt_flag", false)) {
                        ExtGoodixFpManager.this.controlDevice(0);
                        return;
                    }
                    return;
                case 6001:
                default:
                    return;
                case 6002:
                case 6103:
                case 6104:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired IDENTIFY_FAILED = " + acquireInfo);
                    ExtGoodixFpManager.this.mIndentifyResult = new GoodixFpIdentifyResult();
                    ExtGoodixFpManager.this.mIndentifyResult.userId = ExtGoodixFpManager.this.mIdentifyUserID;
                    ExtGoodixFpManager.this.mIndentifyResult.index = -1;
                    ExtGoodixFpManager.this.mIndentifyResult.indexes = new int[1];
                    ExtGoodixFpManager.this.mIndentifyResult.indexes[0] = ExtGoodixFpManager.this.mIndentifyResult.index;
                    if (acquireInfo == 6002) {
                        ExtGoodixFpManager.this.mIndentifyResult.result = 6103;
                        ExtGoodixFpManager.this.mFpEventListener.onEvent(6002, ExtGoodixFpManager.this.mIndentifyResult);
                        return;
                    }
                    ExtGoodixFpManager.this.mIndentifyResult.result = acquireInfo;
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(6002, ExtGoodixFpManager.this.mIndentifyResult);
                    return;
            }
        }
    };
    private GoodixFpCaptureInfo mAuthenticateCaptureInfo;
    private CancellationSignal mAuthenticationCancel;
    private boolean mCaptureDone = false;
    private Context mContext;
    private int mCurrentGroupId = -1;
    private GFDelmarConfig mDelmarConfig;
    private GoodixFpCaptureInfo mEnrollCaptureInfo;
    private GoodixFpEnrollStatus mEnrollStatus;
    private CancellationSignal mEnrollmentCancel;
    private GoodixEventListener mFpEventListener = null;
    private GoodixFpsUserState mFpUserState;
    private GoodixFingerprintManager mGoodixFingerprintManager = null;
    private Handler mHandler;
    private String mIdentifyUserID = null;
    private GoodixFpIdentifyResult mIndentifyResult;
    private GoodixFingerprintManager.UntrustedRemovalCallback mRemoveCallback = new GoodixFingerprintManager.UntrustedRemovalCallback() {
        /* class com.goodix.display.fingerprint.ext.ExtGoodixFpManager.AnonymousClass1 */

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedRemovalCallback
        public void onRemovalError(int errMsgId, CharSequence errString) {
            Log.d(ExtGoodixFpManager.TAG, "onRemovalError errMsgId = " + errMsgId + ", groupId = " + ExtGoodixFpManager.this.mCurrentGroupId);
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedRemovalCallback
        public void onRemovalSucceeded(int fingerId, int groupId, int templateRemain) {
            Log.d(ExtGoodixFpManager.TAG, "onRemovalSucceeded fingerId = " + fingerId + ", groupId = " + ExtGoodixFpManager.this.mCurrentGroupId);
        }
    };
    private GoodixFingerprintManager.UntrustedEnrollmentCallback mUntrustEnrollCallback = new GoodixFingerprintManager.UntrustedEnrollmentCallback() {
        /* class com.goodix.display.fingerprint.ext.ExtGoodixFpManager.AnonymousClass2 */

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedEnrollmentCallback
        public void onEnrollmentError(int errMsgId, CharSequence errString) {
            super.onEnrollmentError(errMsgId, errString);
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedEnrollmentCallback
        public void onEnrollmentHelp(int helpMsgId, CharSequence helpString) {
            super.onEnrollmentHelp(helpMsgId, helpString);
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedEnrollmentCallback
        public void onEnrollmentProgress(int fingerId, int remaining) {
            int progress = ((ExtGoodixFpManager.this.MAX_ENROLL_TEMPLATE - remaining) * 100) / ExtGoodixFpManager.this.MAX_ENROLL_TEMPLATE;
            Log.d(ExtGoodixFpManager.TAG, "onEnrollmentProgress fingerId = " + fingerId + "  progress=" + progress + " , remaining =" + remaining);
            int unused = ExtGoodixFpManager.mEnrollFingerId = fingerId;
            if (ExtGoodixFpManager.this.mEnrollStatus != null) {
                ExtGoodixFpManager.this.mEnrollStatus.progress = progress;
                ExtGoodixFpManager.this.mEnrollStatus.badTrial = ExtGoodixFpManager.mEnrollBadTrial;
                ExtGoodixFpManager.this.mEnrollStatus.successTrial = ExtGoodixFpManager.mEnrollSuccessTrial;
                ExtGoodixFpManager.this.mEnrollStatus.totalTrial = ExtGoodixFpManager.mEnrollBadTrial + ExtGoodixFpManager.mEnrollSuccessTrial;
                ExtGoodixFpManager.this.mFpEventListener.onEvent(5001, ExtGoodixFpManager.this.mEnrollStatus);
                if (progress == 100) {
                    ExtGoodixFpManager.this.mFpUserState.addFingerprint(ExtGoodixFpManager.mEnrollingUserId, ExtGoodixFpManager.mEnrollingIndex, ExtGoodixFpManager.mEnrollFingerId, ExtGoodixFpManager.mEnrollingGroupId);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(5002, null);
                }
            }
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedEnrollmentCallback
        public void onEnrollImage(byte[] bmpData, int bmpW, int bmpH, byte[] weakData, int weakW, int weakH, int imageQuality) {
            Log.d(ExtGoodixFpManager.TAG, "onEnrollImage bmpW = " + bmpW + " bmpH = " + bmpH + " weakW = " + weakW + " weakH =" + weakH);
            if (bmpW > 0 && bmpH > 0) {
                ExtGoodixFpManager.this.mEnrollCaptureInfo = new GoodixFpCaptureInfo();
                ExtGoodixFpManager.this.mEnrollCaptureInfo.bitmap = Util.convertToBitmap(bmpData, bmpW, bmpH, 0);
                ExtGoodixFpManager.this.mEnrollCaptureInfo.width = bmpW;
                ExtGoodixFpManager.this.mEnrollCaptureInfo.height = bmpH;
                ExtGoodixFpManager.this.mEnrollCaptureInfo.quality = imageQuality;
                Log.d(ExtGoodixFpManager.TAG, "onEnrollImage mEnrollCaptureInfo.quality = " + ExtGoodixFpManager.this.mEnrollCaptureInfo.quality);
                ExtGoodixFpManager.this.mEnrollStatus = new GoodixFpEnrollStatus();
                ExtGoodixFpManager.this.mEnrollStatus.badTrial = ExtGoodixFpManager.mEnrollBadTrial;
                ExtGoodixFpManager.this.mEnrollStatus.successTrial = ExtGoodixFpManager.mEnrollSuccessTrial;
                ExtGoodixFpManager.this.mEnrollStatus.totalTrial = ExtGoodixFpManager.mEnrollBadTrial + ExtGoodixFpManager.mEnrollSuccessTrial;
                ExtGoodixFpManager.this.mEnrollStatus.coverageBitmap = Util.convertToBitmap(bmpData, bmpW, bmpH, 0);
            }
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedEnrollmentCallback
        public void onEnrollmentAcquired(int acquireInfo) {
            Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired acquireInfo = " + acquireInfo);
            switch (acquireInfo) {
                case 4001:
                    Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired CAPTURE_READY = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4001, null);
                    return;
                case 4002:
                    Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired CAPTURE_STARTED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4002, null);
                    return;
                case 4003:
                    Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired CAPTURE_COMPLETED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4003, null);
                    return;
                case 4004:
                    Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired CAPTURE_SUCCESS = " + acquireInfo);
                    ExtGoodixFpManager.access$508();
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4004, ExtGoodixFpManager.this.mEnrollCaptureInfo);
                    return;
                case 4005:
                    Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired CAPTURE_FAILED = " + acquireInfo);
                    ExtGoodixFpManager.access$408();
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4005, ExtGoodixFpManager.this.mEnrollCaptureInfo);
                    return;
                case 4006:
                    Log.d(ExtGoodixFpManager.TAG, "onEnrollmentAcquired CAPTURE_FINGER_LEAVED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4006, null);
                    if (GoodixSharePref.getInstance().getBoolean("enable_mt_flag", false)) {
                        ExtGoodixFpManager.this.controlDevice(0);
                        return;
                    }
                    return;
                default:
                    return;
            }
        }
    };
    private GoodixFingerprintManager.UntrustedAuthenticationCallback mVerifyCallback = new GoodixFingerprintManager.UntrustedAuthenticationCallback() {
        /* class com.goodix.display.fingerprint.ext.ExtGoodixFpManager.AnonymousClass3 */

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedAuthenticationCallback
        public void onAuthenticationError(int errorCode, CharSequence errString) {
            super.onAuthenticationError(errorCode, errString);
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedAuthenticationCallback
        public void onAuthenticationHelp(int helpCode, CharSequence helpString) {
            super.onAuthenticationHelp(helpCode, helpString);
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedAuthenticationCallback
        public void onAuthenticationSucceeded(int fingerId) {
            ExtGoodixFpManager.this.mIndentifyResult = new GoodixFpIdentifyResult();
            ExtGoodixFpManager.this.mIndentifyResult.userId = ExtGoodixFpManager.this.mIdentifyUserID;
            ExtGoodixFpManager.this.mFpUserState.loadFingerprintsForUser(ExtGoodixFpManager.this.mIndentifyResult.userId);
            ExtGoodixFpManager.this.mIndentifyResult.index = ExtGoodixFpManager.this.mFpUserState.getIndexByFingerID(fingerId);
            ExtGoodixFpManager.this.mIndentifyResult.indexes = new int[1];
            ExtGoodixFpManager.this.mIndentifyResult.indexes[0] = fingerId;
            ExtGoodixFpManager.this.mFpEventListener.onEvent(6001, ExtGoodixFpManager.this.mIndentifyResult);
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedAuthenticationCallback
        public void onAuthenticateImage(byte[] bmpData, int bmpW, int bmpH, byte[] weakData, int weakW, int weakH, int imageQuality) {
            super.onAuthenticateImage(bmpData, bmpW, bmpH, weakData, weakW, weakH, imageQuality);
            Log.d(ExtGoodixFpManager.TAG, "onAuthenticateImage bmpW = " + bmpW + " bmpH = " + bmpH);
            if (bmpW > 0 && bmpH > 0) {
                ExtGoodixFpManager.this.mAuthenticateCaptureInfo = new GoodixFpCaptureInfo();
                ExtGoodixFpManager.this.mAuthenticateCaptureInfo.bitmap = Util.convertToBitmap(bmpData, bmpW, bmpH, 0);
                ExtGoodixFpManager.this.mAuthenticateCaptureInfo.width = bmpW;
                ExtGoodixFpManager.this.mAuthenticateCaptureInfo.height = bmpH;
                ExtGoodixFpManager.this.mAuthenticateCaptureInfo.quality = imageQuality;
            }
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedAuthenticationCallback
        public void onAuthenticationFailed() {
        }

        @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.UntrustedAuthenticationCallback
        public void onAuthenticationAcquired(int acquireInfo) {
            switch (acquireInfo) {
                case 4001:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_READY = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4001, null);
                    return;
                case 4002:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_STARTED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4002, null);
                    return;
                case 4003:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_COMPLETED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4003, null);
                    return;
                case 4004:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_SUCCESS = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4004, ExtGoodixFpManager.this.mAuthenticateCaptureInfo);
                    return;
                case 4005:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_FAILED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4005, ExtGoodixFpManager.this.mAuthenticateCaptureInfo);
                    return;
                case 4006:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired CAPTURE_FINGER_LEAVED = " + acquireInfo);
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(4006, null);
                    if (GoodixSharePref.getInstance().getBoolean("enable_mt_flag", false)) {
                        ExtGoodixFpManager.this.controlDevice(0);
                        return;
                    }
                    return;
                case 6001:
                default:
                    return;
                case 6002:
                case 6103:
                case 6104:
                    Log.d(ExtGoodixFpManager.TAG, "onAuthenticationAcquired IDENTIFY_FAILED = " + acquireInfo);
                    ExtGoodixFpManager.this.mIndentifyResult = new GoodixFpIdentifyResult();
                    ExtGoodixFpManager.this.mIndentifyResult.userId = ExtGoodixFpManager.this.mIdentifyUserID;
                    ExtGoodixFpManager.this.mIndentifyResult.index = -1;
                    ExtGoodixFpManager.this.mIndentifyResult.indexes = new int[1];
                    ExtGoodixFpManager.this.mIndentifyResult.indexes[0] = ExtGoodixFpManager.this.mIndentifyResult.index;
                    if (acquireInfo == 6002) {
                        ExtGoodixFpManager.this.mIndentifyResult.result = 6103;
                        ExtGoodixFpManager.this.mFpEventListener.onEvent(6002, ExtGoodixFpManager.this.mIndentifyResult);
                        return;
                    }
                    ExtGoodixFpManager.this.mIndentifyResult.result = acquireInfo;
                    ExtGoodixFpManager.this.mFpEventListener.onEvent(6002, ExtGoodixFpManager.this.mIndentifyResult);
                    return;
            }
        }
    };

    static /* synthetic */ int access$408() {
        int i = mEnrollBadTrial;
        mEnrollBadTrial = i + 1;
        return i;
    }

    static /* synthetic */ int access$508() {
        int i = mEnrollSuccessTrial;
        mEnrollSuccessTrial = i + 1;
        return i;
    }

    public ExtGoodixFpManager(Context context) {
        this.mContext = context;
        Log.d(TAG, "mContext = " + this.mContext);
        this.mGoodixFingerprintManager = GoodixFingerprintManager.getFingerprintManager(context);
        this.mFpUserState = new GoodixFpsUserState(this.mContext);
        GoodixSharePref.getInstance().init(context);
        this.mHandler = new Handler();
        this.MAX_ENROLL_TEMPLATE = this.mGoodixFingerprintManager.getShenzhenConfig().mEnrollMinTemplateCount;
        Log.d(TAG, "MAX_ENROLL_TEMPLATE = " + this.MAX_ENROLL_TEMPLATE);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void controlDevice(int flag) {
    }

    public String[] getUserIdList() {
        Log.d(TAG, "getUserIdList");
        String[] userId = null;
        List<GoodixUserInfo> uis = this.mFpUserState.getUserInfo();
        Log.d(TAG, "getUserIdList uis.size()=" + uis.size());
        if (uis.size() > 0) {
            userId = new String[uis.size()];
            for (int i = 0; i < uis.size(); i++) {
                userId[i] = uis.get(i).getUserId().toString();
                Log.d(TAG, "getUserIdList userId[" + i + "]=" + userId[i]);
            }
        }
        return userId;
    }

    public int enroll(String userId, int index) {
        Log.d(TAG, "enroll");
        mCurState = 1;
        mEnrollState = 0;
        mEnrollingIndex = index;
        mEnrollBadTrial = 0;
        mEnrollSuccessTrial = 0;
        mEnrollingUserId = userId;
        controlDevice(1);
        if (GoodixSharePref.getInstance().getBoolean("enable_mt_flag", false)) {
            mEnrollingGroupId = this.mFpUserState.addUserInfo(userId);
            Log.d(TAG, "MT enroll mEnrollingGroupId=" + mEnrollingGroupId);
            setActiveGroup(10000);
        } else {
            if (this.mFpUserState.isUserIdExist(userId)) {
                mEnrollingGroupId = this.mFpUserState.getGroupIdForUser(userId);
            } else {
                mEnrollingGroupId = this.mFpUserState.addUserInfo(userId);
            }
            Log.d(TAG, "enroll mEnrollingGroupId=" + mEnrollingGroupId);
            int i = mEnrollingGroupId;
            if (i >= 0) {
                setActiveGroup(i);
            }
            Log.d(TAG, "after setActiveGroup");
        }
        CancellationSignal cancellationSignal = new CancellationSignal();
        this.mEnrollmentCancel = cancellationSignal;
        this.mGoodixFingerprintManager.untrustedEnroll(cancellationSignal, this.mUntrustEnrollCallback);
        Log.w(TAG, "mUntrustedEnrollmentCallback = " + this.mUntrustEnrollCallback);
        return 0;
    }

    public int identify(String userId) {
        int groupId;
        Log.d(TAG, "identify");
        mCurState = 2;
        this.mIdentifyUserID = userId;
        this.mFpUserState.getFingerprints(userId);
        controlDevice(1);
        if (GoodixSharePref.getInstance().getBoolean("enable_mt_flag", false)) {
            int groupId2 = this.mFpUserState.addUserInfo(userId);
            Log.d(TAG, "MT identify groupId=" + groupId2);
            setActiveGroup(10000);
        } else {
            if (this.mFpUserState.isUserIdExist(userId)) {
                groupId = this.mFpUserState.getGroupIdForUser(userId);
            } else {
                groupId = this.mFpUserState.addUserInfo(userId);
            }
            Log.d(TAG, "identify groupId=" + groupId);
            if (groupId >= 0) {
                setActiveGroup(groupId);
            }
        }
        CancellationSignal cancellationSignal = new CancellationSignal();
        this.mAuthenticationCancel = cancellationSignal;
        this.mGoodixFingerprintManager.untrustedAuthenticate(cancellationSignal, this.mVerifyCallback);
        Log.w(TAG, "mUntrustedAuthenticationCallback = " + this.mVerifyCallback);
        return 0;
    }

    public int cancel() {
        CancellationSignal cancellationSignal;
        Log.d(TAG, "cancel");
        int i = mCurState;
        if (i == 1) {
            CancellationSignal cancellationSignal2 = this.mEnrollmentCancel;
            if (cancellationSignal2 != null && !cancellationSignal2.isCanceled()) {
                Log.d(TAG, "cancel enrollment");
                this.mEnrollmentCancel.cancel();
                this.mFpEventListener.onEvent(5003, 5101);
                this.mEnrollmentCancel = null;
            }
            mEnrollState = 0;
        } else if (i == 2 && (cancellationSignal = this.mAuthenticationCancel) != null && !cancellationSignal.isCanceled()) {
            Log.d(TAG, "cancel identification");
            this.mAuthenticationCancel.cancel();
            GoodixFpIdentifyResult identifyResult = new GoodixFpIdentifyResult();
            identifyResult.userId = this.mIdentifyUserID;
            identifyResult.index = -1;
            identifyResult.indexes = new int[1];
            identifyResult.indexes[0] = -1;
            identifyResult.result = 6101;
            this.mFpEventListener.onEvent(6002, identifyResult);
            this.mAuthenticationCancel = null;
        }
        this.mIdentifyUserID = null;
        mCurState = 0;
        controlDevice(0);
        return 0;
    }

    public void enableMT(boolean enable) {
        GoodixSharePref.getInstance().init(this.mContext);
        GoodixSharePref.getInstance().putBoolean("enable_mt_flag", enable);
    }

    private void setActiveGroup(int groupId) {
        this.mCurrentGroupId = groupId;
        this.mGoodixFingerprintManager.setActiveGroup(groupId);
    }

    public void setEventListener(GoodixEventListener listener) {
        Log.d(TAG, "setEventListener");
        this.mFpEventListener = listener;
    }

    public String getVersion() {
        return "";
    }

    public int setEnrollSession(boolean flag) {
        return 0;
    }

    public int release() {
        return 0;
    }

    public int setAccuracyLevel(int level) {
        return 0;
    }

    public int[] getFingerprintIndexList(String userId) {
        Log.d(TAG, "getFingerprintIndexList");
        List<GoodixFpInfo> fps = this.mFpUserState.getFingerprints(userId);
        int[] fpIndex = null;
        Log.d(TAG, "getFingerprintIndexList fps.size()=" + fps.size());
        if (fps.size() > 0) {
            fpIndex = new int[fps.size()];
            for (int i = 0; i < fps.size(); i++) {
                fpIndex[i] = fps.get(i).getFingerIndex();
                Log.d(TAG, "getFingerprintIndexList fpIndex[" + i + "]=" + fpIndex[i]);
            }
        }
        return fpIndex;
    }

    public int getEnrollRepeatCount() {
        Log.d(TAG, "getEnrollRepeatCount");
        return 20;
    }

    public byte[] getFingerprintId(String userId, int index) {
        Log.d(TAG, "getFingerprintId");
        List<GoodixFpInfo> fps = this.mFpUserState.getFingerprints(userId);
        byte[] fid = null;
        if (fps.size() > 0) {
            for (int i = 0; i < fps.size(); i++) {
                if (index == fps.get(i).getFingerIndex()) {
                    int fingerId = fps.get(i).getFingerId();
                    Log.d(TAG, "getFingerprintId fingerId = " + fingerId);
                    fid = int2bytes(fingerId);
                }
            }
        }
        return fid;
    }

    public void remove(String userId, int index) {
        Log.d(TAG, "remove userId=" + userId + " index =" + index);
        byte[] fid = getFingerprintId(userId, index);
        if (fid != null) {
            int fingerId = byte2int(fid);
            int groupId = this.mFpUserState.getGroupIdForUser(userId);
            Log.d(TAG, "remove userId=" + userId);
            Log.d(TAG, "remove index=" + index);
            Log.d(TAG, "remove fid=" + fid);
            Log.d(TAG, "remove fingerId=" + fingerId);
            Log.d(TAG, "remove groupId=" + groupId);
            this.mGoodixFingerprintManager.setActiveGroup(groupId);
            byte[] byteArray = new byte[8];
            TestParamEncoder.encodeInt32(byteArray, 0, 1305, fingerId);
            Log.d(TAG, "remove fingerId = " + fingerId);
            this.mGoodixFingerprintManager.untrustedRemove(ShenzhenConstants.CMD_TEST_SZ_DELETE_UNTRUSTED_ENROLLED_FINGER, byteArray, this.mRemoveCallback);
            this.mFpUserState.removeFingerprint(userId, index);
            GoodixFpRemoveInfo removeInfo = new GoodixFpRemoveInfo();
            removeInfo.userId = userId;
            removeInfo.index = index;
            removeInfo.groupId = this.mCurrentGroupId;
            this.mFpEventListener.onEvent(9005, removeInfo);
            return;
        }
        this.mFpEventListener.onEvent(9006, null);
    }

    public void deleteUserInfo(String userId) {
        this.mFpUserState.deleteUserInfo(userId);
    }

    private static byte[] int2bytes(int res) {
        return new byte[]{(byte) (res & 255), (byte) ((res >> 8) & 255), (byte) ((res >> 16) & 255), (byte) (res >>> 24)};
    }

    private static int byte2int(byte[] res) {
        return (res[0] & UnsignedBytes.MAX_VALUE) | ((res[1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK) | ((res[2] << 24) >>> 8) | (res[3] << 24);
    }

    private String getProperty(String key, String defaultValue) {
        try {
            Class<?> c = Class.forName("android.os.SystemProperties");
            return (String) c.getMethod("get", String.class, String.class).invoke(c, key, EnvironmentCompat.MEDIA_UNKNOWN);
        } catch (Exception e) {
            e.printStackTrace();
            return defaultValue;
        } catch (Throwable th) {
            return defaultValue;
        }
    }

    public int request(int code, Object data) {
        Log.d(TAG, "request() code = " + code);
        EventData eventData = new EventData();
        switch (code) {
            case 8001:
                this.mGoodixFingerprintManager.sendTouchDown(eventData);
                return 0;
            case 8002:
                this.mGoodixFingerprintManager.sendTouchUp();
                return 0;
            default:
                return 0;
        }
    }

    public void setPassword(String userId, byte[] pwdHash) {
        Log.d(TAG, "setPassword");
        new String(pwdHash);
    }

    public void verifyPassword(String userId, byte[] pwdHash) {
        Log.d(TAG, "VerifyPassword");
        new String(pwdHash);
    }

    public String getSensorInfo() {
        Log.d(TAG, "mChipType info =  " + this.mGoodixFingerprintManager.getConfig().mChipType + "  " + mChipInfo.get(Integer.valueOf(this.mGoodixFingerprintManager.getConfig().mChipType)));
        return "gf-cap-" + this.mGoodixFingerprintManager.getConfig().mChipSeries + "-" + mChipInfo.get(Integer.valueOf(this.mGoodixFingerprintManager.getConfig().mChipType));
    }

    public int getSensorStatus() {
        return -1;
    }

    private Bitmap convertDataToBmp(byte[] data, int width, int height) {
        Log.d(TAG, "convertDataToBmp start");
        Log.d(TAG, "convertToBitmap width=" + width + ",height=" + height + " data=" + data);
        int length = width * height;
        int[] display = new int[length];
        for (int i = 0; i < length; i++) {
            int pixel = data[i] & UnsignedBytes.MAX_VALUE;
            display[i] = -16777216 | (pixel << 16) | (pixel << 8) | pixel;
        }
        return Bitmap.createBitmap(display, width, height, Bitmap.Config.ARGB_8888);
    }
}
