package com.goodix.display.fingerprint.insystem;

import android.content.Context;
import android.util.Log;
import com.goodix.fingerprint.ShenzhenConstants;
import com.goodix.fingerprint.service.GoodixFingerprintManager;
import com.goodix.fingerprint.task.ITask;
import com.goodix.fingerprint.task.TaskQueue;
import com.goodix.fingerprint.utils.ShenzhenTestResultParser;
import com.google.common.primitives.UnsignedBytes;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;

public class InSystemTest {
    public static final int AUTO_EXPOSURE = 7;
    public static final int CALIBRATE = 257;
    public static final int CHART = 14;
    public static final int CHIP_ID = 3;
    public static final int DARK_SCREEN = 12;
    public static final int FT_EXIT = 15;
    public static final int FT_INIT = 6;
    public static final int GET_SENSOR_INFO = 258;
    public static final int H_DARK = 10;
    public static final int H_FLESH = 8;
    public static final int IN_SYSTEM_SPEC = 50;
    public static final int L_DARK = 11;
    public static final int L_FLESH = 9;
    public static final int MT_CHECK = 2;
    public static final int NORMAL_SCAN = 256;
    public static final int PRE_CHART = 13;
    public static final int SAVE_DATA = 17;
    public static final int SENSOR_INFO = 16;
    public static final int SNR = 260;
    public static final int SNR_CHART = 19;
    public static final int SPI = 1;
    public static final int SPI_RST = 5;
    public static final int SUBLINE = 259;
    public static final int SUB_LINE = 18;
    public static final int SYSTEM_SPEC = 261;
    private static final String TAG = "InSystemTest";
    public static final int TEST_FAIL = 513;
    public static final int TEST_SUCCESS = 512;
    public static final int UID_CHECK = 4;
    private CalibrationData mCalibrationData;
    private HashMap<Integer, Integer> mCmdParse;
    private int mCurrentStep = -1;
    private int mG3STest = -1;
    private GoodixFingerprintManager mGoodixFingerprintManager;
    private int mNewSubline = -1;
    private NormalScanData mNormalScanData;
    private SublineData mSublineData;
    private TaskQueue mTaskQueue;
    private GoodixFingerprintManager.TestCmdCallback mTestCmdCallback;
    private ITestResultCallback mTestResultCallback;
    private Threshold mThreshold;
    float tNoise = -1.0f;

    public interface ITestResultCallback {
        void onCalibrationData(CalibrationData calibrationData);

        void onCalibrationDataHelp(String str);

        void onInSystemSpec(String str);

        void onNormalScanData(NormalScanData normalScanData);

        void onNormalScanDataHelp(String str);

        void onResult(int i, int i2);

        void onSNRData(SnrData snrData);

        void onSNRDataHelp(String str);

        void onSensorInfo(SensorInfo sensorInfo);

        void onSensorInfoHelp(String str);

        void onSublineData(SublineData sublineData);

        void onSublineDataHelp(String str);
    }

    public InSystemTest(Context context) {
        initCmdParse();
        this.mGoodixFingerprintManager = GoodixFingerprintManager.getFingerprintManager(context);
        AnonymousClass1 r0 = new GoodixFingerprintManager.TestCmdCallback() {
            /* class com.goodix.display.fingerprint.insystem.InSystemTest.AnonymousClass1 */

            @Override // com.goodix.fingerprint.service.GoodixFingerprintManager.TestCmdCallback
            public void onTestCmd(int cmdId, HashMap<Integer, Object> result) {
                Log.d(InSystemTest.TAG, "onTestCmd " + cmdId);
                if (cmdId == -255) {
                    Log.d(InSystemTest.TAG, "onTestCmd FINGERPRINT_ERROR_HW_UNAVAILABLE");
                    switch (InSystemTest.this.mCurrentStep) {
                        case 256:
                            InSystemTest.this.mNormalScanData = new NormalScanData();
                            InSystemTest.this.mTestResultCallback.onNormalScanData(InSystemTest.this.mNormalScanData);
                            InSystemTest.this.mTestResultCallback.onNormalScanDataHelp(((((("" + "Date: " + new SimpleDateFormat("E, dd MMM yyyy HH:mm:ss z").format(new Date()) + "\n") + "MTCheck;0;0;" + InSystemTest.this.mNormalScanData.MTCheck + "\n") + "ChipIDCheck;0;0;" + InSystemTest.this.mNormalScanData.ChipIDCheck + "\n") + "UIDCheck;0;0;" + InSystemTest.this.mNormalScanData.UIDCheck + "\n") + "SPICheck;0;0;" + InSystemTest.this.mNormalScanData.SPICheck + "\n") + "ResetPinCheck;0;0;" + InSystemTest.this.mNormalScanData.ResetPinCheck + "\n");
                            return;
                        case 257:
                            InSystemTest.this.mCalibrationData = new CalibrationData();
                            InSystemTest.this.mTestResultCallback.onCalibrationData(InSystemTest.this.mCalibrationData);
                            InSystemTest inSystemTest = InSystemTest.this;
                            inSystemTest.calibrationResult(inSystemTest.mCalibrationData);
                            return;
                        case InSystemTest.GET_SENSOR_INFO /*{ENCODED_INT: 258}*/:
                            SensorInfo sensorInfor = new SensorInfo();
                            InSystemTest.this.mTestResultCallback.onSensorInfo(sensorInfor);
                            String sensorInfoHelp = (((("" + "Product Id: " + sensorInfor.mProductId + "\n") + "MT Check: " + sensorInfor.mMTCheck + " \n") + "Calibration: " + sensorInfor.mCalibration + "\n") + "Sensor UID: " + sensorInfor.mSensorUid + "\n") + "EFS UID: " + sensorInfor.mEFSUid + "\n";
                            Log.d(InSystemTest.TAG, "onSensorInfo :" + sensorInfoHelp);
                            InSystemTest.this.mTestResultCallback.onSensorInfoHelp(sensorInfoHelp);
                            return;
                        case InSystemTest.SUBLINE /*{ENCODED_INT: 259}*/:
                            InSystemTest.this.mSublineData = new SublineData();
                            InSystemTest.this.mTestResultCallback.onSublineData(InSystemTest.this.mSublineData);
                            InSystemTest inSystemTest2 = InSystemTest.this;
                            inSystemTest2.sublineResult(inSystemTest2.mSublineData);
                            return;
                        case 260:
                        default:
                            return;
                    }
                } else {
                    InSystemTest.this.filterThreshold(result);
                    InSystemTest.this.filterData(cmdId, result);
                    InSystemTest.this.filterMessage(cmdId, result);
                    InSystemTest.this.continueTest(cmdId, result);
                }
            }
        };
        this.mTestCmdCallback = r0;
        this.mGoodixFingerprintManager.registerTestCmdCallback(r0);
        this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_GET_CONFIG);
        TaskQueue taskQueue = new TaskQueue(1);
        this.mTaskQueue = taskQueue;
        taskQueue.start();
        this.mThreshold = new Threshold();
        startGetInSystemSpec();
    }

    public void setTestResultCallback(ITestResultCallback testResultCallback) {
        this.mTestResultCallback = testResultCallback;
    }

    public void startNormalScan() {
        setBrightnessReady();
        doTestTask(1);
        this.mCurrentStep = 256;
    }

    public void startFleshRubberTest() {
        startGetInSystemSpec();
        doTestTask(6);
        this.mCurrentStep = 257;
    }

    public void startSublineFleshRubberTest() {
        doTestTask(6);
        this.mCurrentStep = SUBLINE;
    }

    public void startBlackRubberTest() {
        doTestTask(10);
        this.mCurrentStep = 257;
    }

    public void start3DRubberTest() {
        doTestTask(13);
        this.mCurrentStep = 257;
    }

    public void startSublineTest() {
        startGetInSystemSpec();
        doTestTask(18);
        this.mCurrentStep = SUBLINE;
    }

    public void startSNRTest() {
        startGetInSystemSpec();
        doTestTask(6);
        this.mCurrentStep = 260;
    }

    public void startGetInSystemSpec() {
    }

    public void cancelTest() {
        this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_EXIT);
        this.mCurrentStep = -1;
    }

    public String getVersion() {
        return this.mGoodixFingerprintManager.getLibaryVersion();
    }

    public String getTestNum() {
        return this.mGoodixFingerprintManager.getTestNum();
    }

    public int getHighBrightness() {
        return this.mGoodixFingerprintManager.getHighBrightness();
    }

    public int getMiddleBrightness() {
        return this.mGoodixFingerprintManager.getMiddleBrightness();
    }

    public int getLowBrightness() {
        return this.mGoodixFingerprintManager.getLowBrightness();
    }

    public void getSensorInfo() {
        setBrightnessReady();
        doTestTask(16);
        this.mCurrentStep = GET_SENSOR_INFO;
    }

    public void setBrightnessReady() {
        this.mTaskQueue.resume();
    }

    public void saveCalibrationData(int saveFlag) {
        this.mGoodixFingerprintManager.saveCalibrationData(saveFlag);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void calibrationResult(CalibrationData caliData) {
        String calibrationData = ((((((((((((((((("" + "Date: " + new SimpleDateFormat("E, dd MMM yyyy HH:mm:ss z").format(new Date()) + "\n") + "AE time;" + this.mThreshold.MinExposure + ";" + this.mThreshold.MaxExposure + ";" + caliData.AETime + "\n") + "Signal;" + this.mThreshold.MinSignal + ";" + this.mThreshold.MaxSignal + ";" + caliData.Signal + "\n") + "T-Noise;" + this.mThreshold.MinTNoise + ";" + this.mThreshold.MaxTNoise + ";" + caliData.TNoise + "\n") + "Dark T Noise;" + this.mThreshold.MinDarkTNoise + ";" + this.mThreshold.MaxDarkTNoise + ";" + caliData.DarkTNoise + "\n") + "Dark S Noise;" + this.mThreshold.MinDarkSNoise + ";" + this.mThreshold.MaxDarkSNoise + ";" + caliData.DarkSNoise + "\n") + "SNR;" + this.mThreshold.MinSNR + ";" + this.mThreshold.MaxSNR + ";" + caliData.SNR + "\n") + "Scale;" + this.mThreshold.MinScaleRatio + ";" + this.mThreshold.MaxScaleRatio + ";" + caliData.Scale + "\n") + "Screen Struct Ratio;" + this.mThreshold.MinStructRatio + ";" + this.mThreshold.MaxStructRatio + ";" + caliData.ScreenStructRatio + "\n") + "Relative illuminance 1;" + this.mThreshold.MinIlluminace1 + ";" + this.mThreshold.MaxIlluminace1 + ";" + caliData.RelativeIlluminance1 + "\n") + "Relative illuminance 2;" + this.mThreshold.MinIlluminace2 + ";" + this.mThreshold.MaxIlluminace2 + ";" + caliData.RelativeIlluminance2 + "\n") + "Relative illuminance 3;" + this.mThreshold.MinIlluminace3 + ";" + this.mThreshold.MaxIlluminace3 + ";" + caliData.RelativeIlluminance3 + "\n") + "Relative illuminance 4;" + this.mThreshold.MinIlluminace4 + ";" + this.mThreshold.MaxIlluminace4 + ";" + caliData.RelativeIlluminance4 + "\n") + "Cluster Number;" + this.mThreshold.MinClusterNumber + ";" + this.mThreshold.MaxClusterNumber + ";" + caliData.ClusterNum + "\n") + "Largest Bad Cluster;" + this.mThreshold.MinLargestBadCluster + ";" + this.mThreshold.MaxLargestBadCluster + ";" + caliData.LargestBadCluster + "\n") + "Bad Pixel;" + this.mThreshold.MinBadPixel + ";" + this.mThreshold.MaxBadPixel + ";" + caliData.BadPixel + "\n") + "Light Leak Ratio;" + this.mThreshold.MinLightLeakRatio + ";" + this.mThreshold.MaxLightLeakRatio + ";" + caliData.LightLeakRatio + "\n") + "Flesh Touch Diff;" + this.mThreshold.MinFleshTouchDiff + ";" + this.mThreshold.MaxFleshTouchDiff + ";" + caliData.FleshTouchDiff;
        if (this.mG3STest == 1) {
            String calibrationData2 = (((((calibrationData + "\nShelter Ratio;" + this.mThreshold.MinShelterRatio + ";" + this.mThreshold.MaxShelterRatio + ";" + caliData.ShelterRatio + "\n") + "Shelter Area;" + this.mThreshold.MinShelterArea + ";" + this.mThreshold.MaxShelterArea + ";" + caliData.ShelterArea + "\n") + "Tilt Level;" + this.mThreshold.MinTiltLevel + ";" + this.mThreshold.MaxTiltLevel + ";" + caliData.TiltLevel + "\n") + "StripeT;" + this.mThreshold.MinStripeT + ";" + this.mThreshold.MaxStripeT + ";" + caliData.StripeT + "\n") + "StripeSTD;" + this.mThreshold.MinStripeSTD + ";" + this.mThreshold.MaxStripeSTD + ";" + caliData.StripeSTD + "\n") + "Bubble Number;0;" + this.mThreshold.MaxBubble + ";" + caliData.BubbleNum + "\n";
            if (caliData.LargestOrient > 0) {
                calibrationData2 = calibrationData2 + "Pixel Of Largest Orient;0;" + this.mThreshold.MaxLargestOrient + ";" + caliData.LargestOrient + "\n";
            }
            calibrationData = (calibrationData2 + "Pixel Of Largest Bad Bubble;0;" + this.mThreshold.MaxBadBubble + ";" + caliData.LargestBadBubble + "\n") + "Chart Dirty;0;" + this.mThreshold.MaxChartDirty + ";" + caliData.ChartDirty;
        }
        this.mTestResultCallback.onCalibrationDataHelp(calibrationData);
        Log.d(TAG, "Calibration result : " + calibrationData);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sublineResult(SublineData subData) {
        String sublineData = ("" + "Date: " + new SimpleDateFormat("E, dd MMM yyyy HH:mm:ss z").format(new Date()) + "\n") + "AE time;" + this.mThreshold.MinSublineExposure + ";" + this.mThreshold.MaxSublineExposure + ";" + subData.AETime + "\n";
        if (this.mNewSubline == 1) {
            sublineData = sublineData + "Signal;" + this.mThreshold.MinSublineSignal + ";" + this.mThreshold.MaxSublineSignal + ";" + subData.Signal + "\n";
        }
        String sublineData2 = ((sublineData + "T-Noise;" + this.mThreshold.MinSublineTNoise + ";" + this.mThreshold.MaxSublineTNoise + ";" + subData.TNoise + "\n") + "Dark T Noise;" + this.mThreshold.MinSublineDarkTNoise + ";" + this.mThreshold.MaxSublineDarkTNoise + ";" + subData.DarkTNoise + "\n") + "Dark S Noise;" + this.mThreshold.MinSublineDarkSNoise + ";" + this.mThreshold.MaxSublineDarkSNoise + ";" + subData.DarkSNoise + "\n";
        if (this.mNewSubline == 1) {
            sublineData2 = (sublineData2 + "SNR;" + this.mThreshold.MinSublineSNR + ";" + this.mThreshold.MaxSublineSNR + ";" + subData.SNR + "\n") + "Scale;" + this.mThreshold.MinSublineScaleRatio + ";" + this.mThreshold.MaxSublineScaleRatio + ";" + subData.Scale + "\n";
        }
        String sublineData3 = (((((((((sublineData2 + "Screen Struct Ratio;" + this.mThreshold.MinSublineStructRatio + ";" + this.mThreshold.MaxSublineStructRatio + ";" + subData.ScreenStructRatio + "\n") + "Relative illuminance 1;" + this.mThreshold.MinSublineRelativeIlluminace1 + ";" + this.mThreshold.MaxSublineRelativeIlluminace1 + ";" + subData.RelativeIlluminance1 + "\n") + "Relative illuminance 2;" + this.mThreshold.MinSublineRelativeIlluminace2 + ";" + this.mThreshold.MaxSublineRelativeIlluminace2 + ";" + subData.RelativeIlluminance2 + "\n") + "Relative illuminance 3;" + this.mThreshold.MinSublineRelativeIlluminace3 + ";" + this.mThreshold.MaxSublineRelativeIlluminace3 + ";" + subData.RelativeIlluminance3 + "\n") + "Relative illuminance 4;" + this.mThreshold.MinSublineRelativeIlluminace4 + ";" + this.mThreshold.MaxSublineRelativeIlluminace4 + ";" + subData.RelativeIlluminance4 + "\n") + "Cluster Number;" + this.mThreshold.MinSublineClusterNumber + ";" + this.mThreshold.MaxSublineClusterNumber + ";" + subData.ClusterNum + "\n") + "Largest Bad Cluster;" + this.mThreshold.MinSublineLargestBadClusterNumber + ";" + this.mThreshold.MaxSublineLargestBadClusterNumber + ";" + subData.LargestBadCluster + "\n") + "Bad Pixel;" + this.mThreshold.MinSublineBadPointNumber + ";" + this.mThreshold.MaxSublineBadPointNumber + ";" + subData.BadPixel + "\n") + "Light Leak Ratio;" + this.mThreshold.MinSublineLightLeakRatio + ";" + this.mThreshold.MaxSublineLightLeakRatio + ";" + subData.LightLeakRatio + "\n") + "Flesh Touch Diff;" + this.mThreshold.MinSublineFleshTouchDiff + ";" + this.mThreshold.MaxSublineFleshTouchDiff + ";" + subData.FleshTouchDiff;
        if (this.mG3STest == 1) {
            String sublineData4 = (((((sublineData3 + "\nShelter Ratio;" + this.mThreshold.MinSublineShelterRatio + ";" + this.mThreshold.MaxSublineShelterRatio + ";" + subData.ShelterRatio + "\n") + "Shelter Area;" + this.mThreshold.MinSublineShelterArea + ";" + this.mThreshold.MaxSublineShelterArea + ";" + subData.ShelterArea + "\n") + "Tilt Level;" + this.mThreshold.MinSublineTiltLevel + ";" + this.mThreshold.MaxSublineTiltLevel + ";" + subData.TiltLevel + "\n") + "StripeT;" + this.mThreshold.MinStripeT + ";" + this.mThreshold.MaxStripeT + ";" + subData.StripeT + "\n") + "StripeSTD;" + this.mThreshold.MinStripeSTD + ";" + this.mThreshold.MaxStripeSTD + ";" + subData.StripeSTD + "\n") + "Bubble Number;0;" + this.mThreshold.MaxSublineBubble + ";" + subData.BubbleNum + "\n";
            if (subData.LargestOrient > 0) {
                sublineData4 = sublineData4 + "Pixel Of Largest Orient;0;" + this.mThreshold.MaxSublineLargestOrient + ";" + subData.LargestOrient + "\n";
            }
            sublineData3 = (sublineData4 + "Pixel Of Largest Bad Bubble;0;" + this.mThreshold.MaxSublineBadBubble + ";" + subData.LargestBadBubble + "\n") + "Chart Dirty;0;" + this.mThreshold.MaxSublineChartDirty + ";" + subData.ChartDirty;
        }
        this.mTestResultCallback.onSublineDataHelp(sublineData3);
        Log.d(TAG, "Subline result: " + sublineData3);
    }

    private void SNRResult(SnrData snrData) {
        String snrDataResult = ((("" + "Date: " + new SimpleDateFormat("E, dd MMM yyyy HH:mm:ss z").format(new Date()) + "\n") + "Signal;" + this.mThreshold.MinSNR_Signal + ";" + this.mThreshold.MaxSNR_Signal + ";" + snrData.Signal + "\n") + "Scale;" + this.mThreshold.MinSNRScaleRatio + ";" + this.mThreshold.MaxSNRScaleRatio + ";" + snrData.Scale + "\n") + "SNR;" + this.mThreshold.MinSNR_SNR + ";" + this.mThreshold.MaxSNR_SNR + ";" + snrData.SNR;
        this.mTestResultCallback.onSNRDataHelp(snrDataResult);
        Log.d(TAG, "SNR result : " + snrDataResult);
    }

    private void initCmdParse() {
        HashMap<Integer, Integer> hashMap = new HashMap<>();
        this.mCmdParse = hashMap;
        hashMap.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_FT_SPI), 1);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_FT_MT_CHECK), 2);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_FT_SPI_RST_INT), 5);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_FT_INIT), 6);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_FT_EXPO_AUTO_CALIBRATION), 7);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_H_FLESH), 8);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_L_FLESH), 9);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_H_DARK), 10);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_L_DARK), 11);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_DARK_BASE), 12);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_CHECKBOX), 13);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_CHART), 14);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_SS_SAVE_DATA), 17);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_SS_SUBLINE), 18);
        this.mCmdParse.put(Integer.valueOf((int) ShenzhenConstants.CMD_TEST_SZ_SS_SNR), 19);
    }

    private static String bytesToHex(byte[] bytes) {
        StringBuilder buf = new StringBuilder(bytes.length * 2);
        int length = bytes.length;
        for (int i = 0; i < length; i++) {
            buf.append(String.format("%02x", new Integer(bytes[i] & UnsignedBytes.MAX_VALUE)));
        }
        return buf.toString().toUpperCase();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void continueTest(int cmdId, HashMap<Integer, Object> hashMap) {
        switch (cmdId) {
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_DARK_BASE:
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_L_FLESH:
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_CHART:
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_LOCATION_IMAGE:
            case ShenzhenConstants.CMD_TEST_SZ_FT_FACTORY_PERFORMANCE:
            case ShenzhenConstants.CMD_TEST_SZ_FT_STOP_EXPO_AUTO_CALIBRATION:
            case ShenzhenConstants.CMD_TEST_SZ_FT_RESET:
            case ShenzhenConstants.CMD_TEST_SZ_FT_SPI_RST_INT:
            case ShenzhenConstants.CMD_TEST_SZ_FT_EXIT:
            case ShenzhenConstants.CMD_TEST_SZ_FT_CALIBRATE:
            default:
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_H_DARK:
                doTestTask(11);
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_L_DARK:
                doTestTask(12);
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_H_FLESH:
                doTestTask(9);
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_CHECKBOX:
                doTestTask(14);
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_EXPO_AUTO_CALIBRATION:
                doTestTask(8);
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_SPI:
                doTestTask(2);
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_INIT:
                int i = this.mCurrentStep;
                if (i != 261 && i != 260) {
                    doTestTask(7);
                    return;
                }
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_MT_CHECK:
                doTestTask(5);
                return;
        }
    }

    private void doTestTask(int testItem) {
        Log.d(TAG, "Test Item : " + testItem);
        TestTask testTask = null;
        switch (testItem) {
            case 1:
                if (!this.mTaskQueue.isRunning()) {
                    this.mTaskQueue.start();
                }
                testTask = new TestTask(1);
                break;
            case 2:
                testTask = new TestTask(2);
                break;
            case 5:
                testTask = new TestTask(5);
                break;
            case 6:
                if (!this.mTaskQueue.isRunning()) {
                    this.mTaskQueue.start();
                }
                testTask = new TestTask(6);
                break;
            case 7:
                testTask = new TestTask(7);
                break;
            case 8:
                testTask = new TestTask(8);
                this.mTaskQueue.waitForReady();
                break;
            case 9:
                testTask = new TestTask(9);
                this.mTaskQueue.waitForReady();
                break;
            case 10:
                testTask = new TestTask(10);
                this.mTaskQueue.waitForReady();
                break;
            case 11:
                testTask = new TestTask(11);
                this.mTaskQueue.waitForReady();
                break;
            case 12:
                testTask = new TestTask(12);
                this.mTaskQueue.waitForReady();
                break;
            case 13:
                testTask = new TestTask(13);
                this.mTaskQueue.waitForReady();
                break;
            case 14:
                testTask = new TestTask(14);
                break;
            case 15:
                testTask = new TestTask(15);
                break;
            case 16:
                if (!this.mTaskQueue.isRunning()) {
                    this.mTaskQueue.start();
                }
                testTask = new TestTask(16);
                break;
            case 18:
                testTask = new TestTask(18);
                break;
            case 19:
                testTask = new TestTask(19);
                break;
            case 50:
                testTask = new TestTask(50);
                break;
            default:
                Log.d(TAG, "Test Item Unknown ");
                break;
        }
        this.mTaskQueue.add(testTask);
    }

    private float formatFloat(float value) {
        return new BigDecimal((double) value).setScale(2, 4).floatValue();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void filterData(int cmdId, HashMap<Integer, Object> result) {
        int error = -9999;
        if (result.containsKey(100)) {
            error = ((Integer) result.get(100)).intValue();
        }
        switch (cmdId) {
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_CHART:
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_PERFORMANCE_P2P))) {
                    int p2p = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_PERFORMANCE_P2P))).intValue();
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART p2p :" + p2p);
                    this.mCalibrationData.Signal = formatFloat(((float) p2p) / 4096.0f);
                    this.mCalibrationData.SNR = formatFloat((((float) p2p) / 4096.0f) / this.tNoise);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_CHART_DIRTY))) {
                    int value = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_CHART_DIRTY))).intValue();
                    this.mCalibrationData.ChartDirty = value;
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX ChartDirty :" + value);
                }
                if (this.mTestResultCallback == null) {
                    return;
                }
                if (error != 0) {
                    Log.d(TAG, "onTestCmd error = " + error + " test fail.");
                    return;
                }
                Log.d(TAG, "report calibrationResult with chart capture");
                this.mTestResultCallback.onCalibrationData(this.mCalibrationData);
                calibrationResult(this.mCalibrationData);
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_CHECKBOX:
                Log.e(TAG, "CMD_TEST_SZ_FT_CAPTURE_CHECKBOX");
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_BAD_POINT_NUM))) {
                    int badpointNum = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_BAD_POINT_NUM))).intValue();
                    this.mCalibrationData.BadPixel = badpointNum;
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX badpointNum :" + badpointNum);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_CLUSTER_NUM))) {
                    int clusterNum = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_CLUSTER_NUM))).intValue();
                    this.mCalibrationData.ClusterNum = clusterNum;
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX clusterNum :" + clusterNum);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_PIXEL_OF_LARGEST_BAD_CLUSTER))) {
                    int pixelOfLargestBad = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_PIXEL_OF_LARGEST_BAD_CLUSTER))).intValue();
                    this.mCalibrationData.LargestBadCluster = pixelOfLargestBad;
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX pixelOfLargestBad :" + pixelOfLargestBad);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_TNOISE))) {
                    int tnoise = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_TNOISE))).intValue();
                    float f = ((float) tnoise) / 1024.0f;
                    this.tNoise = f;
                    this.mCalibrationData.TNoise = formatFloat(f);
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX tnoise :" + tnoise);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_LIGHT_LEAK_RATIO))) {
                    int lightLeakRatio = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_LIGHT_LEAK_RATIO))).intValue();
                    this.mCalibrationData.LightLeakRatio = formatFloat(((float) lightLeakRatio) / 256.0f);
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX lightLeakRatio :" + lightLeakRatio);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_FLESH_TOUCH_DIFF))) {
                    int fleshTouchDiff = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_FLESH_TOUCH_DIFF))).intValue();
                    this.mCalibrationData.FleshTouchDiff = formatFloat(((float) fleshTouchDiff) / 256.0f);
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX fleshTouchDiff :" + fleshTouchDiff);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_SCALE))) {
                    int scale = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_SCALE))).intValue();
                    this.mCalibrationData.Scale = formatFloat(((float) scale) / 1024.0f);
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX scale :" + scale);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_RELATIVE_ILLUMINANCE))) {
                    byte[] ri = (byte[]) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_RELATIVE_ILLUMINANCE));
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX relativeIlluminace length :" + ri.length);
                    int rii1 = (ri[0] & UnsignedBytes.MAX_VALUE) | ((ri[1] & UnsignedBytes.MAX_VALUE) << 8) | ((ri[2] & UnsignedBytes.MAX_VALUE) << 16) | ((ri[3] & UnsignedBytes.MAX_VALUE) << 24);
                    int rii2 = (ri[4] & UnsignedBytes.MAX_VALUE) | ((ri[5] & UnsignedBytes.MAX_VALUE) << 8) | ((ri[6] & UnsignedBytes.MAX_VALUE) << 16) | ((ri[7] & UnsignedBytes.MAX_VALUE) << 24);
                    float ri1 = ((float) rii1) / 256.0f;
                    float ri2 = ((float) rii2) / 256.0f;
                    float ri3 = ((float) ((((ri[8] & UnsignedBytes.MAX_VALUE) | ((ri[9] & UnsignedBytes.MAX_VALUE) << 8)) | ((ri[10] & UnsignedBytes.MAX_VALUE) << 16)) | ((ri[11] & UnsignedBytes.MAX_VALUE) << 24))) / 256.0f;
                    float ri4 = ((float) ((((ri[12] & UnsignedBytes.MAX_VALUE) | ((ri[13] & UnsignedBytes.MAX_VALUE) << 8)) | ((ri[14] & UnsignedBytes.MAX_VALUE) << 16)) | ((ri[15] & UnsignedBytes.MAX_VALUE) << 24))) / 256.0f;
                    this.mCalibrationData.RelativeIlluminance1 = formatFloat(ri1);
                    this.mCalibrationData.RelativeIlluminance2 = formatFloat(ri2);
                    this.mCalibrationData.RelativeIlluminance3 = formatFloat(ri3);
                    this.mCalibrationData.RelativeIlluminance4 = formatFloat(ri4);
                    String str = ri1 + ", " + ri2 + ", " + ri3 + ", " + ri4;
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX relativeIlluminace :" + ri1);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTROY_SCREEN_STRUCT_RATIO))) {
                    int ratio = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTROY_SCREEN_STRUCT_RATIO))).intValue();
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX ratio :" + ratio);
                    this.mCalibrationData.ScreenStructRatio = formatFloat(((float) ratio) / 1024.0f);
                }
                if (result.containsKey(5506)) {
                    int dark_snoise = ((Integer) result.get(5506)).intValue();
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX dark_snoise :" + dark_snoise);
                    this.mCalibrationData.DarkSNoise = formatFloat(((float) dark_snoise) / 1024.0f);
                }
                if (result.containsKey(5504)) {
                    int dark_tnoise = ((Integer) result.get(5504)).intValue();
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX dark_tnoise :" + dark_tnoise);
                    this.mCalibrationData.DarkTNoise = formatFloat(((float) dark_tnoise) / 1024.0f);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SHELTER_RATIO))) {
                    float value2 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SHELTER_RATIO))).floatValue();
                    this.mCalibrationData.ShelterRatio = formatFloat(value2);
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX ShelterRatio :" + value2);
                    this.mG3STest = 1;
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SHELTER_AREA))) {
                    float value3 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SHELTER_AREA))).floatValue();
                    this.mCalibrationData.ShelterArea = formatFloat(value3);
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX ShelterArea :" + value3);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_TILT_LEVEL))) {
                    int value4 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_TILT_LEVEL))).intValue();
                    this.mCalibrationData.TiltLevel = value4;
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX TiltLevel :" + value4);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_STRIPE_T))) {
                    float value5 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_STRIPE_T))).floatValue();
                    this.mCalibrationData.StripeT = formatFloat(value5);
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX StripeT :" + value5);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_STRIPE_STD))) {
                    float value6 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_STRIPE_STD))).floatValue();
                    this.mCalibrationData.StripeSTD = formatFloat(value6);
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX StripeSTD :" + value6);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_BUBBLE_NUM))) {
                    int value7 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_BUBBLE_NUM))).intValue();
                    this.mCalibrationData.BubbleNum = value7;
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX BubbleNum :" + value7);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_PIXEL_OF_ORIENT_LARGEST_BAD_CLUSTER))) {
                    int value8 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_PIXEL_OF_ORIENT_LARGEST_BAD_CLUSTER))).intValue();
                    this.mCalibrationData.LargestOrient = value8;
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX LargestOrient :" + value8);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_PIXEL_OF_LARGEST_BAD_BUBBLE))) {
                    int value9 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_PIXEL_OF_LARGEST_BAD_BUBBLE))).intValue();
                    this.mCalibrationData.LargestBadBubble = value9;
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX LargestBadBubble :" + value9);
                    return;
                }
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_EXPO_AUTO_CALIBRATION:
                Log.e(TAG, "CMD_TEST_SZ_FT_EXPO_AUTO_CALIBRATION");
                this.mSublineData = new SublineData();
                this.mCalibrationData = new CalibrationData();
                if (result.containsKey(6003)) {
                    int expo = ((Integer) result.get(6003)).intValue();
                    this.mCalibrationData.AETime = expo;
                    this.mSublineData.AETime = expo;
                    return;
                }
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_SPI_RST_INT:
            case ShenzhenConstants.CMD_TEST_SZ_FT_MT_CHECK:
            default:
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_SPI:
                this.mNormalScanData = new NormalScanData();
                if (result.containsKey(206)) {
                    Log.e(TAG, "CMD_TEST_SZ_FT_SPI UID: " + bytesToHex((byte[]) result.get(206)));
                }
                if (result.containsKey(208)) {
                    int id = ((Integer) result.get(208)).intValue();
                    Log.e(TAG, "CMD_TEST_SZ_FT_SPI chipId: " + Integer.toHexString(id));
                    if (id > 0) {
                        this.mNormalScanData.ChipIDCheck = 0;
                        this.mNormalScanData.UIDCheck = 0;
                        return;
                    }
                    this.mNormalScanData.ChipIDCheck = -1;
                    this.mNormalScanData.UIDCheck = -1;
                    return;
                }
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_INIT:
                this.tNoise = -1.0f;
                return;
            case ShenzhenConstants.CMD_TEST_SZ_SS_SUBLINE:
                if (this.mSublineData != null) {
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_BAD_POINT_NUM))) {
                        int badpointNum2 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_BAD_POINT_NUM))).intValue();
                        this.mSublineData.BadPixel = badpointNum2;
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX badpointNum :" + badpointNum2);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_CLUSTER_NUM))) {
                        int clusterNum2 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_CLUSTER_NUM))).intValue();
                        this.mSublineData.ClusterNum = clusterNum2;
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX clusterNum :" + clusterNum2);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_PIXEL_OF_LARGEST_BAD_CLUSTER))) {
                        int pixelOfLargestBad2 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_PIXEL_OF_LARGEST_BAD_CLUSTER))).intValue();
                        this.mSublineData.LargestBadCluster = pixelOfLargestBad2;
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX pixelOfLargestBad :" + pixelOfLargestBad2);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_TNOISE))) {
                        int tnoise2 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_TNOISE))).intValue();
                        float f2 = ((float) tnoise2) / 1024.0f;
                        this.tNoise = f2;
                        this.mSublineData.TNoise = formatFloat(f2);
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX tnoise :" + tnoise2);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_LIGHT_LEAK_RATIO))) {
                        int lightLeakRatio2 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_LIGHT_LEAK_RATIO))).intValue();
                        this.mSublineData.LightLeakRatio = formatFloat(((float) lightLeakRatio2) / 256.0f);
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX lightLeakRatio :" + lightLeakRatio2);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_FLESH_TOUCH_DIFF))) {
                        int fleshTouchDiff2 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_FLESH_TOUCH_DIFF))).intValue();
                        this.mSublineData.FleshTouchDiff = formatFloat(((float) fleshTouchDiff2) / 256.0f);
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX fleshTouchDiff :" + fleshTouchDiff2);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_RELATIVE_ILLUMINANCE))) {
                        byte[] ri5 = (byte[]) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_RELATIVE_ILLUMINANCE));
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX relativeIlluminace length :" + ri5.length);
                        int rii12 = (ri5[0] & UnsignedBytes.MAX_VALUE) | ((ri5[1] & UnsignedBytes.MAX_VALUE) << 8) | ((ri5[2] & UnsignedBytes.MAX_VALUE) << 16) | ((ri5[3] & UnsignedBytes.MAX_VALUE) << 24);
                        int rii22 = (ri5[4] & UnsignedBytes.MAX_VALUE) | ((ri5[5] & UnsignedBytes.MAX_VALUE) << 8) | ((ri5[6] & UnsignedBytes.MAX_VALUE) << 16) | ((ri5[7] & UnsignedBytes.MAX_VALUE) << 24);
                        float ri12 = ((float) rii12) / 256.0f;
                        float ri22 = ((float) rii22) / 256.0f;
                        float ri32 = ((float) ((((ri5[8] & UnsignedBytes.MAX_VALUE) | ((ri5[9] & UnsignedBytes.MAX_VALUE) << 8)) | ((ri5[10] & UnsignedBytes.MAX_VALUE) << 16)) | ((ri5[11] & UnsignedBytes.MAX_VALUE) << 24))) / 256.0f;
                        float ri42 = ((float) ((((ri5[12] & UnsignedBytes.MAX_VALUE) | ((ri5[13] & UnsignedBytes.MAX_VALUE) << 8)) | ((ri5[14] & UnsignedBytes.MAX_VALUE) << 16)) | ((ri5[15] & UnsignedBytes.MAX_VALUE) << 24))) / 256.0f;
                        this.mSublineData.RelativeIlluminance1 = formatFloat(ri12);
                        this.mSublineData.RelativeIlluminance2 = formatFloat(ri22);
                        this.mSublineData.RelativeIlluminance3 = formatFloat(ri32);
                        this.mSublineData.RelativeIlluminance4 = formatFloat(ri42);
                        String str2 = ri12 + ", " + ri22 + ", " + ri32 + ", " + ri42;
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX relativeIlluminace :" + ri12);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTROY_SCREEN_STRUCT_RATIO))) {
                        int ratio2 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTROY_SCREEN_STRUCT_RATIO))).intValue();
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHECKBOX ratio :" + ratio2);
                        this.mSublineData.ScreenStructRatio = formatFloat(((float) ratio2) / 1024.0f);
                    }
                    if (result.containsKey(5506)) {
                        int dark_snoise2 = ((Integer) result.get(5506)).intValue();
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART dark_snoise :" + dark_snoise2);
                        this.mSublineData.DarkSNoise = formatFloat(((float) dark_snoise2) / 1024.0f);
                    }
                    if (result.containsKey(5504)) {
                        int dark_tnoise2 = ((Integer) result.get(5504)).intValue();
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART dark_tnoise :" + dark_tnoise2);
                        this.mSublineData.DarkTNoise = formatFloat(((float) dark_tnoise2) / 1024.0f);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_PERFORMANCE_P2P))) {
                        int p2p2 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_PERFORMANCE_P2P))).intValue();
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART subline p2p :" + p2p2);
                        this.mSublineData.Signal = formatFloat(((float) p2p2) / 4096.0f);
                        float f3 = this.tNoise;
                        if (((int) f3) == 0) {
                            this.mSublineData.SNR = formatFloat(-1.0f);
                        } else {
                            this.mSublineData.SNR = formatFloat((((float) p2p2) / 4096.0f) / f3);
                        }
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_SCALE))) {
                        int scale2 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_SCALE))).intValue();
                        this.mSublineData.Scale = formatFloat(((float) scale2) / 1024.0f);
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART scale :" + scale2);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SHELTER_RATIO))) {
                        float value10 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SHELTER_RATIO))).floatValue();
                        this.mSublineData.ShelterRatio = formatFloat(value10);
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART ShelterRatio :" + value10);
                        this.mG3STest = 1;
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SHELTER_AREA))) {
                        float value11 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SHELTER_AREA))).floatValue();
                        this.mSublineData.ShelterArea = formatFloat(value11);
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART ShelterArea :" + value11);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_TILT_LEVEL))) {
                        int value12 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_TILT_LEVEL))).intValue();
                        this.mSublineData.TiltLevel = value12;
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART TiltLevel :" + value12);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_STRIPE_T))) {
                        float value13 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_STRIPE_T))).floatValue();
                        this.mSublineData.StripeT = formatFloat(value13);
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART StripeT :" + value13);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_STRIPE_STD))) {
                        float value14 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_STRIPE_STD))).floatValue();
                        this.mSublineData.StripeSTD = formatFloat(value14);
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART StripeSTD :" + value14);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_BUBBLE_NUM))) {
                        int value15 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_BUBBLE_NUM))).intValue();
                        this.mSublineData.BubbleNum = value15;
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART BubbleNum :" + value15);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_PIXEL_OF_ORIENT_LARGEST_BAD_CLUSTER))) {
                        int value16 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_PIXEL_OF_ORIENT_LARGEST_BAD_CLUSTER))).intValue();
                        this.mSublineData.LargestOrient = value16;
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART LargestOrient :" + value16);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_PIXEL_OF_LARGEST_BAD_BUBBLE))) {
                        int value17 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_PIXEL_OF_LARGEST_BAD_BUBBLE))).intValue();
                        this.mSublineData.LargestBadBubble = value17;
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART LargestBadBubble :" + value17);
                    }
                    if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_CHART_DIRTY))) {
                        int value18 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_CHART_DIRTY))).intValue();
                        this.mSublineData.ChartDirty = value18;
                        Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_FT_CAPTURE_CHART ChartDirty :" + value18);
                    }
                    ITestResultCallback iTestResultCallback = this.mTestResultCallback;
                    if (iTestResultCallback != null) {
                        iTestResultCallback.onSublineData(this.mSublineData);
                        sublineResult(this.mSublineData);
                        return;
                    }
                    return;
                }
                return;
            case ShenzhenConstants.CMD_TEST_SZ_SS_SNR:
                SnrData snrData = new SnrData();
                if (error != 0) {
                    this.mTestResultCallback.onSNRData(snrData);
                    SNRResult(snrData);
                    doTestTask(15);
                    this.mCurrentStep = -1;
                    return;
                }
                int scale3 = -1;
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_SCALE))) {
                    scale3 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_SCALE))).intValue();
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_SS_SNR scale :" + scale3);
                }
                int p2p3 = -1;
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_PERFORMANCE_P2P))) {
                    p2p3 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_PERFORMANCE_P2P))).intValue();
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_SS_SNR p2p :" + p2p3);
                }
                int tnoise3 = -1;
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_TNOISE))) {
                    tnoise3 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_FACTORY_TNOISE))).intValue();
                    Log.d(TAG, "onTestCmd cmdId = CMD_TEST_SZ_SS_SNR tnoise :" + tnoise3);
                }
                snrData.Scale = formatFloat(((float) scale3) / 1024.0f);
                snrData.Signal = formatFloat(((float) p2p3) / 4096.0f);
                float tNoise2 = ((float) tnoise3) / 1024.0f;
                if (tNoise2 == 0.0f) {
                    ITestResultCallback iTestResultCallback2 = this.mTestResultCallback;
                    if (iTestResultCallback2 != null) {
                        iTestResultCallback2.onSNRData(snrData);
                        SNRResult(snrData);
                        doTestTask(15);
                        this.mCurrentStep = -1;
                        return;
                    }
                    return;
                }
                snrData.SNR = formatFloat((((float) p2p3) / 4096.0f) / tNoise2);
                ITestResultCallback iTestResultCallback3 = this.mTestResultCallback;
                if (iTestResultCallback3 != null) {
                    iTestResultCallback3.onSNRData(snrData);
                    SNRResult(snrData);
                    doTestTask(15);
                    this.mCurrentStep = -1;
                    return;
                }
                return;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void filterMessage(int cmdId, HashMap<Integer, Object> result) {
        byte[] SENSOR_UID;
        byte[] EFS_UID;
        byte[] UID;
        int error = -9999;
        if (result.containsKey(100)) {
            error = ((Integer) result.get(100)).intValue();
        }
        int i = 0;
        switch (cmdId) {
            case 1:
                SensorInfo sensorInfor = new SensorInfo();
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SS_PRODUCT_ID))) {
                    String productId = (String) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SS_PRODUCT_ID));
                    sensorInfor.mProductId = productId;
                    Log.d(TAG, "productId " + productId);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SS_MT_CHECK))) {
                    int MTCheck = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SS_MT_CHECK))).intValue();
                    sensorInfor.mMTCheck = MTCheck == 0 ? 0 : 1;
                    Log.d(TAG, "mMTCheck " + MTCheck);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SS_CALIBRATION))) {
                    int calibration = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SS_CALIBRATION))).intValue();
                    if (calibration != 0) {
                        i = 1;
                    }
                    sensorInfor.mCalibration = i;
                    Log.d(TAG, "calibration " + calibration);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SS_UID))) {
                    String sUid = "";
                    for (byte b : (byte[]) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SS_UID))) {
                        String strHex = Integer.toHexString(b & UnsignedBytes.MAX_VALUE);
                        StringBuilder sb = new StringBuilder();
                        sb.append(sUid);
                        sb.append(strHex.length() == 1 ? "0" + strHex : strHex);
                        sUid = sb.toString() + " ";
                    }
                    sensorInfor.mUid = sUid;
                    Log.d(TAG, "UID " + sUid);
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SS_EFS_UID))) {
                    String sEFSUid = "";
                    for (byte b2 : (byte[]) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SS_EFS_UID))) {
                        String strHex2 = Integer.toHexString(b2 & UnsignedBytes.MAX_VALUE);
                        StringBuilder sb2 = new StringBuilder();
                        sb2.append(sEFSUid);
                        sb2.append(strHex2.length() == 1 ? "0" + strHex2 : strHex2);
                        sEFSUid = sb2.toString() + " ";
                    }
                    sensorInfor.mEFSUid = sEFSUid;
                }
                if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SS_SENSOR_UID))) {
                    String sSensorUid = "";
                    for (byte b3 : (byte[]) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_SS_SENSOR_UID))) {
                        String strHex3 = Integer.toHexString(b3 & UnsignedBytes.MAX_VALUE);
                        StringBuilder sb3 = new StringBuilder();
                        sb3.append(sSensorUid);
                        sb3.append(strHex3.length() == 1 ? "0" + strHex3 : strHex3);
                        sSensorUid = sb3.toString() + " ";
                    }
                    sensorInfor.mSensorUid = sSensorUid;
                }
                ITestResultCallback iTestResultCallback = this.mTestResultCallback;
                if (iTestResultCallback != null) {
                    iTestResultCallback.onSensorInfo(sensorInfor);
                    String sensorInfoHelp = (((("" + "Product Id: " + sensorInfor.mProductId + "\n") + "MT Check: " + sensorInfor.mMTCheck + " \n") + "Calibration: " + sensorInfor.mCalibration + "\n") + "Sensor UID: " + sensorInfor.mSensorUid + "\n") + "EFS UID: " + sensorInfor.mEFSUid + "\n";
                    Log.d(TAG, "onSensorInfo :" + sensorInfoHelp);
                    this.mTestResultCallback.onSensorInfoHelp(sensorInfoHelp);
                    return;
                }
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_DARK_BASE:
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_H_DARK:
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_L_DARK:
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_H_FLESH:
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_L_FLESH:
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_CHART:
            case ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_CHECKBOX:
            case ShenzhenConstants.CMD_TEST_SZ_FT_EXPO_AUTO_CALIBRATION:
            case ShenzhenConstants.CMD_TEST_SZ_FT_INIT:
                ITestResultCallback iTestResultCallback2 = this.mTestResultCallback;
                if (iTestResultCallback2 != null) {
                    int i2 = this.mCurrentStep;
                    if (i2 == 261) {
                        return;
                    }
                    if (i2 != 261) {
                        if (error == 0) {
                            Log.d(TAG, "mCmdParse " + this.mCmdParse + " mCmdParse.get(cmdId) " + this.mCmdParse.get(Integer.valueOf(cmdId)));
                            this.mTestResultCallback.onResult(this.mCmdParse.get(Integer.valueOf(cmdId)).intValue(), 512);
                            if (this.mCurrentStep == 260) {
                                doTestTask(19);
                            }
                        } else {
                            iTestResultCallback2.onResult(this.mCmdParse.get(Integer.valueOf(cmdId)).intValue(), 513);
                        }
                    }
                }
                if (error != 0) {
                    if (this.mTestResultCallback != null) {
                        if (this.mCurrentStep == 259) {
                            Log.d(TAG, "report sublineResult with code: " + error);
                            SublineData sublineData = new SublineData();
                            this.mSublineData = sublineData;
                            sublineResult(sublineData);
                        } else {
                            Log.d(TAG, "report calibrationResult with code: " + error);
                            this.mTestResultCallback.onCalibrationData(this.mCalibrationData);
                            calibrationResult(this.mCalibrationData);
                        }
                    }
                    doTestTask(15);
                    this.mTaskQueue.stop();
                    this.mCurrentStep = -1;
                    return;
                }
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_SPI_RST_INT:
                ITestResultCallback iTestResultCallback3 = this.mTestResultCallback;
                if (iTestResultCallback3 != null) {
                    if (error == 0) {
                        Log.d(TAG, "mCmdParse " + this.mCmdParse + " mCmdParse.get(cmdId) " + this.mCmdParse.get(Integer.valueOf(cmdId)));
                        this.mTestResultCallback.onResult(this.mCmdParse.get(Integer.valueOf(cmdId)).intValue(), 512);
                        this.mNormalScanData.ResetPinCheck = 0;
                    } else {
                        iTestResultCallback3.onResult(this.mCmdParse.get(Integer.valueOf(cmdId)).intValue(), 513);
                        this.mNormalScanData.ResetPinCheck = -1;
                    }
                }
                this.mTestResultCallback.onNormalScanData(this.mNormalScanData);
                this.mTestResultCallback.onNormalScanDataHelp(((((("" + "Date: " + new SimpleDateFormat("E, dd MMM yyyy HH:mm:ss z").format(new Date()) + "\n") + "MTCheck;0;0;" + this.mNormalScanData.MTCheck + "\n") + "ChipIDCheck;0;0;" + this.mNormalScanData.ChipIDCheck + "\n") + "UIDCheck;0;0;" + this.mNormalScanData.UIDCheck + "\n") + "SPICheck;0;0;" + this.mNormalScanData.SPICheck + "\n") + "ResetPinCheck;0;0;" + this.mNormalScanData.ResetPinCheck + "\n");
                if (error != 0) {
                    doTestTask(15);
                    this.mTaskQueue.stop();
                    this.mCurrentStep = -1;
                    return;
                }
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_SPI:
                ITestResultCallback iTestResultCallback4 = this.mTestResultCallback;
                if (iTestResultCallback4 == null) {
                    return;
                }
                if (error == 0) {
                    Log.d(TAG, "mCmdParse " + this.mCmdParse + " mCmdParse.get(cmdId) " + this.mCmdParse.get(Integer.valueOf(cmdId)));
                    this.mTestResultCallback.onResult(3, 512);
                    this.mTestResultCallback.onResult(1, 512);
                    this.mTestResultCallback.onResult(4, 512);
                    this.mNormalScanData.SPICheck = 0;
                    return;
                }
                iTestResultCallback4.onResult(3, 513);
                this.mTestResultCallback.onResult(1, 513);
                this.mTestResultCallback.onResult(4, 513);
                this.mNormalScanData.SPICheck = -1;
                return;
            case ShenzhenConstants.CMD_TEST_SZ_FT_MT_CHECK:
                ITestResultCallback iTestResultCallback5 = this.mTestResultCallback;
                if (iTestResultCallback5 == null) {
                    return;
                }
                if (error == 0) {
                    Log.d(TAG, "mCmdParse " + this.mCmdParse + " mCmdParse.get(cmdId) " + this.mCmdParse.get(Integer.valueOf(cmdId)));
                    this.mTestResultCallback.onResult(2, 512);
                    this.mNormalScanData.MTCheck = 0;
                    return;
                }
                iTestResultCallback5.onResult(2, 513);
                this.mNormalScanData.MTCheck = -1;
                return;
            case ShenzhenConstants.CMD_TEST_SZ_SS_SAVE_DATA:
                if (error == 0) {
                    this.mTestResultCallback.onResult(17, 512);
                    return;
                } else {
                    this.mTestResultCallback.onResult(17, 513);
                    return;
                }
            default:
                return;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void filterThreshold(HashMap<Integer, Object> result) {
        String threshold = "";
        Integer valueOf = Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_EXPO_TIME);
        if (result.containsKey(valueOf)) {
            int MinExposure = ((Integer) result.get(valueOf)).intValue();
            Log.e(TAG, "filterThreshold TS_min_expo_time: " + MinExposure);
            this.mThreshold.MinExposure = MinExposure;
            threshold = threshold + "AETime: " + MinExposure + " , ";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_EXPO_TIME))) {
            int MaxExposure = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_EXPO_TIME))).intValue();
            Log.e(TAG, "filterThreshold TS_max_expo_time: " + MaxExposure);
            this.mThreshold.MaxExposure = MaxExposure;
            threshold = threshold + MaxExposure + "\n";
        }
        if (result.containsKey(1414)) {
            float MinP2P = ((Float) result.get(1414)).floatValue();
            Log.e(TAG, "filterThreshold TS_p2p: " + MinP2P);
            this.mThreshold.MinSignal = MinP2P;
            this.mThreshold.MaxSignal = 9999;
            threshold = (threshold + "Signal: " + MinP2P + " , ") + "9999\n";
        }
        if (result.containsKey(1403)) {
            float MaxTNoise = ((Float) result.get(1403)).floatValue();
            Log.e(TAG, "filterThreshold TS_tnoise: " + MaxTNoise);
            this.mThreshold.MinTNoise = 0;
            this.mThreshold.MaxTNoise = MaxTNoise;
            threshold = (threshold + "TNoise: 0 , ") + MaxTNoise + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_DARK_TNOISE))) {
            float MaxDarkTNoise = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_DARK_TNOISE))).floatValue();
            this.mThreshold.MinDarkTNoise = 0;
            this.mThreshold.MaxDarkTNoise = MaxDarkTNoise;
            threshold = (threshold + "DarkTNoise: 0 , ") + MaxDarkTNoise + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_DARK_SNOISE))) {
            float MaxDarkSNoise = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_DARK_SNOISE))).floatValue();
            this.mThreshold.MinDarkSNoise = 0.0f;
            this.mThreshold.MaxDarkSNoise = MaxDarkSNoise;
            threshold = (threshold + "DarkSNoise: 0 , ") + MaxDarkSNoise + "\n";
        }
        if (result.containsKey(1412)) {
            float MinSNR = ((Float) result.get(1412)).floatValue();
            Log.e(TAG, "filterThreshold TS_ssnr: " + MinSNR);
            this.mThreshold.MinSNR = MinSNR;
            this.mThreshold.MaxSNR = 9999;
            threshold = (threshold + "SNR: " + MinSNR + " , ") + "9999\n";
        }
        if (result.containsKey(1410)) {
            float MinScaleRatio = ((Float) result.get(1410)).floatValue();
            Log.e(TAG, "filterThreshold TS_scale_min: " + MinScaleRatio);
            this.mThreshold.MinScaleRatio = MinScaleRatio;
            threshold = threshold + "ScaleRatio: " + MinScaleRatio + " , ";
        }
        if (result.containsKey(1409)) {
            float MaxScaleRatio = ((Float) result.get(1409)).floatValue();
            Log.e(TAG, "filterThreshold TS_scale_max: " + MaxScaleRatio);
            this.mThreshold.MaxScaleRatio = MaxScaleRatio;
            threshold = threshold + MaxScaleRatio + "\n";
        }
        if (result.containsKey(1423)) {
            float MaxStructRatio = ((Float) result.get(1423)).floatValue();
            Log.e(TAG, "filterThreshold TS_structratio: " + MaxStructRatio);
            this.mThreshold.MinStructRatio = 0;
            this.mThreshold.MaxStructRatio = MaxStructRatio;
            threshold = (threshold + "ScreenStructRatio: 0 , ") + MaxStructRatio + "\n";
        }
        if (result.containsKey(1408)) {
            float MinIlluminace = ((Float) result.get(1408)).floatValue();
            Log.e(TAG, "filterThreshold TS_illuminace: " + MinIlluminace);
            this.mThreshold.MinIlluminace1 = MinIlluminace;
            this.mThreshold.MaxIlluminace1 = 9999;
            this.mThreshold.MinIlluminace2 = MinIlluminace;
            this.mThreshold.MaxIlluminace2 = 9999;
            this.mThreshold.MinIlluminace3 = MinIlluminace;
            this.mThreshold.MaxIlluminace3 = 9999;
            this.mThreshold.MinIlluminace4 = MinIlluminace;
            this.mThreshold.MaxIlluminace4 = 9999;
            threshold = (((((((threshold + "RelativeIlluminance1: " + MinIlluminace + " , ") + "9999\n") + "RelativeIlluminance2: " + MinIlluminace + " , ") + "9999\n") + "RelativeIlluminance3: " + MinIlluminace + " , ") + "9999\n") + "RelativeIlluminance4: " + MinIlluminace + " , ") + "9999\n";
        }
        if (result.containsKey(1401)) {
            int MaxClusterNumber = ((Integer) result.get(1401)).intValue();
            Log.e(TAG, "filterThreshold TS_clusterNum: " + MaxClusterNumber);
            this.mThreshold.MinClusterNumber = 0;
            this.mThreshold.MaxClusterNumber = MaxClusterNumber;
            threshold = (threshold + "ClusterNumber: 0 , ") + MaxClusterNumber + "\n";
        }
        if (result.containsKey(1402)) {
            int MaxLargestBadCluster = ((Integer) result.get(1402)).intValue();
            Log.e(TAG, "filterThreshold TS_pixelOfLargestBad: " + MaxLargestBadCluster);
            this.mThreshold.MinLargestBadCluster = 0;
            this.mThreshold.MaxLargestBadCluster = MaxLargestBadCluster;
            threshold = (threshold + "LargestBadClusterNumber: 0 , ") + MaxLargestBadCluster + "\n";
        }
        if (result.containsKey(1400)) {
            int MaxBadPixel = ((Integer) result.get(1400)).intValue();
            Log.e(TAG, "filterThreshold TS_badpointNum: " + MaxBadPixel);
            this.mThreshold.MinBadPixel = 0;
            this.mThreshold.MaxBadPixel = MaxBadPixel;
            threshold = (threshold + "BadPixel: 0 , ") + MaxBadPixel + "\n";
        }
        if (result.containsKey(1407)) {
            float MaxLightLeakRatio = ((Float) result.get(1407)).floatValue();
            Log.e(TAG, "filterThreshold TS_lightLeakRatio: " + MaxLightLeakRatio);
            this.mThreshold.MinLightLeakRatio = 0;
            this.mThreshold.MaxLightLeakRatio = MaxLightLeakRatio;
            threshold = (threshold + "LightLeakRatio: 0 , ") + MaxLightLeakRatio + "\n";
        }
        if (result.containsKey(1405)) {
            float MinFleshTouchDiff = ((Float) result.get(1405)).floatValue();
            Log.e(TAG, "filterThreshold TS_fleshTouchDiff: " + MinFleshTouchDiff);
            this.mThreshold.MinFleshTouchDiff = MinFleshTouchDiff;
            this.mThreshold.MaxFleshTouchDiff = 9999;
            threshold = (threshold + "FleshTouchDiff: " + MinFleshTouchDiff + " , ") + "9999\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SHELTER_RATIO))) {
            float value = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SHELTER_RATIO))).floatValue();
            Log.e(TAG, "filterThreshold MaxShelterRatio: " + value);
            this.mG3STest = 1;
            this.mThreshold.MinShelterRatio = 0.0f;
            this.mThreshold.MaxShelterRatio = value;
            threshold = (threshold + "ShelterRatio: 0 , ") + value + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SHELTER_AREA))) {
            float value2 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SHELTER_AREA))).floatValue();
            Log.e(TAG, "filterThreshold MaxShelterArea: " + value2);
            this.mThreshold.MinShelterArea = 0.0f;
            this.mThreshold.MaxShelterArea = value2;
            threshold = (threshold + "ShelterArea: 0 , ") + value2 + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_TILT_LEVEL))) {
            int value3 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_TILT_LEVEL))).intValue();
            Log.e(TAG, "filterThreshold MaxTiltLevel: " + value3);
            this.mThreshold.MinTiltLevel = 0;
            this.mThreshold.MaxTiltLevel = value3;
            threshold = (threshold + "TiltLevel: 0 , ") + value3 + "\n";
        }
        if (result.containsKey(1404)) {
            float MaxSNoise = ((Float) result.get(1404)).floatValue();
            Log.e(TAG, "filterThreshold TS_snoise: " + MaxSNoise);
            this.mThreshold.MinSNoise = 0;
            this.mThreshold.MaxSNoise = MaxSNoise;
            threshold = (threshold + "SNoise: 0 , ") + MaxSNoise + "\n";
        }
        if (result.containsKey(1406)) {
            int MinFov = ((Integer) result.get(1406)).intValue();
            Log.e(TAG, "filterThreshold TS_fov: " + MinFov);
            this.mThreshold.MinFov = MinFov;
            this.mThreshold.MaxFov = 9999;
            threshold = (threshold + "FOV: " + MinFov + " , ") + "9999\n";
        }
        if (result.containsKey(1413)) {
            float MinSharpness = ((Float) result.get(1413)).floatValue();
            Log.e(TAG, "filterThreshold MinSharpness: " + MinSharpness);
            this.mThreshold.MinSharpness = MinSharpness;
            this.mThreshold.MaxSharpness = 9999;
            threshold = (threshold + "Sharpness: " + MinSharpness + " , ") + "9999\n";
        }
        if (result.containsKey(1415)) {
            float MinContrast = ((Float) result.get(1415)).floatValue();
            Log.e(TAG, "filterThreshold TS_contrast: " + MinContrast);
            this.mThreshold.MinContrast = MinContrast;
            this.mThreshold.MaxContrast = 9999;
            threshold = (threshold + "Contrast: " + MinContrast + " , ") + "9999\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_CENTER_OFFSET))) {
            float MaxCenterOffset = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_CENTER_OFFSET))).floatValue();
            this.mThreshold.MinCenterOffset = 0;
            this.mThreshold.MaxCenterOffset = MaxCenterOffset;
            threshold = (threshold + "CenterOffset: 0 , ") + MaxCenterOffset + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_LENS_TILT_LEVEL))) {
            int MaxLensTiltLevel = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_LENS_TILT_LEVEL))).intValue();
            this.mThreshold.MinLensTiltLevel = 0;
            this.mThreshold.MaxLensTiltLevel = MaxLensTiltLevel;
            threshold = (threshold + "LensTiltLevel: 0 , ") + MaxLensTiltLevel + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_LENS_TILT_ANGLE))) {
            int MaxLensTiltAngle = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_LENS_TILT_ANGLE))).intValue();
            this.mThreshold.MinLensTiltAngle = 0;
            this.mThreshold.MaxLensTiltAngle = MaxLensTiltAngle;
            threshold = (threshold + "LensTiltAngle: 0 , ") + MaxLensTiltAngle + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_PIXEL_OF_LARGEST_ORIENT_BAD_CLUSTER))) {
            int MaxLargestOrientBadCluster = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_PIXEL_OF_LARGEST_ORIENT_BAD_CLUSTER))).intValue();
            this.mThreshold.MinLargestOrientBadCluster = 0;
            this.mThreshold.MaxLargestOrientBadCluster = MaxLargestOrientBadCluster;
            threshold = (threshold + "LargestOrientBadCluster: 0 , ") + MaxLargestOrientBadCluster + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_BUBBLE_NUM))) {
            int value4 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_BUBBLE_NUM))).intValue();
            Log.e(TAG, "filterThreshold MaxBubble: " + value4);
            this.mThreshold.MaxBubble = value4;
            threshold = (threshold + "MaxBubble: 0 , ") + value4 + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_LARGEST_ORIENT))) {
            int value5 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_LARGEST_ORIENT))).intValue();
            Log.e(TAG, "filterThreshold MaxLargestOrient: " + value5);
            this.mThreshold.MaxLargestOrient = value5;
            threshold = (threshold + "MaxLargestOrient: 0 , ") + value5 + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_BAD_BUBBLE))) {
            int value6 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_BAD_BUBBLE))).intValue();
            Log.e(TAG, "filterThreshold MaxBadBubble: " + value6);
            this.mThreshold.MaxBadBubble = value6;
            threshold = (threshold + "MaxBadBubble: 0 , ") + value6 + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_CHART_DIRTY))) {
            int value7 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_CHART_DIRTY))).intValue();
            Log.e(TAG, "filterThreshold MaxChartDirty: " + value7);
            this.mThreshold.MaxChartDirty = value7;
            threshold = (threshold + "MaxChartDirty: 0 , ") + value7 + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_BAD_POINT_NUM))) {
            int MaxSublineBadPointNumber = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_BAD_POINT_NUM))).intValue();
            this.mThreshold.MinSublineBadPointNumber = 0;
            this.mThreshold.MaxSublineBadPointNumber = MaxSublineBadPointNumber;
            threshold = (threshold + "Subline_BadPixel: 0 , ") + MaxSublineBadPointNumber + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_CLUSTER_NUM))) {
            int MaxSublineClusterNumber = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_CLUSTER_NUM))).intValue();
            this.mThreshold.MinSublineClusterNumber = 0;
            this.mThreshold.MaxSublineClusterNumber = MaxSublineClusterNumber;
            threshold = (threshold + "Subline_ClusterNumber: 0 , ") + MaxSublineClusterNumber + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_PIXEL_OF_LARGEST_BAD_CLUSTER))) {
            int MaxSublineLargestBadClusterNumber = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_PIXEL_OF_LARGEST_BAD_CLUSTER))).intValue();
            this.mThreshold.MinSublineLargestBadClusterNumber = 0;
            this.mThreshold.MaxSublineLargestBadClusterNumber = MaxSublineLargestBadClusterNumber;
            threshold = (threshold + "Subline_LargestBadClusterNumber: 0 , ") + MaxSublineLargestBadClusterNumber + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_LIGHT_NOISET))) {
            float MaxSublineTNoise = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_LIGHT_NOISET))).floatValue();
            this.mThreshold.MinSublineTNoise = 0;
            this.mThreshold.MaxSublineTNoise = MaxSublineTNoise;
            threshold = (threshold + "Subline_TNoise: 0 , ") + MaxSublineTNoise + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_DARK_TNOISE))) {
            float MaxSublineDarkTNoise = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_DARK_TNOISE))).floatValue();
            this.mThreshold.MinSublineDarkTNoise = 0;
            this.mThreshold.MaxSublineDarkTNoise = MaxSublineDarkTNoise;
            threshold = (threshold + "Subline_DarkTNoise: 0 , ") + MaxSublineDarkTNoise + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_DARK_SNOISE))) {
            float MaxSublineDarkSNoise = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_DARK_SNOISE))).floatValue();
            this.mThreshold.MinSublineDarkSNoise = 0;
            this.mThreshold.MaxSublineDarkSNoise = MaxSublineDarkSNoise;
            threshold = (threshold + "Subline_DarkSNoise: 0 , ") + MaxSublineDarkSNoise + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_LIGHT_LEAK_RATIO))) {
            float MaxSublineLightLeakRatio = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_LIGHT_LEAK_RATIO))).floatValue();
            this.mThreshold.MinSublineLightLeakRatio = 0;
            this.mThreshold.MaxSublineLightLeakRatio = MaxSublineLightLeakRatio;
            threshold = (threshold + "Subline_LightLeakRatio: 0 , ") + MaxSublineLightLeakRatio + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SUBLINE_FLESH_TOUCH_DIFF))) {
            float MinSublineFleshTouchDiff = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SUBLINE_FLESH_TOUCH_DIFF))).floatValue();
            this.mThreshold.MinSublineFleshTouchDiff = MinSublineFleshTouchDiff;
            this.mThreshold.MaxSublineFleshTouchDiff = 9999;
            threshold = (threshold + "Subline_FleshTouchDiff: " + MinSublineFleshTouchDiff + " , ") + "9999\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUNLINE_SCREEN_STRUCT_RATIO))) {
            float MaxSublineStructRatio = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUNLINE_SCREEN_STRUCT_RATIO))).floatValue();
            this.mThreshold.MinSublineStructRatio = 0;
            this.mThreshold.MaxSublineStructRatio = MaxSublineStructRatio;
            threshold = (threshold + "Subline_ScreenStructRatio: 0 , ") + MaxSublineStructRatio + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SUBLINE_RELATIVE_ILLUMINANCE))) {
            float MinSublineRelativeIlluminace = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SUBLINE_RELATIVE_ILLUMINANCE))).floatValue();
            this.mThreshold.MinSublineRelativeIlluminace1 = MinSublineRelativeIlluminace;
            this.mThreshold.MaxSublineRelativeIlluminace1 = 9999;
            this.mThreshold.MinSublineRelativeIlluminace2 = MinSublineRelativeIlluminace;
            this.mThreshold.MaxSublineRelativeIlluminace2 = 9999;
            this.mThreshold.MinSublineRelativeIlluminace3 = MinSublineRelativeIlluminace;
            this.mThreshold.MaxSublineRelativeIlluminace3 = 9999;
            this.mThreshold.MinSublineRelativeIlluminace4 = MinSublineRelativeIlluminace;
            this.mThreshold.MaxSublineRelativeIlluminace4 = 9999;
            threshold = (((((((threshold + "Subline_RelativeIlluminance1: " + MinSublineRelativeIlluminace + " , ") + "9999\n") + "Subline_RelativeIlluminance2: " + MinSublineRelativeIlluminace + " , ") + "9999\n") + "Subline_RelativeIlluminance3: " + MinSublineRelativeIlluminace + " , ") + "9999\n") + "Subline_RelativeIlluminance4: " + MinSublineRelativeIlluminace + " , ") + "9999\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SUBLINE_EXPO_TIME))) {
            int MinSublineExposure = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SUBLINE_EXPO_TIME))).intValue();
            this.mThreshold.MinSublineExposure = MinSublineExposure;
            threshold = threshold + "Subline_AETime: " + MinSublineExposure + " , ";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_EXPO_TIME))) {
            int MaxSublineExposure = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_EXPO_TIME))).intValue();
            this.mThreshold.MaxSublineExposure = MaxSublineExposure;
            threshold = threshold + MaxSublineExposure + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SUBLINE_P2P))) {
            float MinP2P2 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SUBLINE_P2P))).floatValue();
            Log.e(TAG, "filterThreshold Subline_Signal: " + MinP2P2);
            this.mThreshold.MinSublineSignal = MinP2P2;
            this.mThreshold.MaxSublineSignal = 9999;
            threshold = (threshold + "Subline_Signal: " + MinP2P2 + " , ") + "9999\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SUBLINE_SSNR))) {
            float MinSNR2 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SUBLINE_SSNR))).floatValue();
            Log.e(TAG, "filterThreshold Subline_SNR: " + MinSNR2);
            this.mThreshold.MinSublineSNR = MinSNR2;
            this.mThreshold.MaxSublineSNR = 9999;
            threshold = (threshold + "Subline_SNR: " + MinSNR2 + " , ") + "9999\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SUBLINE_SCALE_RATIO))) {
            float MinScaleRatio2 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SUBLINE_SCALE_RATIO))).floatValue();
            Log.e(TAG, "filterThreshold MinSublineScaleRatio: " + MinScaleRatio2);
            this.mThreshold.MinSublineScaleRatio = MinScaleRatio2;
            threshold = threshold + "Subline_ScaleRatio: " + MinScaleRatio2 + " , ";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_SCALE_RATIO))) {
            float MaxScaleRatio2 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_SCALE_RATIO))).floatValue();
            Log.e(TAG, "filterThreshold MaxSublineScaleRatio: " + MaxScaleRatio2);
            this.mThreshold.MaxSublineScaleRatio = MaxScaleRatio2;
            threshold = threshold + MaxScaleRatio2 + "\n";
        }
        if (result.containsKey(305)) {
            this.mNewSubline = ((Integer) result.get(305)).intValue();
            Log.e(TAG, "filterThreshold mNewSubline: " + this.mNewSubline);
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_SHELTER_RATIO))) {
            float value8 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_SHELTER_RATIO))).floatValue();
            Log.e(TAG, "filterThreshold Subline_MaxSublineShelterRatio: " + value8);
            this.mThreshold.MinSublineShelterRatio = 0.0f;
            this.mThreshold.MaxSublineShelterRatio = value8;
            threshold = (threshold + "Subline_ShelterRatio: 0 , ") + value8 + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_SHELTER_AREA))) {
            float value9 = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_SHELTER_AREA))).floatValue();
            Log.e(TAG, "filterThreshold Subline_MaxShelterArea: " + value9);
            this.mThreshold.MinSublineShelterArea = 0.0f;
            this.mThreshold.MaxSublineShelterArea = value9;
            threshold = (threshold + "Subline_ShelterArea: 0 , ") + value9 + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_TILT_LEVEL))) {
            int value10 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_TILT_LEVEL))).intValue();
            Log.e(TAG, "filterThreshold Subline_MaxTiltLevel: " + value10);
            this.mThreshold.MinSublineTiltLevel = 0;
            this.mThreshold.MaxSublineTiltLevel = value10;
            threshold = (threshold + "Subline_TiltLevel: 0 , ") + value10 + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_BUBBLE_NUM))) {
            int value11 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_BUBBLE_NUM))).intValue();
            Log.e(TAG, "filterThreshold Subline_MaxSublineBubble: " + value11);
            this.mThreshold.MaxSublineBubble = value11;
            threshold = (threshold + "Subline_MaxSublineBubble: 0 , ") + value11 + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_LARGEST_ORIENT))) {
            int value12 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_LARGEST_ORIENT))).intValue();
            Log.e(TAG, "filterThreshold Subline_MaxSublineLargestOrient: " + value12);
            this.mThreshold.MaxSublineLargestOrient = value12;
            threshold = (threshold + "Subline_MaxSublineLargestOrient: 0 , ") + value12 + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_BAD_BUBBLE))) {
            int value13 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_BAD_BUBBLE))).intValue();
            Log.e(TAG, "filterThreshold Subline_MaxSublineBadBubble: " + value13);
            this.mThreshold.MaxSublineBadBubble = value13;
            threshold = (threshold + "Subline_MaxSublineBadBubble: 0 , ") + value13 + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_CHART_DIRTY))) {
            int value14 = ((Integer) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_CHART_DIRTY))).intValue();
            Log.e(TAG, "filterThreshold Subline_MaxSublineChartDirty: " + value14);
            this.mThreshold.MaxSublineChartDirty = value14;
            threshold = (threshold + "Subline_MaxSublineChartDirty: 0 , ") + value14 + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SNR_P2P))) {
            float MinSNR_P2P = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SNR_P2P))).floatValue();
            this.mThreshold.MinSNR_Signal = MinSNR_P2P;
            this.mThreshold.MaxSNR_Signal = 9999;
            threshold = (threshold + "SNR_Signal: " + MinSNR_P2P + " , ") + "9999\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SNR_SCALE_RATIO))) {
            float MinSNRScaleRatio = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SNR_SCALE_RATIO))).floatValue();
            this.mThreshold.MinSNRScaleRatio = MinSNRScaleRatio;
            threshold = threshold + "SNR_ScaleRatio: " + MinSNRScaleRatio + " , ";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SNR_SCALE_RATIO))) {
            float MaxSNRScaleRatio = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MAX_SNR_SCALE_RATIO))).floatValue();
            this.mThreshold.MaxSNRScaleRatio = MaxSNRScaleRatio;
            threshold = threshold + MaxSNRScaleRatio + "\n";
        }
        if (result.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SNR_SSNR))) {
            float MinSNR_SNR = ((Float) result.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_MIN_SNR_SSNR))).floatValue();
            this.mThreshold.MinSNR_SNR = MinSNR_SNR;
            this.mThreshold.MaxSNR_SNR = 9999;
            threshold = (threshold + "SNR_SNR: " + MinSNR_SNR + " , ") + "9999\n";
        }
        Log.d(TAG, "In-System-Spec: " + threshold);
    }

    /* access modifiers changed from: private */
    public class TestTask implements ITask {
        private static final String TASK_TAG = "TestTask";
        private int mTestItem;

        public TestTask(int testItem) {
            this.mTestItem = testItem;
        }

        @Override // com.goodix.fingerprint.task.ITask
        public void run() {
            switch (this.mTestItem) {
                case 1:
                    Log.d(TASK_TAG, "TEST_SPI");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_SPI);
                    return;
                case 2:
                    Log.d(TASK_TAG, "TEST_FT_MT_CHECK");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_MT_CHECK);
                    return;
                case 5:
                    Log.d(TASK_TAG, "TEST_FT_SPI_RST_INT");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_SPI_RST_INT);
                    return;
                case 6:
                    Log.d(TASK_TAG, "FT_INIT");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_INIT);
                    return;
                case 7:
                    Log.d(TASK_TAG, "AUTO_EXPOSURE");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_EXPO_AUTO_CALIBRATION);
                    return;
                case 8:
                    Log.d(TASK_TAG, "H_FLESH");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_H_FLESH);
                    return;
                case 9:
                    Log.d(TASK_TAG, "H_FLESH");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_L_FLESH);
                    return;
                case 10:
                    Log.d(TASK_TAG, "H_DARK");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_H_DARK);
                    return;
                case 11:
                    Log.d(TASK_TAG, "L_DARK");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_L_DARK);
                    return;
                case 12:
                    Log.d(TASK_TAG, "DARK_SCREEN");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_DARK_BASE);
                    return;
                case 13:
                    Log.d(TASK_TAG, "PRE_CHART");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_CHECKBOX);
                    return;
                case 14:
                    Log.d(TASK_TAG, "CHART");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_CAPTURE_CHART);
                    return;
                case 15:
                    Log.d(TASK_TAG, "FT_EXIT");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_EXIT);
                    return;
                case 16:
                    Log.d(TASK_TAG, "SENSOR_INFO");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(1);
                    return;
                case 18:
                    Log.d(TASK_TAG, "SUB_LINE");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_SS_SUBLINE);
                    return;
                case 19:
                    Log.d(TASK_TAG, "SNR_CHART");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_SS_SNR);
                    return;
                case 50:
                    Log.d(TASK_TAG, "IN_SYSTEM_SPEC");
                    InSystemTest.this.mGoodixFingerprintManager.testCmd(ShenzhenConstants.CMD_TEST_SZ_FT_INIT);
                    return;
                default:
                    Log.d(TASK_TAG, "invalid test item.");
                    return;
            }
        }
    }
}
