package com.goodix.fingerprint.service;

import android.util.Log;
import com.goodix.fingerprint.utils.ShenzhenTestResultParser;
import com.goodix.fingerprint.utils.TestResultParser;
import java.util.HashMap;

public class DaemonMessageHandlerBase {
    private static final String TAG = "DaemonMessageHandlerBase";
    private IGoodixFingerprintCallback mFingerprintCallback;

    public void registerFingerprintCallback(IGoodixFingerprintCallback fingerprintCallback) {
        this.mFingerprintCallback = fingerprintCallback;
    }

    public void unRegisterFingerprintCallback() {
        this.mFingerprintCallback = null;
    }

    public void handleMessage(long devId, int msgId, int cmdId, byte[] data) {
        Log.d(TAG, "DaemonMessageHandlerBase, handleMessage msgId :" + msgId + " cmdId:" + cmdId);
        switch (msgId) {
            case GoodixFingerprintManager.FINGERPRINT_ERROR_HW_UNAVAILABLE /*{ENCODED_INT: -255}*/:
                onTestCmd(devId, GoodixFingerprintManager.FINGERPRINT_ERROR_HW_UNAVAILABLE, data);
                return;
            case -1:
                onError(devId, data);
                return;
            case 1:
                onAcquired(devId, data);
                return;
            case 3:
                onEnrollResult(devId, data);
                return;
            case 4:
                onRemoved(devId, data);
                return;
            case 5:
                onAuthenticated(devId, data);
                return;
            case 1001:
                onTestCmd(devId, cmdId, data);
                return;
            default:
                Log.d(TAG, "onDaemonMessage, msg<" + msgId + "> ignored!");
                return;
        }
    }

    public void onTestCmd(long deviceId, int cmdId, byte[] data) {
        handleTestCmd(cmdId, data);
    }

    /* access modifiers changed from: protected */
    public void handleError(int error) {
        this.mFingerprintCallback.onError(error);
    }

    /* access modifiers changed from: protected */
    public void handleAcquired(int acquiredInfo) {
        this.mFingerprintCallback.onAcquired(acquiredInfo);
    }

    /* access modifiers changed from: protected */
    public void handleImageResult(int msgType, byte[] bmpData, int bmpW, int bmpH, byte[] weakData, int weakW, int weakH, int imageQuality) {
        this.mFingerprintCallback.onImageResult(msgType, bmpData, bmpW, bmpH, weakData, weakW, weakH, imageQuality);
    }

    /* access modifiers changed from: protected */
    public void handleEnrollResult(int fingerId, int remaining) {
        this.mFingerprintCallback.onEnrollResult(fingerId, remaining);
    }

    /* access modifiers changed from: protected */
    public void handleRemoved(int fingerId) {
        this.mFingerprintCallback.onRemoved(fingerId);
    }

    /* access modifiers changed from: protected */
    public void handleAuthenticated(int fingerId) {
        if (fingerId != 0) {
            this.mFingerprintCallback.onAuthenticationSucceeded(fingerId);
        } else {
            this.mFingerprintCallback.onAuthenticationFailed();
        }
    }

    public void onEnrollResult(long devId, byte[] data) {
        int bmpHight;
        int weakWidth;
        int weakHight;
        int imageQuality;
        Log.d(TAG, "onEnrollResult, devId :" + devId + " data=" + data);
        HashMap<Integer, Object> testResult = ShenzhenTestResultParser.parse(data);
        if (testResult != null) {
            int msgType = -1;
            if (testResult.containsKey(1303)) {
                msgType = ((Integer) testResult.get(1303)).intValue();
            }
            int fid = -1;
            if (testResult.containsKey(1305)) {
                fid = ((Integer) testResult.get(1305)).intValue();
            }
            int gid = -1;
            if (testResult.containsKey(1306)) {
                gid = ((Integer) testResult.get(1306)).intValue();
            }
            int remaining = -1;
            if (testResult.containsKey(1307)) {
                remaining = ((Integer) testResult.get(1307)).intValue();
                Log.d(TAG, "onEnrollResult token remaining = " + remaining);
            }
            byte[] bmpData = new byte[0];
            if (testResult.containsKey(701)) {
                bmpData = (byte[]) testResult.get(701);
            }
            int bmpWidth = 0;
            if (testResult.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_BMP_DATA_WIDTH))) {
                bmpWidth = ((Integer) testResult.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_BMP_DATA_WIDTH))).intValue();
            }
            if (testResult.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_BMP_DATA_HEIGHT))) {
                bmpHight = ((Integer) testResult.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_BMP_DATA_HEIGHT))).intValue();
            } else {
                bmpHight = 0;
            }
            byte[] weakData = new byte[0];
            if (testResult.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_LONG_EXPOSURE_DATA))) {
                weakData = (byte[]) testResult.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_LONG_EXPOSURE_DATA));
            }
            if (testResult.containsKey(8001)) {
                weakWidth = ((Integer) testResult.get(8001)).intValue();
            } else {
                weakWidth = 0;
            }
            if (testResult.containsKey(8002)) {
                weakHight = ((Integer) testResult.get(8002)).intValue();
            } else {
                weakHight = 0;
            }
            if (testResult.containsKey(500)) {
                imageQuality = ((Integer) testResult.get(500)).intValue();
            } else {
                imageQuality = 0;
            }
            Log.d(TAG, "onEnrollResult bmpWidth = " + bmpWidth + " bmpHight =" + bmpHight + " type =" + msgType + " imageData =" + bmpData);
            Log.d(TAG, "onEnrollResult weakWidth = " + weakWidth + " weakHight =" + weakHight + " type =" + msgType + " weakData =" + weakData);
            if (bmpWidth <= 0 || bmpHight <= 0) {
                Log.d(TAG, "onEnrollResult sampleRemain = " + remaining);
                handleEnrollResult(fid, remaining);
                return;
            }
            Log.d(TAG, "handleImageResult");
            handleImageResult(msgType, bmpData, bmpWidth, bmpHight, weakData, weakWidth, weakHight, imageQuality);
        }
    }

    public void onAcquired(long devId, byte[] data) {
        HashMap<Integer, Object> testResult;
        if (data != null && data.length >= 4 && (testResult = ShenzhenTestResultParser.parse(data)) != null && testResult.containsKey(1304)) {
            int info = ((Integer) testResult.get(1304)).intValue();
            Log.d(TAG, "onAcquired, acquiredInfo :" + info);
            handleAcquired(info);
        }
    }

    public void onError(long devId, byte[] data) {
        if (data == null || data.length < 4) {
            Log.d(TAG, "onError, error.length < 4 or null.");
            return;
        }
        HashMap<Integer, Object> testResult = ShenzhenTestResultParser.parse(data);
        if (testResult != null && testResult.containsKey(100)) {
            int error = ((Integer) testResult.get(100)).intValue();
            Log.d(TAG, "onError, error :" + error);
            handleError(error);
        }
    }

    public void onAuthenticated(long devId, byte[] data) {
        int bmpHight;
        int weakWidth;
        int weakHight;
        int imageQuality;
        HashMap<Integer, Object> testResult = ShenzhenTestResultParser.parse(data);
        if (testResult != null) {
            int msgType = -1;
            if (testResult.containsKey(1303)) {
                msgType = ((Integer) testResult.get(1303)).intValue();
            }
            int fid = -1;
            if (testResult.containsKey(1305)) {
                fid = ((Integer) testResult.get(1305)).intValue();
            }
            if (testResult.containsKey(1306)) {
                ((Integer) testResult.get(1306)).intValue();
            }
            byte[] bmpData = new byte[0];
            if (testResult.containsKey(701)) {
                bmpData = (byte[]) testResult.get(701);
            }
            int bmpWidth = 0;
            if (testResult.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_BMP_DATA_WIDTH))) {
                bmpWidth = ((Integer) testResult.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_BMP_DATA_WIDTH))).intValue();
            }
            if (testResult.containsKey(Integer.valueOf((int) TestResultParser.TEST_TOKEN_BMP_DATA_HEIGHT))) {
                bmpHight = ((Integer) testResult.get(Integer.valueOf((int) TestResultParser.TEST_TOKEN_BMP_DATA_HEIGHT))).intValue();
            } else {
                bmpHight = 0;
            }
            byte[] weakData = new byte[0];
            if (testResult.containsKey(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_LONG_EXPOSURE_DATA))) {
                weakData = (byte[]) testResult.get(Integer.valueOf((int) ShenzhenTestResultParser.TEST_TOKEN_LONG_EXPOSURE_DATA));
            }
            if (testResult.containsKey(8001)) {
                weakWidth = ((Integer) testResult.get(8001)).intValue();
            } else {
                weakWidth = 0;
            }
            if (testResult.containsKey(8002)) {
                weakHight = ((Integer) testResult.get(8002)).intValue();
            } else {
                weakHight = 0;
            }
            if (testResult.containsKey(500)) {
                imageQuality = ((Integer) testResult.get(500)).intValue();
            } else {
                imageQuality = 0;
            }
            Log.d(TAG, "onAuthenticated bmpWidth = " + bmpWidth + " bmpHight =" + bmpHight + " type =" + msgType + " imageData =" + bmpData);
            Log.d(TAG, "onAuthenticated weakWidth = " + weakWidth + " weakHight =" + weakHight + " type =" + msgType + " weakData =" + weakData);
            if (bmpWidth <= 0 || bmpHight <= 0) {
                handleAuthenticated(fid);
                return;
            }
            Log.d(TAG, "handleImageResult");
            handleImageResult(msgType, bmpData, bmpWidth, bmpHight, weakData, weakWidth, weakHight, imageQuality);
        }
    }

    private int getIntValue(byte[] data) {
        return data[0] | (data[1] << 8) | (data[2] << 16) | (data[3] << 24);
    }

    public void onRemoved(long deviceId, byte[] data) {
        HashMap<Integer, Object> testResult = ShenzhenTestResultParser.parse(data);
        if (testResult != null) {
            if (testResult.containsKey(1303)) {
                ((Integer) testResult.get(1303)).intValue();
            }
            int fid = -1;
            if (testResult.containsKey(1305)) {
                fid = ((Integer) testResult.get(1305)).intValue();
            }
            int gid = -1;
            if (testResult.containsKey(1306)) {
                gid = ((Integer) testResult.get(1306)).intValue();
            }
            Log.d(TAG, "onRemoved, fid = " + fid + ", gid = " + gid);
            handleRemoved(fid);
        }
    }

    /* access modifiers changed from: protected */
    public void handleTestCmd(int cmdId, byte[] result) {
        Log.d(TAG, "handleTestCmd, mFingerprintCallback = " + this.mFingerprintCallback);
        this.mFingerprintCallback.onTestCmd(cmdId, result);
    }
}
