package com.goodix.fingerprint.service;

import android.content.Context;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.os.CancellationSignal;
import android.os.Handler;
import android.os.Message;
import android.support.v4.app.NotificationManagerCompat;
import android.support.v4.view.MotionEventCompat;
import android.util.Log;
import com.goodix.fingerprint.GFConfig;
import com.goodix.fingerprint.GFDevice;
import com.goodix.fingerprint.GFShenzhenConfig;
import com.goodix.fingerprint.ShenzhenConstants;
import com.goodix.fingerprint.utils.ShenzhenTestResultParser;
import com.goodix.fingerprint.utils.TestParamEncoder;
import com.goodix.fingerprint.utils.TestResultParser;
import com.google.common.primitives.UnsignedBytes;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;

public class GoodixFingerprintManager {
    public static final int FINGERPRINT_ACQUIRED_GOOD = 0;
    public static final int FINGERPRINT_ACQUIRED_IMAGER_DIRTY = 3;
    public static final int FINGERPRINT_ACQUIRED_INSUFFICIENT = 2;
    public static final int FINGERPRINT_ACQUIRED_PARTIAL = 1;
    public static final int FINGERPRINT_ACQUIRED_TOO_FAST = 5;
    public static final int FINGERPRINT_ACQUIRED_TOO_SLOW = 4;
    public static final int FINGERPRINT_ACQUIRED_VENDOR_BASE = 1000;
    public static final int FINGERPRINT_AREA_CHANGE_CYAN_BGCOLOR = 4;
    public static final int FINGERPRINT_AREA_HIDE = 2;
    public static final int FINGERPRINT_CHANGE_TO_BACKGROUND_BGCOLOR = 3;
    public static final int FINGERPRINT_CHANGE_TO_DARK_BGCOLOR = 12;
    public static final int FINGERPRINT_CHANGE_TO_SPMT_MODE = 5;
    public static final int FINGERPRINT_CLEAR_SPMT_MODE = 6;
    public static final int FINGERPRINT_ERROR_CANCELED = 5;
    public static final int FINGERPRINT_ERROR_HW_UNAVAILABLE = -255;
    public static final int FINGERPRINT_ERROR_INVALID_BASE = 1007;
    public static final int FINGERPRINT_ERROR_LOCKOUT = 7;
    public static final int FINGERPRINT_ERROR_NO_SPACE = 4;
    public static final int FINGERPRINT_ERROR_TIMEOUT = 3;
    public static final int FINGERPRINT_ERROR_UNABLE_TO_PROCESS = 2;
    public static final int FINGERPRINT_ERROR_UNABLE_TO_REMOVE = 6;
    public static final int FINGERPRINT_ERROR_VENDOR_BASE = 1000;
    public static final int FINGERPRINT_SHOW_INDICATOR = 1;
    public static final int GF_FINGERPRINT_AUTO_BACKGROUND_COLOR = 11;
    public static final int GF_FINGERPRINT_HIDE_CHART = 8;
    public static final int GF_FINGERPRINT_HIDE_CIRCLE = 10;
    public static final int GF_FINGERPRINT_SHOW_CHART = 7;
    public static final int GF_FINGERPRINT_SHOW_CIRCLE = 9;
    private static final int MSG_ACQUIRED = 101;
    private static final int MSG_AUTHENTICATED_FIDO = 1002;
    public static final int MSG_AUTHENTICATED_FIDO_CANCELED = 102;
    public static final int MSG_AUTHENTICATED_FIDO_LOCKOUT = 107;
    public static final int MSG_AUTHENTICATED_FIDO_NO_MATCH = 103;
    public static final int MSG_AUTHENTICATED_FIDO_SUCCESS = 100;
    public static final int MSG_AUTHENTICATED_FIDO_TIMEOUT = 113;
    private static final int MSG_AUTHENTICATE_IMAGE_RESULT = 107;
    private static final int MSG_AUTHENTICATION_FAILED = 103;
    private static final int MSG_AUTHENTICATION_SUCCEEDED = 102;
    private static final int MSG_DUMP = 1001;
    private static final int MSG_ENROLL_IMAGE_RESULT = 106;
    private static final int MSG_ENROLL_RESULT = 100;
    private static final int MSG_ERROR = 104;
    private static final int MSG_REMOVED = 105;
    public static final String MSG_REMOVE_FINGER_ID = "remove_finger_id";
    public static final String MSG_REMOVE_GROUP_ID = "remove_group_id";
    public static final String MSG_REMOVE_TEMPLATE_REMAIN = "remove_template_remain";
    private static final int MSG_SEC_AUTHENTICATE_RESULT = 109;
    private static final int MSG_SEC_ENROLL_RESULT = 108;
    private static final int MSG_TEST = 1000;
    private static final String TAG = "GoodixFingerprintManager";
    private static final String fingerprint_acquired_imager_dirty = "Sensor is dirty.";
    private static final String fingerprint_acquired_insufficient = "Can't process fingerprint.";
    private static final String fingerprint_acquired_partial = "Partial touch.";
    private static final String fingerprint_acquired_too_fast = "Moved too fast.";
    private static final String fingerprint_acquired_too_slow = "Moved too slow. ";
    private static final String[] fingerprint_acquired_vendor = {"goodix base", "", "", "", "", "Duplicate area", "Duplicate finger", ""};
    private static final String fingerprint_error_canceled = "Fingerprint operation canceled.";
    private static final String fingerprint_error_hw_not_available = "Fingerprint hardware not available.";
    private static final String fingerprint_error_lockout = "Too many attempts. Try again later.";
    private static final String fingerprint_error_no_space = "Fingerprint can't be stored. Please remove an existing fingerprint.";
    private static final String fingerprint_error_timeout = "Fingerprint time out reached. Try again.";
    private static final String fingerprint_error_unable_to_process = "Try again.";
    private static final String[] fingerprint_error_vendor = {"goodix error base", "Fingerprint hardware not available, too much under saturated pixels", "Fingerprint hardware not available, too much over saturated pixels", "Fingerprint hardware not available, spi communication failed"};
    private static int mEnrollTemplateCount;
    private static IGoodixFingerprintCallback mGoodixFingerprintCallback;
    private static Handler mHandler = null;
    private static GFService mIGoodixFingerprintInterface = null;
    private static GoodixFingerprintManager sGoodixFingerprintManager;
    private AuthenticateFidoCallback mAuthenticateFidoCallback = null;
    private Context mContext = null;
    private DumpCallback mDumpCallback = null;
    public OnTouchAreaCallback mOnTouchAreaCallback = null;
    private String mOpPackageName = null;
    private TestCmdCallback mTestCallback = null;
    private TimeOutRunnable mTimeOutRunnable = null;
    private UntrustedAuthenticationCallback mUntrustedAuthenticationCallback = null;
    private UntrustedEnrollmentCallback mUntrustedEnrollmentCallback = null;
    private UntrustedRemovalCallback mUntrustedRemovalCallback = null;

    public interface AuthenticateFidoCallback {
        void onResult(int i, byte[] bArr, byte[] bArr2);
    }

    public interface DumpCallback {
        void onDump(int i, HashMap<Integer, Object> hashMap);
    }

    public interface TestCmdCallback {
        void onTestCmd(int i, HashMap<Integer, Object> hashMap);
    }

    /* access modifiers changed from: private */
    public class OnUntrustedEnrollCancelListener implements CancellationSignal.OnCancelListener {
        private OnUntrustedEnrollCancelListener() {
        }

        public void onCancel() {
            GoodixFingerprintManager.this.cancelUntrustedEnrollment();
        }
    }

    /* access modifiers changed from: private */
    public class OnUntrustedAuthenticationCancelListener implements CancellationSignal.OnCancelListener {
        private OnUntrustedAuthenticationCancelListener() {
        }

        public void onCancel() {
            GoodixFingerprintManager.this.cancelUntrustedAuthentication();
        }
    }

    public static abstract class OnTouchAreaCallback {
        public void onTouchAreaInfo(int info) {
        }
    }

    public static abstract class UntrustedEnrollmentCallback {
        public void onEnrollmentError(int errMsgId, CharSequence errString) {
        }

        public void onEnrollmentHelp(int helpMsgId, CharSequence helpString) {
        }

        public void onEnrollmentProgress(int fingerId, int remaining) {
        }

        public void onEnrollmentAcquired(int acquireInfo) {
        }

        public void onEnrollImage(byte[] bmpData, int bmpW, int bmpH, byte[] weakData, int weakW, int weakH, int fovAvg) {
        }
    }

    public static abstract class UntrustedAuthenticationCallback {
        public void onAuthenticationError(int errorCode, CharSequence errString) {
        }

        public void onAuthenticationHelp(int helpCode, CharSequence helpString) {
        }

        public void onAuthenticationSucceeded(int fingerId) {
        }

        public void onAuthenticationFailed() {
        }

        public void onAuthenticationAcquired(int acquireInfo) {
        }

        public void onAuthenticateImage(byte[] bmpData, int bmpW, int bmpH, byte[] weakData, int weakW, int weakH, int fovAvg) {
        }
    }

    public static abstract class UntrustedRemovalCallback {
        public void onRemovalError(int errMsgId, CharSequence errString) {
        }

        public void onRemovalSucceeded(int fingerId, int groupId, int templateRemain) {
        }
    }

    private String getAppOpPackageName() {
        Context context = this.mContext;
        if (context == null) {
            return null;
        }
        try {
            Method getOpPackageName = context.getClass().getMethod("getOpPackageName", new Class[0]);
            getOpPackageName.setAccessible(true);
            return (String) getOpPackageName.invoke(this.mContext, new Object[0]);
        } catch (NoSuchMethodException e) {
            Log.e(TAG, "getAppOpPackageName NoSuchMethodException: ", e);
            return null;
        } catch (IllegalAccessException e2) {
            Log.e(TAG, "getAppOpPackageName IllegalAccessException: ", e2);
            return null;
        } catch (InvocationTargetException e3) {
            Log.e(TAG, "getAppOpPackageName InvocationTargetException: ", e3);
            return null;
        } catch (IllegalArgumentException e4) {
            Log.e(TAG, "getAppOpPackageName IllegalArgumentException: ", e4);
            return null;
        }
    }

    private void resetFidoAuthenticateTimeOut(long timeout) {
        Handler handler = mHandler;
        if (handler != null) {
            handler.postDelayed(this.mTimeOutRunnable, timeout);
        }
    }

    private class TimeOutRunnable implements Runnable {
        private TimeOutRunnable() {
        }

        public void run() {
            if (GoodixFingerprintManager.this.mAuthenticateFidoCallback != null) {
                GoodixFingerprintManager.this.mAuthenticateFidoCallback.onResult(113, null, null);
            }
        }
    }

    public static GoodixFingerprintManager getFingerprintManager(Context context) {
        Log.e(TAG, "getFingerprintManager = " + sGoodixFingerprintManager);
        if (sGoodixFingerprintManager == null) {
            Log.e(TAG, "sGoodixFingerprintManager create. ");
            sGoodixFingerprintManager = new GoodixFingerprintManager(context);
        }
        return sGoodixFingerprintManager;
    }

    public void setGoodixFingerprintManager(GoodixFingerprintManager manager) {
        sGoodixFingerprintManager = manager;
    }

    public GoodixFingerprintManager(Context context) {
        this.mContext = context;
        createFingerprintCallback();
        initService(context);
        this.mOpPackageName = getAppOpPackageName();
        sGoodixFingerprintManager = this;
    }

    private void initService(Context context) {
        mHandler = new MyHandler(context);
        mIGoodixFingerprintInterface = new GFService(context);
        Log.d(TAG, "registerFingerprintCallback = " + mGoodixFingerprintCallback);
        mIGoodixFingerprintInterface.registerFingerprintCallback(mGoodixFingerprintCallback);
    }

    public void registerOnTouchAreaCallback(OnTouchAreaCallback callback) {
        this.mOnTouchAreaCallback = callback;
    }

    public void registerTestCmdCallback(TestCmdCallback callback) {
        Log.d(TAG, "GoodixFingerprintManager = " + this);
        Log.d(TAG, "registerTestCmdCallback = " + callback);
        this.mTestCallback = callback;
    }

    public void unregisterTestCmdCallback(TestCmdCallback callback) {
        Log.d(TAG, "unregisterTestCmdCallback = " + callback);
        this.mTestCallback = null;
    }

    public void testCmd(int cmdId) {
        Log.e(TAG, "testCmd  " + cmdId);
        testCmd(cmdId, null);
    }

    public void testCmd(int cmdId, byte[] param) {
        Log.e(TAG, "testCmd  " + cmdId + " mIGoodixFingerprintInterface " + mIGoodixFingerprintInterface);
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "testCmd no com.goodix.FingerprintService");
        } else {
            gFService.testCmd(cmdId, param, this.mOpPackageName);
        }
    }

    public void navigate(int navMode) {
        Log.d(TAG, "navigate");
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "navigate no com.goodix.FingerprintService");
        } else {
            gFService.navigate(navMode, this.mOpPackageName);
        }
    }

    public void stopNavigation() {
        Log.d(TAG, "stopNavigation");
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "stopNavigation no com.goodix.FingerprintService");
        } else {
            gFService.stopNavigation(this.mOpPackageName);
        }
    }

    public GFConfig getConfig() {
        Log.d(TAG, "getConfig");
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService != null) {
            return gFService.getConfig(this.mOpPackageName);
        }
        Log.e(TAG, "getConfig null interface com.goodix.FingerprintService");
        return null;
    }

    public GFDevice getDevice() {
        Log.d(TAG, "getDevice");
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService != null) {
            return gFService.getDevice(this.mOpPackageName);
        }
        Log.e(TAG, "getDevice null interface com.goodix.FingerprintService");
        return null;
    }

    private int getMyUserId() {
        try {
            return ((Integer) Class.forName("android.os.UserHandle").getMethod("myUserId", new Class[0]).invoke(null, new Object[0])).intValue();
        } catch (ClassNotFoundException e) {
            Log.e(TAG, "getMyUserId ClassNotFoundException: ", e);
            return 0;
        } catch (NoSuchMethodException e2) {
            Log.e(TAG, "getMyUserId NoSuchMethodException: ", e2);
            return 0;
        } catch (IllegalAccessException e3) {
            Log.e(TAG, "getMyUserId IllegalAccessException: ", e3);
            return 0;
        } catch (InvocationTargetException e4) {
            Log.e(TAG, "getMyUserId InvocationTargetException: ", e4);
            return 0;
        } catch (IllegalArgumentException e5) {
            Log.e(TAG, "getMyUserId IllegalArgumentException: ", e5);
            return 0;
        }
    }

    public void untrustedAuthenticate(CancellationSignal cancel, UntrustedAuthenticationCallback callback) {
        if (callback != null) {
            if (cancel != null) {
                if (cancel.isCanceled()) {
                    Log.w(TAG, "untrusted authentication already canceled");
                    return;
                }
                cancel.setOnCancelListener(new OnUntrustedAuthenticationCancelListener());
            }
            GFService gFService = mIGoodixFingerprintInterface;
            if (gFService != null) {
                this.mUntrustedAuthenticationCallback = callback;
                gFService.untrustedAuthenticate(getAppOpPackageName());
                return;
            }
            return;
        }
        throw new IllegalArgumentException("Must supply an untrusted authentication callback");
    }

    public void untrustedAuthenticate2(String userDesc, CancellationSignal cancel, UntrustedAuthenticationCallback callback) {
        if (callback != null) {
            if (cancel != null) {
                if (cancel.isCanceled()) {
                    Log.w(TAG, "untrusted authentication already canceled");
                    return;
                }
                cancel.setOnCancelListener(new OnUntrustedAuthenticationCancelListener());
            }
            GFService gFService = mIGoodixFingerprintInterface;
            if (gFService != null) {
                this.mUntrustedAuthenticationCallback = callback;
                gFService.untrustedAuthenticate2(userDesc, getAppOpPackageName());
                return;
            }
            return;
        }
        throw new IllegalArgumentException("Must supply an untrusted authentication callback");
    }

    public void cancelUntrustedAuthentication() {
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService != null) {
            gFService.cancelUntrustedAuthentication(getAppOpPackageName());
        }
        this.mUntrustedAuthenticationCallback = null;
    }

    public void untrustedEnroll(CancellationSignal cancel, UntrustedEnrollmentCallback callback) {
        if (callback != null) {
            if (cancel != null) {
                if (cancel.isCanceled()) {
                    Log.w(TAG, "untrusted enrollment already canceled");
                    return;
                }
                cancel.setOnCancelListener(new OnUntrustedEnrollCancelListener());
            }
            GFService gFService = mIGoodixFingerprintInterface;
            if (gFService != null) {
                this.mUntrustedEnrollmentCallback = callback;
                gFService.untrustedEnroll(getAppOpPackageName());
                return;
            }
            return;
        }
        throw new IllegalArgumentException("Must supply an untrusted enrollment callback");
    }

    public void untrustedEnroll2(String userDesc, CancellationSignal cancel, UntrustedEnrollmentCallback callback) {
        if (callback != null) {
            if (cancel != null) {
                if (cancel.isCanceled()) {
                    Log.w(TAG, "untrusted enrollment already canceled");
                    return;
                }
                cancel.setOnCancelListener(new OnUntrustedEnrollCancelListener());
            }
            GFService gFService = mIGoodixFingerprintInterface;
            if (gFService != null) {
                this.mUntrustedEnrollmentCallback = callback;
                gFService.untrustedEnroll2(userDesc, getAppOpPackageName());
                return;
            }
            return;
        }
        throw new IllegalArgumentException("Must supply an untrusted enrollment callback");
    }

    public void cancelUntrustedEnrollment() {
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService != null) {
            gFService.cancelUntrustedEnrollment(getAppOpPackageName());
        }
        this.mUntrustedEnrollmentCallback = null;
    }

    public void setActiveGroup(int groupId) {
        byte[] byteArray = new byte[8];
        TestParamEncoder.encodeInt32(byteArray, 0, ShenzhenTestResultParser.TEST_TOKEN_SET_GROUP_ID, groupId);
        testCmd(ShenzhenConstants.CMD_TEST_SZ_SET_GROUP_ID, byteArray);
    }

    public void sendTouchDown(EventData eventData) {
        testCmd(1536, null);
    }

    public void sendTouchUp() {
        testCmd(ShenzhenConstants.CMD_TEST_SZ_FINGER_UP, null);
    }

    public void untrustedRemove(int cmdId, byte[] param, UntrustedRemovalCallback callback) {
        if (mIGoodixFingerprintInterface != null) {
            this.mUntrustedRemovalCallback = callback;
            testCmd(cmdId, param);
        }
    }

    public void untrustedRemove(UntrustedRemovalCallback callback) {
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService != null) {
            this.mUntrustedRemovalCallback = callback;
            gFService.untrustedRemove(mGoodixFingerprintCallback, getAppOpPackageName());
        }
    }

    public GFShenzhenConfig getShenzhenConfig() {
        Log.d(TAG, "getShenzhenConfig");
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService != null) {
            return gFService.getShenzhenConfig();
        }
        return null;
    }

    public void setShenzhenConfig(GFShenzhenConfig config) {
        Log.d(TAG, "setShenzhenConfig");
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService != null) {
            gFService.setShenzhenConfig(config);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getErrorString(int errMsg) {
        switch (errMsg) {
            case FINGERPRINT_ERROR_HW_UNAVAILABLE /*{ENCODED_INT: -255}*/:
                return fingerprint_error_hw_not_available;
            case 2:
                return fingerprint_error_unable_to_process;
            case 3:
                return fingerprint_error_timeout;
            case 4:
                return fingerprint_error_no_space;
            case 5:
                return fingerprint_error_canceled;
            case 7:
                return fingerprint_error_lockout;
            default:
                if (errMsg < 1000) {
                    return null;
                }
                int msgNumber = errMsg + NotificationManagerCompat.IMPORTANCE_UNSPECIFIED;
                String[] msgArray = fingerprint_error_vendor;
                if (msgNumber < msgArray.length) {
                    return msgArray[msgNumber];
                }
                return null;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getAcquiredString(int acquireInfo) {
        switch (acquireInfo) {
            case 0:
                return null;
            case 1:
                return fingerprint_acquired_partial;
            case 2:
                return fingerprint_acquired_insufficient;
            case 3:
                return fingerprint_acquired_imager_dirty;
            case 4:
                return fingerprint_acquired_too_slow;
            case 5:
                return fingerprint_acquired_too_fast;
            default:
                if (acquireInfo >= 1000) {
                    int msgNumber = acquireInfo + NotificationManagerCompat.IMPORTANCE_UNSPECIFIED;
                    String[] msgArray = fingerprint_acquired_vendor;
                    if (msgNumber < msgArray.length) {
                        return msgArray[msgNumber];
                    }
                }
                return null;
        }
    }

    public int getEnrollCountMin() {
        return mEnrollTemplateCount;
    }

    /* access modifiers changed from: private */
    public class MyHandler extends Handler {
        private MyHandler(Context context) {
            super(context.getMainLooper());
        }

        public void handleMessage(Message msg) {
            int result;
            switch (msg.what) {
                case 100:
                    if (GoodixFingerprintManager.this.mUntrustedEnrollmentCallback != null) {
                        GoodixFingerprintManager.this.mUntrustedEnrollmentCallback.onEnrollmentProgress(msg.arg1, msg.arg2);
                        return;
                    } else {
                        Log.d(GoodixFingerprintManager.TAG, "MSG_ENROLL_RESULT no callback");
                        return;
                    }
                case 101:
                    if (GoodixFingerprintManager.this.mUntrustedEnrollmentCallback != null) {
                        Log.d(GoodixFingerprintManager.TAG, "MSG_ACQUIRED Enrollment.");
                        GoodixFingerprintManager.this.mUntrustedEnrollmentCallback.onEnrollmentAcquired(msg.arg1);
                        if (GoodixFingerprintManager.this.mUntrustedEnrollmentCallback != null) {
                            GoodixFingerprintManager.this.mUntrustedEnrollmentCallback.onEnrollmentHelp(msg.arg1, GoodixFingerprintManager.this.getAcquiredString(msg.arg1));
                            return;
                        }
                        return;
                    } else if (GoodixFingerprintManager.this.mUntrustedAuthenticationCallback != null) {
                        Log.d(GoodixFingerprintManager.TAG, "MSG_ACQUIRED Authentication.");
                        GoodixFingerprintManager.this.mUntrustedAuthenticationCallback.onAuthenticationAcquired(msg.arg1);
                        if (GoodixFingerprintManager.this.mUntrustedAuthenticationCallback != null) {
                            GoodixFingerprintManager.this.mUntrustedAuthenticationCallback.onAuthenticationHelp(msg.arg1, GoodixFingerprintManager.this.getAcquiredString(msg.arg1));
                            return;
                        }
                        return;
                    } else {
                        Log.d(GoodixFingerprintManager.TAG, "MSG_ACQUIRED no callback");
                        return;
                    }
                case 102:
                    if (GoodixFingerprintManager.this.mUntrustedAuthenticationCallback != null) {
                        GoodixFingerprintManager.this.mUntrustedAuthenticationCallback.onAuthenticationSucceeded(msg.arg1);
                        return;
                    } else {
                        Log.d(GoodixFingerprintManager.TAG, "MSG_AUTHENTICATION_SUCCEEDED no callback");
                        return;
                    }
                case 103:
                    if (GoodixFingerprintManager.this.mUntrustedAuthenticationCallback != null) {
                        GoodixFingerprintManager.this.mUntrustedAuthenticationCallback.onAuthenticationFailed();
                        return;
                    } else {
                        Log.d(GoodixFingerprintManager.TAG, "MSG_AUTHENTICATION_FAILED no callback");
                        return;
                    }
                case 104:
                    Log.d(GoodixFingerprintManager.TAG, "MSG_ERROR .");
                    if (GoodixFingerprintManager.this.mUntrustedEnrollmentCallback != null) {
                        GoodixFingerprintManager.this.mUntrustedEnrollmentCallback.onEnrollmentError(msg.arg1, GoodixFingerprintManager.this.getErrorString(msg.arg1));
                        return;
                    } else if (GoodixFingerprintManager.this.mUntrustedAuthenticationCallback != null) {
                        GoodixFingerprintManager.this.mUntrustedAuthenticationCallback.onAuthenticationError(msg.arg1, GoodixFingerprintManager.this.getErrorString(msg.arg1));
                        return;
                    } else if (GoodixFingerprintManager.this.mUntrustedRemovalCallback != null) {
                        GoodixFingerprintManager.this.mUntrustedRemovalCallback.onRemovalError(msg.arg1, GoodixFingerprintManager.this.getErrorString(msg.arg1));
                        return;
                    } else if (GoodixFingerprintManager.this.mTestCallback != null) {
                        GoodixFingerprintManager.this.mTestCallback.onTestCmd(msg.arg1, ShenzhenTestResultParser.parse((byte[]) msg.obj));
                        return;
                    } else {
                        Log.d(GoodixFingerprintManager.TAG, "MSG_ERROR no callback");
                        return;
                    }
                case 105:
                    if (GoodixFingerprintManager.this.mUntrustedRemovalCallback != null) {
                        Bundle bundle = msg.getData();
                        GoodixFingerprintManager.this.mUntrustedRemovalCallback.onRemovalSucceeded(bundle.getInt(GoodixFingerprintManager.MSG_REMOVE_FINGER_ID), bundle.getInt(GoodixFingerprintManager.MSG_REMOVE_GROUP_ID), bundle.getInt(GoodixFingerprintManager.MSG_REMOVE_TEMPLATE_REMAIN));
                        return;
                    }
                    Log.d(GoodixFingerprintManager.TAG, "MSG_REMOVED no callback");
                    return;
                case 106:
                    if (GoodixFingerprintManager.this.mUntrustedEnrollmentCallback != null) {
                        Log.e(GoodixFingerprintManager.TAG, "handleMessage, MSG_ENROLL_IMAGE_RESULT");
                        Bundle bundle2 = msg.getData();
                        byte[] bmpData = bundle2.getByteArray(ShenzhenConstants.BUNDLE_BMP_DATA);
                        int bmpW = bundle2.getInt(ShenzhenConstants.BUNDLE_BMP_WIDTH, 0);
                        int bmpH = bundle2.getInt(ShenzhenConstants.BUNDLE_BMP_HEIGHT, 0);
                        byte[] weakData = bundle2.getByteArray(ShenzhenConstants.BUNDLE_WEAK_DATA);
                        int weakW = bundle2.getInt(ShenzhenConstants.BUNDLE_WEAK_WIDTH, 0);
                        int weakH = bundle2.getInt(ShenzhenConstants.BUNDLE_WEAK_HEIGHT, 0);
                        Log.d(GoodixFingerprintManager.TAG, "MSG_ENROLL_IMAGE_RESULT,bmpData width:" + bmpW + " height:" + bmpH);
                        Log.d(GoodixFingerprintManager.TAG, "MSG_ENROLL_IMAGE_RESULT,weakData width:" + weakW + " height:" + weakH);
                        GoodixFingerprintManager.this.mUntrustedEnrollmentCallback.onEnrollImage(bmpData, bmpW, bmpH, weakData, weakW, weakH, bundle2.getInt(ShenzhenConstants.BUNDLE_IMAGE_QUALITY, 0));
                        return;
                    }
                    return;
                case 107:
                    if (GoodixFingerprintManager.this.mUntrustedAuthenticationCallback != null) {
                        Log.e(GoodixFingerprintManager.TAG, "handleMessage, MSG_AUTHENTICATE_IMAGE_RESULT");
                        Bundle bundle3 = msg.getData();
                        byte[] bmpData2 = bundle3.getByteArray(ShenzhenConstants.BUNDLE_BMP_DATA);
                        int bmpW2 = bundle3.getInt(ShenzhenConstants.BUNDLE_BMP_WIDTH, 0);
                        int bmpH2 = bundle3.getInt(ShenzhenConstants.BUNDLE_BMP_HEIGHT, 0);
                        byte[] weakData2 = bundle3.getByteArray(ShenzhenConstants.BUNDLE_WEAK_DATA);
                        int weakW2 = bundle3.getInt(ShenzhenConstants.BUNDLE_WEAK_WIDTH, 0);
                        int weakH2 = bundle3.getInt(ShenzhenConstants.BUNDLE_WEAK_HEIGHT, 0);
                        Log.d(GoodixFingerprintManager.TAG, "MSG_AUTHENTICATE_IMAGE_RESULT,bmpData width:" + bmpW2 + " height:" + bmpH2);
                        Log.d(GoodixFingerprintManager.TAG, "MSG_AUTHENTICATE_IMAGE_RESULT,weakData width:" + weakW2 + " height:" + weakH2);
                        GoodixFingerprintManager.this.mUntrustedAuthenticationCallback.onAuthenticateImage(bmpData2, bmpW2, bmpH2, weakData2, weakW2, weakH2, bundle3.getInt(ShenzhenConstants.BUNDLE_IMAGE_QUALITY, 0));
                        return;
                    }
                    return;
                case 1000:
                    Log.e(GoodixFingerprintManager.TAG, "getFingerprintManager = " + GoodixFingerprintManager.sGoodixFingerprintManager);
                    Log.d(GoodixFingerprintManager.TAG, "MSG_TEST mTestCallback = " + GoodixFingerprintManager.this.mTestCallback);
                    if (GoodixFingerprintManager.this.mTestCallback != null) {
                        GoodixFingerprintManager.this.mTestCallback.onTestCmd(msg.arg1, ShenzhenTestResultParser.parse((byte[]) msg.obj));
                        return;
                    }
                    return;
                case 1001:
                    if (GoodixFingerprintManager.this.mDumpCallback != null) {
                        GoodixFingerprintManager.this.mDumpCallback.onDump(msg.arg1, TestResultParser.parse(msg.arg2, (byte[]) msg.obj));
                        return;
                    }
                    return;
                case 1002:
                    if (GoodixFingerprintManager.this.mAuthenticateFidoCallback != null) {
                        int fingerId = msg.arg1;
                        byte[] uvtData = (byte[]) msg.obj;
                        if (fingerId != 0 && uvtData != null && uvtData.length > 0) {
                            result = 100;
                        } else if (fingerId == 0) {
                            result = 103;
                        } else if (fingerId == 0 || !(uvtData == null || uvtData.length == 0)) {
                            result = 113;
                        } else {
                            result = 102;
                        }
                        GoodixFingerprintManager.this.mAuthenticateFidoCallback.onResult(result, uvtData, GoodixFingerprintManager.int2bytes(fingerId));
                        return;
                    }
                    Log.e(GoodixFingerprintManager.TAG, "handleMessage, mAuthenticateFidoCallback is null");
                    return;
                default:
                    return;
            }
        }
    }

    private Bitmap convertToBitmap(byte[] result, int width, int height) {
        Log.d(TAG, "convertToBitmap width=" + width + ",height=" + height + " data=" + result);
        if (width == 0 || height == 0) {
            return null;
        }
        int length = width * height;
        int[] display = new int[length];
        for (int i = 0; i < length; i++) {
            int pixel = result[i] & UnsignedBytes.MAX_VALUE;
            display[i] = -16777216 | (pixel << 16) | (pixel << 8) | pixel;
        }
        return Bitmap.createBitmap(display, width, height, Bitmap.Config.ARGB_8888);
    }

    private static IGoodixFingerprintCallback createFingerprintCallback() {
        AnonymousClass1 r0 = new IGoodixFingerprintCallback() {
            /* class com.goodix.fingerprint.service.GoodixFingerprintManager.AnonymousClass1 */

            @Override // com.goodix.fingerprint.service.IGoodixFingerprintCallback
            public void onImageResult(int msgType, byte[] bmpData, int bmpW, int bmpH, byte[] weakData, int weakW, int weakH, int imageQuality) {
                Log.d(GoodixFingerprintManager.TAG, "onImageResult,bmpData width:" + bmpW + " height:" + bmpH);
                Log.d(GoodixFingerprintManager.TAG, "onImageResult,weakData width:" + weakW + " height:" + weakH);
                Message msg = null;
                switch (msgType) {
                    case 3:
                        msg = GoodixFingerprintManager.mHandler.obtainMessage(106);
                        break;
                    case 5:
                        msg = GoodixFingerprintManager.mHandler.obtainMessage(107);
                        break;
                }
                if (msg != null) {
                    Bundle bundle = new Bundle();
                    bundle.putByteArray(ShenzhenConstants.BUNDLE_BMP_DATA, bmpData);
                    bundle.putInt(ShenzhenConstants.BUNDLE_BMP_WIDTH, bmpW);
                    bundle.putInt(ShenzhenConstants.BUNDLE_BMP_HEIGHT, bmpH);
                    bundle.putByteArray(ShenzhenConstants.BUNDLE_WEAK_DATA, weakData);
                    bundle.putInt(ShenzhenConstants.BUNDLE_WEAK_WIDTH, weakW);
                    bundle.putInt(ShenzhenConstants.BUNDLE_WEAK_HEIGHT, weakH);
                    bundle.putInt(ShenzhenConstants.BUNDLE_IMAGE_QUALITY, imageQuality);
                    msg.setData(bundle);
                    msg.sendToTarget();
                }
            }

            @Override // com.goodix.fingerprint.service.IGoodixFingerprintCallback
            public void onTestCmd(int cmdId, byte[] result) {
                GoodixFingerprintManager.mHandler.obtainMessage(1000, cmdId, 0, result).sendToTarget();
            }

            @Override // com.goodix.fingerprint.service.IGoodixFingerprintCallback
            public void onEnrollResult(int fingerId, int remaining) {
                Log.d(GoodixFingerprintManager.TAG, "onEnrollResult fingerId = " + fingerId + " remaining = " + remaining);
                GoodixFingerprintManager.mHandler.obtainMessage(100, fingerId, remaining).sendToTarget();
            }

            @Override // com.goodix.fingerprint.service.IGoodixFingerprintCallback
            public void onAcquired(int acquireInfo) {
                GoodixFingerprintManager.mHandler.obtainMessage(101, acquireInfo, 0).sendToTarget();
            }

            @Override // com.goodix.fingerprint.service.IGoodixFingerprintCallback
            public void onAuthenticationSucceeded(int fingerId) {
                GoodixFingerprintManager.mHandler.obtainMessage(102, fingerId, 0).sendToTarget();
            }

            @Override // com.goodix.fingerprint.service.IGoodixFingerprintCallback
            public void onAuthenticationFailed() {
                GoodixFingerprintManager.mHandler.obtainMessage(103).sendToTarget();
            }

            @Override // com.goodix.fingerprint.service.IGoodixFingerprintCallback
            public void onError(int error) {
                GoodixFingerprintManager.mHandler.obtainMessage(104, error, 0).sendToTarget();
            }

            @Override // com.goodix.fingerprint.service.IGoodixFingerprintCallback
            public void onRemoved(int fingerId) {
                GoodixFingerprintManager.mHandler.obtainMessage(105, fingerId, 0).sendToTarget();
            }
        };
        mGoodixFingerprintCallback = r0;
        return r0;
    }

    public static byte[] int2bytes(int res) {
        return new byte[]{(byte) (res & 255), (byte) ((res >> 8) & 255), (byte) ((res >> 16) & 255), (byte) (res >>> 24)};
    }

    public static int bytes2int(byte[] res) {
        return (res[0] & UnsignedBytes.MAX_VALUE) | ((res[1] << 8) & MotionEventCompat.ACTION_POINTER_INDEX_MASK) | ((res[2] << 24) >>> 8) | (res[3] << 24);
    }

    public String getLibaryVersion() {
        return mIGoodixFingerprintInterface.getLibaryVersion();
    }

    public String getTestNum() {
        return mIGoodixFingerprintInterface.getTestNum();
    }

    public int getHighBrightness() {
        return mIGoodixFingerprintInterface.getHightBrighness();
    }

    public int getMiddleBrightness() {
        return mIGoodixFingerprintInterface.getMiddleBrightness();
    }

    public int getLowBrightness() {
        return mIGoodixFingerprintInterface.getLowBrightness();
    }

    public void saveCalibrationData(int saveFlag) {
        byte[] dataBytes = new byte[8];
        TestParamEncoder.encodeInt32(dataBytes, 0, 1210, saveFlag);
        testCmd(ShenzhenConstants.CMD_TEST_SZ_SS_SAVE_DATA, dataBytes);
    }

    public void openOrCloseHBMMode(int mode) {
        Log.d(TAG, "openOrCloseHBMMode");
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "openOrCloseHBMMode no com.goodix.FingerprintService");
        } else {
            gFService.openOrCloseHBMMode(mode);
        }
    }

    public void setHBMMode(boolean open) {
        Log.d(TAG, "setHBMMode");
        if (open) {
            testCmd(ShenzhenConstants.CMD_TEST_SZ_SET_HIGH_BRIGHTNESS);
        } else {
            testCmd(ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS);
        }
        mIGoodixFingerprintInterface.setHBMMode(open);
    }

    public void setScreenManualMode() {
        Log.d(TAG, "setScreenManualMode");
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "setScreenManualMode no com.goodix.FingerprintService");
        } else {
            gFService.setScreenManualMode();
        }
    }

    public void setScreenBrightness(int value) {
        Log.d(TAG, "setScreenBrightness");
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService == null) {
            Log.e(TAG, "setScreenBrightness no com.goodix.FingerprintService");
        } else {
            gFService.setScreenBrightness(value);
        }
    }

    public void setScreenBrightnessR15(int value) {
        Log.d(TAG, "setScreenBrightnessR15");
        byte[] dataBytes = new byte[8];
        TestParamEncoder.encodeInt32(dataBytes, 0, 1210, value);
        testCmd(ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS, dataBytes);
        mIGoodixFingerprintInterface.setScreenBrightnessR15(value);
    }

    public int getScreenBrightness() {
        Log.d(TAG, "getScreenBrightness");
        GFService gFService = mIGoodixFingerprintInterface;
        if (gFService != null) {
            return gFService.getScreenBrightness();
        }
        Log.e(TAG, "getScreenBrightness no com.goodix.FingerprintService");
        return 255;
    }
}
