package com.goodix.fingerprint.task;

import android.util.Log;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.locks.LockSupport;

public class TaskExecutor extends Thread {
    private static final String TAG = "TaskExecutor";
    private boolean isPause = false;
    private boolean isRunning = true;
    private BlockingQueue<ITask> taskQueue;

    public TaskExecutor(BlockingQueue<ITask> taskQueue2) {
        this.taskQueue = taskQueue2;
    }

    public void run() {
        ITask iTask;
        while (this.isRunning) {
            try {
                if (this.isPause) {
                    Log.d(TAG, "Wait for ready...");
                    LockSupport.park(this);
                    iTask = this.taskQueue.take();
                    Log.d(TAG, "Ready to Go!");
                } else {
                    iTask = this.taskQueue.take();
                }
                if (iTask != null) {
                    iTask.run();
                }
            } catch (InterruptedException e) {
                if (!this.isRunning) {
                    interrupt();
                    return;
                }
            }
        }
    }

    public void quit() {
        this.isRunning = false;
        interrupt();
    }

    public void pause() {
        this.isPause = true;
    }

    public void continueRun() {
        LockSupport.unpark(this);
        this.isPause = false;
    }

    public boolean isRunning() {
        return this.isRunning;
    }
}
