package com.goodix.fingerprint.utils;

import android.content.Context;
import android.graphics.Rect;
import android.util.Log;
import android.util.TypedValue;
import com.goodix.fingerprint.GFDelmarConfig;
import java.lang.reflect.InvocationTargetException;

public class UtilTools {
    public static final int CALCULATE_GAIN_TYPE = 3;
    public static final int CIRCLE_SENSOR_HEIGHT = 86;
    public static final int CIRCLE_SENSOR_WIDTH = 84;
    public static final int CIRCLE_SENSOR_X = 311;
    public static final int CIRCLE_SENSOR_Y = 934;
    public static final int CMD_FACTORY_TESTING_PERFORMANCE_TESTING_TWO = 32543;
    public static final int CYAN_SENSOR_HEIGHT = 170;
    public static final int CYAN_SENSOR_WIDTH = 130;
    public static final int CYAN_SENSOR_X = 311;
    public static final int CYAN_SENSOR_Y = 934;
    public static int DEFAULT_RUBBER_COUNT = 3;
    public static final int GAIN_AND_CALIBRATION_TYPE = 5;
    public static final int KB_CALIBRATION_TYPE = 1;
    public static final int OPERATION_STEP_BASEDATA_DARK_COLLECT = 101;
    public static final int OPERATION_STEP_BASEDATA_MAX_COLLECT = 107;
    public static final int OPERATION_STEP_BASEDATA_MAX_DARK_COLLECT = 104;
    public static final int OPERATION_STEP_BASEDATA_MED_COLLECT = 106;
    public static final int OPERATION_STEP_BASEDATA_MED_DARK_COLLECT = 103;
    public static final int OPERATION_STEP_BASEDATA_MIN_COLLECT = 105;
    public static final int OPERATION_STEP_BASEDATA_MIN_DARK_COLLECT = 102;
    public static final int OPERATION_STEP_CALCULATE_GAIN = 115;
    public static final int OPERATION_STEP_CALCULATE_GAIN_COLLECT = 114;
    public static final int OPERATION_STEP_CALCULATE_LOW_BRIGHTNESS_DIGIT_GAIN = 121;
    public static final int OPERATION_STEP_CALCULATE_LOW_BRIGHTNESS_GAIN = 118;
    public static final int OPERATION_STEP_CALCULATE_LOW_BRIGHTNESS_GAIN_COLLECT = 117;
    public static final int OPERATION_STEP_CALCULATE_MID_BRIGHTNESS_GAIN_COLLECT = 116;
    public static final int OPERATION_STEP_CALCULATE_RESULT = 110;
    public static final int OPERATION_STEP_CALCULATE_SIMPLIFIED_PERFORMANCE_INDICATORS = 112;
    public static final int OPERATION_STEP_CHARTDATA_COLLECT = 109;
    public static final int OPERATION_STEP_CIRCLEDATA_COLLECT = 108;
    public static final int OPERATION_STEP_FINISHED = 150;
    public static final int OPERATION_STEP_GET_KB_CALIBRATION = 113;
    public static final int OPERATION_STEP_GET_LOCATION_CIRCLE = 111;
    public static final int OPERATION_STEP_LOW_BRIGHTNESS_FRESH_COLLECT = 120;
    public static final int OPERATION_STEP_MID_BRIGHTNESS_FRESH_COLLECT = 119;
    public static final int PERFORMANCE_TESTING_TYPE = 4;
    public static final int PRODUCT_TESTING_TYPE = 2;
    private static final String TAG = "Util_Tools";
    public static final String USE_RUBBER_COUNT_PROPERTY = "persist.test.use_rubber_count";

    public static int getProperty(String key, int defaultValue) {
        int value = defaultValue;
        try {
            value = ((Integer) Class.forName("android.os.SystemProperties").getMethod("getInt", String.class, Integer.TYPE).invoke(null, key, Integer.valueOf(defaultValue))).intValue();
        } catch (ClassNotFoundException e) {
            e.printStackTrace();
        } catch (NoSuchMethodException e2) {
            e2.printStackTrace();
        } catch (IllegalAccessException e3) {
            e3.printStackTrace();
        } catch (IllegalArgumentException e4) {
            e4.printStackTrace();
        } catch (InvocationTargetException e5) {
            e5.printStackTrace();
        }
        Log.d(TAG, "key = " + key + ", value = " + value);
        return value;
    }

    public static void setProperty(String key, String value) {
        try {
            Class.forName("android.os.SystemProperties").getMethod("set", String.class, String.class).invoke(null, key, value);
        } catch (ClassNotFoundException e) {
            e.printStackTrace();
        } catch (NoSuchMethodException e2) {
            e2.printStackTrace();
        } catch (IllegalAccessException e3) {
            e3.printStackTrace();
        } catch (IllegalArgumentException e4) {
            e4.printStackTrace();
        } catch (InvocationTargetException e5) {
            e5.printStackTrace();
        }
    }

    public static boolean isFullScreenPhone() {
        return false;
    }

    public static boolean isSumsungPlatform() {
        return true;
    }

    public static int getSensorRotateAngle() {
        return 0;
    }

    public static int getAlignedAngle(int originalAngle) {
        if (originalAngle <= 45) {
            return 0;
        }
        if (originalAngle <= 135) {
            return 90;
        }
        if (originalAngle <= 225) {
            return 180;
        }
        if (originalAngle <= 315) {
            return 270;
        }
        return 0;
    }

    public static int detectSensorBindingMode(GFDelmarConfig config) {
        int centerX = 0;
        int centerY = 0;
        for (int i = 0; i < config.mSensorNum; i++) {
            Log.d(TAG, "sensor[%d]=" + i + " x=" + config.mSensorCenterX[i]);
            Log.d(TAG, "sensor[%d]=" + i + " y=" + config.mSensorCenterY[i]);
            centerX += config.mSensorCenterX[i];
            centerY += config.mSensorCenterY[i];
        }
        int centerX2 = centerX / config.mSensorNum;
        int centerY2 = centerY / config.mSensorNum;
        if (config.mSensorNum == 4) {
            if (Math.abs(centerX2 - config.mSensorCenterX[0]) < 50 && Math.abs(centerX2 - config.mSensorCenterX[3]) < 50) {
                return 3;
            }
            if (Math.abs(centerY2 - config.mSensorCenterY[0]) >= 50 || Math.abs(centerY2 - config.mSensorCenterY[3]) >= 50) {
                return 2;
            }
            return 1;
        } else if (config.mSensorNum != 8) {
            return 0;
        } else {
            if (Math.abs(centerX2 - config.mSensorCenterX[0]) >= 50 || Math.abs(centerX2 - config.mSensorCenterX[3]) >= 50) {
                return 5;
            }
            return 4;
        }
    }

    public static Rect getBindingSensorArea(GFDelmarConfig config, int margin) {
        int height;
        int width;
        Rect area = new Rect();
        int centerX = 0;
        int centerY = 0;
        for (int i = 0; i < config.mSensorNum; i++) {
            centerX += config.mSensorCenterX[i];
            centerY += config.mSensorCenterY[i];
        }
        int centerX2 = centerX / config.mSensorNum;
        int centerY2 = centerY / config.mSensorNum;
        if (getAlignedAngle(config.mSensorRotateAngle[0]) % 180 == 0) {
            width = 130;
            height = 170;
        } else {
            width = 170;
            height = 130;
        }
        int bindingMode = detectSensorBindingMode(config);
        Log.d(TAG, "bindingMode=" + bindingMode);
        if (bindingMode == 1) {
            width *= 4;
        } else if (bindingMode == 3) {
            height *= 4;
        } else if (bindingMode == 2) {
            width *= 2;
            height *= 2;
        } else if (bindingMode == 4) {
            width *= 4;
            height *= 2;
        } else if (bindingMode == 5) {
            width *= 2;
            height *= 4;
        }
        area.left = (centerX2 - (width / 2)) - margin;
        area.top = (centerY2 - (height / 2)) - margin;
        area.right = (width / 2) + centerX2 + margin;
        area.bottom = (height / 2) + centerY2 + margin;
        return area;
    }

    public static float millimeterToPixels(Context ctx, float millimeter) {
        return TypedValue.applyDimension(5, millimeter, ctx.getResources().getDisplayMetrics());
    }
}
