package com.google.zxing.maxicode.decoder;

import com.goodix.cap.fingerprint.Constants;
import com.goodix.display.fingerprint.insystem.InSystemTest;
import com.goodix.fingerprint.ShenzhenConstants;
import com.goodix.fingerprint.utils.ShenzhenTestResultParser;
import com.goodix.fingerprint.utils.TestResultParser;
import com.google.zxing.common.BitMatrix;
import com.sec.factory.aporiented.athandler.AtTspptestStandard;
import com.sec.factory.app.factorytest.FactoryTestManager;
import org.apache.poi.hssf.record.UnknownRecord;
import org.apache.poi.util.Units;

/* access modifiers changed from: package-private */
public final class BitMatrixParser {
    private static final int[][] BITNR = {new int[]{121, 120, 127, 126, 133, 132, 139, 138, 145, 144, 151, 150, 157, 156, 163, 162, 169, 168, 175, 174, 181, 180, 187, 186, 193, 192, 199, 198, -2, -2}, new int[]{123, 122, 129, 128, 135, 134, 141, 140, 147, 146, 153, 152, 159, 158, 165, 164, 171, 170, 177, 176, 183, 182, 189, 188, 195, 194, 201, 200, 816, -3}, new int[]{125, 124, 131, 130, 137, 136, 143, 142, 149, 148, 155, 154, 161, 160, 167, 166, 173, 172, 179, 178, 185, 184, 191, 190, 197, 196, 203, 202, 818, 817}, new int[]{283, 282, 277, 276, 271, 270, 265, 264, InSystemTest.SUBLINE, InSystemTest.GET_SENSOR_INFO, 253, 252, 247, 246, 241, 240, 235, 234, FactoryTestManager.TEST_COAXIAL_CABLE_DETECT, 228, FactoryTestManager.TEST_FOLDED_TELE_CAMERA_CAPTURE, FactoryTestManager.TEST_REAR_CAMERA_MULTI_CAL, FactoryTestManager.TEST_WIRELESS_FAST_CHARGE_2, 216, 211, 210, 205, 204, 819, -3}, new int[]{285, 284, 279, 278, 273, AtTspptestStandard.NV_TSPCAL2, 267, 266, InSystemTest.SYSTEM_SPEC, 260, 255, 254, 249, 248, 243, 242, 237, 236, 231, FactoryTestManager.TEST_OCTA_CELL_ID_READ_FOR_FOOLPROOF, FactoryTestManager.TEST_ECHO_PARALLEL, FactoryTestManager.TEST_LEAKAGE_CURRENT_CHECK_2, FactoryTestManager.TEST_MACRO_CAMERA_CAPTURE, FactoryTestManager.TEST_SPEN_PAIRING, TestResultParser.TEST_TOKEN_FLASH_ID, 212, 207, 206, 821, 820}, new int[]{287, 286, 281, 280, 275, 274, 269, 268, 263, 262, 257, 256, 251, 250, 245, 244, UnknownRecord.PHONETICPR_00EF, 238, UnknownRecord.BITMAP_00E9, 232, FactoryTestManager.TEST_MIC_MUTE_PARALLEL, FactoryTestManager.TEST_MIC_GAIN_PARALLEL, FactoryTestManager.TEST_MIC_MUTE, FactoryTestManager.TEST_MACRO_CAMERA_RESOLUTION, 215, 214, 209, 208, 822, -3}, new int[]{289, 288, 295, 294, 301, 300, 307, 306, 313, 312, com.goodix.cap.fingerprint.utils.TestResultParser.TEST_TOKEN_LOCAL_BIG_BAD_PIXEL_NUM, 318, 325, 324, FactoryTestManager.TEST_SUB_MCD_PRESENTATION, FactoryTestManager.TEST_LCD_GRADATION_120HZ_TEST, 337, 336, FactoryTestManager.TEST_HLPM_TEST, FactoryTestManager.TEST_FOLDER_TENSION_TEST, FactoryTestManager.TEST_LCD_9GRAY_60HZ_TEST, FactoryTestManager.TEST_LCD_120HZ11HZ_FREQ_TEST, FactoryTestManager.TEST_ALWAYS_ON_TOUCH, FactoryTestManager.TEST_LCD_32GRAY_120HZ_BRIGHT0_TEST, 361, FactoryTestManager.TEST_UDC_CAPTURE, FactoryTestManager.TEST_SUB_LCD_9GRAY_120HZ_TEST, 366, 824, 823}, new int[]{291, 290, 297, 296, 303, 302, 309, 308, 315, 314, com.goodix.cap.fingerprint.utils.TestResultParser.TEST_TOKEN_IS_BAD_LINE, 320, 327, 326, FactoryTestManager.TEST_SUB_TSP_OPEN_SHORT_PRESENTATION, FactoryTestManager.TEST_SUB_TSP_SELF_PRESENTATION, 339, 338, FactoryTestManager.TEST_RANGING_SENSOR_300, FactoryTestManager.TEST_RANGING_SENSOR_CAL, 351, FactoryTestManager.TEST_TSP_JITTER_TEST_2, FactoryTestManager.TEST_LCD_9GRAY_HS90HZ_TEST, FactoryTestManager.TEST_NFC_FELICA_SELF_CAL, FactoryTestManager.TEST_TSP_JITTER_DELTA_TEST_2, FactoryTestManager.TEST_TSP_JITTER_DELTA_TEST, FactoryTestManager.TEST_S_PEN_DRAWING1_1, FactoryTestManager.TEST_SUB_LCD_32GRAY_120HZ_BRIGHT0_TEST, 825, -3}, new int[]{293, 292, Constants.MilanC.TEST_SPI_CHIP_ID, 298, 305, 304, 311, 310, 317, 316, 323, 322, FactoryTestManager.TEST_3D_DIGITAL_HALL_IC_TEST, FactoryTestManager.TEST_3D_DIGITAL_HALL_IC_CAL_TEST, 335, 334, 341, 340, FactoryTestManager.TEST_RANGING_SENSOR_500, FactoryTestManager.TEST_LCD_9GRAY_120HZ_TEST, FactoryTestManager.TEST_RGB_PE_ONOFF_TEST, FactoryTestManager.TEST_LCD_BRIGHT_DOT_TEST, 359, FactoryTestManager.TEST_DISPLAY_LINEAR_TEST, 365, 364, FactoryTestManager.TEST_TSP_COLOR_DIFF_TEST, FactoryTestManager.TEST_S_PEN_MAGNETIC, 827, 826}, new int[]{409, 408, 403, 402, 397, 396, 391, 390, 79, 78, -2, -2, 13, 12, 37, 36, 2, -1, 44, 43, 109, 108, 385, 384, 379, FactoryTestManager.TEST_ACH_MOTOR_SOUND, FactoryTestManager.TEST_LIGHT_SENSOR, FactoryTestManager.TEST_PROXIMITY_SENSOR_TEST, 828, -3}, new int[]{411, 410, 405, 404, 399, 398, 393, 392, 81, 80, 40, -2, 15, 14, 39, 38, 3, -1, -1, 45, 111, 110, 387, 386, 381, 380, 375, FactoryTestManager.TEST_LED_KEY, 830, 829}, new int[]{413, 412, 407, 406, 401, 400, 395, 394, 83, 82, 41, -3, -3, -3, -3, -3, 5, 4, 47, 46, 113, 112, 389, 388, 383, 382, FactoryTestManager.TEST_MAGNET_TEST, 376, 831, -3}, new int[]{415, 414, 421, 420, 427, 426, 103, 102, 55, 54, 16, -3, -3, -3, -3, -3, -3, -3, 20, 19, 85, 84, 433, 432, 439, 438, 445, 444, 833, 832}, new int[]{417, 416, 423, 422, 429, 428, 105, 104, 57, 56, -3, -3, -3, -3, -3, -3, -3, -3, 22, 21, 87, 86, 435, 434, 441, 440, 447, 446, 834, -3}, new int[]{419, 418, 425, 424, 431, 430, 107, 106, 59, 58, -3, -3, -3, -3, -3, -3, -3, -3, -3, 23, 89, 88, 437, 436, 443, UnknownRecord.CODENAME_1BA, 449, 448, 836, 835}, new int[]{481, 480, 475, 474, 469, 468, 48, -2, 30, -3, -3, -3, -3, -3, -3, -3, -3, -3, -3, 0, 53, 52, 463, 462, 457, 456, 451, 450, 837, -3}, new int[]{483, 482, 477, 476, 471, 470, 49, -1, -2, -3, -3, -3, -3, -3, -3, -3, -3, -3, -3, -3, -2, -1, 465, 464, 459, 458, ShenzhenConstants.DEFAULT_SENSOR_X, 452, 839, 838}, new int[]{485, 484, 479, 478, 473, 472, 51, 50, 31, -3, -3, -3, -3, -3, -3, -3, -3, -3, -3, 1, -2, 42, 467, 466, 461, 460, 455, 454, 840, -3}, new int[]{487, 486, 493, 492, 499, 498, 97, 96, 61, 60, -3, -3, -3, -3, -3, -3, -3, -3, -3, 26, 91, 90, 505, 504, 511, 510, 517, 516, 842, 841}, new int[]{489, 488, 495, 494, 501, 500, 99, 98, 63, 62, -3, -3, -3, -3, -3, -3, -3, -3, 28, 27, 93, 92, 507, 506, 513, 512, 519, 518, 843, -3}, new int[]{491, 490, 497, 496, 503, 502, 101, 100, 65, 64, 17, -3, -3, -3, -3, -3, -3, -3, 18, 29, 95, 94, 509, 508, 515, 514, 521, 520, 845, 844}, new int[]{559, 558, 553, 552, 547, 546, 541, 540, 73, 72, 32, -3, -3, -3, -3, -3, -3, 10, 67, 66, 115, 114, 535, 534, 529, 528, 523, 522, 846, -3}, new int[]{561, 560, 555, 554, 549, 548, 543, 542, 75, 74, -2, -1, 7, 6, 35, 34, 11, -2, 69, 68, 117, 116, 537, 536, 531, 530, 525, 524, 848, 847}, new int[]{563, 562, 557, 556, 551, 550, 545, 544, 77, 76, -2, 33, 9, 8, 25, 24, -1, -2, 71, 70, 119, 118, 539, 538, 533, 532, 527, 526, 849, -3}, new int[]{565, 564, 571, 570, 577, Units.MASTER_DPI, 583, 582, 589, 588, 595, 594, 601, 600, 607, 606, 613, 612, 619, 618, 625, 624, 631, 630, 637, 636, 643, 642, 851, 850}, new int[]{567, 566, 573, 572, 579, 578, 585, 584, 591, 590, 597, 596, 603, 602, 609, 608, 615, 614, 621, 620, 627, 626, 633, 632, 639, 638, 645, 644, 852, -3}, new int[]{569, 568, 575, 574, 581, 580, 587, 586, 593, 592, 599, 598, 605, 604, 611, 610, 617, 616, 623, 622, 629, 628, 635, 634, 641, 640, 647, 646, 854, 853}, new int[]{727, 726, 721, 720, 715, 714, 709, 708, 703, 702, 697, 696, TestResultParser.TEST_TOKEN_BMP_DATA_HEIGHT, TestResultParser.TEST_TOKEN_BMP_DATA_WIDTH, 685, 684, 679, 678, 673, 672, 667, 666, 661, 660, 655, 654, 649, 648, 855, -3}, new int[]{729, 728, 723, 722, 717, 716, 711, 710, 705, 704, 699, 698, 693, TestResultParser.TEST_TOKEN_FOV_AVG, 687, 686, 681, 680, 675, 674, 669, 668, 663, 662, 657, 656, 651, 650, 857, 856}, new int[]{731, 730, 725, 724, 719, 718, 713, 712, 707, 706, 701, 700, 695, 694, 689, 688, 683, 682, 677, 676, 671, 670, 665, 664, 659, 658, 653, 652, 858, -3}, new int[]{733, 732, 739, 738, 745, 744, 751, 750, 757, 756, 763, 762, 769, 768, 775, 774, 781, 780, 787, 786, 793, 792, 799, 798, 805, 804, 811, 810, 860, 859}, new int[]{735, 734, 741, 740, 747, 746, ShenzhenTestResultParser.TEST_TOKEN_BMP_DATA_RAW, 752, 759, 758, 765, 764, 771, 770, 777, 776, 783, 782, 789, 788, 795, 794, 801, 800, 807, 806, 813, 812, 861, -3}, new int[]{737, ShenzhenTestResultParser.TEST_TOKEN_FW_EXPOSE_TIME, 743, 742, 749, 748, 755, 754, 761, 760, 767, 766, 773, 772, 779, 778, 785, 784, 791, 790, 797, 796, 803, 802, 809, 808, 815, 814, 863, 862}};
    private final BitMatrix bitMatrix;

    BitMatrixParser(BitMatrix bitMatrix2) {
        this.bitMatrix = bitMatrix2;
    }

    /* access modifiers changed from: package-private */
    public byte[] readCodewords() {
        byte[] result = new byte[144];
        int height = this.bitMatrix.getHeight();
        int width = this.bitMatrix.getWidth();
        for (int y = 0; y < height; y++) {
            int[] bitnrRow = BITNR[y];
            for (int x = 0; x < width; x++) {
                int bit = bitnrRow[x];
                if (bit >= 0 && this.bitMatrix.get(x, y)) {
                    int i = bit / 6;
                    result[i] = (byte) (result[i] | ((byte) (1 << (5 - (bit % 6)))));
                }
            }
        }
        return result;
    }
}
