package com.google.zxing.pdf417.decoder;

import com.google.zxing.FormatException;
import com.google.zxing.common.CharacterSetECI;
import com.google.zxing.common.DecoderResult;
import com.google.zxing.pdf417.PDF417ResultMetadata;
import java.io.ByteArrayOutputStream;
import java.math.BigInteger;
import java.nio.charset.Charset;
import java.util.Arrays;

/* access modifiers changed from: package-private */
public final class DecodedBitStreamParser {
    private static final int AL = 28;
    private static final int AS = 27;
    private static final int BEGIN_MACRO_PDF417_CONTROL_BLOCK = 928;
    private static final int BEGIN_MACRO_PDF417_OPTIONAL_FIELD = 923;
    private static final int BYTE_COMPACTION_MODE_LATCH = 901;
    private static final int BYTE_COMPACTION_MODE_LATCH_6 = 924;
    private static final Charset DEFAULT_ENCODING = Charset.forName("ISO-8859-1");
    private static final int ECI_CHARSET = 927;
    private static final int ECI_GENERAL_PURPOSE = 926;
    private static final int ECI_USER_DEFINED = 925;
    private static final BigInteger[] EXP900;
    private static final int LL = 27;
    private static final int MACRO_PDF417_TERMINATOR = 922;
    private static final int MAX_NUMERIC_CODEWORDS = 15;
    private static final char[] MIXED_CHARS = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '&', '\r', '\t', ',', ':', '#', '-', '.', '$', '/', '+', '%', '*', '=', '^'};
    private static final int ML = 28;
    private static final int MODE_SHIFT_TO_BYTE_COMPACTION_MODE = 913;
    private static final int NUMBER_OF_SEQUENCE_CODEWORDS = 2;
    private static final int NUMERIC_COMPACTION_MODE_LATCH = 902;
    private static final int PAL = 29;
    private static final int PL = 25;
    private static final int PS = 29;
    private static final char[] PUNCT_CHARS = {';', '<', '>', '@', '[', '\\', ']', '_', '`', '~', '!', '\r', '\t', ',', ':', '\n', '-', '.', '$', '/', '\"', '|', '*', '(', ')', '?', '{', '}', '\''};
    private static final int TEXT_COMPACTION_MODE_LATCH = 900;

    /* access modifiers changed from: private */
    public enum Mode {
        ALPHA,
        LOWER,
        MIXED,
        PUNCT,
        ALPHA_SHIFT,
        PUNCT_SHIFT
    }

    static {
        BigInteger[] bigIntegerArr = new BigInteger[16];
        EXP900 = bigIntegerArr;
        bigIntegerArr[0] = BigInteger.ONE;
        BigInteger nineHundred = BigInteger.valueOf(900);
        bigIntegerArr[1] = nineHundred;
        int i = 2;
        while (true) {
            BigInteger[] bigIntegerArr2 = EXP900;
            if (i < bigIntegerArr2.length) {
                bigIntegerArr2[i] = bigIntegerArr2[i - 1].multiply(nineHundred);
                i++;
            } else {
                return;
            }
        }
    }

    private DecodedBitStreamParser() {
    }

    static DecoderResult decode(int[] iArr, String str) throws FormatException {
        int i;
        StringBuilder sb = new StringBuilder(iArr.length * 2);
        Charset charset = DEFAULT_ENCODING;
        int i2 = iArr[1];
        PDF417ResultMetadata pDF417ResultMetadata = new PDF417ResultMetadata();
        for (int i3 = 2; i3 < iArr[0]; i3 = i + 1) {
            switch (i2) {
                case 900:
                    i = textCompaction(iArr, i3, sb);
                    break;
                case 901:
                case 924:
                    i = byteCompaction(i2, iArr, charset, i3, sb);
                    break;
                case 902:
                    i = numericCompaction(iArr, i3, sb);
                    break;
                case 913:
                    sb.append((char) iArr[i3]);
                    i = i3 + 1;
                    break;
                case 922:
                case 923:
                    throw FormatException.getFormatInstance();
                case 925:
                    i = i3 + 1;
                    break;
                case 926:
                    i = i3 + 2;
                    break;
                case 927:
                    int i4 = i3 + 1;
                    Charset forName = Charset.forName(CharacterSetECI.getCharacterSetECIByValue(iArr[i3]).name());
                    i = i4;
                    charset = forName;
                    break;
                case 928:
                    i = decodeMacroBlock(iArr, i3, pDF417ResultMetadata);
                    break;
                default:
                    i = textCompaction(iArr, i3 - 1, sb);
                    break;
            }
            if (i < iArr.length) {
                i2 = iArr[i];
            } else {
                throw FormatException.getFormatInstance();
            }
        }
        if (sb.length() != 0) {
            DecoderResult decoderResult = new DecoderResult(null, sb.toString(), null, str);
            decoderResult.setOther(pDF417ResultMetadata);
            return decoderResult;
        }
        throw FormatException.getFormatInstance();
    }

    /* JADX INFO: Multiple debug info for r10v6 int: [D('code' int), D('codeIndex' int)] */
    private static int decodeMacroBlock(int[] codewords, int codeIndex, PDF417ResultMetadata resultMetadata) throws FormatException {
        if (codeIndex + 2 <= codewords[0]) {
            int[] segmentIndexArray = new int[2];
            int i = 0;
            while (i < 2) {
                segmentIndexArray[i] = codewords[codeIndex];
                i++;
                codeIndex++;
            }
            resultMetadata.setSegmentIndex(Integer.parseInt(decodeBase900toBase10(segmentIndexArray, 2)));
            StringBuilder fileId = new StringBuilder();
            int codeIndex2 = textCompaction(codewords, codeIndex, fileId);
            resultMetadata.setFileId(fileId.toString());
            if (codewords[codeIndex2] == 923) {
                int code = codeIndex2 + 1;
                int[] additionalOptionCodeWords = new int[(codewords[0] - code)];
                int additionalOptionCodeWordsIndex = 0;
                boolean end = false;
                while (code < codewords[0] && !end) {
                    int codeIndex3 = code + 1;
                    int codeIndex4 = codewords[code];
                    if (codeIndex4 < 900) {
                        additionalOptionCodeWords[additionalOptionCodeWordsIndex] = codeIndex4;
                        code = codeIndex3;
                        additionalOptionCodeWordsIndex++;
                    } else {
                        switch (codeIndex4) {
                            default:
                                throw FormatException.getFormatInstance();
                            case 922:
                                resultMetadata.setLastSegment(true);
                                end = true;
                                code = codeIndex3 + 1;
                                continue;
                        }
                    }
                }
                resultMetadata.setOptionalData(Arrays.copyOf(additionalOptionCodeWords, additionalOptionCodeWordsIndex));
                return code;
            } else if (codewords[codeIndex2] != 922) {
                return codeIndex2;
            } else {
                resultMetadata.setLastSegment(true);
                return codeIndex2 + 1;
            }
        } else {
            throw FormatException.getFormatInstance();
        }
    }

    /* JADX INFO: Multiple debug info for r9v2 int: [D('code' int), D('codeIndex' int)] */
    private static int textCompaction(int[] codewords, int code, StringBuilder result) {
        int[] textCompactionData = new int[((codewords[0] - code) * 2)];
        int[] byteCompactionData = new int[((codewords[0] - code) * 2)];
        int index = 0;
        boolean end = false;
        while (code < codewords[0] && !end) {
            int codeIndex = code + 1;
            int codeIndex2 = codewords[code];
            if (codeIndex2 < 900) {
                textCompactionData[index] = codeIndex2 / 30;
                textCompactionData[index + 1] = codeIndex2 % 30;
                index += 2;
                code = codeIndex;
            } else {
                switch (codeIndex2) {
                    case 900:
                        textCompactionData[index] = 900;
                        code = codeIndex;
                        index++;
                        continue;
                    case 901:
                    case 902:
                    case 922:
                    case 923:
                    case 924:
                    case 928:
                        end = true;
                        code = codeIndex - 1;
                        continue;
                    case 913:
                        textCompactionData[index] = 913;
                        byteCompactionData[index] = codewords[codeIndex];
                        index++;
                        code = codeIndex + 1;
                        continue;
                    default:
                        code = codeIndex;
                        continue;
                }
            }
        }
        decodeTextCompaction(textCompactionData, byteCompactionData, index, result);
        return code;
    }

    private static void decodeTextCompaction(int[] textCompactionData, int[] byteCompactionData, int length, StringBuilder result) {
        Mode subMode = Mode.ALPHA;
        Mode priorToShiftMode = Mode.ALPHA;
        for (int i = 0; i < length; i++) {
            int subModeCh = textCompactionData[i];
            char ch = 0;
            switch (AnonymousClass1.$SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode[subMode.ordinal()]) {
                case 1:
                    if (subModeCh >= 26) {
                        if (subModeCh != 26) {
                            if (subModeCh != 27) {
                                if (subModeCh != 28) {
                                    if (subModeCh != 29) {
                                        if (subModeCh != 913) {
                                            if (subModeCh == 900) {
                                                subMode = Mode.ALPHA;
                                                break;
                                            }
                                        } else {
                                            result.append((char) byteCompactionData[i]);
                                            break;
                                        }
                                    } else {
                                        priorToShiftMode = subMode;
                                        subMode = Mode.PUNCT_SHIFT;
                                        break;
                                    }
                                } else {
                                    subMode = Mode.MIXED;
                                    break;
                                }
                            } else {
                                subMode = Mode.LOWER;
                                break;
                            }
                        } else {
                            ch = ' ';
                            break;
                        }
                    } else {
                        ch = (char) (subModeCh + 65);
                        break;
                    }
                    break;
                case 2:
                    if (subModeCh >= 26) {
                        if (subModeCh != 26) {
                            if (subModeCh != 27) {
                                if (subModeCh != 28) {
                                    if (subModeCh != 29) {
                                        if (subModeCh != 913) {
                                            if (subModeCh == 900) {
                                                subMode = Mode.ALPHA;
                                                break;
                                            }
                                        } else {
                                            result.append((char) byteCompactionData[i]);
                                            break;
                                        }
                                    } else {
                                        priorToShiftMode = subMode;
                                        subMode = Mode.PUNCT_SHIFT;
                                        break;
                                    }
                                } else {
                                    subMode = Mode.MIXED;
                                    break;
                                }
                            } else {
                                priorToShiftMode = subMode;
                                subMode = Mode.ALPHA_SHIFT;
                                break;
                            }
                        } else {
                            ch = ' ';
                            break;
                        }
                    } else {
                        ch = (char) (subModeCh + 97);
                        break;
                    }
                    break;
                case 3:
                    if (subModeCh >= 25) {
                        if (subModeCh != 25) {
                            if (subModeCh != 26) {
                                if (subModeCh != 27) {
                                    if (subModeCh != 28) {
                                        if (subModeCh != 29) {
                                            if (subModeCh != 913) {
                                                if (subModeCh == 900) {
                                                    subMode = Mode.ALPHA;
                                                    break;
                                                }
                                            } else {
                                                result.append((char) byteCompactionData[i]);
                                                break;
                                            }
                                        } else {
                                            priorToShiftMode = subMode;
                                            subMode = Mode.PUNCT_SHIFT;
                                            break;
                                        }
                                    } else {
                                        subMode = Mode.ALPHA;
                                        break;
                                    }
                                } else {
                                    subMode = Mode.LOWER;
                                    break;
                                }
                            } else {
                                ch = ' ';
                                break;
                            }
                        } else {
                            subMode = Mode.PUNCT;
                            break;
                        }
                    } else {
                        ch = MIXED_CHARS[subModeCh];
                        break;
                    }
                    break;
                case 4:
                    if (subModeCh >= 29) {
                        if (subModeCh != 29) {
                            if (subModeCh != 913) {
                                if (subModeCh == 900) {
                                    subMode = Mode.ALPHA;
                                    break;
                                }
                            } else {
                                result.append((char) byteCompactionData[i]);
                                break;
                            }
                        } else {
                            subMode = Mode.ALPHA;
                            break;
                        }
                    } else {
                        ch = PUNCT_CHARS[subModeCh];
                        break;
                    }
                    break;
                case 5:
                    subMode = priorToShiftMode;
                    if (subModeCh >= 26) {
                        if (subModeCh != 26) {
                            if (subModeCh == 900) {
                                subMode = Mode.ALPHA;
                                break;
                            }
                        } else {
                            ch = ' ';
                            break;
                        }
                    } else {
                        ch = (char) (subModeCh + 65);
                        break;
                    }
                    break;
                case 6:
                    subMode = priorToShiftMode;
                    if (subModeCh >= 29) {
                        if (subModeCh != 29) {
                            if (subModeCh != 913) {
                                if (subModeCh == 900) {
                                    subMode = Mode.ALPHA;
                                    break;
                                }
                            } else {
                                result.append((char) byteCompactionData[i]);
                                break;
                            }
                        } else {
                            subMode = Mode.ALPHA;
                            break;
                        }
                    } else {
                        ch = PUNCT_CHARS[subModeCh];
                        break;
                    }
                    break;
            }
            if (ch != 0) {
                result.append(ch);
            }
        }
    }

    /* access modifiers changed from: package-private */
    /* renamed from: com.google.zxing.pdf417.decoder.DecodedBitStreamParser$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode;

        static {
            int[] iArr = new int[Mode.values().length];
            $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode = iArr;
            try {
                iArr[Mode.ALPHA.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode[Mode.LOWER.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode[Mode.MIXED.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode[Mode.PUNCT.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode[Mode.ALPHA_SHIFT.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode[Mode.PUNCT_SHIFT.ordinal()] = 6;
            } catch (NoSuchFieldError e6) {
            }
        }
    }

    /* JADX INFO: Multiple debug info for r2v4 int: [D('code' int), D('codeIndex' int)] */
    /* JADX WARNING: Code restructure failed: missing block: B:50:0x00ce, code lost:
        if (r2 == 922) goto L_0x00d5;
     */
    private static int byteCompaction(int mode, int[] codewords, Charset encoding, int codeIndex, StringBuilder result) {
        int count;
        boolean end;
        ByteArrayOutputStream decodedBytes = new ByteArrayOutputStream();
        int i = 928;
        int i2 = 902;
        long j = 900;
        if (mode == 901) {
            int[] byteCompactedCodewords = new int[6];
            int nextCode = codewords[codeIndex];
            int count2 = 0;
            boolean end2 = false;
            count = codeIndex + 1;
            long value = 0;
            while (count < codewords[0] && !end2) {
                int count3 = count2 + 1;
                byteCompactedCodewords[count2] = nextCode;
                value = (value * j) + ((long) nextCode);
                int codeIndex2 = count + 1;
                nextCode = codewords[count];
                if (nextCode == 900 || nextCode == 901 || nextCode == 902 || nextCode == 924 || nextCode == 928 || nextCode == 923 || nextCode == 922) {
                    count = codeIndex2 - 1;
                    end2 = true;
                    count2 = count3;
                    j = 900;
                } else if (count3 % 5 != 0 || count3 <= 0) {
                    count2 = count3;
                    count = codeIndex2;
                    j = 900;
                } else {
                    for (int j2 = 0; j2 < 6; j2++) {
                        decodedBytes.write((byte) ((int) (value >> ((5 - j2) * 8))));
                    }
                    value = 0;
                    count2 = 0;
                    count = codeIndex2;
                    j = 900;
                }
            }
            if (count == codewords[0] && nextCode < 900) {
                byteCompactedCodewords[count2] = nextCode;
                count2++;
            }
            for (int i3 = 0; i3 < count2; i3++) {
                decodedBytes.write((byte) byteCompactedCodewords[i3]);
            }
        } else if (mode == 924) {
            long value2 = 0;
            boolean end3 = false;
            int count4 = 0;
            int count5 = codeIndex;
            for (char c = 0; count5 < codewords[c] && !end3; c = 0) {
                int codeIndex3 = count5 + 1;
                int codeIndex4 = codewords[count5];
                if (codeIndex4 < 900) {
                    count4++;
                    value2 = (value2 * 900) + ((long) codeIndex4);
                } else {
                    if (codeIndex4 != 900 && codeIndex4 != 901 && codeIndex4 != i2 && codeIndex4 != 924 && codeIndex4 != i) {
                        if (codeIndex4 != 923) {
                        }
                    }
                    codeIndex3--;
                    end3 = true;
                }
                if (count4 % 5 != 0 || count4 <= 0) {
                    end = end3;
                } else {
                    int j3 = 0;
                    while (j3 < 6) {
                        decodedBytes.write((byte) ((int) (value2 >> ((5 - j3) * 8))));
                        j3++;
                        end3 = end3;
                    }
                    end = end3;
                    count4 = 0;
                    value2 = 0;
                }
                end3 = end;
                count5 = codeIndex3;
                i = 928;
                i2 = 902;
            }
            count = count5;
        } else {
            count = codeIndex;
        }
        result.append(new String(decodedBytes.toByteArray(), encoding));
        return count;
    }

    /* JADX INFO: Multiple debug info for r6v2 int: [D('code' int), D('codeIndex' int)] */
    private static int numericCompaction(int[] codewords, int code, StringBuilder result) throws FormatException {
        int count = 0;
        boolean end = false;
        int[] numericCodewords = new int[15];
        while (code < codewords[0] && !end) {
            int codeIndex = code + 1;
            int codeIndex2 = codewords[code];
            if (codeIndex == codewords[0]) {
                end = true;
            }
            if (codeIndex2 < 900) {
                numericCodewords[count] = codeIndex2;
                count++;
            } else if (codeIndex2 == 900 || codeIndex2 == 901 || codeIndex2 == 924 || codeIndex2 == 928 || codeIndex2 == 923 || codeIndex2 == 922) {
                codeIndex--;
                end = true;
            }
            if ((count % 15 == 0 || codeIndex2 == 902 || end) && count > 0) {
                result.append(decodeBase900toBase10(numericCodewords, count));
                count = 0;
            }
            code = codeIndex;
        }
        return code;
    }

    private static String decodeBase900toBase10(int[] codewords, int count) throws FormatException {
        BigInteger result = BigInteger.ZERO;
        for (int i = 0; i < count; i++) {
            result = result.add(EXP900[(count - i) - 1].multiply(BigInteger.valueOf((long) codewords[i])));
        }
        String resultString = result.toString();
        if (resultString.charAt(0) == '1') {
            return resultString.substring(1);
        }
        throw FormatException.getFormatInstance();
    }
}
