package com.qualcomm.qti.biometrics.fingerprint;

import android.graphics.Bitmap;
import android.util.Log;
import dalvik.system.DexClassLoader;
import java.io.File;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;

public class QFSManager {
    private static final String DEFAULT_JAR_PATH = "/vendor/framework/";
    private static final String TAG = "StaticQFSManager";
    private static final String VERSION = "09132021";
    private static QFSEventListener mQFSEventListener;
    private static Object mQFSEventListenerProxy;
    private static QFSLivePreviewListener mQFSLivePreviewListener;
    private static Object mQFSLivePreviewListenerProxy;
    private static QFSScanListener mQFSScanListener;
    private static Object mQFSScanListenerProxy;
    private static Object mQfsManagerObject;
    private HashMap<String, Class<?>> map = new HashMap<>();

    public QFSManager() {
        Log.i(TAG, "Static QFSManager version: 09132021");
        createInstances(DEFAULT_JAR_PATH);
    }

    public void createInstances(String path) {
        File file = new File(path + "QFSManager.jar");
        File tmpDir = new File(path);
        tmpDir.mkdir();
        try {
            Iterator<Class<?>> it = ((ArrayList) new DexClassLoader(file.getAbsolutePath(), tmpDir.getAbsolutePath(), path, ClassLoader.getSystemClassLoader()).loadClass("com.qualcomm.qti.biometrics.fingerprint.Registry").getDeclaredField("_classes").get(null)).iterator();
            while (it.hasNext()) {
                Class<?> cls = it.next();
                Log.v(TAG, "Class loaded " + cls.getName());
                if (cls.getName().equals("com.qualcomm.qti.biometrics.fingerprint.QFSManager")) {
                    mQfsManagerObject = cls.getDeclaredConstructor(new Class[0]).newInstance(new Object[0]);
                } else if (cls.getName().equals("com.qualcomm.qti.biometrics.fingerprint.QFSEventListener")) {
                    mQFSEventListenerProxy = Proxy.newProxyInstance(cls.getClassLoader(), new Class[]{cls}, new QFSInvocationHandler());
                } else if (cls.getName().equals("com.qualcomm.qti.biometrics.fingerprint.QFSScanListener")) {
                    mQFSScanListenerProxy = Proxy.newProxyInstance(cls.getClassLoader(), new Class[]{cls}, new QFSInvocationHandler());
                } else if (cls.getName().equals("com.qualcomm.qti.biometrics.fingerprint.QFSLivePreviewListener")) {
                    mQFSLivePreviewListenerProxy = Proxy.newProxyInstance(cls.getClassLoader(), new Class[]{cls}, new QFSInvocationHandler());
                } else {
                    Log.v(TAG, "Putting [" + cls.getName() + "]");
                    this.map.put(cls.getName(), cls);
                }
            }
        } catch (ClassNotFoundException e) {
            Log.e(TAG, "ClassNotFoundException " + e.getMessage());
            e.printStackTrace();
        } catch (InstantiationException e2) {
            Log.e(TAG, "InstantiationException " + e2.getMessage());
            e2.printStackTrace();
        } catch (InvocationTargetException e3) {
            Log.e(TAG, "InvocationTargetException " + e3.getMessage());
            e3.printStackTrace();
        } catch (NoSuchMethodException e4) {
            Log.e(TAG, "NoSuchMethodException " + e4.getMessage());
            e4.printStackTrace();
        } catch (IllegalAccessException e5) {
            Log.e(TAG, "IllegalAccessException " + e5.getMessage());
            e5.printStackTrace();
        } catch (NoSuchFieldException e6) {
            Log.e(TAG, "NoSuchFieldException " + e6.getMessage());
            e6.printStackTrace();
        }
    }

    private Object executeAPI(String methodName, Object... params) {
        Log.i(TAG, "executeAPI [" + methodName + "]");
        Object obj = mQfsManagerObject;
        if (obj == null) {
            Log.e(TAG, "QfsManagerObject NULL");
            return null;
        }
        Class<?>[] paramTypes = null;
        try {
            Method[] qfsManagerMethods = obj.getClass().getDeclaredMethods();
            for (int i = 0; i < qfsManagerMethods.length; i++) {
                if (qfsManagerMethods[i].getName().equals(methodName) && params != null && qfsManagerMethods[i].getParameterCount() == params.length) {
                    paramTypes = qfsManagerMethods[i].getParameterTypes();
                }
            }
            Method method = mQfsManagerObject.getClass().getDeclaredMethod(methodName, paramTypes);
            if (method != null) {
                return method.invoke(mQfsManagerObject, params);
            }
            Log.e(TAG, "Failed to get method");
            return null;
        } catch (NoSuchMethodException e) {
            Log.e(TAG, "NoSuchMethodException " + e.getMessage());
            e.printStackTrace();
            return null;
        } catch (IllegalAccessException e2) {
            Log.e(TAG, "IllegalAccessException " + e2.getMessage());
            e2.printStackTrace();
            return null;
        } catch (InvocationTargetException e3) {
            Log.e(TAG, "InvocationTargetException " + e3.getMessage());
            e3.printStackTrace();
            return null;
        }
    }

    public void startLivePreview(QFSLivePreviewListener listener) {
        mQFSLivePreviewListener = listener;
        executeAPI("startLivePreview", mQFSLivePreviewListenerProxy);
    }

    public void stopLivePreview() {
        executeAPI("stopLivePreview", null);
    }

    public void setEnrollmentTimeout(int timeout) {
        executeAPI("setEnrollmentTimeout", Integer.valueOf(timeout));
    }

    public void setTrackingFilePath(String path) {
        executeAPI("setTrackingFilePath", path);
    }

    public void runQFSTest(int testId) {
        executeAPI("runQFSTest", Integer.valueOf(testId));
    }

    public int setActiveStorage(String userId, String path) {
        return ((Integer) executeAPI("setActiveStorage", userId, path)).intValue();
    }

    public int authenticate(String userId) {
        return ((Integer) executeAPI("authenticate", userId)).intValue();
    }

    public int cancel() {
        return ((Integer) executeAPI("cancel", null)).intValue();
    }

    public int dispatch(int eventId, Object object) {
        return ((Integer) executeAPI("dispatch", Integer.valueOf(eventId), object)).intValue();
    }

    public int enroll(String userId, int index) {
        return ((Integer) executeAPI("enroll", userId, Integer.valueOf(index))).intValue();
    }

    public byte[] getFingerprintId(String userId, int index) {
        return (byte[]) executeAPI("getFingerprintId", userId, Integer.valueOf(index));
    }

    public int[] getFingerprintIndexList(String userId) {
        return (int[]) executeAPI("getFingerprintIndexList", userId);
    }

    public String getSensorInfo() {
        return (String) executeAPI("getSensorInfo", null);
    }

    public void getSensorInfo(QFSScanListener scanListener) {
        mQFSScanListener = scanListener;
        Object[] objArr = new Object[1];
        objArr[0] = scanListener == null ? null : mQFSScanListenerProxy;
        executeAPI("getSensorInfo", objArr);
    }

    public int getSensorStatus() {
        return ((Integer) executeAPI("getSensorStatus", null)).intValue();
    }

    public String[] getUserIdList() {
        return (String[]) executeAPI("getUserIdList", null);
    }

    public boolean delBGE(String path) {
        return ((Boolean) executeAPI("delBGE", path)).booleanValue();
    }

    public BGEInfo getBGEInfo() {
        Class<?>[] clsArr = null;
        Object customObject = executeAPI("getBGEInfo", null);
        Log.d(TAG, "Map get:[" + this.map.get(customObject.getClass().getName()).getName() + "]");
        this.map.get(customObject.getClass().getName()).cast(customObject);
        try {
            Method getBinIndex = customObject.getClass().getDeclaredMethod("getCurrentBins", null);
            ArrayList<BinData> binDataList = new ArrayList<>();
            for (Object binObj : (List) getBinIndex.invoke(customObject, null)) {
                this.map.get(binObj.getClass().getName()).cast(binObj);
                binDataList.add(new BinData(((Integer) binObj.getClass().getDeclaredMethod("getCalibTime", clsArr).invoke(binObj, clsArr)).intValue(), ((Integer) binObj.getClass().getDeclaredMethod("getBinTemperature", clsArr).invoke(binObj, clsArr)).intValue(), ((Integer) binObj.getClass().getDeclaredMethod("getBinIndex", null).invoke(binObj, null)).intValue()));
                getBinIndex = getBinIndex;
                clsArr = null;
            }
            return new BGEInfo(binDataList, ((Integer) customObject.getClass().getDeclaredMethod("getCurrentTemp", null).invoke(customObject, null)).intValue(), ((Integer) customObject.getClass().getDeclaredMethod("getBinIndexToReplace", null).invoke(customObject, null)).intValue());
        } catch (NoSuchMethodException e) {
            Log.e(TAG, "BGEInfo exception " + e.getMessage());
            e.printStackTrace();
            return null;
        } catch (IllegalAccessException e2) {
            Log.e(TAG, "BGEInfo exception " + e2.getMessage());
            e2.printStackTrace();
            return null;
        } catch (InvocationTargetException e3) {
            Log.e(TAG, "BGEInfo exception " + e3.getMessage());
            e3.printStackTrace();
            return null;
        }
    }

    public void runBGECalibration(String path) {
        executeAPI("runBGECalibration", path);
    }

    public boolean checkBGE() {
        return ((Boolean) executeAPI("checkBGE", null)).booleanValue();
    }

    public String getVersion() {
        return (String) executeAPI("getVersion", null);
    }

    public String getFpVersion() {
        return (String) executeAPI("getFpVersion", null);
    }

    public void startNormalScan(QFSScanListener scanListener) {
        mQFSScanListener = scanListener;
        Object[] objArr = new Object[1];
        objArr[0] = scanListener == null ? null : mQFSScanListenerProxy;
        executeAPI("startNormalScan", objArr);
    }

    public void cancelTest() {
        mQFSScanListener = null;
        mQFSEventListener = null;
        executeAPI("cancelTest", null);
    }

    public void endTest() {
        executeAPI("endTest", null);
    }

    public void startSNRPrepare(QFSScanListener scanListener) {
        mQFSScanListener = scanListener;
        Object[] objArr = new Object[1];
        objArr[0] = scanListener == null ? null : mQFSScanListenerProxy;
        executeAPI("startSNRPrepare", objArr);
    }

    public void startSNR() {
        executeAPI("startSNR", null);
    }

    public void remove(String userId, int index) {
        executeAPI("remove", userId, Integer.valueOf(index));
    }

    public int request(int code, Object data) {
        return ((Integer) executeAPI("request", Integer.valueOf(code), data)).intValue();
    }

    public void setEventListener(QFSEventListener listener) {
        mQFSEventListener = listener;
        Object[] objArr = new Object[1];
        objArr[0] = listener == null ? null : mQFSEventListenerProxy;
        executeAPI("setEventListener", objArr);
    }

    /* access modifiers changed from: private */
    public class QFSInvocationHandler implements InvocationHandler {
        private QFSInvocationHandler() {
        }

        @Override // java.lang.reflect.InvocationHandler
        public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
            if (args == null) {
                return null;
            }
            try {
                if (method.getName().equals("onFingerprintEvent")) {
                    if (args[1] == null || (args[1] instanceof Integer)) {
                        if (QFSManager.mQFSEventListener != null) {
                            Log.i(QFSManager.TAG, "onFingerprintEvent invoke mQFSEventListener callback");
                            QFSManager.mQFSEventListener.onFingerprintEvent(((Integer) args[0]).intValue(), args[1]);
                        }
                        if (QFSManager.mQFSScanListener == null) {
                            return null;
                        }
                        Log.i(QFSManager.TAG, "onFingerprintEvent invoke mQFSScanListener callback");
                        QFSManager.mQFSScanListener.onFingerprintEvent(((Integer) args[0]).intValue(), args[1]);
                        return null;
                    }
                    Object customObject = args[1];
                    if (customObject == null || args[1].getClass().getName() == null || QFSManager.this.map.get(args[1].getClass().getName()) == null) {
                        Log.e(QFSManager.TAG, "Null on onFingerprintEvent invoke");
                    } else {
                        ((Class) QFSManager.this.map.get(args[1].getClass().getName())).cast(customObject);
                        if (args[1].getClass().getName().contains("QFSCaptureInfo")) {
                            QFSCaptureInfo newCaptureInfo = new QFSCaptureInfo((Bitmap) customObject.getClass().getDeclaredMethod("getBitmap", null).invoke(customObject, null), ((Integer) customObject.getClass().getDeclaredMethod("getHeight", null).invoke(customObject, null)).intValue(), ((Integer) customObject.getClass().getDeclaredMethod("getQuality", null).invoke(customObject, null)).intValue(), (Bitmap) customObject.getClass().getDeclaredMethod("getRawBitmap", null).invoke(customObject, null), ((Integer) customObject.getClass().getDeclaredMethod("getWidth", null).invoke(customObject, null)).intValue());
                            if (QFSManager.mQFSEventListener != null) {
                                QFSManager.mQFSEventListener.onFingerprintEvent(((Integer) args[0]).intValue(), newCaptureInfo);
                            }
                        } else if (args[1].getClass().getName().contains("QFSEnrollStatus")) {
                            QFSEnrollStatus newEnrollStatus = new QFSEnrollStatus(((Integer) customObject.getClass().getDeclaredMethod("getBadTrial", null).invoke(customObject, null)).intValue(), ((Integer) customObject.getClass().getDeclaredMethod("getProgress", null).invoke(customObject, null)).intValue(), ((Integer) customObject.getClass().getDeclaredMethod("getSuccessTrial", null).invoke(customObject, null)).intValue(), ((Integer) customObject.getClass().getDeclaredMethod("getTotalTrial", null).invoke(customObject, null)).intValue());
                            if (QFSManager.mQFSEventListener != null) {
                                QFSManager.mQFSEventListener.onFingerprintEvent(((Integer) args[0]).intValue(), newEnrollStatus);
                            }
                        } else if (args[1].getClass().getName().contains("QFSIdentifyResult")) {
                            QFSIdentifyResult identifyResult = new QFSIdentifyResult(((Integer) customObject.getClass().getDeclaredMethod("getIndex", null).invoke(customObject, null)).intValue(), (int[]) customObject.getClass().getDeclaredMethod("getIndexes", null).invoke(customObject, null), ((Integer) customObject.getClass().getDeclaredMethod("getResult", null).invoke(customObject, null)).intValue(), (String) customObject.getClass().getDeclaredMethod("getUserId", null).invoke(customObject, null));
                            if (QFSManager.mQFSEventListener != null) {
                                QFSManager.mQFSEventListener.onFingerprintEvent(((Integer) args[0]).intValue(), identifyResult);
                            }
                        } else {
                            Log.e(QFSManager.TAG, "Unknown class on onFingerprintEvent");
                        }
                    }
                    return null;
                } else if (!method.getName().equals("onLivePreview")) {
                    return null;
                } else {
                    QFSManager.mQFSLivePreviewListener.onLivePreview((Bitmap) args[0]);
                    return null;
                }
            } catch (NullPointerException e) {
                Log.e(QFSManager.TAG, "onFingerprintEvent invoke Null Pointer exception " + e.getMessage());
                e.printStackTrace();
                return null;
            } catch (Throwable e2) {
                Log.e(QFSManager.TAG, "onFingerprintEvent invoke exception " + e2.getMessage());
                e2.printStackTrace();
                return null;
            }
        }
    }

    public void setProtectionFilmChoice(boolean bUserChoice) {
        executeAPI("setProtectionFilmChoice", Boolean.valueOf(bUserChoice));
    }

    public void VapStressTest(QFSScanListener scanListener) {
        mQFSScanListener = scanListener;
        Object[] objArr = new Object[1];
        objArr[0] = scanListener == null ? null : mQFSScanListenerProxy;
        executeAPI("VapStressTest", objArr);
    }
}
