package com.samsung.android.sdk.cover;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.os.RemoteException;
import com.samsung.android.cover.ICoverStateListenerCallback;
import com.samsung.android.sdk.cover.ScoverManager;
import java.lang.ref.WeakReference;

class CoverStateListenerDelegate extends ICoverStateListenerCallback.Stub {
    private static final int MSG_LISTEN_COVER_ATTACH_STATE_CHANGE = 1;
    private static final int MSG_LISTEN_COVER_SWITCH_STATE_CHANGE = 0;
    public static final int TYPE_COVER_STATE_LISTENER = 2;
    private ListenerDelegateHandler mHandler;
    private final ScoverManager.CoverStateListener mListener;

    CoverStateListenerDelegate(ScoverManager.CoverStateListener listener, Handler handler, Context context) {
        Looper looper;
        this.mListener = listener;
        if (handler == null) {
            looper = context.getMainLooper();
        } else {
            looper = handler.getLooper();
        }
        this.mHandler = new ListenerDelegateHandler(looper, listener);
    }

    public ScoverManager.CoverStateListener getListener() {
        return this.mListener;
    }

    public void onCoverSwitchStateChanged(boolean switchState) throws RemoteException {
        Message.obtain(this.mHandler, 0, switchState ? 1 : 0, 0).sendToTarget();
    }

    public void onCoverAttachStateChanged(boolean attached) throws RemoteException {
        Message.obtain(this.mHandler, 1, attached ? 1 : 0, 0).sendToTarget();
    }

    public String getListenerInfo() throws RemoteException {
        return this.mListener.toString();
    }

    private static class ListenerDelegateHandler extends Handler {
        private final WeakReference<ScoverManager.CoverStateListener> mListenerRef;

        public ListenerDelegateHandler(Looper looper, ScoverManager.CoverStateListener listener) {
            super(looper);
            this.mListenerRef = new WeakReference<>(listener);
        }

        public void handleMessage(Message msg) {
            ScoverManager.CoverStateListener listener = this.mListenerRef.get();
            if (listener != null) {
                boolean z = false;
                switch (msg.what) {
                    case 0:
                        if (msg.arg1 == 1) {
                            z = true;
                        }
                        listener.onCoverSwitchStateChanged(z);
                        return;
                    case 1:
                        if (msg.arg1 == 1) {
                            z = true;
                        }
                        listener.onCoverAttachStateChanged(z);
                        return;
                    default:
                        return;
                }
            }
        }
    }
}
