package com.samsung.android.sdk.cover;

import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.os.RemoteException;
import android.util.Log;
import com.samsung.android.cover.INfcLedCoverTouchListenerCallback;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

class LegacyLedSystemEventListenerDelegate extends INfcLedCoverTouchListenerCallback.Stub {
    private static final int MSG_SYSTEM_COVER_EVENT = 0;
    private static final String SYSTEM_EVENT_LED_OFF_COMMAND = "led_off_command";
    private static final String TAG = LegacyLedSystemEventListenerDelegate.class.getSimpleName();
    private ListenerDelegateHandler mHandler;
    private Object mListener;

    LegacyLedSystemEventListenerDelegate(Object listener, Handler handler, Context context) {
        this.mListener = listener;
        this.mHandler = new ListenerDelegateHandler(handler == null ? context.getMainLooper() : handler.getLooper(), this.mListener);
    }

    public Object getListener() {
        return this.mListener;
    }

    public void onCoverTouchAccept() throws RemoteException {
    }

    public void onCoverTouchReject() throws RemoteException {
    }

    public void onSystemCoverEvent(int event, int[] args) throws RemoteException {
        Message msg = this.mHandler.obtainMessage(0);
        msg.arg1 = event;
        msg.obj = args;
        msg.sendToTarget();
    }

    private static class ListenerDelegateHandler extends Handler {
        private final Object mListener;

        public ListenerDelegateHandler(Looper looper, Object listener) {
            super(looper);
            this.mListener = listener;
        }

        public void handleMessage(Message msg) {
            if (this.mListener != null) {
                switch (msg.what) {
                    case 0:
                        int[] args = (int[]) msg.obj;
                        Method onSystemCoverEventMethod = null;
                        try {
                            onSystemCoverEventMethod = this.mListener.getClass().getMethod("onSystemCoverEvent", Integer.TYPE, Bundle.class);
                        } catch (SecurityException e) {
                            Log.e(LegacyLedSystemEventListenerDelegate.TAG, "Error getting onSystemCoverEvent method", e);
                        } catch (NoSuchMethodException e2) {
                            Log.e(LegacyLedSystemEventListenerDelegate.TAG, "Error getting onSystemCoverEvent method", e2);
                        }
                        if (onSystemCoverEventMethod != null) {
                            if (args != null) {
                                try {
                                    if (args.length >= 1) {
                                        Bundle argsBundle = new Bundle();
                                        argsBundle.putInt(LegacyLedSystemEventListenerDelegate.SYSTEM_EVENT_LED_OFF_COMMAND, args[0]);
                                        onSystemCoverEventMethod.invoke(this.mListener, Integer.valueOf(msg.arg1), argsBundle);
                                        return;
                                    }
                                } catch (IllegalAccessException e3) {
                                    String str = LegacyLedSystemEventListenerDelegate.TAG;
                                    Log.e(str, "Error invoking " + onSystemCoverEventMethod.getName(), e3);
                                    return;
                                } catch (IllegalArgumentException e4) {
                                    String str2 = LegacyLedSystemEventListenerDelegate.TAG;
                                    Log.e(str2, "Error invoking " + onSystemCoverEventMethod.getName(), e4);
                                    return;
                                } catch (InvocationTargetException e5) {
                                    String str3 = LegacyLedSystemEventListenerDelegate.TAG;
                                    Log.e(str3, "Error invoking " + onSystemCoverEventMethod.getName(), e5);
                                    return;
                                }
                            }
                            String str4 = LegacyLedSystemEventListenerDelegate.TAG;
                            Log.e(str4, "Error: system event args empty: " + args);
                            return;
                        }
                        return;
                    default:
                        return;
                }
            }
        }
    }
}
