package com.samsung.android.sdk.cover;

import android.content.ComponentName;
import android.content.Context;
import android.os.Binder;
import android.os.Bundle;
import android.os.IBinder;
import android.os.RemoteException;
import android.os.ServiceManager;
import android.text.TextUtils;
import android.util.Log;
import android.util.Slog;
import android.view.Window;
import android.view.WindowManager;
import com.samsung.android.cover.CoverState;
import com.samsung.android.cover.ICoverManager;
import com.samsung.android.sdk.SsdkUnsupportedException;
import java.util.Iterator;
import java.util.concurrent.CopyOnWriteArrayList;

public class ScoverManager {
    public static final int COVER_MODE_HIDE_SVIEW_ONCE = 2;
    public static final int COVER_MODE_NONE = 0;
    public static final int COVER_MODE_SVIEW = 1;
    private static final String FEATURE_COVER_CLEAR = "com.sec.feature.cover.clearcover";
    private static final String FEATURE_COVER_CLEAR_SIDE_VIEW = "com.sec.feature.cover.clearsideviewcover";
    private static final String FEATURE_COVER_FLIP = "com.sec.feature.cover.flip";
    private static final String FEATURE_COVER_LED_BACK = "com.sec.feature.cover.ledbackcover";
    private static final String FEATURE_COVER_MINI_SVIEW_WALLET = "com.sec.feature.cover.minisviewwalletcover";
    private static final String FEATURE_COVER_NEON = "com.sec.feature.cover.neoncover";
    private static final String FEATURE_COVER_NFCLED = "com.sec.feature.cover.nfcledcover";
    private static final String FEATURE_COVER_SVIEW = "com.sec.feature.cover.sview";
    static final int SDK_VERSION = 16842752;
    private static final String TAG = "ScoverManager";
    private static boolean sIsClearCoverSystemFeatureEnabled = false;
    private static boolean sIsClearSideViewCoverSystemFeatureEnabled = false;
    private static boolean sIsFilpCoverSystemFeatureEnabled = false;
    private static boolean sIsLEDBackCoverSystemFeatureEnabled = false;
    private static boolean sIsMiniSviewWalletCoverSysltemFeatureEnabled = false;
    private static boolean sIsNeonCoverSystemFeatureEnabled = false;
    private static boolean sIsNfcLedCoverSystemFeatureEnabled = false;
    private static boolean sIsSViewCoverSystemFeatureEnabled = false;
    private static boolean sIsSystemFeatureQueried = false;
    private static int sServiceVersion = 16777216;
    private Context mContext;
    private final CopyOnWriteArrayList<CoverPowerKeyListenerDelegate> mCoverPowerKeyListenerDelegates = new CopyOnWriteArrayList<>();
    private final CopyOnWriteArrayList<CoverStateListenerDelegate> mCoverStateListenerDelegates = new CopyOnWriteArrayList<>();
    private final CopyOnWriteArrayList<CoverListenerDelegate> mLcdOffDisableDelegates = new CopyOnWriteArrayList<>();
    private final CopyOnWriteArrayList<LedSystemEventListenerDelegate> mLedSystemEventListenerDelegates = new CopyOnWriteArrayList<>();
    private final CopyOnWriteArrayList<LegacyLedSystemEventListenerDelegate> mLegacyLedSystemEventListenerDelegates = new CopyOnWriteArrayList<>();
    private final CopyOnWriteArrayList<CoverListenerDelegate> mListenerDelegates = new CopyOnWriteArrayList<>();
    private final CopyOnWriteArrayList<NfcLedCoverTouchListenerDelegate> mNfcLedCoverTouchListenerDelegates = new CopyOnWriteArrayList<>();
    private ICoverManager mService;
    private IBinder mToken = new Binder();

    @Deprecated
    public interface ScoverStateListener {
        void onCoverStateChanged(ScoverState scoverState);
    }

    public ScoverManager(Context context) {
        this.mContext = context;
        initSystemFeature();
    }

    private void initSystemFeature() {
        if (!sIsSystemFeatureQueried) {
            sIsFilpCoverSystemFeatureEnabled = this.mContext.getPackageManager().hasSystemFeature(FEATURE_COVER_FLIP);
            sIsSViewCoverSystemFeatureEnabled = this.mContext.getPackageManager().hasSystemFeature(FEATURE_COVER_SVIEW);
            sIsNfcLedCoverSystemFeatureEnabled = this.mContext.getPackageManager().hasSystemFeature(FEATURE_COVER_NFCLED);
            sIsClearCoverSystemFeatureEnabled = this.mContext.getPackageManager().hasSystemFeature(FEATURE_COVER_CLEAR);
            sIsNeonCoverSystemFeatureEnabled = this.mContext.getPackageManager().hasSystemFeature(FEATURE_COVER_NEON);
            sIsClearSideViewCoverSystemFeatureEnabled = this.mContext.getPackageManager().hasSystemFeature(FEATURE_COVER_CLEAR_SIDE_VIEW);
            sIsLEDBackCoverSystemFeatureEnabled = this.mContext.getPackageManager().hasSystemFeature(FEATURE_COVER_LED_BACK);
            sIsMiniSviewWalletCoverSysltemFeatureEnabled = this.mContext.getPackageManager().hasSystemFeature(FEATURE_COVER_MINI_SVIEW_WALLET);
            sIsSystemFeatureQueried = true;
            sServiceVersion = getCoverManagerVersion();
        }
    }

    public boolean isSupportCover() {
        return sIsFilpCoverSystemFeatureEnabled || sIsSViewCoverSystemFeatureEnabled || sIsClearCoverSystemFeatureEnabled || sIsNeonCoverSystemFeatureEnabled || sIsClearSideViewCoverSystemFeatureEnabled || sIsNfcLedCoverSystemFeatureEnabled || sIsLEDBackCoverSystemFeatureEnabled || sIsMiniSviewWalletCoverSysltemFeatureEnabled;
    }

    /* access modifiers changed from: package-private */
    public boolean isSmartCover() {
        ScoverState coverState = getCoverState();
        if (coverState == null || coverState.type != 255) {
            return false;
        }
        return true;
    }

    /* access modifiers changed from: package-private */
    public boolean isSupportFlipCover() {
        return sIsFilpCoverSystemFeatureEnabled;
    }

    /* access modifiers changed from: package-private */
    public boolean isSupportSViewCover() {
        return sIsSViewCoverSystemFeatureEnabled;
    }

    /* access modifiers changed from: package-private */
    public boolean isSupportClearCover() {
        return sIsClearCoverSystemFeatureEnabled;
    }

    /* access modifiers changed from: package-private */
    public boolean isSupportNfcLedCover() {
        return sIsNfcLedCoverSystemFeatureEnabled;
    }

    /* access modifiers changed from: package-private */
    public boolean isSupportNeonCover() {
        return sIsNeonCoverSystemFeatureEnabled;
    }

    /* access modifiers changed from: package-private */
    public boolean isSupportClearSideViewCover() {
        return sIsClearSideViewCoverSystemFeatureEnabled;
    }

    /* access modifiers changed from: package-private */
    public boolean isSupportLEDBackCover() {
        return sIsLEDBackCoverSystemFeatureEnabled;
    }

    /* access modifiers changed from: package-private */
    public boolean isSupportTypeOfCover(int type) {
        switch (type) {
            case 0:
                return sIsFilpCoverSystemFeatureEnabled;
            case 1:
            case 3:
                return sIsSViewCoverSystemFeatureEnabled;
            case 7:
                return sIsNfcLedCoverSystemFeatureEnabled;
            case 8:
                return sIsClearCoverSystemFeatureEnabled;
            case 11:
                return sIsNeonCoverSystemFeatureEnabled;
            case 14:
                return sIsLEDBackCoverSystemFeatureEnabled;
            case 15:
                return sIsClearSideViewCoverSystemFeatureEnabled;
            default:
                return false;
        }
    }

    /* access modifiers changed from: package-private */
    public int getCoverManagerVersion() {
        int serviceVersion = 16777216;
        if (isSupportCover()) {
            try {
                serviceVersion = ((Integer) ICoverManager.class.getMethod("getVersion", new Class[0]).invoke(getService(), new Object[0])).intValue();
            } catch (Exception e) {
                Log.w(TAG, "getVersion failed : " + e);
            }
        }
        Log.d(TAG, "serviceVersion : " + serviceVersion);
        return serviceVersion;
    }

    public String getServiceVersionName() {
        int i = sServiceVersion;
        return String.format("%d.%d.%d", Integer.valueOf((i >> 24) & 255), Integer.valueOf((i >> 16) & 255), Integer.valueOf(i & 65535));
    }

    static boolean isSupportableVersion(int supportableVersion) {
        int majorVersion = (supportableVersion >> 24) & 255;
        int minorVersion = (supportableVersion >> 16) & 255;
        int revisions = supportableVersion & 65535;
        int i = sServiceVersion;
        int serviceMinorVersion = (i >> 16) & 255;
        int serviceRevisions = 65535 & i;
        if (((i >> 24) & 255) < majorVersion || serviceMinorVersion < minorVersion || serviceRevisions < revisions) {
            return false;
        }
        return true;
    }

    private synchronized ICoverManager getService() {
        if (this.mService == null) {
            ICoverManager asInterface = ICoverManager.Stub.asInterface(ServiceManager.getService("cover"));
            this.mService = asInterface;
            if (asInterface == null) {
                Slog.w(TAG, "warning: no COVER_MANAGER_SERVICE");
            }
        }
        return this.mService;
    }

    public void setCoverModeToWindow(Window window, int coverMode) {
        if (!isSupportSViewCover()) {
            Log.w(TAG, "setSViewCoverModeToWindow : This device is not supported s view cover");
            return;
        }
        WindowManager.LayoutParams wlp = window.getAttributes();
        if (wlp != null) {
            wlp.coverMode = coverMode;
            window.setAttributes(wlp);
        }
    }

    @Deprecated
    public void registerListener(ScoverStateListener listener) {
        Log.d(TAG, "registerListener : Use deprecated API!! Change ScoverStateListener to StateListener");
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r3v4, types: [com.samsung.android.sdk.cover.CoverListenerDelegate] */
    /* JADX WARN: Type inference failed for: r4v5, types: [com.samsung.android.sdk.cover.CoverListenerDelegate] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public void registerListener(StateListener listener) {
        Log.d(TAG, "registerListener");
        if (!isSupportCover()) {
            Log.w(TAG, "registerListener : This device is not supported cover");
        } else if (isSmartCover()) {
            Log.w(TAG, "registerListener : If cover is smart cover, it does not need to register listener of intenal App");
        } else if (listener == null) {
            Log.w(TAG, "registerListener : listener is null");
        } else {
            IBinder iBinder = null;
            boolean hasDelegate = false;
            Iterator<CoverListenerDelegate> i = this.mListenerDelegates.iterator();
            while (true) {
                if (!i.hasNext()) {
                    break;
                }
                CoverListenerDelegate next = i.next();
                if (next.getListener().equals(listener)) {
                    iBinder = next;
                    hasDelegate = true;
                    break;
                }
            }
            if (iBinder == null) {
                iBinder = new CoverListenerDelegate(listener, null, this.mContext);
            }
            try {
                ICoverManager svc = getService();
                if (svc != null) {
                    ComponentName cm = new ComponentName(this.mContext.getPackageName(), getClass().getCanonicalName());
                    if (iBinder != null) {
                        svc.registerCallback(iBinder, cm);
                        if (!hasDelegate) {
                            this.mListenerDelegates.add(iBinder);
                        }
                    }
                }
            } catch (RemoteException e) {
                Log.e(TAG, "RemoteException in registerListener: ", e);
            }
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r5v4, types: [com.samsung.android.sdk.cover.CoverStateListenerDelegate] */
    /* JADX WARN: Type inference failed for: r6v4, types: [com.samsung.android.sdk.cover.CoverStateListenerDelegate] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public void registerListener(CoverStateListener listener) throws SsdkUnsupportedException {
        Log.d(TAG, "registerListener");
        if (!isSupportCover()) {
            Log.w(TAG, "registerListener : This device is not supported cover");
        } else if (isSmartCover()) {
            Log.w(TAG, "registerListener : If cover is smart cover, it does not need to register listener of intenal App");
        } else if (!isSupportableVersion(SDK_VERSION)) {
            throw new SsdkUnsupportedException("This device is not supported this function. Device is must higher then v1.1.0", 2);
        } else if (listener == null) {
            Log.w(TAG, "registerListener : listener is null");
        } else {
            IBinder iBinder = null;
            boolean hasDelegate = false;
            Iterator<CoverStateListenerDelegate> i = this.mCoverStateListenerDelegates.iterator();
            while (true) {
                if (!i.hasNext()) {
                    break;
                }
                CoverStateListenerDelegate next = i.next();
                if (next.getListener().equals(listener)) {
                    iBinder = next;
                    hasDelegate = true;
                    break;
                }
            }
            if (iBinder == null) {
                iBinder = new CoverStateListenerDelegate(listener, null, this.mContext);
            }
            try {
                ICoverManager svc = getService();
                if (svc != null) {
                    ComponentName cm = new ComponentName(this.mContext.getPackageName(), getClass().getCanonicalName());
                    if (iBinder != null) {
                        svc.registerListenerCallback(iBinder, cm, 2);
                        if (!hasDelegate) {
                            this.mCoverStateListenerDelegates.add(iBinder);
                        }
                    }
                }
            } catch (RemoteException e) {
                Log.e(TAG, "RemoteException in registerListener: ", e);
            }
        }
    }

    @Deprecated
    public void unregisterListener(ScoverStateListener listener) {
        Log.d(TAG, "unregisterListener : Use deprecated API!! Change ScoverStateListener to StateListener");
    }

    /* JADX DEBUG: Multi-variable search result rejected for r3v5, resolved type: com.samsung.android.sdk.cover.CoverListenerDelegate */
    /* JADX WARN: Multi-variable type inference failed */
    public void unregisterListener(StateListener listener) {
        Log.d(TAG, "unregisterListener");
        if (!isSupportCover()) {
            Log.w(TAG, "unregisterListener : This device is not supported cover");
        } else if (isSmartCover()) {
            Log.w(TAG, "unregisterListener : If cover is smart cover, it does not need to unregister listener of intenal App");
        } else if (listener == null) {
            Log.w(TAG, "unregisterListener : listener is null");
        } else {
            IBinder iBinder = null;
            Iterator<CoverListenerDelegate> i = this.mListenerDelegates.iterator();
            while (true) {
                if (!i.hasNext()) {
                    break;
                }
                CoverListenerDelegate delegate = i.next();
                if (delegate.getListener().equals(listener)) {
                    iBinder = delegate;
                    break;
                }
            }
            if (iBinder != null) {
                try {
                    ICoverManager svc = getService();
                    if (svc != null && svc.unregisterCallback(iBinder)) {
                        this.mListenerDelegates.remove(iBinder);
                    }
                } catch (RemoteException e) {
                    Log.e(TAG, "RemoteException in unregisterListener: ", e);
                }
            }
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r4v5, resolved type: com.samsung.android.sdk.cover.CoverStateListenerDelegate */
    /* JADX WARN: Multi-variable type inference failed */
    public void unregisterListener(CoverStateListener listener) throws SsdkUnsupportedException {
        Log.d(TAG, "unregisterListener");
        if (!isSupportCover()) {
            Log.w(TAG, "unregisterListener : This device is not supported cover");
        } else if (isSmartCover()) {
            Log.w(TAG, "unregisterListener : If cover is smart cover, it does not need to unregister listener of intenal App");
        } else if (!isSupportableVersion(SDK_VERSION)) {
            throw new SsdkUnsupportedException("This device is not supported this function. Device is must higher then v1.1.0", 2);
        } else if (listener == null) {
            Log.w(TAG, "unregisterListener : listener is null");
        } else {
            IBinder iBinder = null;
            Iterator<CoverStateListenerDelegate> i = this.mCoverStateListenerDelegates.iterator();
            while (true) {
                if (!i.hasNext()) {
                    break;
                }
                CoverStateListenerDelegate delegate = i.next();
                if (delegate.getListener().equals(listener)) {
                    iBinder = delegate;
                    break;
                }
            }
            if (iBinder != null) {
                try {
                    ICoverManager svc = getService();
                    if (svc != null && svc.unregisterCallback(iBinder)) {
                        this.mCoverStateListenerDelegates.remove(iBinder);
                    }
                } catch (RemoteException e) {
                    Log.e(TAG, "RemoteException in unregisterListener: ", e);
                }
            }
        }
    }

    public ScoverState getCoverState() {
        if (!isSupportCover()) {
            Log.w(TAG, "getCoverState : This device is not supported cover");
            return null;
        }
        try {
            ICoverManager svc = getService();
            if (svc == null) {
                return null;
            }
            CoverState coverState = svc.getCoverState();
            if (coverState == null) {
                Log.e(TAG, "getCoverState : coverState is null");
                return null;
            } else if (coverState.type == 255 && !coverState.switchState) {
                Log.e(TAG, "getCoverState : type of cover is nfc smart cover and cover is closed");
                return null;
            } else if (isSupportableVersion(17498112)) {
                return new ScoverState(coverState.switchState, coverState.type, coverState.color, coverState.widthPixel, coverState.heightPixel, coverState.attached, coverState.model, coverState.fakeCover, coverState.fotaMode);
            } else {
                if (isSupportableVersion(17235968)) {
                    return new ScoverState(coverState.switchState, coverState.type, coverState.color, coverState.widthPixel, coverState.heightPixel, coverState.attached, coverState.model, coverState.fakeCover);
                }
                if (isSupportableVersion(16908288)) {
                    return new ScoverState(coverState.switchState, coverState.type, coverState.color, coverState.widthPixel, coverState.heightPixel, coverState.attached, coverState.model);
                }
                if (isSupportableVersion(SDK_VERSION)) {
                    return new ScoverState(coverState.switchState, coverState.type, coverState.color, coverState.widthPixel, coverState.heightPixel, coverState.attached);
                }
                return new ScoverState(coverState.switchState, coverState.type, coverState.color, coverState.widthPixel, coverState.heightPixel);
            }
        } catch (RemoteException e) {
            Log.e(TAG, "RemoteException in getCoverState: ", e);
            return null;
        }
    }

    public boolean checkValidPacakge(String pkg) {
        if (!isSupportCover()) {
            Log.w(TAG, "checkValidPacakge : This device is not supported cover");
            return false;
        } else if (pkg == null) {
            Log.w(TAG, "checkValidPacakge : pkg is null");
            return false;
        } else {
            try {
                ICoverManager svc = getService();
                if (svc != null) {
                    CoverState coverState = svc.getCoverState();
                    if (coverState == null || !coverState.attached) {
                        Log.e(TAG, "checkValidPacakge : coverState is null or cover is detached");
                    } else {
                        String coverAppUri = coverState.getSmartCoverAppUri();
                        if (!TextUtils.isEmpty(coverAppUri) && pkg.equals(coverAppUri.substring(1, coverAppUri.length()))) {
                            return true;
                        }
                    }
                }
            } catch (RemoteException e) {
                Log.e(TAG, "RemoteException in checkCoverAppUri: ", e);
            }
            return false;
        }
    }

    public void sendDataToCover(int command, byte[] data) throws SsdkUnsupportedException {
        if (!isSupportCover()) {
            Log.w(TAG, "sendDataToCover : This device is not supported cover");
        } else if (isSmartCover()) {
            Log.w(TAG, "sendDataToCover : If cover is smart cover, it does not need to send the data to cover");
        } else if (isSupportableVersion(16908288)) {
            ICoverManager svc = getService();
            if (svc != null) {
                try {
                    svc.sendDataToCover(command, data);
                } catch (RemoteException e) {
                    Log.e(TAG, "RemoteException in sendData : ", e);
                }
            }
        } else {
            throw new SsdkUnsupportedException("This device is not supported this function. Device is must higher then v1.2.0", 2);
        }
    }

    public static class StateListener {
        public void onCoverStateChanged(ScoverState state) {
        }
    }

    public static class CoverStateListener {
        public void onCoverSwitchStateChanged(boolean switchState) {
        }

        public void onCoverAttachStateChanged(boolean attached) {
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r4v4, types: [com.samsung.android.sdk.cover.NfcLedCoverTouchListenerDelegate] */
    /* JADX WARN: Type inference failed for: r5v5, types: [com.samsung.android.sdk.cover.NfcLedCoverTouchListenerDelegate] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public void registerNfcTouchListener(int type, NfcLedCoverTouchListener listener) throws SsdkUnsupportedException {
        if (!isSupportCover()) {
            Log.w(TAG, "registerNfcTouchListener : This device does not support cover");
            return;
        }
        Log.d(TAG, "registerNfcTouchListener");
        if (!isSupportNfcLedCover()) {
            Log.w(TAG, "registerNfcTouchListener : This device does not support NFC Led cover");
        } else if (!isSupportableVersion(16973824)) {
            throw new SsdkUnsupportedException("This device does not support this function. Device is must higher then v1.3.0", 2);
        } else if (listener == null) {
            Log.w(TAG, "registerNfcTouchListener : listener is null");
        } else {
            IBinder iBinder = null;
            boolean hasDelegate = false;
            Iterator<NfcLedCoverTouchListenerDelegate> i = this.mNfcLedCoverTouchListenerDelegates.iterator();
            while (true) {
                if (!i.hasNext()) {
                    break;
                }
                NfcLedCoverTouchListenerDelegate next = i.next();
                if (next.getListener().equals(listener)) {
                    iBinder = next;
                    hasDelegate = true;
                    break;
                }
            }
            if (iBinder == null) {
                iBinder = new NfcLedCoverTouchListenerDelegate(listener, null, this.mContext);
            }
            try {
                ICoverManager svc = getService();
                if (svc != null) {
                    ComponentName cm = new ComponentName(this.mContext.getPackageName(), getClass().getCanonicalName());
                    if (iBinder != null) {
                        svc.registerNfcTouchListenerCallback(type, iBinder, cm);
                        if (!hasDelegate) {
                            this.mNfcLedCoverTouchListenerDelegates.add(iBinder);
                        }
                    }
                }
            } catch (RemoteException e) {
                Log.e(TAG, "RemoteException in registerNfcTouchListener: ", e);
            }
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r4v5, resolved type: com.samsung.android.sdk.cover.NfcLedCoverTouchListenerDelegate */
    /* JADX WARN: Multi-variable type inference failed */
    public void unregisterNfcTouchListener(NfcLedCoverTouchListener listener) throws SsdkUnsupportedException {
        Log.d(TAG, "unregisterNfcTouchListener");
        if (!isSupportCover()) {
            Log.w(TAG, "unregisterNfcTouchListener : This device does not support cover");
        } else if (!isSupportNfcLedCover()) {
            Log.w(TAG, "unregisterNfcTouchListener : This device does not support NFC Led cover");
        } else if (!isSupportableVersion(16973824)) {
            throw new SsdkUnsupportedException("This device does not support this function. Device is must higher then v1.3.0", 2);
        } else if (listener == null) {
            Log.w(TAG, "unregisterNfcTouchListener : listener is null");
        } else {
            IBinder iBinder = null;
            Iterator<NfcLedCoverTouchListenerDelegate> i = this.mNfcLedCoverTouchListenerDelegates.iterator();
            while (true) {
                if (!i.hasNext()) {
                    break;
                }
                NfcLedCoverTouchListenerDelegate delegate = i.next();
                if (delegate.getListener().equals(listener)) {
                    iBinder = delegate;
                    break;
                }
            }
            if (iBinder != null) {
                try {
                    ICoverManager svc = getService();
                    if (svc != null && svc.unregisterNfcTouchListenerCallback(iBinder)) {
                        this.mNfcLedCoverTouchListenerDelegates.remove(iBinder);
                    }
                } catch (RemoteException e) {
                    Log.e(TAG, "RemoteException in unregisterNfcTouchListener: ", e);
                }
            }
        }
    }

    public void sendDataToNfcLedCover(int command, byte[] data) throws SsdkUnsupportedException {
        if (!isSupportCover()) {
            Log.w(TAG, "sendDataToNfcLedCover : This device does not support cover");
        } else if (!isSupportNfcLedCover()) {
            Log.w(TAG, "sendDataToNfcLedCover : This device does not support NFC Led cover");
        } else if (isSupportableVersion(16973824)) {
            ICoverManager svc = getService();
            if (svc != null) {
                try {
                    svc.sendDataToNfcLedCover(command, data);
                } catch (RemoteException e) {
                    Log.e(TAG, "RemoteException in sendData to NFC : ", e);
                }
            }
        } else {
            throw new SsdkUnsupportedException("This device does not support this function. Device is must higher then v1.3.0", 2);
        }
    }

    public void addLedNotification(Bundle data) throws SsdkUnsupportedException {
        if (!isSupportCover()) {
            Log.w(TAG, "addLedNotification : This device does not support cover");
        } else if (!isSupportNfcLedCover()) {
            Log.w(TAG, "addLedNotification : This device does not support NFC Led cover");
        } else if (!isSupportableVersion(17039360)) {
            throw new SsdkUnsupportedException("This device does not support this function. Device is must higher then v1.4.0", 2);
        } else if (data == null) {
            Log.e(TAG, "addLedNotification : Null notification data!");
        } else {
            ICoverManager svc = getService();
            if (svc != null) {
                try {
                    svc.addLedNotification(data);
                } catch (RemoteException e) {
                    Log.e(TAG, "addLedNotification in sendData to NFC : ", e);
                }
            }
        }
    }

    public void removeLedNotification(Bundle data) throws SsdkUnsupportedException {
        if (!isSupportCover()) {
            Log.w(TAG, "removeLedNotification : This device does not support cover");
        } else if (!isSupportNfcLedCover()) {
            Log.w(TAG, "removeLedNotification : This device does not support NFC Led cover");
        } else if (!isSupportableVersion(17039360)) {
            throw new SsdkUnsupportedException("This device does not support this function. Device is must higher then v1.4.0", 2);
        } else if (data == null) {
            Log.e(TAG, "removeLedNotification : Null notification data!");
        } else {
            ICoverManager svc = getService();
            if (svc != null) {
                try {
                    svc.removeLedNotification(data);
                } catch (RemoteException e) {
                    Log.e(TAG, "removeLedNotification in sendData to NFC : ", e);
                }
            }
        }
    }

    public void sendSystemEvent(Bundle data) throws SsdkUnsupportedException {
        if (!isSupportCover()) {
            Log.w(TAG, "sendSystemEvent : This device does not support cover");
        } else if (!isSupportNfcLedCover()) {
            Log.w(TAG, "sendSystemEvent : This device does not support NFC Led cover");
        } else if (!isSupportableVersion(17170432)) {
            throw new SsdkUnsupportedException("This device does not support this function. Device is must higher then v1.6.0", 2);
        } else if (data == null) {
            Log.e(TAG, "sendSystemEvent : Null system event data!");
        } else {
            ICoverManager svc = getService();
            if (svc != null) {
                try {
                    svc.sendSystemEvent(data);
                } catch (RemoteException e) {
                    Log.e(TAG, "sendSystemEvent in sendData to NFC : ", e);
                }
            }
        }
    }

    public static class NfcLedCoverTouchListener {
        public static final int EVENT_TYPE_ALARM = 1;
        public static final int EVENT_TYPE_BIXBY = 9;
        public static final int EVENT_TYPE_CALL = 0;
        public static final int EVENT_TYPE_FACTORY = 5;
        public static final int EVENT_TYPE_REMINDER = 6;
        public static final int EVENT_TYPE_SCHEDULE = 3;
        public static final int EVENT_TYPE_TIMER = 2;
        public static final int EVENT_TYPE_VOICE_RECORDER = 7;
        public static final int EVENT_TYPE_VOLUME_CONTROLLER = 8;

        public void onCoverTouchAccept() {
        }

        public void onCoverTouchReject() {
        }

        public void onCoverTapLeft() {
        }

        public void onCoverTapMid() {
        }

        public void onCoverTapRight() {
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r5v4, types: [com.samsung.android.sdk.cover.LedSystemEventListenerDelegate] */
    /* JADX WARN: Type inference failed for: r6v5, types: [com.samsung.android.sdk.cover.LedSystemEventListenerDelegate] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public void registerLedSystemListener(LedSystemEventListener listener) throws SsdkUnsupportedException {
        if (!isSupportCover()) {
            Log.w(TAG, "registerLedSystemListener : This device does not support cover");
            return;
        }
        Log.d(TAG, "registerLedSystemListener");
        if (!isSupportNfcLedCover() && !isSupportNeonCover()) {
            Log.w(TAG, "registerLedSystemListener : This device does not support NFC Led cover or Neon Cover");
        } else if ((!isSupportNfcLedCover() || !isSupportableVersion(16973824)) && (!isSupportNeonCover() || !isSupportableVersion(17301504))) {
            throw new SsdkUnsupportedException("This device does not support this function. Device is must higher then v1.3.0 for NFC LED Cover and v1.8.0 for Neon cover", 2);
        } else if (listener == null) {
            Log.w(TAG, "registerLedSystemListener : listener is null");
        } else if (!supportNewLedSystemEventListener()) {
            registerLegacyLedSystemListener(listener);
        } else {
            IBinder iBinder = null;
            boolean hasDelegate = false;
            Iterator<LedSystemEventListenerDelegate> i = this.mLedSystemEventListenerDelegates.iterator();
            while (true) {
                if (!i.hasNext()) {
                    break;
                }
                LedSystemEventListenerDelegate next = i.next();
                if (next.getListener().equals(listener)) {
                    iBinder = next;
                    hasDelegate = true;
                    break;
                }
            }
            if (iBinder == null) {
                iBinder = new LedSystemEventListenerDelegate(listener, null, this.mContext);
            }
            try {
                ICoverManager svc = getService();
                if (svc != null) {
                    ComponentName cm = new ComponentName(this.mContext.getPackageName(), getClass().getCanonicalName());
                    if (iBinder != null) {
                        svc.registerNfcTouchListenerCallback(4, iBinder, cm);
                        if (!hasDelegate) {
                            this.mLedSystemEventListenerDelegates.add(iBinder);
                        }
                    }
                }
            } catch (RemoteException e) {
                Log.e(TAG, "RemoteException in registerLedSystemListener: ", e);
            }
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v5, resolved type: com.samsung.android.sdk.cover.LedSystemEventListenerDelegate */
    /* JADX WARN: Multi-variable type inference failed */
    public void unregisterLedSystemEventListener(LedSystemEventListener listener) throws SsdkUnsupportedException {
        Log.d(TAG, "unregisterLedSystemEventListener");
        if (!isSupportCover()) {
            Log.w(TAG, "unregisterLedSystemEventListener : This device does not support cover");
            return;
        }
        Log.d(TAG, "unregisterLedSystemEventListener");
        if (!isSupportNfcLedCover() && !isSupportNeonCover()) {
            Log.w(TAG, "unregisterLedSystemEventListener : This device does not support NFC Led cover or Neon Cover");
        } else if ((!isSupportNfcLedCover() || !isSupportableVersion(16973824)) && (!isSupportNeonCover() || !isSupportableVersion(17301504))) {
            throw new SsdkUnsupportedException("This device does not support this function. Device is must higher then v1.3.0 for NFC LED Cover and v1.8.0 for Neon cover", 2);
        } else if (listener == null) {
            Log.w(TAG, "unregisterLedSystemEventListener : listener is null");
        } else if (!supportNewLedSystemEventListener()) {
            unregisterLegacyLedSystemEventListener(listener);
        } else {
            IBinder iBinder = null;
            Iterator<LedSystemEventListenerDelegate> i = this.mLedSystemEventListenerDelegates.iterator();
            while (true) {
                if (!i.hasNext()) {
                    break;
                }
                LedSystemEventListenerDelegate delegate = i.next();
                if (delegate.getListener().equals(listener)) {
                    iBinder = delegate;
                    break;
                }
            }
            if (iBinder != null) {
                try {
                    ICoverManager svc = getService();
                    if (svc != null && svc.unregisterNfcTouchListenerCallback(iBinder)) {
                        this.mLedSystemEventListenerDelegates.remove(iBinder);
                    }
                } catch (RemoteException e) {
                    Log.e(TAG, "RemoteException in unregisterLedSystemEventListener: ", e);
                }
            }
        }
    }

    public static class LedSystemEventListener {
        private static final int EVENT_TYPE_SYSTEM = 4;

        public void onSystemCoverEvent(int event, Bundle args) {
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r4v4, types: [com.samsung.android.sdk.cover.CoverPowerKeyListenerDelegate] */
    /* JADX WARN: Type inference failed for: r5v5, types: [com.samsung.android.sdk.cover.CoverPowerKeyListenerDelegate] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public void registerCoverPowerKeyListener(CoverPowerKeyListener listener) throws SsdkUnsupportedException {
        if (!isSupportCover()) {
            Log.w(TAG, "registerCoverPowerKeyListener : This device does not support cover");
            return;
        }
        Log.d(TAG, "registerCoverPowerKeyListener");
        if (!isSupportFlipCover() && !isSupportNeonCover()) {
            Log.w(TAG, "registerLedSystemListener : This device does not support Flip cover or Neon Cover");
        } else if (!isSupportableVersion(17432576)) {
            throw new SsdkUnsupportedException("This device does not support this function. Device is must higher then v1.10.0 for Flip Cover and Neon cover", 2);
        } else if (listener == null) {
            Log.w(TAG, "registerCoverPowerKeyListener : listener is null");
        } else {
            IBinder iBinder = null;
            boolean hasDelegate = false;
            Iterator<CoverPowerKeyListenerDelegate> i = this.mCoverPowerKeyListenerDelegates.iterator();
            while (true) {
                if (!i.hasNext()) {
                    break;
                }
                CoverPowerKeyListenerDelegate next = i.next();
                if (next.getListener().equals(listener)) {
                    iBinder = next;
                    hasDelegate = true;
                    break;
                }
            }
            if (iBinder == null) {
                iBinder = new CoverPowerKeyListenerDelegate(listener, null, this.mContext);
            }
            try {
                ICoverManager svc = getService();
                if (svc != null) {
                    ComponentName cm = new ComponentName(this.mContext.getPackageName(), getClass().getCanonicalName());
                    if (iBinder != null) {
                        svc.registerNfcTouchListenerCallback(10, iBinder, cm);
                        if (!hasDelegate) {
                            this.mCoverPowerKeyListenerDelegates.add(iBinder);
                        }
                    }
                }
            } catch (RemoteException e) {
                Log.e(TAG, "RemoteException in registerCoverPowerKeyListener: ", e);
            }
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r4v5, resolved type: com.samsung.android.sdk.cover.CoverPowerKeyListenerDelegate */
    /* JADX WARN: Multi-variable type inference failed */
    public void unregisterCoverPowerKeyListener(CoverPowerKeyListener listener) throws SsdkUnsupportedException {
        if (!isSupportCover()) {
            Log.w(TAG, "unregisterCoverPowerKeyListener : This device does not support cover");
            return;
        }
        Log.d(TAG, "unregisterCoverPowerKeyListener");
        if (!isSupportFlipCover() && !isSupportNeonCover()) {
            Log.w(TAG, "unregisterCoverPowerKeyListener : This device does not support Flip cover or Neon Cover");
        } else if (!isSupportableVersion(17432576)) {
            throw new SsdkUnsupportedException("This device does not support this function. Device is must higher then v1.1.0 for Flip Cover Neon cover", 2);
        } else if (listener == null) {
            Log.w(TAG, "unregisterCoverPowerKeyListener : listener is null");
        } else {
            IBinder iBinder = null;
            Iterator<CoverPowerKeyListenerDelegate> i = this.mCoverPowerKeyListenerDelegates.iterator();
            while (true) {
                if (!i.hasNext()) {
                    break;
                }
                CoverPowerKeyListenerDelegate delegate = i.next();
                if (delegate.getListener().equals(listener)) {
                    iBinder = delegate;
                    break;
                }
            }
            if (iBinder != null) {
                try {
                    ICoverManager svc = getService();
                    if (svc != null && svc.unregisterNfcTouchListenerCallback(iBinder)) {
                        this.mCoverPowerKeyListenerDelegates.remove(iBinder);
                    }
                } catch (RemoteException e) {
                    Log.e(TAG, "RemoteException in unregisterCoverPowerKeyListener: ", e);
                }
            }
        }
    }

    public static class CoverPowerKeyListener {
        private static final int EVENT_TYPE_POWER_KEY = 10;

        public void onPowerKeyPress() {
        }
    }

    private static boolean supportNewLedSystemEventListener() throws SsdkUnsupportedException {
        return isSupportableVersion(17104896);
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r2v4, types: [com.samsung.android.sdk.cover.LegacyLedSystemEventListenerDelegate] */
    /* JADX WARN: Type inference failed for: r3v5, types: [com.samsung.android.sdk.cover.LegacyLedSystemEventListenerDelegate] */
    /* JADX WARNING: Unknown variable types count: 1 */
    private void registerLegacyLedSystemListener(LedSystemEventListener listener) throws SsdkUnsupportedException {
        if (listener == null) {
            Log.w(TAG, "registerLegacyLedSystemListener : listener is null");
            return;
        }
        IBinder iBinder = null;
        Iterator<LegacyLedSystemEventListenerDelegate> i = this.mLegacyLedSystemEventListenerDelegates.iterator();
        while (true) {
            if (!i.hasNext()) {
                break;
            }
            LegacyLedSystemEventListenerDelegate next = i.next();
            if (next.getListener().equals(listener)) {
                iBinder = next;
                break;
            }
        }
        if (iBinder == null) {
            iBinder = new LegacyLedSystemEventListenerDelegate(listener, null, this.mContext);
            this.mLegacyLedSystemEventListenerDelegates.add(iBinder);
        }
        try {
            ICoverManager svc = getService();
            if (svc != null) {
                ComponentName cm = new ComponentName(this.mContext.getPackageName(), getClass().getCanonicalName());
                if (iBinder != null) {
                    svc.registerNfcTouchListenerCallback(4, iBinder, cm);
                }
            }
        } catch (RemoteException e) {
            Log.e(TAG, "RemoteException in registerLegacyLedSystemListener: ", e);
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r3v5, resolved type: com.samsung.android.sdk.cover.LegacyLedSystemEventListenerDelegate */
    /* JADX WARN: Multi-variable type inference failed */
    private void unregisterLegacyLedSystemEventListener(LedSystemEventListener listener) throws SsdkUnsupportedException {
        Log.d(TAG, "unregisterLegacyLedSystemEventListener");
        if (listener == null) {
            Log.w(TAG, "unregisterLegacyLedSystemEventListener : listener is null");
            return;
        }
        IBinder iBinder = null;
        Iterator<LegacyLedSystemEventListenerDelegate> i = this.mLegacyLedSystemEventListenerDelegates.iterator();
        while (true) {
            if (!i.hasNext()) {
                break;
            }
            LegacyLedSystemEventListenerDelegate delegate = i.next();
            if (delegate.getListener().equals(listener)) {
                iBinder = delegate;
                break;
            }
        }
        if (iBinder != null) {
            try {
                ICoverManager svc = getService();
                if (svc != null && svc.unregisterNfcTouchListenerCallback(iBinder)) {
                    this.mLegacyLedSystemEventListenerDelegates.remove(iBinder);
                }
            } catch (RemoteException e) {
                Log.e(TAG, "RemoteException in unregisterLegacyLedSystemEventListener: ", e);
            }
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r4v4, types: [com.samsung.android.sdk.cover.CoverListenerDelegate] */
    /* JADX WARN: Type inference failed for: r5v5, types: [com.samsung.android.sdk.cover.CoverListenerDelegate] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public boolean disableLcdOffByCover(StateListener listener) throws SsdkUnsupportedException {
        if (!isSupportCover()) {
            Log.w(TAG, "disableLcdOffByCover : This device does not support cover");
            return false;
        } else if (!isSupportableVersion(17104896)) {
            throw new SsdkUnsupportedException("This device does not support this function. Device is must higher then v1.5.0", 2);
        } else if (listener == null) {
            Log.w(TAG, "disableLcdOffByCover : listener cannot be null");
            return false;
        } else {
            Log.d(TAG, "disableLcdOffByCover");
            IBinder iBinder = null;
            Iterator<CoverListenerDelegate> i = this.mLcdOffDisableDelegates.iterator();
            while (true) {
                if (!i.hasNext()) {
                    break;
                }
                CoverListenerDelegate next = i.next();
                if (next.getListener().equals(listener)) {
                    iBinder = next;
                    break;
                }
            }
            if (iBinder == null) {
                iBinder = new CoverListenerDelegate(listener, null, this.mContext);
            }
            try {
                ICoverManager svc = getService();
                if (svc != null && svc.disableLcdOffByCover(iBinder, new ComponentName(this.mContext.getPackageName(), getClass().getCanonicalName()))) {
                    this.mLcdOffDisableDelegates.add(iBinder);
                    return true;
                }
            } catch (RemoteException e) {
                Log.e(TAG, "RemoteException in disableLcdOffByCover: ", e);
            }
            return false;
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v4, resolved type: com.samsung.android.sdk.cover.CoverListenerDelegate */
    /* JADX WARN: Multi-variable type inference failed */
    public boolean enableLcdOffByCover(StateListener listener) throws SsdkUnsupportedException {
        if (!isSupportCover()) {
            Log.w(TAG, "enableLcdOffByCover : This device does not support cover");
            return false;
        } else if (!isSupportableVersion(17104896)) {
            throw new SsdkUnsupportedException("This device does not support this function. Device is must higher then v1.5.0", 2);
        } else if (listener == null) {
            Log.w(TAG, "enableLcdOffByCover : listener cannot be null");
            return false;
        } else {
            Log.d(TAG, "enableLcdOffByCover");
            IBinder iBinder = null;
            Iterator<CoverListenerDelegate> i = this.mLcdOffDisableDelegates.iterator();
            while (true) {
                if (!i.hasNext()) {
                    break;
                }
                CoverListenerDelegate delegate = i.next();
                if (delegate.getListener().equals(listener)) {
                    iBinder = delegate;
                    break;
                }
            }
            if (iBinder == null) {
                Log.e(TAG, "enableLcdOffByCover: Matching listener not found, cannot enable");
                return false;
            }
            try {
                ICoverManager svc = getService();
                if (svc != null && svc.enableLcdOffByCover(iBinder, new ComponentName(this.mContext.getPackageName(), getClass().getCanonicalName()))) {
                    this.mLcdOffDisableDelegates.remove(iBinder);
                    return true;
                }
            } catch (RemoteException e) {
                Log.e(TAG, "RemoteException in unregisterNfcTouchListener: ", e);
            }
            return false;
        }
    }

    public boolean isCoverManagerDisabled() {
        if (!isSupportCover()) {
            Log.w(TAG, "isCoverManagerDisabled : This device is not supported cover");
            return false;
        }
        try {
            ICoverManager svc = getService();
            if (svc != null) {
                return svc.isCoverManagerDisabled();
            }
            return false;
        } catch (RemoteException e) {
            Log.e(TAG, "RemoteException in isCoverManagerDisabled : ", e);
            return false;
        }
    }

    public void disableCoverManager(boolean disable) {
        if (!isSupportCover()) {
            Log.w(TAG, "disableCoverManager : This device is not supported cover");
            return;
        }
        try {
            ICoverManager svc = getService();
            if (svc != null) {
                svc.disableCoverManager(disable, this.mToken, this.mContext.getPackageName());
            }
        } catch (RemoteException e) {
            Log.e(TAG, "RemoteException in disalbeCoverManager : ", e);
        }
    }
}
