package com.samsung.android.sdk.dualscreen;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.util.Log;
import com.samsung.android.sdk.dualscreen.SDualScreenConstantsReflector;
import com.samsung.android.sdk.dualscreen.SDualScreenListener;

public class SDualScreenActivity {
    private static final boolean DEBUG = true;
    public static final int FLAG_COUPLED_TASK_CONTEXTUAL_MODE = SDualScreenConstantsReflector.DualScreenLaunchParams.FLAG_COUPLED_TASK_CONTEXTUAL_MODE;
    public static final int FLAG_COUPLED_TASK_EXPAND_MODE = SDualScreenConstantsReflector.DualScreenLaunchParams.FLAG_COUPLED_TASK_EXPAND_MODE;
    private static final String TAG = SDualScreenActivity.class.getSimpleName();
    private static boolean mDualScreenAvailable = false;
    private static boolean mDualScreenAvailableChecked = false;
    private SDualScreenManagerReflector mDualScreenManagerReflector;
    private ScreenChangeListener mScreenChangeListener;

    public interface ScreenChangeListener {
        void onScreenChanged();
    }

    public enum DualScreen {
        MAIN(SDualScreenManagerReflector.ORDINALS[0]),
        SUB(SDualScreenManagerReflector.ORDINALS[1]),
        EXPANDED(SDualScreenManagerReflector.ORDINALS[2]),
        UNKNOWN(SDualScreenManagerReflector.ORDINALS[3]);
        
        int targetOrdinal;

        private DualScreen(int ordinal) {
            this.targetOrdinal = ordinal;
        }
    }

    private SDualScreenActivity() {
    }

    public SDualScreenActivity(Activity activity) {
        if (activity != null) {
            this.mDualScreenManagerReflector = new SDualScreenManagerReflector(activity);
            return;
        }
        throw new NullPointerException("activity is null");
    }

    public DualScreen getScreen() {
        String str = TAG;
        Log.d(str, "getScreen()");
        if (isDualScreenAvailable()) {
            DualScreen ret = this.mDualScreenManagerReflector.getScreen();
            Log.d(str, "getScreen() ret=" + ret);
            return ret;
        }
        Log.w(str, "DualScreenManager is not loaded");
        return DualScreen.UNKNOWN;
    }

    public void expand() {
        String str = TAG;
        Log.d(str, "expand()");
        if (isDualScreenAvailable()) {
            this.mDualScreenManagerReflector.moveToScreen(DualScreen.EXPANDED);
        } else {
            Log.w(str, "DualScreenManager is not loaded");
        }
    }

    public void collapse() {
        String str = TAG;
        Log.d(str, "collapse()");
        if (isDualScreenAvailable()) {
            boolean ret = this.mDualScreenManagerReflector.moveToScreen(DualScreen.MAIN);
            Log.d(str, "collapse() ret=" + ret);
            return;
        }
        Log.w(str, "DualScreenManager is not loaded");
    }

    public void switchScreen() {
        String str = TAG;
        Log.d(str, "switchScreen()");
        if (isDualScreenAvailable()) {
            this.mDualScreenManagerReflector.switchScreen();
        } else {
            Log.w(str, "DualScreenManager is not loaded");
        }
    }

    public void swapTopTask() {
        String str = TAG;
        Log.d(str, "swapTopTask()");
        if (isDualScreenAvailable()) {
            this.mDualScreenManagerReflector.swapTopTask();
        } else {
            Log.w(str, "DualScreenManager is not loaded");
        }
    }

    public static Intent makeIntent(Context context, Intent intent, DualScreen targetScreen, int flags) {
        String str = TAG;
        Log.d(str, "makeIntent()");
        Intent ret = SDualScreenManagerReflector.makeIntent(context, intent, targetScreen, flags);
        Log.d(str, "makeIntent() : ret=" + ret);
        return ret;
    }

    public static DualScreen getFocusedScreen() {
        Log.d(TAG, "getFocusedScreen()");
        return SDualScreenManagerReflector.getFocusedScreen();
    }

    public SDualScreenCoupledTaskInfo getCoupledTaskInfo() {
        Log.d(TAG, "getCoupledTaskInfo()");
        return this.mDualScreenManagerReflector.getCoupledTaskInfo();
    }

    public void setScreenChangeListener(ScreenChangeListener listener) {
        String str = TAG;
        Log.d(str, "setScreenChangeListener()");
        if (isDualScreenAvailable()) {
            this.mScreenChangeListener = listener;
            if (listener != null) {
                this.mDualScreenManagerReflector.setScreenChangedListner(new SDualScreenListener.ScreenChangeListener() {
                    /* class com.samsung.android.sdk.dualscreen.SDualScreenActivity.AnonymousClass1 */

                    public void onScreenChanged() {
                        SDualScreenActivity.this.mScreenChangeListener.onScreenChanged();
                    }
                });
                return;
            }
            return;
        }
        Log.w(str, "DualScreenManager is not loaded");
    }

    private boolean isDualScreenAvailable() {
        if (mDualScreenAvailableChecked) {
            return mDualScreenAvailable;
        }
        SDualScreenManagerReflector sDualScreenManagerReflector = this.mDualScreenManagerReflector;
        boolean z = sDualScreenManagerReflector != null && sDualScreenManagerReflector.initialized();
        mDualScreenAvailable = z;
        mDualScreenAvailableChecked = true;
        return z;
    }
}
