package com.samsung.android.sdk.dualscreen;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.util.Log;
import com.samsung.android.sdk.dualscreen.SDualScreenActivity;
import com.samsung.android.sdk.dualscreen.SDualScreenListener;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.Locale;

class SDualScreenManagerReflector extends SDualScreenReflector {
    private static final boolean DEBUG = true;
    static String[] DUALSCREEN_ENUM_FIELD_NAMES;
    static int[] ORDINALS;
    private static final String TAG = SDualScreenManagerReflector.class.getSimpleName();
    private static Class<?> sKlassCoupledTaskInfo;
    private static Class<?> sKlassDualScreen;
    private static Class<?> sKlassDualScreenManager;
    static Method sMethodEnumOrdinal;
    private Context mContext;
    private boolean mInitialized = false;
    private Object mInstanceActivity;
    private Object mInstanceDualScreenManager;

    static {
        String[] strArr = {"MAIN", "SUB", "EXPANDED", "UNKNOWN"};
        DUALSCREEN_ENUM_FIELD_NAMES = strArr;
        ORDINALS = new int[strArr.length];
        loadKlass();
    }

    public SDualScreenManagerReflector(Context context) {
        if (context != null) {
            try {
                loadKlass();
                this.mInstanceDualScreenManager = sKlassDualScreenManager.getConstructor(Context.class).newInstance(context);
                this.mContext = context;
                if (context instanceof Activity) {
                    Class<?> activityClass = ((Activity) context).getClass();
                    this.mInstanceActivity = context;
                    putMethod(activityClass, "setScreenChangedListner", new Class[]{SDualScreenListener.ScreenChangeListener.class});
                }
                this.mInitialized = true;
                Log.d(TAG, "completely initialized");
            } catch (NoSuchMethodException e) {
                Log.e(TAG, "NoSuchMethodException !");
                e.printStackTrace();
            } catch (InstantiationException e2) {
                Log.e(TAG, "InstantiationException !");
                e2.printStackTrace();
            } catch (IllegalAccessException e3) {
                Log.e(TAG, "IllegalAccessException !");
                e3.printStackTrace();
            } catch (IllegalArgumentException e4) {
                Log.e(TAG, "IllegalArgumentException !");
                e4.printStackTrace();
            } catch (InvocationTargetException e5) {
                String str = TAG;
                Log.e(str, "InvocationTargetException ! cause=" + e5.getCause());
                e5.printStackTrace();
            }
        } else {
            throw new NullPointerException("context is null");
        }
    }

    static void loadKlass() {
        if (sKlassDualScreenManager == null) {
            try {
                Class<?> cls = Class.forName("com.samsung.android.dualscreen.DualScreenManager");
                sKlassDualScreenManager = cls;
                Method[] arr$ = cls.getMethods();
                for (Method m : arr$) {
                    Log.d(TAG, "DualScreenManager : available method => " + m);
                }
            } catch (ClassNotFoundException e) {
                e.printStackTrace();
            }
            String str = TAG;
            Log.d(str, "loadKlass() : DualScreen SDK version (0.3)");
            Log.d(str, "loadKlass() : Device supports DualScreen version (" + getVersionName() + ")");
            Log.d(str, "loadKlass() : Device supports Minimum SDK version (" + getMinimumSdkVersionName() + ")");
            Class[] clsArr = null;
            putMethod(sKlassDualScreenManager, "getScreen", clsArr);
            putMethod(sKlassDualScreenManager, "getScreen", new Class[]{Integer.TYPE});
            putMethod(sKlassDualScreenManager, "moveToScreen", new Class[]{sKlassDualScreen});
            putMethod(sKlassDualScreenManager, "switchScreen", clsArr);
            putMethod(sKlassDualScreenManager, "swapTopTask", clsArr);
            putMethod(sKlassDualScreenManager, "getCoupledTaskInfo", clsArr);
            checkVersion();
        }
        loadDualScreenEnumKlass();
        if (sKlassCoupledTaskInfo == null) {
            try {
                Class<?> cls2 = Class.forName("com.samsung.android.dualscreen.CoupledTaskInfo");
                sKlassCoupledTaskInfo = cls2;
                Method[] arr$2 = cls2.getMethods();
                for (Method m2 : arr$2) {
                    Log.d(TAG, "CoupledTaskInfo : available method => " + m2);
                }
                putMethod(sKlassCoupledTaskInfo, "getTaskId", null);
                putMethod(sKlassCoupledTaskInfo, "getCoupledTaskMode", null);
                putMethod(sKlassCoupledTaskInfo, "getParentCoupledTaskId", null);
                putMethod(sKlassCoupledTaskInfo, "getChildCoupledTaskId", null);
                putMethod(sKlassCoupledTaskInfo, "isCoupled", null);
            } catch (ClassNotFoundException e2) {
                e2.printStackTrace();
            }
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v4, resolved type: java.lang.Object[] */
    /* JADX WARN: Multi-variable type inference failed */
    static void loadDualScreenEnumKlass() {
        if (sKlassDualScreen == null) {
            try {
                Class<?> cls = Class.forName("com.samsung.android.dualscreen.DualScreen");
                sKlassDualScreen = cls;
                if (cls.isEnum()) {
                    Log.d(TAG, String.format(Locale.US, "Enum name:  %s%nEnum constants:  %s%n", sKlassDualScreen.getName(), Arrays.asList(sKlassDualScreen.getEnumConstants())));
                }
                Method[] arr$ = sKlassDualScreen.getMethods();
                for (Method m : arr$) {
                    Log.d(TAG, "DualScreen : available method => " + m);
                }
                Field[] arr$2 = sKlassDualScreen.getDeclaredFields();
                for (Field f : arr$2) {
                    if (f.isEnumConstant()) {
                        Log.d(TAG, "DualScreen : available fields => " + f.getName() + " (enum constant)");
                    } else {
                        Log.d(TAG, "DualScreen : available fields => " + f.getName());
                    }
                }
                int N = DUALSCREEN_ENUM_FIELD_NAMES.length;
                for (int i = 0; i < N; i++) {
                    Field src = sKlassDualScreen.getDeclaredField(DUALSCREEN_ENUM_FIELD_NAMES[i]);
                    String str = TAG;
                    Log.d(str, "loadDualScreenEnums() : ===================================");
                    Log.d(str, "loadDualScreenEnums() : DUALSCREEN_ENUM_FIELD_NAMES[" + i + "]=" + src);
                    int constansLenth = sKlassDualScreen.getEnumConstants().length;
                    for (int j = 0; j < constansLenth; j++) {
                        Object o = sKlassDualScreen.getEnumConstants()[j];
                        boolean same = o.toString().equals(DUALSCREEN_ENUM_FIELD_NAMES[i]);
                        Log.d(TAG, "loadDualScreenEnums() : o=" + o + ", same=" + same + " index=" + j);
                        if (same) {
                            ORDINALS[i] = j;
                        }
                    }
                }
            } catch (ClassNotFoundException e) {
                Log.e(TAG, "loadDualScreenEnums : ClassNotFoundException !");
                e.printStackTrace();
            } catch (NoSuchFieldException e2) {
                Log.e(TAG, "loadDualScreenEnums : NoSuchFieldException !");
                e2.printStackTrace();
            } catch (IllegalArgumentException e3) {
                Log.e(TAG, "loadDualScreenEnums : IllegalArgumentException !");
                e3.printStackTrace();
            }
        }
        if (sMethodEnumOrdinal == null) {
            try {
                sMethodEnumOrdinal = sKlassDualScreen.getMethod("ordinal", null);
            } catch (NoSuchMethodException e4) {
                e4.printStackTrace();
            } catch (IllegalArgumentException e5) {
                e5.printStackTrace();
            }
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v3, resolved type: java.lang.Object[] */
    /* JADX WARN: Multi-variable type inference failed */
    static Object convertToNativeDualScreenEnum(SDualScreenActivity.DualScreen screen) {
        loadKlass();
        if (screen != null) {
            return sKlassDualScreen.getEnumConstants()[screen.targetOrdinal];
        }
        return null;
    }

    static SDualScreenActivity.DualScreen convertToSdkDualScreenEnum(Object screen) {
        loadKlass();
        if (screen != null) {
            int ordinal = -1;
            try {
                ordinal = ((Integer) sMethodEnumOrdinal.invoke(screen, new Object[0])).intValue();
            } catch (IllegalAccessException e) {
                e.printStackTrace();
            } catch (IllegalArgumentException e2) {
                e2.printStackTrace();
            } catch (InvocationTargetException e3) {
                e3.printStackTrace();
            }
            SDualScreenActivity.DualScreen[] arr$ = SDualScreenActivity.DualScreen.values();
            for (SDualScreenActivity.DualScreen o : arr$) {
                if (o.targetOrdinal == ordinal) {
                    return o;
                }
            }
        }
        return SDualScreenActivity.DualScreen.UNKNOWN;
    }

    static SDualScreenCoupledTaskInfo convertToSdkCoupledTaskInfo(Object coupledTaskInfo) {
        loadKlass();
        SDualScreenCoupledTaskInfo sdualScreenCoupledTaskInfo = null;
        if (checkMethod("getTaskId()")) {
            int taskId = ((Integer) invoke("getTaskId()", coupledTaskInfo, new Object[0])).intValue();
            if (taskId > 0) {
                String str = TAG;
                Log.d(str, "convertToSdkCoupledTaskInfo() : taskId=" + taskId);
                sdualScreenCoupledTaskInfo = new SDualScreenCoupledTaskInfo(taskId);
                int coupledTaskMode = 0;
                int parentTaskId = 0;
                int childTaskId = 0;
                boolean isCoupled = false;
                if (checkMethod("getCoupledTaskMode()")) {
                    coupledTaskMode = ((Integer) invoke("getCoupledTaskMode()", coupledTaskInfo, new Object[0])).intValue();
                } else {
                    Log.w(str, "getCoupledTaskMode() is not loaded");
                }
                if (checkMethod("getParentCoupledTaskId()")) {
                    parentTaskId = ((Integer) invoke("getParentCoupledTaskId()", coupledTaskInfo, new Object[0])).intValue();
                } else {
                    Log.w(str, "getParentCoupledTaskId() is not loaded");
                }
                if (checkMethod("getChildCoupledTaskId()")) {
                    childTaskId = ((Integer) invoke("getChildCoupledTaskId()", coupledTaskInfo, new Object[0])).intValue();
                } else {
                    Log.w(str, "getParentCoupledTaskId() is not loaded");
                }
                if (checkMethod("isCoupled()")) {
                    isCoupled = ((Boolean) invoke("isCoupled()", coupledTaskInfo, new Object[0])).booleanValue();
                } else {
                    Log.w(str, "isCoupled() is not loaded");
                }
                sdualScreenCoupledTaskInfo.setCoupledTaskMode(coupledTaskMode);
                sdualScreenCoupledTaskInfo.setParentCoupledTaskId(parentTaskId);
                sdualScreenCoupledTaskInfo.setChildCoupledTaskId(childTaskId);
                sdualScreenCoupledTaskInfo.setCoupledState(isCoupled);
            }
        } else {
            Log.w(TAG, "getTaskId() is not loaded");
        }
        return sdualScreenCoupledTaskInfo;
    }

    public boolean initialized() {
        return this.mInitialized;
    }

    /* access modifiers changed from: package-private */
    public SDualScreenActivity.DualScreen getScreen() {
        String str = TAG;
        Log.d(str, "getScreen()");
        Object ret = null;
        if (checkMethod("getScreen()")) {
            ret = invoke("getScreen()", this.mInstanceDualScreenManager, new Object[0]);
        }
        if (ret == null) {
            return SDualScreenActivity.DualScreen.UNKNOWN;
        }
        Log.d(str, "getScreen() ret=" + ret);
        return convertToSdkDualScreenEnum(ret);
    }

    /* access modifiers changed from: package-private */
    public SDualScreenActivity.DualScreen getScreen(int taskId) {
        String str = TAG;
        Log.d(str, "getScreen() : taskId=" + taskId);
        if (!checkMethod("getScreen(int)")) {
            return SDualScreenActivity.DualScreen.UNKNOWN;
        }
        return (SDualScreenActivity.DualScreen) invoke("getScreen(int)", this.mInstanceDualScreenManager, Integer.valueOf(taskId));
    }

    /* access modifiers changed from: package-private */
    public boolean moveToScreen(SDualScreenActivity.DualScreen toScreen) {
        String str = TAG;
        Log.d(str, "moveToScreen() : toScreen=" + toScreen);
        Object nativeEnum = convertToNativeDualScreenEnum(toScreen);
        Log.d(str, "moveToScreen() : nativeEnum=" + nativeEnum);
        if (!checkMethod("moveToScreen(DualScreen)")) {
            return false;
        }
        try {
            return ((Boolean) invoke("moveToScreen(DualScreen)", this.mInstanceDualScreenManager, nativeEnum)).booleanValue();
        } catch (Exception e) {
            return false;
        }
    }

    /* access modifiers changed from: package-private */
    public void switchScreen() {
        Log.d(TAG, "switchScreen()");
        if (checkMethod("switchScreen()")) {
            invoke("switchScreen()", this.mInstanceDualScreenManager, new Object[0]);
        }
    }

    /* access modifiers changed from: package-private */
    public void swapTopTask() {
        Log.d(TAG, "swapTopTask()");
        if (checkMethod("swapTopTask()")) {
            invoke("swapTopTask()", this.mInstanceDualScreenManager, new Object[0]);
        }
    }

    /* access modifiers changed from: package-private */
    public void setScreenChangedListner(SDualScreenListener.ScreenChangeListener listener) {
        Log.d(TAG, "setScreenChangedListner()");
        if (checkMethod("setScreenChangedListner(ScreenChangeListener)")) {
            invoke("setScreenChangedListner(ScreenChangeListener)", this.mInstanceActivity, listener);
        }
    }

    /* access modifiers changed from: package-private */
    public SDualScreenCoupledTaskInfo getCoupledTaskInfo() {
        String str = TAG;
        Log.d(str, "getCoupledTaskInfo()");
        if (checkMethod("getCoupledTaskInfo()")) {
            Object ret = invoke("getCoupledTaskInfo()", this.mInstanceDualScreenManager, new Object[0]);
            if (ret != null) {
                Log.d(str, "getCoupledTaskInfo() ret=" + ret);
                return convertToSdkCoupledTaskInfo(ret);
            }
            Context context = this.mContext;
            if (context instanceof Activity) {
                new SDualScreenCoupledTaskInfo(((Activity) context).getTaskId());
            }
            return null;
        }
        Log.w(str, "getCoupledTaskInfo() is not loaded");
        return null;
    }

    static Intent makeIntent(Context context, Intent intent, SDualScreenActivity.DualScreen targetScreen, int flags) {
        String str = TAG;
        Log.d(str, "makeIntent()");
        if (!checkMethod("makeIntent(Context,Intent,DualScreen,int)")) {
            loadKlass();
            putMethod(sKlassDualScreenManager, "makeIntent", new Class[]{Context.class, Intent.class, sKlassDualScreen, Integer.TYPE});
        }
        if (checkMethod("makeIntent(Context,Intent,DualScreen,int)")) {
            invoke("makeIntent(Context,Intent,DualScreen,int)", null, context, intent, convertToNativeDualScreenEnum(targetScreen), Integer.valueOf(flags));
        } else {
            Log.w(str, "makeIntent(Context,Intent,DualScreen,int) is not loaded");
        }
        return intent;
    }

    static SDualScreenActivity.DualScreen getFocusedScreen() {
        String str = TAG;
        Log.d(str, "getFocusedScreen()");
        Object ret = null;
        if (!checkMethod("getFocusedScreen()")) {
            loadKlass();
            putMethod(sKlassDualScreenManager, "getFocusedScreen", null);
        }
        if (checkMethod("getFocusedScreen()")) {
            ret = invoke("getFocusedScreen()", null, new Object[0]);
        } else {
            Log.w(str, "getFocusedScreen() is not loaded");
        }
        if (ret == null) {
            return SDualScreenActivity.DualScreen.UNKNOWN;
        }
        Log.d(str, "getFocusedScreen() ret=" + ret);
        return convertToSdkDualScreenEnum(ret);
    }

    static int getVersionCode() {
        Object ret = null;
        if (!checkMethod("getVersionCode()")) {
            loadKlass();
            putMethod(sKlassDualScreenManager, "getVersionCode", null);
        }
        if (checkMethod("getVersionCode()")) {
            ret = invoke("getVersionCode()", null, new Object[0]);
        } else {
            Log.w(TAG, "getVersionCode() is not loaded");
        }
        if (ret == null) {
            return -1;
        }
        String str = TAG;
        Log.d(str, "getVersionCode() ret=" + ret);
        return ((Integer) ret).intValue();
    }

    static String getVersionName() {
        Object ret = null;
        if (!checkMethod("getVersionName()")) {
            loadKlass();
            putMethod(sKlassDualScreenManager, "getVersionName", null);
        }
        if (checkMethod("getVersionName()")) {
            ret = invoke("getVersionName()", null, new Object[0]);
        }
        if (ret == null) {
            return "UNKNOWN";
        }
        String str = TAG;
        Log.d(str, "getVersionName() ret=" + ret);
        return (String) ret;
    }

    static int getMinimumSdkVersionCode() {
        Object ret = null;
        if (!checkMethod("getMinimumSdkVersionCode()")) {
            loadKlass();
            putMethod(sKlassDualScreenManager, "getMinimumSdkVersionCode", null);
        }
        if (checkMethod("getMinimumSdkVersionCode()")) {
            ret = invoke("getMinimumSdkVersionCode()", null, new Object[0]);
        }
        if (ret == null) {
            return -1;
        }
        String str = TAG;
        Log.d(str, "getMinimumSdkVersionCode() : " + ret);
        return ((Integer) ret).intValue();
    }

    static String getMinimumSdkVersionName() {
        Object ret = null;
        if (!checkMethod("getMinimumSdkVersionName()")) {
            loadKlass();
            putMethod(sKlassDualScreenManager, "getMinimumSdkVersionName", null);
        }
        if (checkMethod("getMinimumSdkVersionName()")) {
            ret = invoke("getMinimumSdkVersionName()", null, new Object[0]);
        }
        if (ret == null) {
            return "UNKNOWN";
        }
        String str = TAG;
        Log.d(str, "getMinimumSdkVersionName() : " + ret);
        return (String) ret;
    }

    static void checkVersion() {
        if (3 < getMinimumSdkVersionCode()) {
            throw new RuntimeException("Application using SDK version is old (version 0.3). The device requires (version " + getMinimumSdkVersionName() + ") at least");
        }
    }
}
