package com.sec.factory.aporiented;

import android.content.Context;
import android.content.Intent;
import com.sec.factory.aporiented.ParallelCommandsParser;
import com.sec.factory.aporiented.ResponseWriter;
import com.sec.factory.aporiented.athandler.AtCommandHandler;
import com.sec.factory.app.factorytest.FactoryTestRemoteController;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Locale;
import java.util.concurrent.ConcurrentLinkedQueue;

public class AtParser implements CommandListener, ResponseWriter.ResponseListener {
    public static final String ACTION_NV_INFORMATION = "com.sec.factory.CMD_NV_INFORMATION";
    public static final String ACTION_RECEIVED_FROM_RIL = "com.sec.factory.RECEIVED_FROM_RIL";
    public static final String CLASS_NAME = "AtParser";
    private final HashMap<String, AtCommandHandler> atHandlers;
    private Context mContext;
    String[] mFilteredcommandList;
    private ProcessThread[] mProcessThread;
    private ConcurrentLinkedQueue<WaitingNodeInfo> mWaitingList;
    ResponseWriter mWriter;
    private boolean mbExistADC;

    public static final class WaitingNodeInfo {
        private String CMD;
        private int ID;
        private String mIndex;

        WaitingNodeInfo(String cmd, String index, int id) {
            this.CMD = cmd;
            this.mIndex = index;
            this.ID = id;
        }

        public String getIndex() {
            return this.mIndex;
        }

        public String getCMD() {
            return this.CMD;
        }

        public int getID() {
            return this.ID;
        }

        public String toString() {
            return this.CMD + ", " + this.mIndex + ", ID=" + this.ID;
        }
    }

    public AtParser() {
        this.mFilteredcommandList = Support.CommandFilter.getFilteredCommands();
        this.mProcessThread = null;
        this.mWaitingList = new ConcurrentLinkedQueue<>();
        this.mbExistADC = false;
        this.atHandlers = new HashMap<>();
        this.mbExistADC = Support.Kernel.isExistFileID(Support.Kernel.JIG_CONNECTION_CHECK_ADC);
    }

    public void registerAllHandler(Context context, ResponseWriter writer) {
        RegisterCommonHandler registerATHandler;
        FtUtil.log_d(CLASS_NAME, "registerAllHandler", "Register AT command handler");
        this.mContext = context;
        this.mWriter = writer;
        if (FtUtil.isFactoryBinary()) {
            registerATHandler = new RegisterFactoryBinHandler(this.atHandlers, context, writer);
        } else {
            registerATHandler = new RegisterCommonHandler(this.atHandlers, context, writer);
        }
        registerATHandler.registerHandler();
        FtUtil.log_d(CLASS_NAME, "registerAllHandler", FtUtil.setMspSeqMessage(0, "BOOTING COMPLETED", "ING : registered AtHandlers -> waiting nfc f/w update and Esim"));
    }

    public boolean process(String cmd, ResponseWriter writer) {
        FtUtil.log_d(CLASS_NAME, "process", cmd);
        if (FtUtil.isFactoryBinary()) {
            FtUtil.log_d(CLASS_NAME, "process", "Usb Configuration Status = " + Support.Kernel.read(Support.Kernel.USB_CONFIG_CHECK));
            if (this.mbExistADC) {
                FtUtil.log_d(CLASS_NAME, "process", "Usb ADC Status = " + Support.Kernel.read(Support.Kernel.JIG_CONNECTION_CHECK_ADC));
            }
        }
        if (cmd != null) {
            try {
                if (cmd.length() >= 1) {
                    if (cmd.contains(";")) {
                        String[] cmdList = cmd.split(";");
                        if (cmdList != null) {
                            if (cmdList.length > 0) {
                                if ("AT+PARALLEL=0,0,00000".equalsIgnoreCase(cmdList[0])) {
                                    AtCommandHandler.STAGE_PARALLEL = true;
                                    this.mWriter.setResponseListener(this);
                                    ParallelCommandsParser mParallelCommandsParser = new ParallelCommandsParser();
                                    for (String command : cmdList) {
                                        mParallelCommandsParser.add(command);
                                    }
                                    Collection<ParallelCommandsParser.Category> categories = mParallelCommandsParser.getHitCommandsList();
                                    this.mProcessThread = new ProcessThread[categories.size()];
                                    int index = 0;
                                    for (int i = 4; i >= 0; i--) {
                                        for (ParallelCommandsParser.Category category : categories) {
                                            if (category.getPriority() == i) {
                                                this.mProcessThread[index] = new ProcessThread(this, category, this.mProcessThread, index);
                                                int priority = this.mProcessThread[index].getPriority() + i;
                                                int priority2 = 10;
                                                if (priority <= 10) {
                                                    priority2 = priority;
                                                }
                                                this.mProcessThread[index].setPriority(priority2);
                                                index++;
                                                categories.remove(category);
                                            }
                                        }
                                    }
                                    for (int i2 = 0; i2 < index; i2++) {
                                        this.mProcessThread[i2].start();
                                    }
                                } else {
                                    int i3 = 0;
                                    while (cmdList.length > i3 && cmdList[i3] != null) {
                                        if (runCmd(cmdList[i3], writer)) {
                                            FtUtil.log_d(CLASS_NAME, "process done successfully. cmdList = ", cmdList[i3]);
                                        }
                                        i3++;
                                    }
                                }
                            }
                        }
                        FtUtil.log_e(CLASS_NAME, "process done successfully. cmdList is null");
                        return false;
                    } else if (runCmd(cmd, writer)) {
                        FtUtil.log_d(CLASS_NAME, "process done successfully. cmd = ", cmd);
                    }
                    return true;
                }
            } catch (StringIndexOutOfBoundsException e) {
                FtUtil.log_e(e);
                return false;
            }
        }
        return false;
    }

    @Override // com.sec.factory.aporiented.CommandListener
    public boolean onRunCommand(String cmd) {
        FtUtil.log_d(CLASS_NAME, "runCommand", cmd);
        return runCmd(cmd, this.mWriter);
    }

    @Override // com.sec.factory.aporiented.CommandListener
    public synchronized boolean onFinishAllCommand(String cmd, int id) {
        FtUtil.log_d(CLASS_NAME, "onFinishAllCommand", cmd + ", ID = " + id);
        ProcessThread[] processThreadArr = this.mProcessThread;
        if (processThreadArr != null && processThreadArr[id].isAlive()) {
            this.mProcessThread[id].kill();
        }
        ProcessThread[] processThreadArr2 = this.mProcessThread;
        if (processThreadArr2 != null) {
            for (ProcessThread p : processThreadArr2) {
                if (p != null && !p.mIsKilled) {
                    FtUtil.log_d(CLASS_NAME, "onFinishAllCommand", "Working = " + p.getCategoryName());
                    return false;
                }
            }
        }
        FtUtil.log_d(CLASS_NAME, "onFinishAllCommand", "All Threads are done");
        if (this.mProcessThread != null) {
            int i = 0;
            while (true) {
                ProcessThread[] processThreadArr3 = this.mProcessThread;
                if (i >= processThreadArr3.length) {
                    break;
                }
                processThreadArr3[i] = null;
                i++;
            }
        }
        this.mProcessThread = null;
        this.mWriter.setResponseListener(null);
        return true;
    }

    @Override // com.sec.factory.aporiented.CommandListener
    public boolean onWaitingResponse(String cmd, int id) {
        FtUtil.log_d(CLASS_NAME, "onWaitingResponse", cmd + ", ID = " + id);
        if (cmd == null) {
            return false;
        }
        String command = cmd.substring(cmd.indexOf("+") + 1, cmd.indexOf("="));
        String index = cmd.substring(cmd.lastIndexOf(",") + 1);
        FtUtil.log_d(CLASS_NAME, "onWaitingResponse", "cmd : " + command + ", Index : " + index + ", ID = " + id);
        this.mWaitingList.add(new WaitingNodeInfo(command, index, id));
        return true;
    }

    @Override // com.sec.factory.aporiented.ResponseWriter.ResponseListener
    public boolean onResponse(String res) {
        FtUtil.log_d(CLASS_NAME, "onResponse", res != null ? res.replaceAll("\\s+", "") : null);
        ConcurrentLinkedQueue<WaitingNodeInfo> concurrentLinkedQueue = this.mWaitingList;
        if (concurrentLinkedQueue == null || concurrentLinkedQueue.isEmpty() || res == null) {
            return true;
        }
        Iterator<WaitingNodeInfo> it = this.mWaitingList.iterator();
        while (it.hasNext()) {
            WaitingNodeInfo item = it.next();
            String cmd = item.getCMD();
            String index = item.getIndex();
            FtUtil.log_d(CLASS_NAME, "onResponse", "itme info : " + item);
            if (res.contains(cmd) && res.contains(index)) {
                FtUtil.log_d(CLASS_NAME, "onResponse", "catch response : " + item);
                int id = item.getID();
                ProcessThread[] processThreadArr = this.mProcessThread;
                if (!(processThreadArr == null || processThreadArr[id] == null || processThreadArr[id].isInterrupted())) {
                    this.mProcessThread[id].interrupt();
                }
                this.mWaitingList.remove(item);
            }
        }
        return true;
    }

    public boolean terminateThreads() {
        FtUtil.log_d(CLASS_NAME, "terminateThreads");
        ProcessThread[] processThreadArr = this.mProcessThread;
        if (processThreadArr == null) {
            return true;
        }
        for (ProcessThread p : processThreadArr) {
            if (p != null && p.isAlive()) {
                p.kill();
            }
        }
        this.mProcessThread = null;
        return true;
    }

    public boolean runCmd(String cmd, ResponseWriter writer) {
        String commandName;
        FtUtil.log_d(CLASS_NAME, "runCmd", cmd);
        String resData = null;
        boolean result = false;
        if (cmd != null) {
            try {
                if (cmd.length() >= 1) {
                    if (cmd.contains("=") && cmd.indexOf("=") != 0) {
                        commandName = cmd.substring(0, cmd.indexOf("=")).toUpperCase(Locale.ENGLISH);
                    } else if (cmd.contains("?")) {
                        commandName = cmd.substring(0, cmd.indexOf("?")).toUpperCase(Locale.ENGLISH);
                    } else {
                        commandName = cmd.trim().substring(0, cmd.length()).toUpperCase(Locale.ENGLISH);
                    }
                    FtUtil.log_d(CLASS_NAME, "process", "command : " + commandName);
                    if (commandName == null || !this.atHandlers.containsKey(commandName) || isFilteredCommand(cmd, commandName)) {
                        FtUtil.log_d(CLASS_NAME, "runCmd: ", cmd + " is not registered in the atHandler.");
                        if (cmd.contains("SETTESTNV") || cmd.contains("GETTESTNV")) {
                            try {
                                int cmdNv = Integer.parseInt(cmd.split("=")[1].split(",")[0]);
                                Intent nvInfoIntent = new Intent(ACTION_NV_INFORMATION);
                                nvInfoIntent.putExtra("nv", cmdNv);
                                this.mContext.sendBroadcast(nvInfoIntent);
                            } catch (NumberFormatException ne) {
                                FtUtil.log_e(ne);
                            }
                        }
                        Intent intent = new Intent(ACTION_RECEIVED_FROM_RIL);
                        intent.putExtra(FactoryTestRemoteController.COMMAND, cmd);
                        if ("AT+RSTVERIF=0,0".equalsIgnoreCase(cmd)) {
                            intent.addFlags(268435456);
                        } else if ("AT+KSTRINGB=0,2".equalsIgnoreCase(cmd) || "AT+KSTRINGB=0,3".equalsIgnoreCase(cmd) || "AT+KSTRINGB=1,1".equalsIgnoreCase(cmd)) {
                            intent.setPackage("com.sec.hiddenmenu");
                            intent.addFlags(268435456);
                        } else if (cmd.contains("AT+SETTESTNV=117")) {
                            FtUtil.log_d(CLASS_NAME, "runCmd: ", cmd + " (NFC_FT)");
                        }
                        intent.addFlags(16777216);
                        this.mContext.sendBroadcast(intent);
                        FtUtil.log_d(CLASS_NAME, "runCmd: ", "Broadcast unregistered command: " + cmd);
                        result = true;
                    } else {
                        String[] argu = splitArgu(cmd);
                        FtUtil.log_d(CLASS_NAME, "runCmd", FtUtil.setMspSeqMessage(0, cmd.replace("+", ":"), "Start"));
                        resData = this.atHandlers.get(commandName).handleCommand(argu);
                        FtUtil.log_d(CLASS_NAME, "runCmd: ", "CMD : " + cmd + ", result : " + resData);
                        if (!AtCommandHandler.STAGE_PARALLEL) {
                            AtCommandInfo instance = AtCommandInfo.getInstance();
                            instance.addCommandHistory("Registered CMD : " + cmd);
                        }
                    }
                    if (resData == null) {
                        return result;
                    }
                    if (!"NOT_APPLICABLE".equals(resData)) {
                        writer.write(resData);
                    }
                    return true;
                }
            } catch (StringIndexOutOfBoundsException e) {
                FtUtil.log_e(e);
                return false;
            }
        }
        return false;
    }

    /* JADX WARNING: Removed duplicated region for block: B:19:0x00eb  */
    /* JADX WARNING: Removed duplicated region for block: B:29:? A[RETURN, SYNTHETIC] */
    public String[] splitArgu(String cmd) {
        if (!cmd.contains("=")) {
            return new String[0];
        }
        String args = cmd.substring(cmd.indexOf("=") + 1, cmd.length());
        String[] deposit = new String[10];
        int index = 0;
        while (args.contains("\"")) {
            int fIndex = args.indexOf("\"");
            String subStr = args.substring(fIndex, args.indexOf("\"", fIndex + 1) + 1);
            args = args.replace(subStr, "__ARG__" + index);
            FtUtil.log_d(CLASS_NAME, "splitArgu()", "subStr : " + subStr + ", REPLACE : " + "__ARG__" + index + ", args : " + args);
            deposit[index] = subStr;
            index++;
        }
        String[] res = args.split(",");
        while (true) {
            int index2 = index - 1;
            if (index > 0 && res != null) {
                int i = 0;
                while (true) {
                    if (i >= res.length) {
                        break;
                    }
                    if (res[i].equalsIgnoreCase("__ARG__" + index2)) {
                        FtUtil.log_d(CLASS_NAME, "splitArgu()", "res : " + res[i] + " : " + "__ARG__" + index2 + " : " + deposit[index2]);
                        res[i] = deposit[index2];
                        StringBuilder sb = new StringBuilder();
                        sb.append("res : ");
                        sb.append(res[i]);
                        FtUtil.log_d(CLASS_NAME, "splitArgu()", sb.toString());
                        break;
                    }
                    i++;
                }
                index = index2;
            } else if (res != null) {
                return res;
            } else {
                FtUtil.log_d(CLASS_NAME, "splitArgu()", "args : " + res.length + " : " + Arrays.toString(res));
                return res;
            }
        }
        if (res != null) {
        }
    }

    private boolean isFilteredCommand(String fullCMD, String commandName) {
        String[] argu = splitArgu(fullCMD);
        String[] strArr = this.mFilteredcommandList;
        if (strArr == null) {
            return false;
        }
        for (String command : strArr) {
            String[] item = command.split("/");
            if (commandName.equals(item[0]) && compareArgu(argu, item[1].split(","), item[2])) {
                FtUtil.log_d(CLASS_NAME, "isFilteredCommand", "---filtered CMD= " + command + "  , commandName=" + commandName);
                return true;
            }
        }
        return false;
    }

    private boolean compareArgu(String[] argu, String[] para, String count) {
        for (int i = 0; i < Integer.parseInt(count); i++) {
            try {
                FtUtil.log_d(CLASS_NAME, "compareArgu", "compareArgu : argu[" + i + "]=" + argu[i] + ", para[" + i + "]=" + para[i]);
                if (!argu[i].equals(para[i])) {
                    return false;
                }
            } catch (Exception e) {
                e.printStackTrace();
                return false;
            }
        }
        return true;
    }
}
