package com.sec.factory.aporiented;

import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.net.LocalSocket;
import android.net.LocalSocketAddress;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.os.Process;
import com.sec.factory.modules.ModuleCommon;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.XMLDataStorage;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;

public class DummyFtClient extends Service {
    public static final String CLASS_NAME = "DummyFtClient";
    public static final int FINISH = 102;
    public static final int SEND_BOOT_COMPLETED = 1002;
    LocalSocket clientSocket_recv = new LocalSocket();
    LocalSocket clientSocket_send = new LocalSocket();
    private ConnectionThread connectionThread;
    private Handler mHandler = new Handler() {
        /* class com.sec.factory.aporiented.DummyFtClient.AnonymousClass1 */

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 102:
                    DummyFtClient.this.stopService();
                    return;
                case 1002:
                    DummyFtClient.this.writer.write("BOOTING COMPLETED\r\n");
                    return;
                default:
                    return;
            }
        }
    };
    public ResponseWriter writer;

    public IBinder onBind(Intent intent) {
        return null;
    }

    public void onCreate() {
        FtUtil.log_d(CLASS_NAME, "onCreate", "Create DummyFtClient service");
        if (!XMLDataStorage.instance().parseXML(this)) {
            FtUtil.log_d(CLASS_NAME, "onReceive", "ACTION_SIM_STATE_CHANGED => XML data parsing was failed.");
        }
        if (ModuleCommon.instance(this).isConnectionModeNone()) {
            ConnectionThread connectionThread2 = new ConnectionThread(this);
            this.connectionThread = connectionThread2;
            connectionThread2.start();
        }
    }

    public int onStartCommand(Intent intent, int flags, int startId) {
        FtUtil.log_d(CLASS_NAME, "onStartCommand", "...");
        sendBootCompletedAndFinish();
        return 2;
    }

    public void onDestroy() {
        super.onDestroy();
        FtUtil.log_d(CLASS_NAME, "onDestroy", "Destroy DummyFtClient service");
        if (ModuleCommon.instance(this).isConnectionModeNone()) {
            this.connectionThread.kill();
            LocalSocket localSocket = this.clientSocket_recv;
            if (localSocket != null) {
                try {
                    localSocket.close();
                    FtUtil.log_i(CLASS_NAME, "onDestroy", "Close client socket(receiver)");
                } catch (IOException e) {
                    FtUtil.log_e(e);
                }
            }
            LocalSocket localSocket2 = this.clientSocket_send;
            if (localSocket2 != null) {
                try {
                    localSocket2.close();
                    FtUtil.log_i(CLASS_NAME, "onDestroy", "Close client socket(sender)");
                } catch (IOException e2) {
                    FtUtil.log_e(e2);
                }
            }
        }
        if (ModuleCommon.instance(this).isRunningFtClient()) {
            FtUtil.log_d(CLASS_NAME, "onDestroy", "now running FtClient");
            return;
        }
        FtUtil.log_d(CLASS_NAME, "onDestroy", "kill process");
        Process.killProcess(Process.myPid());
    }

    private void sendBootCompletedAndFinish() {
        FtUtil.log_d(CLASS_NAME, "sendBootCompletedAndFinish", "...");
        if (!ModuleCommon.instance(this).isConnectionModeNone()) {
            new IPCWriterToSecPhoneService(this);
        } else {
            this.mHandler.post(new Runnable() {
                /* class com.sec.factory.aporiented.DummyFtClient.AnonymousClass2 */

                public void run() {
                    for (int retryCount = 0; retryCount < 10; retryCount++) {
                        if (!DummyFtClient.this.clientSocket_recv.isConnected() || !DummyFtClient.this.clientSocket_send.isConnected() || DummyFtClient.this.writer == null) {
                            FtUtil.log_d(DummyFtClient.CLASS_NAME, "sendBootCompletedAndFinish", "Retry couter : " + retryCount);
                            try {
                                Thread.sleep(1000);
                            } catch (InterruptedException e) {
                                e.printStackTrace();
                            }
                        } else {
                            FtUtil.log_d(DummyFtClient.CLASS_NAME, "sendBootCompletedAndFinish", "BOOTING COMPLETED!!");
                            DummyFtClient.this.mHandler.sendEmptyMessage(1002);
                            return;
                        }
                    }
                }
            });
        }
        this.mHandler.post(new Runnable() {
            /* class com.sec.factory.aporiented.DummyFtClient.AnonymousClass3 */

            public void run() {
                DummyFtClient.this.mHandler.sendEmptyMessageDelayed(102, 15000);
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void stopService() {
        stopSelf();
    }

    private class ConnectionThread extends Thread {
        private boolean active = true;
        private final Context context;
        private BufferedReader in;

        public ConnectionThread(Context context2) {
            this.context = context2;
        }

        public void run() {
            FtUtil.log_d(DummyFtClient.CLASS_NAME, "run", "ConnectionThread start");
            boolean connected = false;
            int garbage_count = 0;
            LocalSocketAddress lsa_recv = new LocalSocketAddress("FactoryClientRecv");
            LocalSocketAddress lsa_send = new LocalSocketAddress("FactoryClientSend");
            while (!connected) {
                try {
                    if (!DummyFtClient.this.clientSocket_recv.isConnected()) {
                        DummyFtClient.this.clientSocket_recv.connect(lsa_recv);
                        FtUtil.log_i(DummyFtClient.CLASS_NAME, "run", "Connect client socket(receiver)");
                    }
                    if (!DummyFtClient.this.clientSocket_send.isConnected()) {
                        DummyFtClient.this.clientSocket_send.connect(lsa_send);
                        FtUtil.log_i(DummyFtClient.CLASS_NAME, "run", "Connect client socket(sender)");
                    }
                } catch (IOException e) {
                    FtUtil.log_e(e);
                }
                if (!DummyFtClient.this.clientSocket_recv.isConnected() || !DummyFtClient.this.clientSocket_send.isConnected()) {
                    connected = false;
                    try {
                        Thread.sleep(3000);
                    } catch (InterruptedException e2) {
                        FtUtil.log_e(e2);
                    }
                } else {
                    connected = true;
                    FtUtil.log_i(DummyFtClient.CLASS_NAME, "run", "Client socket connect success");
                }
                if (connected) {
                    FtUtil.log_i(DummyFtClient.CLASS_NAME, "run", "Connected to AT Core");
                    this.active = true;
                    DummyFtClient.this.writer = new ResponseWriter(DummyFtClient.this.clientSocket_send);
                    try {
                        this.in = new BufferedReader(new InputStreamReader(DummyFtClient.this.clientSocket_recv.getInputStream()));
                    } catch (IOException e3) {
                        FtUtil.log_e(e3);
                        this.active = false;
                        connected = false;
                    }
                    while (this.active) {
                        try {
                            if (this.in.readLine() == null) {
                                garbage_count++;
                                FtUtil.log_i(DummyFtClient.CLASS_NAME, "run", "Garbage data incoming...");
                                if (garbage_count > 10) {
                                    FtUtil.log_i(DummyFtClient.CLASS_NAME, "run", "Stop DummyFtClient(Garbage data count=" + garbage_count + ")");
                                    this.active = false;
                                }
                            }
                        } catch (IOException e4) {
                            FtUtil.log_e(e4);
                            this.active = false;
                            connected = false;
                        }
                    }
                }
            }
        }

        public void kill() {
            this.active = false;
            FtUtil.log_d(DummyFtClient.CLASS_NAME, "run", "Kill ConnectionThread");
        }
    }
}
