package com.sec.factory.aporiented;

import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.XMLDataStorage;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentLinkedQueue;
import org.w3c.dom.Element;

public class ParallelCommandsParser {
    public static final String CLASS_NAME = "ParallelCommandsParser";
    private ConcurrentHashMap<String, Category> mCategoryMap;

    public ConcurrentHashMap<String, Category> getMap() {
        return this.mCategoryMap;
    }

    public static class Category {
        public static final int PRIORITY_DEFAULT = 1;
        public static final int PRIORITY_HIGH = 3;
        public static final int PRIORITY_HIGHEST = 4;
        public static final int PRIORITY_LOW = 0;
        public static final int PRIORITY_MID = 2;
        private int mCommandsGap;
        private LinkedList<String> mDependencyList;
        private boolean mIsRunning;
        private String mName;
        private int mPriority;
        private ConcurrentLinkedQueue<String> mQueue;

        Category(String name, int priority, String[] dependency) {
            this.mQueue = null;
            this.mDependencyList = null;
            this.mCommandsGap = -1;
            this.mIsRunning = false;
            this.mName = name;
            this.mPriority = priority;
            this.mQueue = new ConcurrentLinkedQueue<>();
            if (dependency != null) {
                this.mDependencyList = new LinkedList<>();
                for (String cmd : dependency) {
                    this.mDependencyList.add(cmd);
                }
            }
        }

        Category(String name, int priority, String[] dependency, int gap) {
            this(name, priority, dependency);
            this.mCommandsGap = gap;
        }

        public String toString() {
            return this.mName;
        }

        public String getDependencyList() {
            LinkedList<String> linkedList = this.mDependencyList;
            if (linkedList == null || linkedList.isEmpty()) {
                return null;
            }
            return this.mDependencyList.toString();
        }

        public String getName() {
            return this.mName;
        }

        public int getPriority() {
            return this.mPriority;
        }

        public boolean addToQueue(String cmd) {
            ConcurrentLinkedQueue<String> concurrentLinkedQueue = this.mQueue;
            if (concurrentLinkedQueue == null) {
                return false;
            }
            concurrentLinkedQueue.add(cmd);
            return false;
        }

        public boolean isEnabled() {
            ConcurrentLinkedQueue<String> concurrentLinkedQueue = this.mQueue;
            if (concurrentLinkedQueue == null || concurrentLinkedQueue.isEmpty()) {
                return false;
            }
            return true;
        }

        public String pollCommand() {
            return this.mQueue.poll();
        }

        public boolean isRunning() {
            return this.mIsRunning;
        }

        public void setRunningStatus(boolean r) {
            this.mIsRunning = r;
        }

        public int getCommandGap() {
            return this.mCommandsGap;
        }
    }

    public static class CommandAttr {
        static ArrayList<Category> table = null;

        public static synchronized ArrayList<Category> getCommandAttr() {
            synchronized (CommandAttr.class) {
                ArrayList<Category> arrayList = table;
                if (arrayList != null) {
                    return arrayList;
                }
                table = new ArrayList<>();
                try {
                    Element[] items = XMLDataStorage.instance().getChildElementSet("ParallelCommand");
                    for (Element item : items) {
                        if (item.getNodeName().equals("item") && item.getNodeType() == 1) {
                            String name = "AT+" + item.getAttributes().getNamedItem("id").getNodeValue();
                            int nPriority = 1;
                            try {
                                nPriority = Integer.valueOf(item.getAttributes().getNamedItem("priority").getNodeValue()).intValue();
                            } catch (NumberFormatException ne) {
                                FtUtil.log_e(ne);
                            }
                            String dependencies = item.getAttributes().getNamedItem("dependencies").getNodeValue();
                            String[] depArray = dependencies != null ? dependencies.split(",") : null;
                            String gap = item.getAttributes().getNamedItem("gap").getNodeValue();
                            int nGap = 100;
                            try {
                                nGap = Integer.valueOf(gap).intValue();
                            } catch (NumberFormatException ne2) {
                                FtUtil.log_e(ne2);
                            }
                            FtUtil.log_d(ParallelCommandsParser.CLASS_NAME, "CommandAttr", "getCommandAttr-" + name + "/" + nPriority + "/" + dependencies + "/" + gap);
                            table.add(new Category(name, nPriority, depArray, nGap));
                        }
                    }
                } catch (Exception e) {
                    FtUtil.log_e(e);
                    table = null;
                }
                return table;
            }
        }
    }

    public ParallelCommandsParser() {
        this.mCategoryMap = null;
        this.mCategoryMap = new ConcurrentHashMap<>();
        ArrayList<Category> arrayList = CommandAttr.getCommandAttr();
        if (arrayList != null) {
            Iterator<Category> it = arrayList.iterator();
            while (it.hasNext()) {
                Category category = it.next();
                this.mCategoryMap.put(category.getName(), category);
            }
        }
    }

    public boolean add(String cmd) {
        FtUtil.log_d(CLASS_NAME, "add", cmd);
        if (!cmd.contains("=") || cmd.indexOf("=") == 0) {
            FtUtil.log_e(CLASS_NAME, "wrong command", cmd);
            return false;
        }
        Category category = this.mCategoryMap.get(cmd.substring(0, cmd.indexOf("=")));
        if (category != null) {
            category.addToQueue(cmd);
            return true;
        }
        this.mCategoryMap.get("AT+NONE").addToQueue(cmd);
        return true;
    }

    public Collection<Category> getHitCommandsList() {
        for (Category category : this.mCategoryMap.values()) {
            if (!category.isEnabled()) {
                this.mCategoryMap.remove(category.getName());
            }
        }
        return this.mCategoryMap.values();
    }
}
