package com.sec.factory.aporiented;

import com.sec.factory.aporiented.ParallelCommandsParser;
import com.sec.factory.support.FtUtil;

public class ProcessThread extends Thread {
    private static final String CLASS_NAME = "ProcessThread";
    private static final int POLLING_TIME = 50;
    private int ID = -1;
    public boolean active;
    private ParallelCommandsParser.Category mCategory;
    private CommandListener mCommandListener;
    public boolean mIsKilled = false;
    private ProcessThread[] mProcessThread;
    private String pastCMD = null;

    public ProcessThread(CommandListener listener, ParallelCommandsParser.Category category, ProcessThread[] threads, int id) {
        this.mCommandListener = listener;
        this.active = false;
        this.mCategory = category;
        this.mProcessThread = threads;
        this.ID = id;
        if (category != null) {
            FtUtil.log_d(CLASS_NAME, CLASS_NAME, "category [" + this.mCategory.getName() + "], priority [" + this.mCategory.getPriority() + "]");
            return;
        }
        FtUtil.log_w(CLASS_NAME, CLASS_NAME, "category [" + ((Object) null) + "]");
    }

    public String getCategoryName() {
        ParallelCommandsParser.Category category = this.mCategory;
        if (category != null) {
            return category.getName();
        }
        return null;
    }

    public int getCategoryPriority() {
        ParallelCommandsParser.Category category = this.mCategory;
        if (category != null) {
            return category.getPriority();
        }
        return -1;
    }

    public void run() {
        FtUtil.log_d(CLASS_NAME, "run", "ProcessThread [" + getCategoryName() + "] start");
        String dependencies = this.mCategory.getDependencyList();
        FtUtil.log_d(CLASS_NAME, "run", "ProcessThread [" + getCategoryName() + "] dependencies = " + dependencies);
        boolean isMyTurn = false;
        while (true) {
            if (isMyTurn) {
                break;
            }
            isMyTurn = true;
            if (this.mProcessThread == null) {
                FtUtil.log_w(CLASS_NAME, "run", getCategoryName() + ", mProcessThread = null");
                break;
            }
            if (dependencies == null) {
                FtUtil.log_w(CLASS_NAME, "run", getCategoryName() + ", dependencies = null");
                dependencies = "";
            }
            for (int i = 0; i < this.ID; i++) {
                ProcessThread[] processThreadArr = this.mProcessThread;
                if (processThreadArr != null && processThreadArr[i] != null && !processThreadArr[i].mIsKilled && processThreadArr[i].isAlive() && !this.mProcessThread[i].isInterrupted() && dependencies.contains(this.mProcessThread[i].getCategoryName())) {
                    try {
                        String joinThreadName = this.mProcessThread[i].getCategoryName();
                        FtUtil.log_d(CLASS_NAME, "run", getCategoryName() + ", Start Join[ " + joinThreadName + " ]");
                        this.mProcessThread[i].join();
                        FtUtil.log_d(CLASS_NAME, "run", getCategoryName() + ", End Join[ " + joinThreadName + " ]");
                    } catch (InterruptedException e) {
                        FtUtil.log_e(e);
                    }
                }
            }
        }
        this.active = true;
        FtUtil.log_d(CLASS_NAME, "run", "ProcessThread [" + getCategoryName() + "] activate");
        while (this.mCategory.isEnabled() && this.active) {
            String cmd = this.mCategory.pollCommand();
            FtUtil.log_d(CLASS_NAME, "run[" + toString() + "]", "ProcessThread cmd = " + cmd + ", ID=" + this.ID);
            if (cmd != null && this.mCategory.getCommandGap() > 0) {
                try {
                    String str = cmd.substring(0, cmd.lastIndexOf(","));
                    if (str != null && str.equalsIgnoreCase(this.pastCMD)) {
                        FtUtil.log_d(CLASS_NAME, "run", "cmd = " + cmd + ", Sleep : " + this.mCategory.getCommandGap() + "ms");
                        FtUtil.Sleep.sleep((long) this.mCategory.getCommandGap());
                    }
                    this.pastCMD = str;
                } catch (IndexOutOfBoundsException ioobe) {
                    FtUtil.log_e(ioobe);
                }
            }
            if (!this.mCommandListener.onRunCommand(cmd) && this.ID > 0) {
                FtUtil.log_d(CLASS_NAME, cmd + ", Waiting response...");
                this.mCommandListener.onWaitingResponse(cmd, this.ID);
                this.active = false;
                while (!this.active) {
                    try {
                        Thread.sleep(50);
                    } catch (InterruptedException e2) {
                        FtUtil.log_d(CLASS_NAME, "run", "The thread interrupted");
                        this.active = true;
                    }
                }
                FtUtil.log_d(CLASS_NAME, cmd + ", Catch response...");
            }
        }
        FtUtil.log_d(CLASS_NAME, "run", "ProcessThread [" + getCategoryName() + "] done");
        this.mCommandListener.onFinishAllCommand(this.mCategory.getName(), this.ID);
        this.active = false;
    }

    public void kill() {
        this.mIsKilled = true;
        this.active = false;
        interrupt();
        FtUtil.log_d(CLASS_NAME, "run", "Kill ProcessThread ID = " + this.ID);
    }
}
