package com.sec.factory.aporiented;

import android.content.Context;
import android.content.Intent;
import android.net.LocalSocket;
import com.sec.factory.support.FtUtil;
import java.io.BufferedOutputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.concurrent.ConcurrentLinkedQueue;

public class ResponseWriter {
    public static final String CLASS_NAME = "ResponseWriter";
    private static boolean mWritable = true;
    private Context mContext;
    private ResponseListener mResponseListener = null;
    private ConcurrentLinkedQueue<String> mStringQueue;
    public boolean mcalledBottomLayerCmd = false;
    private boolean mcalledDeviceCmd = false;
    private DataOutputStream out;

    public interface ResponseListener {
        boolean onResponse(String str);
    }

    public synchronized void setWritable(boolean w) {
        FtUtil.log_d(CLASS_NAME, CLASS_NAME, "setWritable = " + w);
        mWritable = w;
        if (w) {
            write(null);
        }
    }

    public synchronized boolean getWritable() {
        return mWritable;
    }

    public ResponseWriter(LocalSocket clientSocketSend) {
        FtUtil.log_d(CLASS_NAME, CLASS_NAME, "Create ResponseWriter");
        this.mStringQueue = new ConcurrentLinkedQueue<>();
        if (clientSocketSend.isConnected()) {
            try {
                this.out = new DataOutputStream(new BufferedOutputStream(clientSocketSend.getOutputStream(), 8192));
            } catch (IOException e) {
                FtUtil.log_e(e);
            }
        } else {
            FtUtil.log_i(CLASS_NAME, CLASS_NAME, "Socket is closed");
        }
    }

    public boolean getCalledBottomCmd() {
        return this.mcalledBottomLayerCmd;
    }

    public void setCalledBottomCmd(boolean isCalled) {
        this.mcalledBottomLayerCmd = isCalled;
    }

    public ResponseWriter(Context context, boolean calledDeviceCmd) {
        FtUtil.log_d(CLASS_NAME, CLASS_NAME, "Create ResponseWriter");
        this.mStringQueue = new ConcurrentLinkedQueue<>();
        this.mContext = context;
        this.mcalledDeviceCmd = calledDeviceCmd;
    }

    public synchronized boolean write(String msg) {
        if (this.mStringQueue == null) {
            FtUtil.log_e(CLASS_NAME, CLASS_NAME, "write - Queue is null");
            return false;
        }
        boolean result = false;
        if (msg != null) {
            if (this.mcalledDeviceCmd) {
                Intent i = new Intent("com.sec.factory.intent.action.DEVICE_CMD_RSP");
                i.putExtra("COMMAND", msg);
                this.mContext.sendBroadcast(i);
                return true;
            } else if (!getCalledBottomCmd() || this.mContext == null) {
                if (msg.contains("NFCMTEST") || msg.contains("RESOFREQ")) {
                    FtUtil.log_d(CLASS_NAME, "write", FtUtil.setMspSeqMessage(3, "TX", msg.replace("\r\n", ";") + " (NFC_FT)"));
                } else {
                    FtUtil.log_d(CLASS_NAME, "write", FtUtil.setMspSeqMessage(3, "TX", msg.replace("\r\n", ";")));
                }
                if (getWritable()) {
                    while (!this.mStringQueue.isEmpty()) {
                        FtUtil.log_d(CLASS_NAME, CLASS_NAME, "write - poll queue");
                        writeToSocket(this.mStringQueue.poll());
                    }
                    result = writeToSocket(msg);
                } else {
                    FtUtil.log_d(CLASS_NAME, CLASS_NAME, "write - need to queueing");
                    result = this.mStringQueue.add(msg);
                }
            } else {
                Intent i2 = new Intent("com.sec.factory.intent.action.BOTTOM_LAYER_CMD_RSP");
                i2.putExtra("COMMAND", msg);
                this.mContext.sendBroadcast(i2);
                return true;
            }
        }
        ResponseListener responseListener = this.mResponseListener;
        if (responseListener != null) {
            responseListener.onResponse(msg);
        }
        return result;
    }

    public boolean writeToSocket(String msg) {
        DataOutputStream dataOutputStream = this.out;
        if (dataOutputStream == null || msg == null) {
            FtUtil.log_i(CLASS_NAME, "write", "out is null");
            return false;
        }
        try {
            dataOutputStream.writeBytes(msg);
            this.out.flush();
            return true;
        } catch (IOException e) {
            FtUtil.log_e(e);
            return false;
        }
    }

    public void close() {
        DataOutputStream dataOutputStream = this.out;
        if (dataOutputStream != null) {
            try {
                dataOutputStream.close();
            } catch (IOException e) {
                FtUtil.log_e(e);
            }
            this.out = null;
        }
    }

    public void setResponseListener(ResponseListener listener) {
        this.mResponseListener = listener;
    }
}
