package com.sec.factory.aporiented;

import android.app.Service;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothGatt;
import android.bluetooth.BluetoothGattCallback;
import android.bluetooth.BluetoothGattCharacteristic;
import android.bluetooth.BluetoothGattDescriptor;
import android.bluetooth.BluetoothGattService;
import android.bluetooth.BluetoothManager;
import android.bluetooth.BluetoothUuid;
import android.bluetooth.le.BluetoothLeScanner;
import android.bluetooth.le.ScanCallback;
import android.bluetooth.le.ScanFilter;
import android.bluetooth.le.ScanResult;
import android.bluetooth.le.ScanSettings;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Binder;
import android.os.Handler;
import android.os.IBinder;
import com.google.common.primitives.UnsignedBytes;
import com.samsung.android.content.smartclip.SpenGestureManager;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.UUID;

public class SpenBluetoothService extends Service {
    private static final int ACC_GYRO_DEFAULT_MODE = 1;
    private static final int ACC_GYRO_HID_MODE = 2;
    public static final String ACTION_BATTERY = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_BATTERY";
    public static final String ACTION_BTSPEN_LONGPRESS = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_BTSPEN_LONGPRESS";
    public static final String ACTION_BTSPEN_PRESS = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_BTSPEN_PRESS";
    public static final String ACTION_BUTTON_EVENT = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_BUTTON_EVENT";
    public static final String ACTION_DATA_READY = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_DATA_READY";
    public static final String ACTION_DATE = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_DATE";
    public static final String ACTION_FW_VER = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_FW_VER";
    public static final String ACTION_GATT_CONNECTED = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_GATT_CONNECTED";
    public static final String ACTION_GATT_DISCONNECTED = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_GATT_DISCONNECTED";
    public static final String ACTION_GATT_RECONNECT = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_GATT_RECONNECT";
    public static final String ACTION_GEOGYRO_GRAVITY_BLOCK_CHECK_DATA_NOTIFICATION_MODE_ON = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_GEOGYRO_GRAVITY_BLOCK_CHECK_DATA_NOTIFICATION_MODE_ON";
    public static final String ACTION_GEOGYRO_GRAVITY_BLOCK_CHECK_DATA_RESULT = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_GEOGYRO_GRAVITY_BLOCK_CHECK_DATA_RESULT";
    public static final String ACTION_GEOGYRO_RAW_DATA_NOTIFICATION_MODE_ON = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_GEOGYRO_RAW_DATA_NOTIFICATION_MODE_ON";
    public static final String ACTION_GEOGYRO_RAW_DATA_RESULT = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_GEOGYRO_RAW_DATA_RESULT";
    public static final String ACTION_GEOGYRO_SELFTEST_DATA_NOTIFICATION_MODE_ON = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_GEOGYRO_SELFTEST_DATA_NOTIFICATION_MODE_ON";
    public static final String ACTION_GEOGYRO_SELFTEST_DATA_RESULT = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_GEOGYRO_SELFTEST_DATA_RESULT";
    public static final String ACTION_KEYEVENT_READY = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_KEYEVENT_READY";
    public static final String ACTION_MODE_WRITE_SUCCESS = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_MODE_WRITE_SUCCESS";
    public static final String ACTION_NOT_FOUND = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_NOT_FOUND";
    public static final String ACTION_PAIRING_REQUEST = "android.bluetooth.device.action.PAIRING_REQUEST";
    public static final String ACTION_RSSI = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_RSSI";
    public static final String ACTION_SCAN_START = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_SCAN_START";
    public static final String ACTION_SCAN_SUCCESS = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_SCAN_SUCCESS";
    public static final String ACTION_SLAVELATENCY1S_CHANGE = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_SLAVELATENCY1S_CHANGE";
    public static final String ACTION_SLAVELATENCY9S_CHANGE = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_SLAVELATENCY9S_CHANGE";
    public static final String ACTION_SUBCOLORCODE_RESULT = "com.sec.factory.aporiented.SpenBluetoothService.ACTION_SUBCOLORCODE_RESULT";
    private static final String BATTERY_LEVEL_RAW = "5b87b4ef-3bfa-76a8-e642-92933c31435f";
    public static final String BUTTON_EVENT = "6c290d2e-1c03-aca1-ab48-a9b908bae79e";
    private static final String CLASS_NAME = "SpenBluetoothService";
    private static final String CLIENT_CHARACTERISTIC_CONFIG = "00002902-0000-1000-8000-00805f9b34fb";
    private static final String DATE = "f3275252-e029-4c8e-99ae-092f2dfa6572";
    public static final String EVENT_NAME = "com.sec.factory.aporiented.SpenBluetoothService.EVENT_NAME";
    public static final String EXTRA_DATA = "com.sec.factory.aporiented.SpenBluetoothService.EXTRA_DATA";
    private static final String FW_VER = "a1a6932a-2f2e-1c03-2e1c-03ac2e1c03ac";
    public static final String GEOGYRO_GRAVITY_BLOCK_CHECK_DATA = "7740b6ab-1e77-46d0-ad22-179ef3a890c2";
    public static final String GEOGYRO_RAW_DATA = "ddb42396-ca00-4db3-b87d-2ee458279360";
    public static final String GEOGYRO_SELFTEST_DATA = "8bd867d3-d619-45d9-8ee0-3814dbd5b3f0";
    private static final String MODE = "aca1ab48-08ba-e79e-ab48-a9b9e6429293";
    private static final int READ_FLASH = 128;
    private static final int SLAVE_LATENCY_1S = 65;
    private static final int SLAVE_LATENCY_9S = 64;
    private static final String SPEN_ADD_ON = "EDFEC62E-9910-0BAC-5241-D8BDA6932A30";
    private static final String SPEN_BUILT_IN = "EDFEC62E-9910-0BAC-5241-D8BDA6932A2F";
    private static String SPEN_SERVICE = null;
    private static final String SPEN_SERVICE_CROWN = "edfec62e-9910-0bac-5241-d8bda6932a2f";
    private static final String SPEN_SERVICE_DAVINCI = "dc6bb0a8-202e-487c-8f1b-53b37cc837c6";
    private static final String SPEN_SERVICE_NEW = "0000fd6c-0000-1000-8000-00805f9b34fb";
    public static final int STATE_CONNECTED = 2;
    public static final int STATE_CONNECTING = 1;
    public static final int STATE_DISCONNECTED = 0;
    public static final String SUB_COLORCODE = "6f4a7fca-de9d-4ba0-9132-6d004a7979f1";
    private static int mMinRSSI = -90;
    private static long mScanPeriod = 60000;
    private int[] arrRSSI = new int[25];
    private BluetoothLeScanner mBLEScanner;
    private int mBLE_Discon_cnt = 0;
    private final IBinder mBinder = new LocalBinder();
    private BluetoothAdapter mBluetoothAdapter;
    private String mBluetoothDeviceAddress = null;
    private BluetoothGatt mBluetoothGatt;
    private BluetoothManager mBluetoothManager;
    private final BroadcastReceiver mBondStateReceiver = new BroadcastReceiver() {
        /* class com.sec.factory.aporiented.SpenBluetoothService.AnonymousClass2 */

        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "mBondStateReceiver", "receiver:" + action);
            if ("com.samsung.bluetooth.device.action.BOND_STATE_CHANGED_FROM_NEARBY_DEVICE".equals(intent.getAction())) {
                int bondState = intent.getIntExtra("android.bluetooth.device.extra.BOND_STATE", 0);
                FtUtil.log_i(SpenBluetoothService.CLASS_NAME, "mBondStateReceiver.onReceive", "EXTRA_BOND_STATE result=" + bondState);
                if (12 == bondState && SpenBluetoothService.this.mConnectionState == 1) {
                    FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "startServiceDiscovery", "Attempting to start service discovery:" + SpenBluetoothService.this.mBluetoothGatt.discoverServices());
                }
            }
        }
    };
    private BluetoothGattCharacteristic mCharacteristic;
    private String mColorCodeForCMD = null;
    public int mConnectionState = 0;
    private BluetoothDevice mDevice;
    private final BluetoothGattCallback mGattCallback = new BluetoothGattCallback() {
        /* class com.sec.factory.aporiented.SpenBluetoothService.AnonymousClass3 */

        public void onConnectionStateChange(BluetoothGatt gatt, int status, int newState) {
            if (newState == 2) {
                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "mGattCallback", "ACTION_GATT_CONNECTED");
                SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) SpenBluetoothService.ACTION_GATT_CONNECTED);
                if (!SpenBluetoothService.this.mIsFirstPairing) {
                    FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "startServiceDiscovery", "Attempting to start service discovery:" + SpenBluetoothService.this.mBluetoothGatt.discoverServices());
                }
            } else if (newState == 0) {
                FtUtil.log_e(SpenBluetoothService.CLASS_NAME, "mGattCallback", "STATE_DISCONNECTED ,mBLE_Discon_cnt:" + SpenBluetoothService.this.mBLE_Discon_cnt);
                String intentAction = SpenBluetoothService.ACTION_GATT_DISCONNECTED;
                if (SpenBluetoothService.this.mConnectionState == 1 || SpenBluetoothService.this.mConnectionState == 2) {
                    SpenBluetoothService.access$1708(SpenBluetoothService.this);
                }
                SpenBluetoothService.this.changeConnection(0);
                if (SpenBluetoothService.this.mBluetoothGatt != null) {
                    SpenBluetoothService.this.mBluetoothGatt.close();
                }
                if (SpenBluetoothService.this.mBLE_Discon_cnt <= 3) {
                    intentAction = SpenBluetoothService.ACTION_GATT_RECONNECT;
                    SpenBluetoothService.this.scanSpen(SpenBluetoothService.mScanPeriod);
                }
                SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) intentAction);
            } else if (newState == 1) {
                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "mGattCallback", "STATE_CONNECTING");
            } else if (newState == 3) {
                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "mGattCallback", "STATE_DISCONNECTING");
            }
        }

        /* JADX WARNING: Removed duplicated region for block: B:22:0x0094 A[EDGE_INSN: B:22:0x0094->B:16:0x0094 ?: BREAK  , SYNTHETIC] */
        /* JADX WARNING: Removed duplicated region for block: B:5:0x0044  */
        public void onServicesDiscovered(BluetoothGatt gatt, int status) {
            String SearchedUuid;
            FtUtil.log_i(SpenBluetoothService.CLASS_NAME, "onServicesDiscovered");
            if (status == 0) {
                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onServicesDiscovered", "onServicesDiscovered: GATT_SUCCESS");
                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onServicesDiscovered", "getServices size:" + SpenBluetoothService.this.mBluetoothGatt.getServices().size());
                Iterator<BluetoothGattService> it = SpenBluetoothService.this.mBluetoothGatt.getServices().iterator();
                while (true) {
                    if (!it.hasNext()) {
                        SearchedUuid = it.next().getUuid().toString();
                        FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onServicesDiscovered", "SearchedUuid:" + SearchedUuid);
                        if (SearchedUuid.equalsIgnoreCase(SpenBluetoothService.SPEN_SERVICE_NEW) || SearchedUuid.equalsIgnoreCase(SpenBluetoothService.SPEN_SERVICE_DAVINCI) || SearchedUuid.equalsIgnoreCase(SpenBluetoothService.SPEN_SERVICE_CROWN) || SearchedUuid.equalsIgnoreCase(SpenBluetoothService.SPEN_BUILT_IN) || SearchedUuid.equalsIgnoreCase(SpenBluetoothService.SPEN_ADD_ON)) {
                            String unused = SpenBluetoothService.SPEN_SERVICE = SearchedUuid;
                        }
                        if (!it.hasNext()) {
                            break;
                        }
                    }
                }
                String unused2 = SpenBluetoothService.SPEN_SERVICE = SearchedUuid;
                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onServicesDiscovered", "FOUND SPEN UUID:" + SpenBluetoothService.SPEN_SERVICE);
                if (SpenBluetoothService.this.mIsIntervalCheckSkip && SpenBluetoothService.this.mConnectionState == 1) {
                    SpenBluetoothService.this.changeConnection(2);
                    SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) SpenBluetoothService.ACTION_DATA_READY);
                    return;
                }
                return;
            }
            FtUtil.log_w(SpenBluetoothService.CLASS_NAME, "onServicesDiscovered", "onServicesDiscovered: " + status);
        }

        public void onDescriptorWrite(BluetoothGatt gatt, BluetoothGattDescriptor descriptor, int status) {
            if (status == 0) {
                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onDescriptorWrite", "characteristic:" + descriptor.getCharacteristic().getUuid() + " ,descriptor:" + descriptor.getUuid());
                SpenBluetoothService.this.mIsProcessFunctionCall = false;
                if (UUID.fromString(SpenBluetoothService.BUTTON_EVENT).equals(descriptor.getCharacteristic().getUuid())) {
                    SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) SpenBluetoothService.ACTION_KEYEVENT_READY);
                } else if (UUID.fromString(SpenBluetoothService.SUB_COLORCODE).equals(descriptor.getCharacteristic().getUuid())) {
                    SpenBluetoothService.this.subColorCodeReadFromCharacteristic();
                } else if (UUID.fromString(SpenBluetoothService.GEOGYRO_SELFTEST_DATA).equals(descriptor.getCharacteristic().getUuid())) {
                    SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) SpenBluetoothService.ACTION_GEOGYRO_SELFTEST_DATA_NOTIFICATION_MODE_ON);
                } else if (UUID.fromString(SpenBluetoothService.GEOGYRO_RAW_DATA).equals(descriptor.getCharacteristic().getUuid())) {
                    SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) SpenBluetoothService.ACTION_GEOGYRO_RAW_DATA_NOTIFICATION_MODE_ON);
                } else if (UUID.fromString(SpenBluetoothService.GEOGYRO_GRAVITY_BLOCK_CHECK_DATA).equals(descriptor.getCharacteristic().getUuid())) {
                    SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) SpenBluetoothService.ACTION_GEOGYRO_GRAVITY_BLOCK_CHECK_DATA_NOTIFICATION_MODE_ON);
                }
            } else {
                FtUtil.log_e(SpenBluetoothService.CLASS_NAME, "onDescriptorWrite", "FAIL - status:" + status + " ,descriptor:" + descriptor.toString());
            }
        }

        public void onCharacteristicWrite(BluetoothGatt gatt, BluetoothGattCharacteristic characteristic, int status) {
            if (status == 0) {
                SpenBluetoothService.this.mIsProcessFunctionCall = false;
                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onCharacteristicWrite", "GATT_SUCCESS " + characteristic.getUuid());
                if (UUID.fromString(SpenBluetoothService.SUB_COLORCODE).equals(characteristic.getUuid())) {
                    SpenBluetoothService.this.mHandler.postDelayed(new Runnable() {
                        /* class com.sec.factory.aporiented.SpenBluetoothService.AnonymousClass3.AnonymousClass1 */

                        public void run() {
                            if (SpenBluetoothService.this.mIsFwVer0x17) {
                                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onCharacteristicWrite", "onCharacteristicWrite: FW ver : 0x17");
                                SpenBluetoothService.this.setCharacteristicNotification(SpenBluetoothService.SUB_COLORCODE, true);
                                return;
                            }
                            SpenBluetoothService.this.subColorCodeReadFromCharacteristic();
                        }
                    }, 4000);
                } else if (UUID.fromString(SpenBluetoothService.MODE).equals(characteristic.getUuid())) {
                    SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) SpenBluetoothService.ACTION_MODE_WRITE_SUCCESS);
                }
            } else {
                FtUtil.log_e(SpenBluetoothService.CLASS_NAME, "onCharacteristicWrite", "FAIL - status:" + status + " ,characteristic:" + characteristic.toString());
            }
        }

        /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
        public void onCharacteristicChanged(BluetoothGatt gatt, BluetoothGattCharacteristic characteristic) {
            char c;
            FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onCharacteristicChanged", "uuid: " + characteristic.getUuid().toString());
            String uuid = characteristic.getUuid().toString();
            switch (uuid.hashCode()) {
                case -1117713490:
                    if (uuid.equals(SpenBluetoothService.GEOGYRO_RAW_DATA)) {
                        c = 2;
                        break;
                    }
                    c = 65535;
                    break;
                case -928695865:
                    if (uuid.equals(SpenBluetoothService.BUTTON_EVENT)) {
                        c = 0;
                        break;
                    }
                    c = 65535;
                    break;
                case 406823428:
                    if (uuid.equals(SpenBluetoothService.GEOGYRO_SELFTEST_DATA)) {
                        c = 1;
                        break;
                    }
                    c = 65535;
                    break;
                case 413285732:
                    if (uuid.equals(SpenBluetoothService.GEOGYRO_GRAVITY_BLOCK_CHECK_DATA)) {
                        c = 3;
                        break;
                    }
                    c = 65535;
                    break;
                case 2083657710:
                    if (uuid.equals(SpenBluetoothService.SUB_COLORCODE)) {
                        c = 4;
                        break;
                    }
                    c = 65535;
                    break;
                default:
                    c = 65535;
                    break;
            }
            switch (c) {
                case 0:
                case 1:
                case 2:
                case 3:
                    SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) characteristic);
                    return;
                case 4:
                    FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onCharacteristicChanged", "mIsFwVer0x17:" + SpenBluetoothService.this.mIsFwVer0x17 + " ,mIsFirstNotiColorCode : " + SpenBluetoothService.this.mIsFirstNotiColorCode);
                    if (!SpenBluetoothService.this.mIsFwVer0x17) {
                        return;
                    }
                    if (!SpenBluetoothService.this.mIsFirstNotiColorCode) {
                        SpenBluetoothService.this.setCharacteristicNotification(SpenBluetoothService.SUB_COLORCODE, false);
                        SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) characteristic);
                        return;
                    }
                    SpenBluetoothService.this.mIsFirstNotiColorCode = false;
                    return;
                default:
                    return;
            }
        }

        /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
        /* JADX WARNING: Code restructure failed: missing block: B:6:0x0046, code lost:
            if (r0.equals(com.sec.factory.aporiented.SpenBluetoothService.BATTERY_LEVEL_RAW) != false) goto L_0x007c;
         */
        public void onCharacteristicRead(BluetoothGatt gatt, BluetoothGattCharacteristic characteristic, int status) {
            char c = 0;
            SpenBluetoothService.this.mIsProcessFunctionCall = false;
            FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onCharacteristicRead", "uuid: " + characteristic.getUuid().toString());
            String uuid = characteristic.getUuid().toString();
            switch (uuid.hashCode()) {
                case -1856148506:
                    if (uuid.equals(SpenBluetoothService.FW_VER)) {
                        c = 1;
                        break;
                    }
                    c = 65535;
                    break;
                case -1117713490:
                    if (uuid.equals(SpenBluetoothService.GEOGYRO_RAW_DATA)) {
                        c = 5;
                        break;
                    }
                    c = 65535;
                    break;
                case 406823428:
                    if (uuid.equals(SpenBluetoothService.GEOGYRO_SELFTEST_DATA)) {
                        c = 4;
                        break;
                    }
                    c = 65535;
                    break;
                case 413285732:
                    if (uuid.equals(SpenBluetoothService.GEOGYRO_GRAVITY_BLOCK_CHECK_DATA)) {
                        c = 6;
                        break;
                    }
                    c = 65535;
                    break;
                case 1702990902:
                    if (uuid.equals(SpenBluetoothService.DATE)) {
                        c = 2;
                        break;
                    }
                    c = 65535;
                    break;
                case 1720853869:
                    break;
                case 2083657710:
                    if (uuid.equals(SpenBluetoothService.SUB_COLORCODE)) {
                        c = 3;
                        break;
                    }
                    c = 65535;
                    break;
                default:
                    c = 65535;
                    break;
            }
            switch (c) {
                case 0:
                case 1:
                case 2:
                case 3:
                case 4:
                case 5:
                case 6:
                    SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) characteristic);
                    return;
                default:
                    return;
            }
        }

        public void onReadRemoteRssi(BluetoothGatt gatt, int rssi, int status) {
            if (status == 0) {
                SpenBluetoothService.this.mIsProcessFunctionCall = false;
                SpenBluetoothService.this.mRSSI_array.add(Integer.valueOf(rssi));
                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onReadRemoteRssi", "Read count : " + SpenBluetoothService.this.mRSSI_array.size() + " RSSI: " + rssi);
                if (SpenBluetoothService.this.mRSSI_array.size() == 5) {
                    int max = ((Integer) Collections.max(SpenBluetoothService.this.mRSSI_array)).intValue();
                    int min = ((Integer) Collections.min(SpenBluetoothService.this.mRSSI_array)).intValue();
                    FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onReadRemoteRssi", "Max : " + max + " Min : " + min);
                    int sum = 0;
                    Iterator it = SpenBluetoothService.this.mRSSI_array.iterator();
                    while (it.hasNext()) {
                        sum += ((Integer) it.next()).intValue();
                    }
                    int avg = ((sum - max) - min) / 3;
                    FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onReadRemoteRssi", "Sum : " + sum + " Avg : " + avg);
                    SpenBluetoothService.this.broadcastUpdate(SpenBluetoothService.ACTION_RSSI, avg);
                    return;
                }
                SpenBluetoothService.this.mHandler.postDelayed(new Runnable() {
                    /* class com.sec.factory.aporiented.SpenBluetoothService.AnonymousClass3.AnonymousClass2 */

                    public void run() {
                        SpenBluetoothService.this.mBluetoothGatt.readRemoteRssi();
                    }
                }, 1000);
            }
        }

        public void onConnectionUpdated(BluetoothGatt gatt, int interval, int latency, int timeout, int status) {
            if (status == 0) {
                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onConnectionUpdated", "GATT_SUCCESS interval: " + interval + " latency: " + latency + " mConnectionState:" + SpenBluetoothService.this.mConnectionState);
                if (!SpenBluetoothService.this.mIsIntervalCheckSkip) {
                    boolean intervalCheck = false;
                    if (Support.Feature.getInt(Support.Feature.SPEN_BLE_INTERVAL_VER) == 2) {
                        if (interval == 32 || interval == 33) {
                            intervalCheck = true;
                        }
                    } else if (interval == 48 || interval == 49) {
                        intervalCheck = true;
                    }
                    if (intervalCheck && SpenBluetoothService.this.mConnectionState == 1) {
                        SpenBluetoothService.this.changeConnection(2);
                        SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) SpenBluetoothService.ACTION_DATA_READY);
                    }
                } else {
                    FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "onConnectionUpdated", "Connection Interval Check Skip");
                }
                if (SpenBluetoothService.this.mConnectionState != 2) {
                    return;
                }
                if ((interval == 48 && latency == 15) || (interval == 49 && latency == 15)) {
                    SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) SpenBluetoothService.ACTION_SLAVELATENCY1S_CHANGE);
                } else if (interval == 49 && latency == 146) {
                    SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) SpenBluetoothService.ACTION_SLAVELATENCY9S_CHANGE);
                }
            }
        }
    };
    private Handler mHandler;
    private boolean mIsFirstNotiColorCode = false;
    private boolean mIsFirstPairing = true;
    private boolean mIsFirstTry = true;
    private boolean mIsFwVer0x17 = false;
    private boolean mIsIntervalCheckSkip = false;
    private boolean mIsProcessFunctionCall = false;
    private boolean mIsSaveRSSI = false;
    public int mPairingRssi = 0;
    private ArrayList<Integer> mRSSI_array = new ArrayList<>();
    private int mSaveRSSIMaxCnt = 0;
    private final ScanCallback mScanCallback = new ScanCallback() {
        /* class com.sec.factory.aporiented.SpenBluetoothService.AnonymousClass1 */

        public void onScanResult(int callbackType, final ScanResult result) {
            synchronized (this) {
                int mRssiValue = result.getRssi();
                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "mScanCallback", "Device:" + result.getDevice() + " ,RSSI:" + mRssiValue + " ,minSpec: " + SpenBluetoothService.mMinRSSI + " ,mConnectionState: " + SpenBluetoothService.this.mConnectionState);
                if (SpenBluetoothService.this.mConnectionState == 0 && mRssiValue >= SpenBluetoothService.mMinRSSI) {
                    if (SpenBluetoothService.this.mIsSaveRSSI) {
                        FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "mScanCallback", "mSaveRSSIMaxCnt:" + SpenBluetoothService.this.mSaveRSSIMaxCnt + "rcvRSSICount:" + SpenBluetoothService.this.rcvRSSICount);
                        if (SpenBluetoothService.this.rcvRSSICount < 6) {
                            SpenBluetoothService.access$308(SpenBluetoothService.this);
                            return;
                        } else if (SpenBluetoothService.this.rcvRSSICount >= 6 && SpenBluetoothService.this.rcvRSSICount <= SpenBluetoothService.this.mSaveRSSIMaxCnt) {
                            SpenBluetoothService.this.arrRSSI[SpenBluetoothService.this.rcvRSSICount - 6] = mRssiValue;
                            if (SpenBluetoothService.this.rcvRSSICount == SpenBluetoothService.this.mSaveRSSIMaxCnt) {
                                SpenBluetoothService spenBluetoothService = SpenBluetoothService.this;
                                SpenBluetoothService.access$584(spenBluetoothService, mRssiValue + "_");
                            } else {
                                SpenBluetoothService spenBluetoothService2 = SpenBluetoothService.this;
                                SpenBluetoothService.access$584(spenBluetoothService2, mRssiValue + ",");
                            }
                            SpenBluetoothService.access$308(SpenBluetoothService.this);
                            return;
                        } else if (SpenBluetoothService.this.rcvRSSICount > SpenBluetoothService.this.mSaveRSSIMaxCnt) {
                            Arrays.sort(SpenBluetoothService.this.arrRSSI);
                            if (SpenBluetoothService.this.mSaveRSSIMaxCnt == 30) {
                                for (int i = 2; i <= 22; i++) {
                                    SpenBluetoothService spenBluetoothService3 = SpenBluetoothService.this;
                                    SpenBluetoothService.access$612(spenBluetoothService3, spenBluetoothService3.arrRSSI[i]);
                                }
                                SpenBluetoothService spenBluetoothService4 = SpenBluetoothService.this;
                                SpenBluetoothService.access$584(spenBluetoothService4, String.format("%.1f", Float.valueOf(((float) spenBluetoothService4.sumRSSI) / 21.0f)));
                                SpenBluetoothService spenBluetoothService5 = SpenBluetoothService.this;
                                spenBluetoothService5.rawData30RSSI = spenBluetoothService5.rawDataRSSI;
                                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "mScanCallback", "Final Return Data: " + SpenBluetoothService.this.rawData30RSSI);
                            } else if (SpenBluetoothService.this.mSaveRSSIMaxCnt == 10) {
                                for (int i2 = 1; i2 <= 3; i2++) {
                                    SpenBluetoothService spenBluetoothService6 = SpenBluetoothService.this;
                                    SpenBluetoothService.access$612(spenBluetoothService6, spenBluetoothService6.arrRSSI[i2]);
                                }
                                SpenBluetoothService spenBluetoothService7 = SpenBluetoothService.this;
                                SpenBluetoothService.access$584(spenBluetoothService7, String.format("%.1f", Float.valueOf(((float) spenBluetoothService7.sumRSSI) / 3.0f)));
                                SpenBluetoothService spenBluetoothService8 = SpenBluetoothService.this;
                                spenBluetoothService8.rawData10RSSI = spenBluetoothService8.rawDataRSSI;
                                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "mScanCallback", "Final Return Data: " + SpenBluetoothService.this.rawData10RSSI);
                            }
                        }
                    }
                    SpenBluetoothService.this.changeConnection(1);
                    SpenBluetoothService.this.mBLEScanner.stopScan(SpenBluetoothService.this.mScanCallback);
                    SpenBluetoothService.this.mScanResult = true;
                    SpenBluetoothService.this.mPairingRssi = mRssiValue;
                    SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) SpenBluetoothService.ACTION_SCAN_SUCCESS);
                    SpenBluetoothService.this.mHandler.postDelayed(new Runnable() {
                        /* class com.sec.factory.aporiented.SpenBluetoothService.AnonymousClass1.AnonymousClass1 */

                        public void run() {
                            SpenBluetoothService.this.connectSpen(result.getDevice());
                        }
                    }, 1000);
                }
                super.onScanResult(callbackType, result);
            }
        }
    };
    private List<ScanFilter> mScanFilters = new ArrayList();
    private boolean mScanResult = false;
    private String rawData10RSSI = "";
    private String rawData30RSSI = "";
    private String rawDataRSSI = "";
    private int rcvRSSICount = 1;
    private int sumRSSI = 0;

    static /* synthetic */ int access$1708(SpenBluetoothService x0) {
        int i = x0.mBLE_Discon_cnt;
        x0.mBLE_Discon_cnt = i + 1;
        return i;
    }

    static /* synthetic */ int access$308(SpenBluetoothService x0) {
        int i = x0.rcvRSSICount;
        x0.rcvRSSICount = i + 1;
        return i;
    }

    static /* synthetic */ String access$584(SpenBluetoothService x0, Object x1) {
        String str = x0.rawDataRSSI + x1;
        x0.rawDataRSSI = str;
        return str;
    }

    static /* synthetic */ int access$612(SpenBluetoothService x0, int x1) {
        int i = x0.sumRSSI + x1;
        x0.sumRSSI = i;
        return i;
    }

    private List<ScanFilter> getScanFilters() {
        byte[] menuData = {1, FactoryTestManager.TEST_CAPTURE, 80, 69, 78, FactoryTestManager.MACRO_AF, FactoryTestManager.TEST_BARCODE_EMUL};
        FtUtil.log_d(CLASS_NAME, "getScanFilters", "ScanFilter by ManufacturerData ID:" + 117);
        ScanFilter filter = new ScanFilter.Builder().setManufacturerData(117, menuData).build();
        if (!this.mScanFilters.contains(filter)) {
            this.mScanFilters.add(filter);
        }
        return this.mScanFilters;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void broadcastUpdate(String action) {
        sendBroadcast(new Intent(action));
    }

    /* JADX INFO: Multiple debug info for r7v6 int: [D('data' byte[]), D('z' int)] */
    /* JADX INFO: Multiple debug info for r6v5 int: [D('data' byte[]), D('z' int)] */
    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void broadcastUpdate(BluetoothGattCharacteristic characteristic) {
        String str;
        String str2;
        SpenBluetoothService spenBluetoothService;
        Intent intent;
        String str3;
        String str4;
        Intent intent2;
        FtUtil.log_d(CLASS_NAME, "broadcastUpdate", "uuid: " + characteristic.getUuid().toString());
        Intent intent3 = new Intent();
        if (UUID.fromString(BUTTON_EVENT).equals(characteristic.getUuid())) {
            byte[] data = characteristic.getValue();
            if (data != null && data.length > 0) {
                FtUtil.log_d(CLASS_NAME, "broadcastUpdate", "Data:" + ((int) data[0]));
                if (data[0] == 1) {
                    intent3.setAction(ACTION_BTSPEN_PRESS);
                } else if (data[0] == 2) {
                    intent3.setAction(ACTION_BTSPEN_LONGPRESS);
                }
                intent3.putExtra(EXTRA_DATA, (int) data[0]);
            }
            str = CLASS_NAME;
            str2 = "broadcastUpdate";
            spenBluetoothService = this;
            intent = intent3;
        } else if (UUID.fromString(BATTERY_LEVEL_RAW).equals(characteristic.getUuid())) {
            byte[] data2 = characteristic.getValue();
            if (data2 != null && data2.length > 0) {
                int batteryLevelRaw = byteArrayToInt(data2);
                int batteryVoltage = (int) Math.round((((double) batteryLevelRaw) / 1023.0d) * 3600.0d);
                FtUtil.log_d(CLASS_NAME, "broadcastUpdate", " batteryLevelRaw : " + batteryLevelRaw + " batteryVoltage:" + batteryVoltage);
                intent3.setAction(ACTION_BATTERY);
                intent3.putExtra(EXTRA_DATA, batteryVoltage);
            }
            str = CLASS_NAME;
            str2 = "broadcastUpdate";
            spenBluetoothService = this;
            intent = intent3;
        } else if (UUID.fromString(FW_VER).equals(characteristic.getUuid())) {
            byte[] data3 = characteristic.getValue();
            if (data3 != null && data3.length > 0) {
                int fwVer = byteArrayToInt(data3);
                FtUtil.log_d(CLASS_NAME, "broadcastUpdate", "FW Ver : " + fwVer);
                this.mIsFwVer0x17 = false;
                intent3.setAction(ACTION_FW_VER);
                intent3.putExtra(EXTRA_DATA, fwVer);
            }
            str = CLASS_NAME;
            str2 = "broadcastUpdate";
            spenBluetoothService = this;
            intent = intent3;
        } else if (UUID.fromString(DATE).equals(characteristic.getUuid())) {
            String dateRaw = new String(characteristic.getValue());
            FtUtil.log_d(CLASS_NAME, "broadcastUpdate", "dateRaw : " + dateRaw);
            intent3.setAction(ACTION_DATE);
            intent3.putExtra(EXTRA_DATA, dateRaw);
            str = CLASS_NAME;
            str2 = "broadcastUpdate";
            spenBluetoothService = this;
            intent = intent3;
        } else if (UUID.fromString(SUB_COLORCODE).equals(characteristic.getUuid())) {
            String result = new String(characteristic.getValue());
            String reverseResult = new StringBuffer(result).reverse().toString();
            if (reverseResult.length() > 2) {
                this.mColorCodeForCMD = reverseResult.substring(0, 2);
            } else {
                this.mColorCodeForCMD = "";
            }
            FtUtil.log_d(CLASS_NAME, "broadcastUpdate", "mColorCodeForCMD:" + this.mColorCodeForCMD);
            intent3.setAction(ACTION_SUBCOLORCODE_RESULT);
            intent3.putExtra(EXTRA_DATA, result);
            str = CLASS_NAME;
            str2 = "broadcastUpdate";
            spenBluetoothService = this;
            intent = intent3;
        } else if (UUID.fromString(GEOGYRO_SELFTEST_DATA).equals(characteristic.getUuid())) {
            byte[] data4 = characteristic.getValue();
            printByteArrayLog(data4);
            StringBuilder stringBuilder = new StringBuilder();
            if (data4.length > 0) {
                int[] value = new int[18];
                int i = 0;
                for (int i2 = 18; i < i2; i2 = 18) {
                    value[i] = (((short) data4[(i * 2) + 1]) << 8) | (((short) data4[i * 2]) & 255);
                    i++;
                }
                int value1G = ((int) Math.pow(2.0d, 15.0d)) / 4;
                int x = value[0];
                int y = value[1];
                int z = value[2];
                stringBuilder.append(String.format("%d,", Integer.valueOf(x)));
                stringBuilder.append(String.format("%d,", Integer.valueOf(y)));
                stringBuilder.append(String.format("%d,", Integer.valueOf(z)));
                double gValue = Double.parseDouble(((DecimalFormat) NumberFormat.getInstance(Locale.ENGLISH)).format(Math.sqrt((double) (((x * x) + (y * y)) + (z * z))) / ((double) value1G)));
                stringBuilder.append(String.format("%.2f,", Double.valueOf(gValue)));
                str3 = CLASS_NAME;
                str4 = "broadcastUpdate";
                FtUtil.log_d(str3, str4, "x:" + x + " ,y:" + y + " ,z:" + z + " ,gValue:" + gValue + " ,value1G:" + value1G);
                stringBuilder.append(String.format("%d,", Integer.valueOf((value[3] * 1000) / value1G)));
                stringBuilder.append(String.format("%d,", Integer.valueOf((value[4] * 1000) / value1G)));
                stringBuilder.append(String.format("%d,", Integer.valueOf((value[5] * 1000) / value1G)));
                stringBuilder.append(String.format("%d,", Integer.valueOf((value[12] * 1000) / value1G)));
                stringBuilder.append(String.format("%d,", Integer.valueOf((value[13] * 1000) / value1G)));
                stringBuilder.append(String.format("%d,", Integer.valueOf((value[14] * 1000) / value1G)));
                stringBuilder.append(String.format("%d,", Integer.valueOf((int) (((float) value[15]) * 0.07f))));
                stringBuilder.append(String.format("%d,", Integer.valueOf((int) (((float) value[16]) * 0.07f))));
                stringBuilder.append(String.format("%d,", Integer.valueOf((int) (((float) value[17]) * 0.07f))));
                stringBuilder.append(String.format("%d,", Integer.valueOf((int) (((float) value[6]) * 0.07f))));
                stringBuilder.append(String.format("%d,", Integer.valueOf((int) (((float) value[7]) * 0.07f))));
                stringBuilder.append(String.format("%d,", Integer.valueOf((int) (((float) value[8]) * 0.07f))));
                stringBuilder.append(String.format("%d,", Integer.valueOf((int) (((float) value[9]) * 0.07f))));
                stringBuilder.append(String.format("%d,", Integer.valueOf((int) (((float) value[10]) * 0.07f))));
                stringBuilder.append(String.format("%d,", Integer.valueOf((int) (((float) value[11]) * 0.07f))));
                stringBuilder.append(String.format("%d,", Integer.valueOf((int) (((float) (value[9] - value[15])) * 0.07f))));
                stringBuilder.append(String.format("%d,", Integer.valueOf((int) (((float) (value[10] - value[16])) * 0.07f))));
                stringBuilder.append(String.format("%d,", Integer.valueOf((int) (((float) (value[11] - value[17])) * 0.07f))));
                intent2 = intent3;
                intent2.setAction(ACTION_GEOGYRO_SELFTEST_DATA_RESULT);
                intent2.putExtra(EXTRA_DATA, stringBuilder.toString());
            } else {
                intent2 = intent3;
                str3 = CLASS_NAME;
                str4 = "broadcastUpdate";
                FtUtil.log_e(str3, str4, "GEOGYRO_SELFTEST_DATA Error");
            }
            spenBluetoothService = this;
            intent = intent2;
            str2 = str4;
            str = str3;
        } else {
            intent = intent3;
            String str5 = EXTRA_DATA;
            if (UUID.fromString(GEOGYRO_RAW_DATA).equals(characteristic.getUuid())) {
                byte[] data5 = characteristic.getValue();
                printByteArrayLog(data5);
                StringBuilder stringBuilder2 = new StringBuilder();
                if (data5.length > 0) {
                    int value1G2 = ((int) Math.pow(2.0d, 15.0d)) / data5[0];
                    int[] value2 = new int[3];
                    int i3 = 0;
                    for (int i4 = 3; i3 < i4; i4 = 3) {
                        value2[i3] = (((short) data5[(i3 * 2) + 2]) << 8) | (((short) data5[(i3 * 2) + 1]) & 255);
                        i3++;
                        str5 = str5;
                    }
                    int x2 = value2[0];
                    int y2 = value2[1];
                    int z2 = value2[2];
                    stringBuilder2.append(String.format("%d,", Integer.valueOf(x2)));
                    stringBuilder2.append(String.format("%d,", Integer.valueOf(y2)));
                    stringBuilder2.append(String.format("%d_", Integer.valueOf(z2)));
                    double gValue2 = Double.parseDouble(((DecimalFormat) NumberFormat.getInstance(Locale.ENGLISH)).format(Math.sqrt((double) (((x2 * x2) + (y2 * y2)) + (z2 * z2))) / ((double) value1G2)));
                    stringBuilder2.append(String.format("%.2f_", Double.valueOf(gValue2)));
                    str = CLASS_NAME;
                    str2 = "broadcastUpdate";
                    FtUtil.log_d(str, str2, "x:" + x2 + " ,y:" + y2 + " ,z:" + z2 + " ,gValue:" + gValue2 + " ,value1G:" + value1G2);
                    intent.setAction(ACTION_GEOGYRO_RAW_DATA_RESULT);
                    intent.putExtra(str5, stringBuilder2.toString());
                } else {
                    str2 = "broadcastUpdate";
                    str = CLASS_NAME;
                    FtUtil.log_e(str, str2, "GEOGYRO_RAW_DATA Error");
                }
                spenBluetoothService = this;
            } else {
                str2 = "broadcastUpdate";
                str = CLASS_NAME;
                if (UUID.fromString(GEOGYRO_GRAVITY_BLOCK_CHECK_DATA).equals(characteristic.getUuid())) {
                    byte[] data6 = characteristic.getValue();
                    spenBluetoothService = this;
                    spenBluetoothService.printByteArrayLog(data6);
                    if (data6.length > 0) {
                        intent.setAction(ACTION_GEOGYRO_GRAVITY_BLOCK_CHECK_DATA_RESULT);
                        intent.putExtra(str5, data6[0] == 1);
                    } else {
                        FtUtil.log_e(str, str2, "GEOGYRO_RAW_DATA Error");
                    }
                } else {
                    FtUtil.log_e(str, str2, "UnKnown UUID");
                    return;
                }
            }
        }
        FtUtil.log_d(str, str2, "action: " + intent.getAction());
        spenBluetoothService.sendBroadcast(intent);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void broadcastUpdate(String action, int data) {
        Intent intent = new Intent(action);
        FtUtil.log_d(CLASS_NAME, "broadcastUpdate", "Data:" + data);
        intent.putExtra(EXTRA_DATA, data);
        sendBroadcast(intent);
    }

    public class LocalBinder extends Binder {
        public LocalBinder() {
        }

        public SpenBluetoothService getService() {
            return SpenBluetoothService.this;
        }
    }

    public IBinder onBind(Intent intent) {
        this.mBLE_Discon_cnt = 0;
        this.mIsFirstTry = true;
        registerReceiver(this.mBondStateReceiver, new IntentFilter("com.samsung.bluetooth.device.action.BOND_STATE_CHANGED_FROM_NEARBY_DEVICE"));
        boolean booleanExtra = intent.getBooleanExtra("save_rssi", false);
        this.mIsSaveRSSI = booleanExtra;
        if (booleanExtra) {
            this.mSaveRSSIMaxCnt = intent.getIntExtra("save_rssi_cnt", 0);
        }
        FtUtil.log_d(CLASS_NAME, "onBind", "mIsSaveRSSI : " + this.mIsSaveRSSI + " ,mSaveRSSIMaxCnt:" + this.mSaveRSSIMaxCnt);
        this.mIsIntervalCheckSkip = Support.Feature.getBoolean(Support.Feature.SUPPORT_SPEN_BLE_CONNECTION_INTERVAL_SKIP);
        StringBuilder sb = new StringBuilder();
        sb.append("mIsIntervalCheckSkip : ");
        sb.append(this.mIsIntervalCheckSkip);
        FtUtil.log_d(CLASS_NAME, "onBind", sb.toString());
        return this.mBinder;
    }

    public boolean onUnbind(Intent intent) {
        fixScanChannel(false);
        close();
        return super.onUnbind(intent);
    }

    public void close() {
        try {
            if (this.mDevice != null) {
                FtUtil.log_d(CLASS_NAME, "close", "removeBond");
                this.mDevice.removeBond();
            }
        } catch (Exception e) {
            FtUtil.log_e(CLASS_NAME, "close", e.getMessage());
        }
        this.mHandler.removeCallbacksAndMessages(null);
        BluetoothLeScanner bluetoothLeScanner = this.mBLEScanner;
        if (bluetoothLeScanner != null) {
            bluetoothLeScanner.stopScan(this.mScanCallback);
            FtUtil.log_d(CLASS_NAME, "close", "scan stop");
        }
        BluetoothGatt bluetoothGatt = this.mBluetoothGatt;
        if (bluetoothGatt != null) {
            bluetoothGatt.close();
            this.mBluetoothGatt = null;
            unregisterReceiver(this.mBondStateReceiver);
        }
    }

    public boolean initialize() {
        this.mHandler = new Handler();
        if (this.mBluetoothManager == null) {
            BluetoothManager bluetoothManager = (BluetoothManager) getSystemService("bluetooth");
            this.mBluetoothManager = bluetoothManager;
            if (bluetoothManager == null) {
                FtUtil.log_e(CLASS_NAME, "initialize", "Unable to initialize BluetoothManager.");
                return false;
            }
            FtUtil.log_d(CLASS_NAME, "initialize", "BluetoothManager");
        }
        BluetoothAdapter adapter = this.mBluetoothManager.getAdapter();
        this.mBluetoothAdapter = adapter;
        if (adapter == null) {
            FtUtil.log_e(CLASS_NAME, "initialize", "Unable to obtain a BluetoothAdapter.");
            return false;
        }
        fixScanChannel(true);
        long j = Support.Spec.getLong(Support.Spec.SPEN_BLE_TEST_SCAN_PERIOD);
        mScanPeriod = j;
        if (scanSpen(j)) {
            return true;
        }
        broadcastUpdate(ACTION_NOT_FOUND);
        return false;
    }

    public boolean scanSpen(long scan_period) {
        ScanSettings scanSettings;
        FtUtil.log_d(CLASS_NAME, "scanSpen", "scan for spen");
        this.mHandler.removeCallbacksAndMessages(null);
        if (!this.mIsSaveRSSI) {
            mMinRSSI = Support.Spec.getInt(Support.Spec.SPEN_BLE_TEST_MINRSSI);
        } else {
            mMinRSSI = Support.Spec.getInt(Support.Spec.SPEN_BLE_TEST_MINRSSI_FINAL);
        }
        this.mScanResult = false;
        if (!getPackageManager().hasSystemFeature("android.hardware.bluetooth_le")) {
            FtUtil.log_d(CLASS_NAME, "scanSpen", "Bluetooth is not supported");
            return false;
        }
        this.mBLEScanner = this.mBluetoothAdapter.getBluetoothLeScanner();
        if (!this.mIsSaveRSSI || this.mSaveRSSIMaxCnt != 10) {
            scanSettings = new ScanSettings.Builder().setScanMode(2).build();
        } else {
            scanSettings = new ScanSettings.Builder().setScanMode(1).build();
        }
        this.mHandler.postDelayed(new Runnable() {
            /* class com.sec.factory.aporiented.SpenBluetoothService.AnonymousClass4 */

            public void run() {
                if (SpenBluetoothService.this.mBLEScanner != null) {
                    SpenBluetoothService.this.mBLEScanner.stopScan(SpenBluetoothService.this.mScanCallback);
                }
                FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "scanSpen", "stop scan");
                if (!SpenBluetoothService.this.mScanResult) {
                    FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "scanSpen", FtUtil.setMspSeqMessage(-1, "SPEN BLE TEST", "Fail to Scan Devices for Pairing"));
                    if (!SpenBluetoothService.this.mIsFirstTry) {
                        FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "scanSpen", "mIsFirstTry = false");
                        SpenBluetoothService.this.broadcastUpdate((SpenBluetoothService) SpenBluetoothService.ACTION_NOT_FOUND);
                        return;
                    }
                    FtUtil.log_d(SpenBluetoothService.CLASS_NAME, "scanSpen", "mIsFirstTry = true");
                    SpenBluetoothService.this.mIsFirstTry = false;
                    SpenBluetoothService.this.penHwReset();
                }
            }
        }, scan_period);
        if (this.mBLEScanner == null) {
            return false;
        }
        FtUtil.log_d(CLASS_NAME, "scanSpen", "Scan starts with timeout: " + scan_period);
        if (this.mIsSaveRSSI) {
            this.rcvRSSICount = 1;
            this.sumRSSI = 0;
            this.rawDataRSSI = "";
            this.arrRSSI = new int[25];
        }
        this.mBLEScanner.startScan(getScanFilters(), scanSettings, this.mScanCallback);
        return true;
    }

    private void fixScanChannel(boolean enable) {
        FtUtil.log_d(CLASS_NAME, "fixScanChannel", "enable : " + enable);
        BluetoothAdapter bluetoothAdapter = this.mBluetoothAdapter;
        if (bluetoothAdapter == null) {
            return;
        }
        if (enable) {
            bluetoothAdapter.sendRawHci(65009, new byte[]{FactoryTestManager.TEST_IDCHECK, 1, 1}, 3);
        } else {
            bluetoothAdapter.sendRawHci(65009, new byte[]{FactoryTestManager.TEST_IDCHECK, 0, 0}, 3);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean connectSpen(BluetoothDevice device) {
        FtUtil.log_d(CLASS_NAME, "connectSpen", "mConnectionState:" + this.mConnectionState + " Device : address : " + device.getAddress() + " name :" + device.getName());
        if (this.mConnectionState != 1) {
            return false;
        }
        this.mBluetoothDeviceAddress = device.getAddress();
        this.mDevice = device;
        this.mIsFirstPairing = true;
        if (device.getBondState() == 12) {
            this.mIsFirstPairing = false;
        }
        FtUtil.log_d(CLASS_NAME, "connectSpen", "mIsFirstPairing : " + this.mIsFirstPairing);
        BluetoothGatt connectGatt = this.mDevice.connectGatt(this, false, this.mGattCallback, 0, false, 1, BluetoothUuid.SPEN_ADD_ON, null);
        this.mBluetoothGatt = connectGatt;
        if (connectGatt == null) {
            FtUtil.log_e(CLASS_NAME, "connectSpen", "Fail to get mBluetoothGatt");
        }
        writeBleSpenAddress();
        return true;
    }

    public boolean writeBleSpenColorCode() {
        if (this.mColorCodeForCMD == null) {
            FtUtil.log_d(CLASS_NAME, "writeBleSpenColorCode", "colorCode is null");
            return false;
        }
        FtUtil.log_d(CLASS_NAME, "writeBleSpenColorCode", "mColorCodeForCMD :" + this.mColorCodeForCMD);
        try {
            ((SpenGestureManager) getSystemService("spengestureservice")).setBleSpenCmfCode(this.mColorCodeForCMD);
            return true;
        } catch (Exception e) {
            e.printStackTrace();
            return false;
        }
    }

    public String getBtAddress() {
        return this.mBluetoothDeviceAddress;
    }

    public String getRSSI30Avg() {
        return this.rawData30RSSI;
    }

    public String getRSSI10Avg() {
        return this.rawData10RSSI;
    }

    public void setCharacteristicNotification(String id, boolean enable) {
        BluetoothGatt bluetoothGatt;
        BluetoothGattDescriptor descriptor;
        FtUtil.log_d(CLASS_NAME, "setCharacteristicNotification", "id:" + id + " ,enable:" + enable);
        if (this.mBluetoothAdapter == null || (bluetoothGatt = this.mBluetoothGatt) == null) {
            FtUtil.log_e(CLASS_NAME, "setCharacteristicNotification", "BluetoothAdapter not initialized");
        } else if (this.mIsProcessFunctionCall) {
            FtUtil.log_e(CLASS_NAME, "setCharacteristicNotification", "Function call is processing");
        } else {
            BluetoothGattService blgservice = bluetoothGatt.getService(UUID.fromString(SPEN_SERVICE));
            if (blgservice != null) {
                BluetoothGattCharacteristic characteristic = blgservice.getCharacteristic(UUID.fromString(id));
                this.mCharacteristic = characteristic;
                this.mBluetoothGatt.setCharacteristicNotification(characteristic, enable);
                if (enable) {
                    this.mIsProcessFunctionCall = true;
                    BluetoothGattCharacteristic bluetoothGattCharacteristic = this.mCharacteristic;
                    if (bluetoothGattCharacteristic != null && (descriptor = bluetoothGattCharacteristic.getDescriptor(UUID.fromString(CLIENT_CHARACTERISTIC_CONFIG))) != null) {
                        descriptor.setValue(BluetoothGattDescriptor.ENABLE_NOTIFICATION_VALUE);
                        if (this.mBluetoothGatt.writeDescriptor(descriptor)) {
                            FtUtil.log_d(CLASS_NAME, "setCharacteristicNotification", "setCharacteristicNotification Finish");
                        }
                    }
                }
            }
        }
    }

    public boolean writeCharacteristic(BluetoothGattCharacteristic characteristic) {
        BluetoothGatt bluetoothGatt;
        FtUtil.log_d(CLASS_NAME, "writeCharacteristic", "characteristic:" + characteristic.getUuid());
        boolean result = false;
        if (this.mBluetoothAdapter == null || (bluetoothGatt = this.mBluetoothGatt) == null) {
            FtUtil.log_e(CLASS_NAME, "writeCharacteristic", "mBluetoothAdapter:" + this.mBluetoothAdapter + " ,mBluetoothGatt:" + this.mBluetoothGatt);
        } else {
            result = bluetoothGatt.writeCharacteristic(characteristic);
        }
        FtUtil.log_d(CLASS_NAME, "writeCharacteristic", "result:" + result);
        return result;
    }

    public void readBatteryLevelRaw() {
        BluetoothGatt bluetoothGatt;
        FtUtil.log_d(CLASS_NAME, "readBatteryLevelRaw", "readBatteryLevelRaw");
        if (this.mBluetoothAdapter == null || (bluetoothGatt = this.mBluetoothGatt) == null) {
            FtUtil.log_e(CLASS_NAME, "readBatteryLevelRaw", "mBluetoothAdapter:" + this.mBluetoothAdapter + " ,mBluetoothGatt:" + this.mBluetoothGatt);
        } else if (this.mIsProcessFunctionCall) {
            FtUtil.log_e(CLASS_NAME, "readBatteryLevelRaw", "Function call is processing");
        } else {
            this.mIsProcessFunctionCall = true;
            BluetoothGattService blgservice = bluetoothGatt.getService(UUID.fromString(SPEN_SERVICE));
            if (blgservice != null) {
                BluetoothGattCharacteristic characteristic = blgservice.getCharacteristic(UUID.fromString(BATTERY_LEVEL_RAW));
                this.mCharacteristic = characteristic;
                if (characteristic != null && this.mBluetoothGatt.readCharacteristic(characteristic)) {
                    FtUtil.log_d(CLASS_NAME, "readBatteryLevelRaw", "readBatteryLevelRaw Finish");
                }
            }
        }
    }

    public void readBatteryLevelRawNew() {
        if (this.mBluetoothAdapter == null || this.mBluetoothGatt == null) {
            FtUtil.log_w(CLASS_NAME, "readBatteryLevelRawNew", "BluetoothAdapter not initialized");
            return;
        }
        FtUtil.log_d(CLASS_NAME, "readBatteryLevelRawNew", "readBatteryLevelRawNew");
        if (this.mIsProcessFunctionCall) {
            FtUtil.log_w(CLASS_NAME, "readBatteryLevelRawNew", "Function call is processing");
            return;
        }
        this.mIsProcessFunctionCall = true;
        BluetoothGattService blgservice = this.mBluetoothGatt.getService(UUID.fromString(SPEN_SERVICE));
        if (blgservice != null) {
            this.mCharacteristic = blgservice.getCharacteristic(UUID.fromString(BATTERY_LEVEL_RAW));
        }
        BluetoothGattCharacteristic bluetoothGattCharacteristic = this.mCharacteristic;
        if (bluetoothGattCharacteristic != null) {
            this.mBluetoothGatt.readCharacteristic(bluetoothGattCharacteristic);
        }
    }

    public void readRssi() {
        if (this.mBluetoothAdapter == null || this.mBluetoothGatt == null) {
            FtUtil.log_w(CLASS_NAME, "readRssi", "BluetoothAdapter not initialized");
        } else if (this.mIsProcessFunctionCall) {
            FtUtil.log_w(CLASS_NAME, "readRssi", "Function call is processing");
        } else {
            this.mIsProcessFunctionCall = true;
            this.mRSSI_array.clear();
            this.mBluetoothGatt.readRemoteRssi();
            FtUtil.log_d(CLASS_NAME, "readRssi", "readRssi");
        }
    }

    public boolean pairingCheck() {
        FtUtil.log_d(CLASS_NAME, "pairingCheck", "mConnectionState:" + this.mConnectionState);
        return this.mConnectionState == 2;
    }

    public boolean startFastDischarging() {
        return startFastDischarging(4);
    }

    public boolean startFastDischarging(int cmd) {
        if (this.mBluetoothAdapter == null || this.mBluetoothGatt == null) {
            FtUtil.log_w(CLASS_NAME, "startFastDischarging", "BluetoothAdapter not initialized");
            return false;
        }
        FtUtil.log_d(CLASS_NAME, "startFastDischarging", "cmd : " + cmd);
        if (this.mIsProcessFunctionCall) {
            FtUtil.log_w(CLASS_NAME, "startFastDischarging", "Function call is processing");
            return false;
        }
        this.mIsProcessFunctionCall = true;
        BluetoothGattService blgservice = this.mBluetoothGatt.getService(UUID.fromString(SPEN_SERVICE));
        if (blgservice != null) {
            this.mCharacteristic = blgservice.getCharacteristic(UUID.fromString(MODE));
        }
        BluetoothGattCharacteristic bluetoothGattCharacteristic = this.mCharacteristic;
        if (bluetoothGattCharacteristic == null) {
            return false;
        }
        bluetoothGattCharacteristic.setValue(cmd + 80, 17, 0);
        if (writeCharacteristic(this.mCharacteristic)) {
            return true;
        }
        return false;
    }

    public boolean changeSlaveLatency(int mode) {
        if (this.mBluetoothAdapter == null || this.mBluetoothGatt == null) {
            FtUtil.log_w(CLASS_NAME, "changeSlaveLatency", "BluetoothAdapter not initialized");
            return false;
        }
        FtUtil.log_d(CLASS_NAME, "changeSlaveLatency", "mode : " + mode);
        if (this.mIsProcessFunctionCall) {
            FtUtil.log_w(CLASS_NAME, "changeSlaveLatency", "Function call is processing");
            return false;
        }
        this.mIsProcessFunctionCall = true;
        BluetoothGattService blgservice = this.mBluetoothGatt.getService(UUID.fromString(SPEN_SERVICE));
        if (blgservice != null) {
            this.mCharacteristic = blgservice.getCharacteristic(UUID.fromString(MODE));
        }
        BluetoothGattCharacteristic bluetoothGattCharacteristic = this.mCharacteristic;
        if (bluetoothGattCharacteristic == null) {
            return false;
        }
        if (mode == 1) {
            bluetoothGattCharacteristic.setValue(65, 17, 0);
        } else if (mode == 9) {
            bluetoothGattCharacteristic.setValue(64, 17, 0);
        }
        if (writeCharacteristic(this.mCharacteristic)) {
            return true;
        }
        return false;
    }

    public boolean subResultWrite(String result) {
        if (this.mBluetoothAdapter == null || this.mBluetoothGatt == null) {
            FtUtil.log_w(CLASS_NAME, "subResultWrite", "BluetoothAdapter not initialized");
            return false;
        }
        FtUtil.log_d(CLASS_NAME, "subResultWrite", "result : " + result);
        if (this.mIsProcessFunctionCall) {
            FtUtil.log_w(CLASS_NAME, "subResultWrite", "Function call is processing");
            return false;
        }
        this.mIsProcessFunctionCall = true;
        BluetoothGattService blgservice = this.mBluetoothGatt.getService(UUID.fromString(SPEN_SERVICE));
        if (blgservice != null) {
            this.mCharacteristic = blgservice.getCharacteristic(UUID.fromString(SUB_COLORCODE));
        }
        BluetoothGattCharacteristic bluetoothGattCharacteristic = this.mCharacteristic;
        if (bluetoothGattCharacteristic == null) {
            return false;
        }
        bluetoothGattCharacteristic.setValue(result);
        if (writeCharacteristic(this.mCharacteristic)) {
            return true;
        }
        return false;
    }

    public boolean accGyroRawData(boolean enable) {
        boolean result = false;
        if (this.mBluetoothAdapter == null || this.mBluetoothGatt == null) {
            FtUtil.log_e(CLASS_NAME, "accGyroRawData", "mBluetoothAdapter:" + this.mBluetoothAdapter + " ,mBluetoothGatt:" + this.mBluetoothGatt);
        }
        if (this.mIsProcessFunctionCall) {
            FtUtil.log_e(CLASS_NAME, "accGyroRawData", "Function call is processing");
        }
        FtUtil.log_d(CLASS_NAME, "accGyroRawData", "enable : " + enable);
        this.mIsProcessFunctionCall = true;
        BluetoothGattService blgservice = this.mBluetoothGatt.getService(UUID.fromString(SPEN_SERVICE));
        if (blgservice != null) {
            BluetoothGattCharacteristic characteristic = blgservice.getCharacteristic(UUID.fromString(MODE));
            this.mCharacteristic = characteristic;
            if (characteristic != null) {
                if (enable) {
                    characteristic.setValue(2, 17, 0);
                } else {
                    characteristic.setValue(1, 17, 0);
                }
                if (writeCharacteristic(this.mCharacteristic)) {
                    result = true;
                }
            }
        }
        FtUtil.log_d(CLASS_NAME, "accGyroRawData", "result:" + result);
        return result;
    }

    public void fwVerRead() {
        if (this.mBluetoothAdapter == null || this.mBluetoothGatt == null) {
            FtUtil.log_w(CLASS_NAME, "fwVerRead", "BluetoothAdapter not initialized");
            return;
        }
        FtUtil.log_d(CLASS_NAME, "fwVerRead", "fwVerRead");
        if (this.mIsProcessFunctionCall) {
            FtUtil.log_w(CLASS_NAME, "fwVerRead", "Function call is processing");
            return;
        }
        this.mIsProcessFunctionCall = true;
        BluetoothGattService blgservice = this.mBluetoothGatt.getService(UUID.fromString(SPEN_SERVICE));
        if (blgservice != null) {
            this.mCharacteristic = blgservice.getCharacteristic(UUID.fromString(FW_VER));
        }
        BluetoothGattCharacteristic bluetoothGattCharacteristic = this.mCharacteristic;
        if (bluetoothGattCharacteristic != null) {
            this.mBluetoothGatt.readCharacteristic(bluetoothGattCharacteristic);
        }
    }

    public void dateRead() {
        if (this.mBluetoothAdapter == null || this.mBluetoothGatt == null) {
            FtUtil.log_w(CLASS_NAME, "dateRead", "BluetoothAdapter not initialized");
            return;
        }
        FtUtil.log_d(CLASS_NAME, "dateRead", "dateRead");
        if (this.mIsProcessFunctionCall) {
            FtUtil.log_w(CLASS_NAME, "dateRead", "Function call is processing");
            return;
        }
        this.mIsProcessFunctionCall = true;
        BluetoothGattService blgservice = this.mBluetoothGatt.getService(UUID.fromString(SPEN_SERVICE));
        if (blgservice != null) {
            this.mCharacteristic = blgservice.getCharacteristic(UUID.fromString(DATE));
        }
        BluetoothGattCharacteristic bluetoothGattCharacteristic = this.mCharacteristic;
        if (bluetoothGattCharacteristic != null) {
            this.mBluetoothGatt.readCharacteristic(bluetoothGattCharacteristic);
        }
    }

    public void subResultRead() {
        if (this.mBluetoothAdapter == null || this.mBluetoothGatt == null) {
            FtUtil.log_w(CLASS_NAME, "subResultRead", "BluetoothAdapter not initialized");
            return;
        }
        FtUtil.log_d(CLASS_NAME, "subResultRead", "subResultRead");
        if (this.mIsProcessFunctionCall) {
            FtUtil.log_w(CLASS_NAME, "subResultRead", "Function call is processing");
            return;
        }
        BluetoothGattService blgservice = this.mBluetoothGatt.getService(UUID.fromString(SPEN_SERVICE));
        if (this.mIsFwVer0x17) {
            FtUtil.log_d(CLASS_NAME, "subResultRead", "subResultRead: FW ver : 0x17");
            this.mIsFirstNotiColorCode = true;
            setCharacteristicNotification(SUB_COLORCODE, true);
            return;
        }
        this.mIsProcessFunctionCall = true;
        if (blgservice != null) {
            this.mCharacteristic = blgservice.getCharacteristic(UUID.fromString(SUB_COLORCODE));
        }
        BluetoothGattCharacteristic bluetoothGattCharacteristic = this.mCharacteristic;
        if (bluetoothGattCharacteristic != null) {
            this.mBluetoothGatt.readCharacteristic(bluetoothGattCharacteristic);
        }
    }

    public boolean subColorCodeWrite(String subResult, String colorCode) {
        if (this.mBluetoothAdapter == null || this.mBluetoothGatt == null) {
            FtUtil.log_w(CLASS_NAME, "subColorCodeWrite", "BluetoothAdapter not initialized");
            return false;
        }
        FtUtil.log_d(CLASS_NAME, "subColorCodeWrite", "subResult : " + subResult + " colorCode : " + colorCode);
        if (this.mIsProcessFunctionCall) {
            FtUtil.log_w(CLASS_NAME, "subColorCodeWrite", "Function call is processing");
            return false;
        }
        this.mIsProcessFunctionCall = true;
        BluetoothGattService blgservice = this.mBluetoothGatt.getService(UUID.fromString(SPEN_SERVICE));
        if (blgservice != null) {
            this.mCharacteristic = blgservice.getCharacteristic(UUID.fromString(SUB_COLORCODE));
        }
        String s = resultSubColorCode(subResult, colorCode);
        BluetoothGattCharacteristic bluetoothGattCharacteristic = this.mCharacteristic;
        if (bluetoothGattCharacteristic == null) {
            return false;
        }
        bluetoothGattCharacteristic.setValue(s);
        return writeCharacteristic(this.mCharacteristic);
    }

    public void subColorCodeReadFromCharacteristic() {
        if (this.mBluetoothAdapter == null || this.mBluetoothGatt == null) {
            FtUtil.log_w(CLASS_NAME, "subColorCodeReadFromCharacteristic", "BluetoothAdapter not initialized");
            return;
        }
        FtUtil.log_d(CLASS_NAME, "subColorCodeReadFromCharacteristic", "subColorCodeReadFromCharacteristic");
        if (this.mIsProcessFunctionCall) {
            FtUtil.log_w(CLASS_NAME, "subColorCodeReadFromCharacteristic", "Function call is processing");
            return;
        }
        this.mIsProcessFunctionCall = true;
        BluetoothGattService blgservice = this.mBluetoothGatt.getService(UUID.fromString(SPEN_SERVICE));
        if (this.mIsFwVer0x17) {
            this.mIsFirstNotiColorCode = true;
            FtUtil.log_d(CLASS_NAME, "subColorCodeReadFromCharacteristic", "subColorCodeReadFromCharacteristic: FW ver : 0x17");
            if (blgservice != null) {
                this.mCharacteristic = blgservice.getCharacteristic(UUID.fromString(MODE));
            }
            BluetoothGattCharacteristic bluetoothGattCharacteristic = this.mCharacteristic;
            if (bluetoothGattCharacteristic != null) {
                bluetoothGattCharacteristic.setValue(128, 17, 0);
                writeCharacteristic(this.mCharacteristic);
                return;
            }
            return;
        }
        if (blgservice != null) {
            this.mCharacteristic = blgservice.getCharacteristic(UUID.fromString(SUB_COLORCODE));
        }
        BluetoothGattCharacteristic bluetoothGattCharacteristic2 = this.mCharacteristic;
        if (bluetoothGattCharacteristic2 != null) {
            this.mBluetoothGatt.readCharacteristic(bluetoothGattCharacteristic2);
        }
    }

    private void writeBleSpenAddress() {
        FtUtil.log_d(CLASS_NAME, "writeBleSpenAddress", "");
        String str = this.mBluetoothDeviceAddress;
        if (str != null && str.length() > 0) {
            try {
                ((SpenGestureManager) getSystemService("spengestureservice")).setBleSpenAddress(this.mBluetoothDeviceAddress);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public void disconnect() {
        BluetoothGatt bluetoothGatt;
        if (this.mBluetoothAdapter == null || (bluetoothGatt = this.mBluetoothGatt) == null) {
            FtUtil.log_w(CLASS_NAME, "disconnect", "BluetoothAdapter not initialized");
        } else {
            bluetoothGatt.disconnect();
        }
    }

    public boolean isFwVer0x17() {
        FtUtil.log_w(CLASS_NAME, "isFwVer0x17", "mIsFwVer0x17 : " + this.mIsFwVer0x17);
        return this.mIsFwVer0x17;
    }

    private void printByteArrayLog(byte[] data) {
        StringBuilder stringBuilder = new StringBuilder();
        int length = data.length;
        for (int i = 0; i < length; i++) {
            stringBuilder.append(String.format("%02X ", Byte.valueOf(data[i])));
        }
        FtUtil.log_d(CLASS_NAME, "printByteArrayLog", "length: " + data.length + " ,data: " + stringBuilder.toString());
    }

    private int byteArrayToInt(byte[] buff) {
        FtUtil.log_d(CLASS_NAME, "byteArrayToInt", "start");
        int result = 0;
        if (buff != null && buff.length > 0) {
            for (int i = buff.length - 1; i >= 0; i--) {
                result = (result << 8) | (buff[i] & UnsignedBytes.MAX_VALUE);
            }
        }
        return result;
    }

    private String resultSubColorCode(String subResult, String colorCode) {
        String result;
        String result2;
        FtUtil.log_d(CLASS_NAME, "resultSubColorCode", "subResult:" + subResult + " ,colorCode:" + colorCode);
        if (subResult == null) {
            result = "" + "  ";
        } else {
            result = "" + subResult + " ";
        }
        if (colorCode == null) {
            result2 = result + "  ";
        } else {
            result2 = result + new StringBuffer(colorCode).reverse().toString();
        }
        FtUtil.log_d(CLASS_NAME, "resultSubColorCode", "result :" + result2);
        return result2;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void penHwReset() {
        FtUtil.log_d(CLASS_NAME, "penHwReset", "penHwReset");
        if (Support.Feature.getInt(Support.Feature.SPEN_BLE_CHARGE_VER) == 2) {
            Support.Kernel.write(Support.Kernel.EPEN_BLE_CHARGING_MODE, EgisFingerprint.MAJOR_VERSION);
            this.mHandler.postDelayed(new Runnable() {
                /* class com.sec.factory.aporiented.SpenBluetoothService.AnonymousClass5 */

                public void run() {
                    Support.Kernel.write(Support.Kernel.EPEN_BLE_CHARGING_MODE, egis.optical.client.api.EgisFingerprint.MAJOR_VERSION);
                }
            }, 200);
            this.mHandler.postDelayed(new Runnable() {
                /* class com.sec.factory.aporiented.SpenBluetoothService.AnonymousClass6 */

                public void run() {
                    Support.Kernel.write(Support.Kernel.EPEN_BLE_CHARGING_MODE, "2");
                }
            }, 600);
            this.mHandler.postDelayed(new Runnable() {
                /* class com.sec.factory.aporiented.SpenBluetoothService.AnonymousClass7 */

                public void run() {
                    Support.Kernel.write(Support.Kernel.EPEN_BLE_CHARGING_MODE, "4");
                    long unused = SpenBluetoothService.mScanPeriod = Support.Spec.getLong(Support.Spec.SPEN_BLE_TEST_SCAN_PERIOD_RETRY);
                    SpenBluetoothService.this.scanSpen(SpenBluetoothService.mScanPeriod);
                }
            }, 1300);
            return;
        }
        try {
            Support.Kernel.write(Support.Kernel.EPEN_BLE_CHARGING_MODE, EgisFingerprint.MAJOR_VERSION);
            this.mHandler.postDelayed(new Runnable() {
                /* class com.sec.factory.aporiented.SpenBluetoothService.AnonymousClass8 */

                public void run() {
                    Support.Kernel.write(Support.Kernel.EPEN_BLE_CHARGING_MODE, "2");
                }
            }, 20);
            this.mHandler.postDelayed(new Runnable() {
                /* class com.sec.factory.aporiented.SpenBluetoothService.AnonymousClass9 */

                public void run() {
                    Support.Kernel.write(Support.Kernel.EPEN_BLE_CHARGING_MODE, egis.optical.client.api.EgisFingerprint.MAJOR_VERSION);
                    SpenBluetoothService.this.scanSpen(SpenBluetoothService.mScanPeriod);
                }
            }, 16000);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* access modifiers changed from: package-private */
    public void changeConnection(int newConnectionState) {
        this.mConnectionState = newConnectionState;
        String msg = "";
        switch (newConnectionState) {
            case 0:
                msg = "STATE_DISCONNECTED";
                break;
            case 1:
                msg = "STATE_CONNECTING";
                break;
            case 2:
                msg = "STATE_CONNECTED";
                break;
        }
        FtUtil.log_d(CLASS_NAME, "changeConnection", FtUtil.setMspSeqMessage(-1, "SPEN BLE TEST", "Pairing - " + msg));
    }
}
