package com.sec.factory.aporiented;

import android.content.Context;
import android.os.FactoryTest;
import com.sec.factory.aporiented.athandler.AtCametest;
import com.sec.factory.aporiented.athandler.AtCommandHandler;
import com.sec.factory.aporiented.athandler.AtDebugLvC;
import com.sec.factory.aporiented.athandler.AtDisptest;
import com.sec.factory.aporiented.athandler.AtLedlampt;
import com.sec.factory.aporiented.athandler.AtNcamtest;
import com.sec.factory.aporiented.athandler.AtScampara;
import com.sec.factory.aporiented.athandler.AtSysdump;
import com.sec.factory.support.FtUtil;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Locale;

public class UsbAtParser {
    public static final String CLASS_NAME = "UsbAtParser";
    public static final String RESPONSE_NA = "NA";
    private final HashMap<String, AtCommandHandler> atHandlers = new HashMap<>();
    ResponseWriter mWriter;

    public void registerAllHandler(Context context, ResponseWriter writer) {
        FtUtil.log_d(CLASS_NAME, "registerAllHandler", "Register AT command handler");
        this.mWriter = writer;
        this.atHandlers.put("AT+SYSDUMP", new AtSysdump(context, writer));
        this.atHandlers.put("AT+DEBUGLVC", new AtDebugLvC(context, writer, 1));
        if (FactoryTest.isRunningFactoryApp()) {
            this.atHandlers.put("AT+CAMETEST", new AtCametest(context, writer, 1));
            this.atHandlers.put("AT+SCAMPARA", new AtScampara(context, writer, 1));
            this.atHandlers.put("AT+DISPTEST", new AtDisptest(context, writer, 1));
            this.atHandlers.put("AT+LEDLAMPT", new AtLedlampt(context, 1));
            this.atHandlers.put("AT+NCAMTEST", new AtNcamtest(context, writer, 1));
        }
    }

    public boolean process(String cmd, ResponseWriter writer) {
        FtUtil.log_d(CLASS_NAME, "process", cmd);
        if (cmd != null) {
            try {
                if (cmd.length() >= 1) {
                    if (cmd.contains(";")) {
                        String[] cmdList = cmd.split(";");
                        if (cmdList != null) {
                            if (cmdList.length > 0) {
                                int i = 0;
                                while (cmdList.length > i && cmdList[i] != null) {
                                    if (runCmd(cmdList[i], writer)) {
                                        FtUtil.log_d(CLASS_NAME, "process done successfully. cmdList = ", cmdList[i]);
                                    }
                                    i++;
                                }
                            }
                        }
                        FtUtil.log_e(CLASS_NAME, "process done successfully. cmdList is null");
                        return false;
                    } else if (runCmd(cmd, writer)) {
                        FtUtil.log_d(CLASS_NAME, "process done successfully. cmd = ", cmd);
                    }
                    return true;
                }
            } catch (StringIndexOutOfBoundsException e) {
                FtUtil.log_e(e);
                return false;
            }
        }
        return false;
    }

    public boolean runCmd(String cmd, ResponseWriter writer) {
        String commandName;
        FtUtil.log_d(CLASS_NAME, "runCmd", cmd);
        String resData = null;
        if (cmd != null) {
            try {
                if (cmd.length() >= 1) {
                    if (cmd.contains("=") && cmd.indexOf("=") != 0) {
                        commandName = cmd.substring(0, cmd.indexOf("=")).toUpperCase(Locale.ENGLISH);
                    } else if (cmd.contains("?")) {
                        commandName = cmd.substring(0, cmd.indexOf("?")).toUpperCase(Locale.ENGLISH);
                    } else {
                        commandName = cmd.trim().substring(0, cmd.length()).toUpperCase(Locale.ENGLISH);
                    }
                    FtUtil.log_d(CLASS_NAME, "process", "command : " + commandName);
                    if (commandName == null || !this.atHandlers.containsKey(commandName)) {
                        writer.write("NA");
                    } else {
                        resData = this.atHandlers.get(commandName).handleCommand(splitArgu(cmd));
                        FtUtil.log_d(CLASS_NAME, "runCmd: ", "CMD : " + cmd + ", result : " + resData);
                    }
                    if (resData == null) {
                        return false;
                    }
                    writer.write(resData);
                    return true;
                }
            } catch (StringIndexOutOfBoundsException e) {
                FtUtil.log_e(e);
                return false;
            }
        }
        return false;
    }

    /* JADX WARNING: Removed duplicated region for block: B:19:0x00eb  */
    /* JADX WARNING: Removed duplicated region for block: B:29:? A[RETURN, SYNTHETIC] */
    public String[] splitArgu(String cmd) {
        if (!cmd.contains("=")) {
            return new String[0];
        }
        String args = cmd.substring(cmd.indexOf("=") + 1, cmd.length());
        String[] deposit = new String[10];
        int index = 0;
        while (args.contains("\"")) {
            int fIndex = args.indexOf("\"");
            String subStr = args.substring(fIndex, args.indexOf("\"", fIndex + 1) + 1);
            args = args.replace(subStr, "__ARG__" + index);
            FtUtil.log_d(CLASS_NAME, "splitArgu()", "subStr : " + subStr + ", REPLACE : " + "__ARG__" + index + ", args : " + args);
            deposit[index] = subStr;
            index++;
        }
        String[] res = args.split(",");
        while (true) {
            int index2 = index - 1;
            if (index > 0 && res != null) {
                int i = 0;
                while (true) {
                    if (i >= res.length) {
                        break;
                    }
                    if (res[i].equalsIgnoreCase("__ARG__" + index2)) {
                        FtUtil.log_d(CLASS_NAME, "splitArgu()", "res : " + res[i] + " : " + "__ARG__" + index2 + " : " + deposit[index2]);
                        res[i] = deposit[index2];
                        StringBuilder sb = new StringBuilder();
                        sb.append("res : ");
                        sb.append(res[i]);
                        FtUtil.log_d(CLASS_NAME, "splitArgu()", sb.toString());
                        break;
                    }
                    i++;
                }
                index = index2;
            } else if (res != null) {
                return res;
            } else {
                FtUtil.log_d(CLASS_NAME, "splitArgu()", "args : " + res.length + " : " + Arrays.toString(res));
                return res;
            }
        }
        if (res != null) {
        }
    }
}
