package com.sec.factory.aporiented;

import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.net.LocalSocket;
import android.net.LocalSocketAddress;
import android.os.IBinder;
import com.sec.factory.aporiented.athandler.AtSysdump;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.XMLDataStorage;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;

public class UsbFtClient extends Service {
    public static final String ACTION_DISCONNECT_USB_CMD_CLIENT = "com.samsung.datadistributor.disconnect";
    public static final String ACTION_REQUEST_USB_CMD_CLIENT_START = "com.samsung.datadistributor.request_reconnect";
    public static final String ACTION_RESPONSE_USB_CMD_CLIENT_DONE = "com.samsung.datadistributor.response_reconnect";
    public static final String CLASS_NAME = "UsbFtClient";
    private ConnectionThread connectionThread;
    public UsbAtParser parser;
    public ResponseWriter writer;

    public IBinder onBind(Intent intent) {
        return null;
    }

    public int onStartCommand(Intent intent, int flags, int startId) {
        FtUtil.log_d(CLASS_NAME, "onStartCommand", "...");
        if (isRunningService()) {
            sendStartResponse("OK");
        }
        if (this.connectionThread != null) {
            return 1;
        }
        ConnectionThread connectionThread2 = new ConnectionThread(this);
        this.connectionThread = connectionThread2;
        connectionThread2.start();
        return 1;
    }

    public void onCreate() {
        FtUtil.log_d(CLASS_NAME, "onCreate", "Create UsbFtClient service");
        if (!XMLDataStorage.instance().parseXML(getApplicationContext())) {
            FtUtil.log_i(CLASS_NAME, "onCreate", "UsbFtClient => XML data parsing was failed.");
        }
    }

    public void onDestroy() {
        super.onDestroy();
        FtUtil.log_d(CLASS_NAME, "onDestroy", "UsbFtClient service");
        this.connectionThread.kill();
    }

    private boolean isRunningService() {
        ConnectionThread connectionThread2 = this.connectionThread;
        if (connectionThread2 == null || connectionThread2.isInterrupted() || !this.connectionThread.active) {
            return false;
        }
        return true;
    }

    /* access modifiers changed from: private */
    public class ConnectionThread extends Thread {
        public static final String USB_SOCKET_NAME = "/data/.socket_stream";
        private int MAX_TIMEOUT = 80;
        public boolean active;
        private BufferedReader in;
        private final Context mContext;
        private LocalSocket mLocalSocket;
        private LocalSocketAddress mLocalSocketAddress;

        public ConnectionThread(Context context) {
            this.mContext = context;
            this.active = true;
            this.mLocalSocket = new LocalSocket(2);
            this.mLocalSocketAddress = new LocalSocketAddress(USB_SOCKET_NAME, LocalSocketAddress.Namespace.FILESYSTEM);
        }

        public void run() {
            FtUtil.log_d(UsbFtClient.CLASS_NAME, "run", "ConnectionThread start");
            boolean connected = false;
            int garbage_count = 0;
            while (!connected) {
                try {
                    if (!this.mLocalSocket.isConnected()) {
                        this.mLocalSocket.connect(this.mLocalSocketAddress);
                        FtUtil.log_i(UsbFtClient.CLASS_NAME, "run", "Connect client socket");
                    }
                } catch (IOException e) {
                    if (FtUtil.isFactoryBinary()) {
                        FtUtil.log_e(e);
                    }
                }
                if (this.mLocalSocket.isConnected()) {
                    connected = true;
                    FtUtil.log_i(UsbFtClient.CLASS_NAME, "run", "Client socket connect success");
                    continue;
                } else {
                    connected = false;
                    int i = this.MAX_TIMEOUT;
                    this.MAX_TIMEOUT = i - 1;
                    if (i < 0) {
                        FtUtil.log_w(UsbFtClient.CLASS_NAME, "run", "Connection accept failed");
                        UsbFtClient.this.sendStartResponse("NG");
                        return;
                    }
                    try {
                        Thread.sleep(1000);
                        continue;
                    } catch (InterruptedException e2) {
                        FtUtil.log_e(e2);
                        continue;
                    }
                }
                if (connected) {
                    FtUtil.log_i(UsbFtClient.CLASS_NAME, "run", "Connected to AT Core");
                    this.active = true;
                    if (UsbFtClient.this.writer == null) {
                        UsbFtClient.this.writer = new ResponseWriter(this.mLocalSocket);
                    }
                    if (UsbFtClient.this.parser == null) {
                        UsbFtClient.this.parser = new UsbAtParser();
                        UsbFtClient.this.parser.registerAllHandler(this.mContext, UsbFtClient.this.writer);
                    }
                    try {
                        this.in = new BufferedReader(new InputStreamReader(this.mLocalSocket.getInputStream()));
                    } catch (IOException e3) {
                        FtUtil.log_e(e3);
                        this.active = false;
                        connected = false;
                    }
                    UsbFtClient.this.sendStartResponse("OK");
                    while (this.active) {
                        try {
                            if (this.in.readLine() == null) {
                                garbage_count++;
                                FtUtil.log_i(UsbFtClient.CLASS_NAME, "run", "Garbage data incoming...");
                                if (garbage_count > 10) {
                                    FtUtil.log_i(UsbFtClient.CLASS_NAME, "run", "Stop UsbFtClient(Garbage data count=" + garbage_count + ")");
                                    this.active = false;
                                }
                            }
                        } catch (IOException e4) {
                            FtUtil.log_e(e4);
                            this.active = false;
                            connected = false;
                        }
                    }
                    FtUtil.log_d(UsbFtClient.CLASS_NAME, "killed thread", "connected value : " + connected);
                    return;
                }
            }
        }

        public void kill() {
            this.active = false;
            UsbFtClient.this.connectionThread.interrupt();
            LocalSocket localSocket = this.mLocalSocket;
            if (localSocket != null) {
                try {
                    localSocket.shutdownInput();
                    this.mLocalSocket.shutdownOutput();
                    this.mLocalSocket.close();
                    this.mLocalSocket = null;
                    FtUtil.log_i(UsbFtClient.CLASS_NAME, AtSysdump.REMOTE_SYSDUMP_EXTRA_KILL, "Close client socket(sender)");
                } catch (IOException e) {
                    FtUtil.log_e(e);
                }
            }
            UsbFtClient.this.connectionThread = null;
            FtUtil.log_d(UsbFtClient.CLASS_NAME, "run", "Kill ConnectionThread done");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sendStartResponse(String result) {
        FtUtil.log_w(CLASS_NAME, "sendStartResponse", "result = " + result);
        Intent intent = new Intent(ACTION_RESPONSE_USB_CMD_CLIENT_DONE);
        intent.putExtra("result", result);
        sendBroadcast(intent);
    }
}
