package com.sec.factory.aporiented.athandler;

import android.content.Context;
import android.content.SharedPreferences;
import com.sec.factory.modules.ModuleCommunicationService;
import com.sec.factory.modules.ModuleSensor;
import com.sec.factory.modules.SensorCalculator;
import com.sec.factory.modules.SensorDeviceInfo;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.optical.client.api.EgisFingerprint;

public class AtAcsensor extends AtCommandHandler {
    private static final int TYPE_ACC_MAIN = 1001;
    private static final int TYPE_ACC_SUB = 1002;
    private int mAccelerometer1GValue = 256;
    private int mAccelerometerBitCount = 10;
    private int mAccelerometerFullScale = 2;
    private final Context mContext;
    private int[] mSensorID;
    private int[] mSubSensorID;

    public AtAcsensor(Context context) {
        super(context);
        this.CMD_NAME = "ACSENSOR";
        this.CLASS_NAME = "AtAcsensor";
        this.NUM_ARGS = 2;
        this.mContext = context;
        this.mSensorID = new int[]{ModuleSensor.ID_FILE____ACCELEROMETER, ModuleSensor.ID_FILE____ACCELEROMETER_SELF, ModuleSensor.ID_FILE____ACCELEROMETER_SELFTEST, ModuleSensor.ID_FILE____ACCELEROMETER_CAL, ModuleSensor.ID_FILE____ACCELEROMETER_INTPIN, ModuleSensor.ID_MANAGER_ACCELEROMETER};
        this.mSubSensorID = new int[]{ModuleSensor.ID_FILE____SUB_ACCELEROMETER, ModuleSensor.ID_FILE____SUB_ACCELEROMETER_SELFTEST, ModuleSensor.ID_MANAGER_SUB_ACCELEROMETER};
    }

    @Override // com.sec.factory.aporiented.athandler.AtCommandHandler
    public synchronized String handleCommand(String[] argu) {
        String data;
        String resData = null;
        if (argu.length != (STAGE_PARALLEL ? this.NUM_ARGS + 1 : this.NUM_ARGS)) {
            return responseNA();
        }
        if (FtUtil.isFactoryBinary()) {
            if (checkArgu(argu, new String[]{"0", EgisFingerprint.MAJOR_VERSION})) {
                mModuleSensor.SensorOn(this.mSubSensorID);
                resData = mModuleSensor.isSensorOn(ModuleSensor.ID_MANAGER_SUB_ACCELEROMETER) ? responseOK(argu[0]) : responseNG(argu[0]);
            } else if (checkArgu(argu, new String[]{"0", "4"})) {
                mModuleSensor.SensorOff(this.mSubSensorID);
                resData = mModuleSensor.isSensorOn(ModuleSensor.ID_MANAGER_SUB_ACCELEROMETER) ? responseNG(argu[0]) : responseOK(argu[0]);
            } else if (checkArgu(argu, new String[]{"0", "5"})) {
                if (!mModuleSensor.isSensorOn(ModuleSensor.ID_FILE____SUB_ACCELEROMETER_CAL)) {
                    mModuleSensor.SensorOn(new int[]{ModuleSensor.ID_FILE____SUB_ACCELEROMETER_CAL});
                }
                resData = (!mModuleSensor.isSensorOn(ModuleSensor.ID_FILE____SUB_ACCELEROMETER_CAL) || !Support.Kernel.write(Support.Kernel.SUB_ACCEL_SENSOR_CAL, egis.client.api.EgisFingerprint.MAJOR_VERSION)) ? responseNG(argu[0]) : responseOK(argu[0]);
            } else if (checkArgu(argu, new String[]{"0", EgisFingerprint.JAR_VERSION})) {
                String result = getSelfTestResult(false, 1002);
                resData = (result == null || "NG_null".equals(result)) ? responseNG(argu[0]) : responseString(argu[0], result);
            } else if (checkArgu(argu, new String[]{egis.client.api.EgisFingerprint.MAJOR_VERSION, egis.client.api.EgisFingerprint.MAJOR_VERSION})) {
                SharedPreferences preferences = this.mContext.getSharedPreferences("ACC_RESULT", 0);
                String result2 = preferences.getString("RESULT_DATA", "0");
                if (result2.equals("0")) {
                    String str = this.CLASS_NAME;
                    FtUtil.log_i(str, "handleCommand", "result = " + result2);
                    SharedPreferences.Editor editor = preferences.edit();
                    editor.putString("RESULT_DATA", "NONE");
                    editor.apply();
                    result2 = preferences.getString("RESULT_DATA", "0");
                }
                resData = responseString(argu[0], result2);
            } else if (checkArgu(argu, new String[]{egis.client.api.EgisFingerprint.MAJOR_VERSION, "2"})) {
                SharedPreferences preferences2 = this.mContext.getSharedPreferences("SUB_ACC_RESULT", 0);
                String result3 = preferences2.getString("RESULT_DATA", "0");
                if (result3.equals("0")) {
                    String str2 = this.CLASS_NAME;
                    FtUtil.log_i(str2, "handleCommand", "result = " + result3);
                    SharedPreferences.Editor editor2 = preferences2.edit();
                    editor2.putString("RESULT_DATA", "NONE");
                    editor2.apply();
                    result3 = preferences2.getString("RESULT_DATA", "0");
                }
                resData = responseString(argu[0], result3);
            } else if (checkArgu(argu, new String[]{egis.client.api.EgisFingerprint.MAJOR_VERSION, "7"})) {
                if (!mModuleSensor.isSensorOn(ModuleSensor.ID_FILE____SUB_ACCELEROMETER) || !mModuleSensor.isSensorOn(ModuleSensor.ID_MANAGER_SUB_ACCELEROMETER)) {
                    resData = responseNG(argu[0]);
                } else {
                    if (!STAGE_PARALLEL) {
                        try {
                            Thread.sleep(1000);
                        } catch (InterruptedException e) {
                            e.printStackTrace();
                        }
                    }
                    String responseData = getXYZResult(false, 1002);
                    resData = responseData != null ? responseString(argu[0], responseData) : responseNG(argu[0]);
                }
            } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION})) {
                String result4 = getVectorSUM(false, 1002);
                resData = result4 != null ? responseString(argu[0], result4) : responseNG(argu[0]);
            } else if (checkArgu(argu, new String[]{"4"}) && (data = argu[1]) != null) {
                if (data.equalsIgnoreCase("G_N") || data.equalsIgnoreCase("G_NV")) {
                    String result5 = fullTest(data, 1002);
                    resData = result5 != null ? responseString(argu[0], result5) : responseNG(argu[0]);
                } else {
                    resData = responseNA();
                }
            }
        }
        if (checkArgu(argu, new String[]{"0", "0"})) {
            mModuleSensor.SensorOn(this.mSensorID);
            if (mModuleSensor.isSensorOn(ModuleSensor.ID_MANAGER_ACCELEROMETER)) {
                resData = responseOK(argu[0]);
            } else {
                resData = responseNG(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{"0", egis.client.api.EgisFingerprint.MAJOR_VERSION})) {
            mModuleSensor.SensorOff(this.mSensorID);
            if (mModuleSensor.isSensorOn(ModuleSensor.ID_MANAGER_ACCELEROMETER)) {
                resData = responseNG(argu[0]);
            } else {
                resData = responseOK(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{"0", "2"})) {
            if (!mModuleSensor.isSensorOn(ModuleSensor.ID_FILE____ACCELEROMETER_CAL)) {
                mModuleSensor.SensorOn(new int[]{ModuleSensor.ID_FILE____ACCELEROMETER_CAL});
            }
            if (!mModuleSensor.isSensorOn(ModuleSensor.ID_FILE____ACCELEROMETER_CAL) || !Support.Kernel.write(Support.Kernel.ACCEL_SENSOR_CAL, egis.client.api.EgisFingerprint.MAJOR_VERSION)) {
                resData = responseNG(argu[0]);
            } else {
                resData = responseOK(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{"0", "6"})) {
            String result6 = getSelfTestResult(false, 1001);
            if (result6 == null || "NG_null".equals(result6)) {
                resData = responseNG(argu[0]);
            } else {
                resData = responseString(argu[0], result6);
            }
        } else if (checkArgu(argu, new String[]{"0", "7"})) {
            if (!mModuleSensor.isSensorOn(ModuleSensor.ID_FILE____ACCELEROMETER_CAL)) {
                mModuleSensor.SensorOn(new int[]{ModuleSensor.ID_FILE____ACCELEROMETER_CAL});
            }
            if (!mModuleSensor.isSensorOn(ModuleSensor.ID_FILE____ACCELEROMETER_CAL) || !Support.Kernel.write(Support.Kernel.ACCEL_SENSOR_CAL, "0")) {
                resData = responseNG(argu[0]);
            } else {
                resData = responseOK(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{"0"})) {
            String data2 = argu[1];
            if (data2 != null && (data2.equals("G_N") || data2.equals("G_NI") || data2.equals("G_NV") || data2.equals("G_NIV") || data2.equals("g_n") || data2.equals("g_ni") || data2.equals("g_nv") || data2.equals("g_niv"))) {
                String result7 = fullTest(data2, 1001);
                if (result7 != null) {
                    resData = responseString(argu[0], result7);
                } else {
                    resData = responseNG(argu[0]);
                }
            }
        } else if (checkArgu(argu, new String[]{egis.client.api.EgisFingerprint.MAJOR_VERSION, "0"})) {
            if (!mModuleSensor.isSensorOn(ModuleSensor.ID_FILE____ACCELEROMETER) || !mModuleSensor.isSensorOn(ModuleSensor.ID_MANAGER_ACCELEROMETER)) {
                resData = responseNG(argu[0]);
            } else {
                if (!STAGE_PARALLEL) {
                    try {
                        Thread.sleep(1000);
                    } catch (InterruptedException e2) {
                        e2.printStackTrace();
                    }
                }
                String responseData2 = getXYZResult(false, 1001);
                if (responseData2 != null) {
                    resData = responseString(argu[0], responseData2);
                } else {
                    resData = responseNG(argu[0]);
                }
            }
        } else if (checkArgu(argu, new String[]{egis.client.api.EgisFingerprint.MAJOR_VERSION, "4"})) {
            if (mModuleSensor.isSensorOn(ModuleSensor.ID_FILE____ACCELEROMETER_SELF)) {
                String[] result8 = mModuleSensor.getData(ModuleSensor.ID_FILE____ACCELEROMETER_SELF);
                if (result8 != null) {
                    resData = responseString(argu[0], result8[2]);
                } else {
                    resData = responseNG(argu[0]);
                }
            } else {
                resData = responseNG(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{egis.client.api.EgisFingerprint.MAJOR_VERSION, "5"})) {
            String result9 = Support.Kernel.read(Support.Kernel.ACCEL_SENSOR_CAL);
            if (result9 == null) {
                resData = responseNG(argu[0]);
            } else if (result9.charAt(0) > '0') {
                resData = responseOK(argu[0]);
            } else {
                resData = responseNG(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{egis.client.api.EgisFingerprint.MAJOR_VERSION, "6"})) {
            if ("OK".equals(checkIntPin())) {
                resData = responseOK(argu[0]);
            } else {
                resData = responseNG(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "0"})) {
            String feature = SensorDeviceInfo.getSensorName(SensorDeviceInfo.TYPE_ACCELEROMETER, SensorDeviceInfo.TARGET_FILE);
            if (feature != null) {
                resData = responseString(argu[0], feature);
            } else {
                resData = responseString(argu[0], "NONE");
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, egis.client.api.EgisFingerprint.MAJOR_VERSION})) {
            String result10 = getVectorSUM(false, 1001);
            if (result10 != null) {
                resData = responseString(argu[0], result10);
            } else {
                resData = responseNG(argu[0]);
            }
        }
        if (resData == null) {
            resData = responseNA();
        }
        return resData;
    }

    private double getVectorSumToG(String mCoordinates_x, String mCoordinates_y, String mCoordinates_z) {
        int x = Integer.parseInt(mCoordinates_x);
        int y = Integer.parseInt(mCoordinates_y);
        int z = Integer.parseInt(mCoordinates_z);
        this.mAccelerometerBitCount = Integer.parseInt(Support.TestCase.getString(Support.TestCase.SENSOR_TEST_ACC_BIT));
        int accelerometerFullScale = SensorCalculator.getAccelerometerFullScale(this.mContext);
        this.mAccelerometerFullScale = accelerometerFullScale;
        this.mAccelerometerFullScale = accelerometerFullScale;
        this.mAccelerometer1GValue = SensorCalculator.getAccelerometer1GValue(this.mAccelerometerBitCount, accelerometerFullScale);
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "getVectorSumToG", "x : " + x + " y : " + y + " z : " + z + " mAccelerometer1GValue : " + this.mAccelerometer1GValue);
        return ((double) Math.round((Math.sqrt((double) (((x * x) + (y * y)) + (z * z))) / ((double) this.mAccelerometer1GValue)) * 100.0d)) / 100.0d;
    }

    /* JADX WARNING: Removed duplicated region for block: B:108:0x030a  */
    /* JADX WARNING: Removed duplicated region for block: B:114:0x0341  */
    private String fullTest(String cmdType, int accType) {
        int[] accSensorID;
        int accSensorType;
        String returnData;
        String returnData2;
        boolean z;
        String returnData3;
        String testResult;
        String testResult2;
        String testResult3;
        String testResult4;
        String niv_ng1text = "NG1_";
        String niv_ng1result = "_";
        String vectorSUMResult = null;
        String intPinCheck = null;
        if (accType == 1001) {
            int accSensorType2 = ModuleSensor.ID_MANAGER_ACCELEROMETER;
            accSensorID = this.mSensorID;
            accSensorType = accSensorType2;
        } else if (accType == 1002) {
            int accSensorType3 = ModuleSensor.ID_MANAGER_SUB_ACCELEROMETER;
            accSensorID = this.mSubSensorID;
            accSensorType = accSensorType3;
        } else {
            FtUtil.log_d(this.CLASS_NAME, "fullTest", "accType mismatch");
            return null;
        }
        FtUtil.log_d(this.CLASS_NAME, "fullTest", "sensorType=" + accSensorType);
        mModuleSensor.SensorOn(accSensorID);
        if (mModuleSensor.isSensorOn(accSensorType)) {
            try {
                Thread.sleep(300);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            String testResult5 = getXYZResult(true, accType);
            if (testResult5 != null) {
                String returnData4 = "OK," + testResult5;
                String testResult6 = getFlatness(accType);
                if (testResult6 != null) {
                    String returnData5 = returnData4 + testResult6;
                    if (cmdType.equals("G_NV") || cmdType.equals("g_nv") || cmdType.equals("G_NIV") || cmdType.equals("g_niv")) {
                        if (cmdType.equals("G_NIV") || cmdType.equals("g_niv")) {
                            intPinCheck = checkIntPin();
                        }
                        z = true;
                        vectorSUMResult = getVectorSUM(true, accType);
                    } else {
                        z = true;
                    }
                    String testResult7 = getSelfTestResult(z, accType);
                    if (testResult7 == null) {
                        testResult7 = "NG_SELF TEST_NULL";
                    }
                    boolean niv_ng = false;
                    if (!testResult7.contains("NG_SELF TEST")) {
                        returnData3 = returnData5 + testResult7;
                        testResult = null;
                    } else if (cmdType.equals("G_NIV") || cmdType.equals("g_niv")) {
                        niv_ng = true;
                        niv_ng1text = niv_ng1text + "SELF TEST";
                        String testResult8 = testResult7.replace("NG_SELF TEST_", "");
                        returnData3 = returnData5.replace("OK,", "");
                        niv_ng1result = niv_ng1result + returnData3 + testResult8 + ",";
                        testResult = testResult8;
                    } else {
                        mModuleSensor.SensorOff(accSensorID);
                        return testResult7;
                    }
                    if (cmdType.equals("G_N")) {
                        testResult2 = testResult;
                    } else if (cmdType.equals("g_n")) {
                        testResult2 = testResult;
                    } else {
                        if (!cmdType.equals("G_NI")) {
                            if (!cmdType.equals("g_ni")) {
                                if (cmdType.equals("G_NV")) {
                                    testResult3 = testResult;
                                } else if (cmdType.equals("g_nv")) {
                                    testResult3 = testResult;
                                } else {
                                    if (cmdType.equals("G_NIV") || cmdType.equals("g_niv")) {
                                        if (intPinCheck != null) {
                                            if (niv_ng) {
                                                niv_ng1result = niv_ng1result + "1,";
                                                testResult4 = testResult;
                                            } else {
                                                returnData3 = returnData3 + "1,";
                                                testResult4 = testResult;
                                            }
                                        } else if (niv_ng) {
                                            StringBuilder sb = new StringBuilder();
                                            sb.append(niv_ng1text);
                                            testResult4 = testResult;
                                            sb.append(",INT PIN");
                                            niv_ng1text = sb.toString();
                                            niv_ng1result = niv_ng1result + "0,";
                                        } else {
                                            testResult4 = testResult;
                                            niv_ng = true;
                                            niv_ng1text = niv_ng1text + "INT PIN";
                                            returnData3 = returnData3.replace("OK,", "");
                                            niv_ng1result = niv_ng1result + returnData3 + "0,";
                                        }
                                        if (vectorSUMResult == null || vectorSUMResult.contains("NG_VECTOR SUM")) {
                                            String vectorSUMResult2 = vectorSUMResult != null ? vectorSUMResult.replace("NG_VECTOR SUM_", "") : ModuleCommunicationService.SMD_NOK;
                                            if (niv_ng) {
                                                niv_ng1text = niv_ng1text + ",VECTOR SUM";
                                                niv_ng1result = niv_ng1result + vectorSUMResult2;
                                            } else {
                                                niv_ng = true;
                                                niv_ng1text = niv_ng1text + "VECTOR SUM";
                                                returnData3 = returnData3.replace("OK,", "");
                                                niv_ng1result = niv_ng1result + returnData3 + vectorSUMResult2;
                                            }
                                        } else if (niv_ng) {
                                            niv_ng1result = niv_ng1result + vectorSUMResult;
                                        } else {
                                            returnData3 = returnData3 + vectorSUMResult;
                                        }
                                    }
                                    mModuleSensor.SensorOff(accSensorID);
                                    if (!mModuleSensor.isSensorOn(accSensorType)) {
                                        if ((!cmdType.equals("G_NIV") && !cmdType.equals("g_niv")) || niv_ng) {
                                            return "NG1_SENSOR OFF";
                                        }
                                        String niv_ng1text2 = niv_ng1text + "SENSOR OFF";
                                        String niv_ng1result2 = niv_ng1result + returnData3.replace("OK,", "");
                                        return "NG1_SENSOR OFF";
                                    } else if (!niv_ng) {
                                        return returnData3;
                                    } else {
                                        return niv_ng1text + niv_ng1result;
                                    }
                                }
                                if (vectorSUMResult == null || !vectorSUMResult.contains("NG_VECTOR SUM")) {
                                    returnData3 = returnData3 + "NA," + vectorSUMResult;
                                    mModuleSensor.SensorOff(accSensorID);
                                    if (!mModuleSensor.isSensorOn(accSensorType)) {
                                    }
                                } else {
                                    mModuleSensor.SensorOff(accSensorID);
                                    return vectorSUMResult;
                                }
                            }
                        }
                        if (checkIntPin() != null) {
                            returnData3 = returnData3 + ",1,NA";
                            mModuleSensor.SensorOff(accSensorID);
                            if (!mModuleSensor.isSensorOn(accSensorType)) {
                            }
                        } else {
                            mModuleSensor.SensorOff(accSensorID);
                            return "NG_INT PIN";
                        }
                    }
                    returnData3 = returnData3 + "NA,NA";
                    mModuleSensor.SensorOff(accSensorID);
                    if (!mModuleSensor.isSensorOn(accSensorType)) {
                    }
                } else {
                    if (cmdType.equals("G_NIV") || cmdType.equals("g_niv")) {
                        returnData2 = "NG1_READ VALUE";
                    } else {
                        returnData2 = "NG_READ VALUE";
                    }
                    mModuleSensor.SensorOff(accSensorID);
                    return returnData2;
                }
            } else {
                if (cmdType.equals("G_NIV") || cmdType.equals("g_niv")) {
                    returnData = "NG1_READ VALUE";
                } else {
                    returnData = "NG_READ VALUE";
                }
                mModuleSensor.SensorOff(accSensorID);
                return returnData;
            }
        } else if (cmdType.equals("G_NIV") || cmdType.equals("g_niv")) {
            return "NG1_SENSOR ON";
        } else {
            return "NG_SENSOR ON";
        }
    }

    private String getXYZResult(boolean cmdType, int accType) {
        int sensorFileType;
        int sensorManagerType;
        if (accType == 1001) {
            sensorManagerType = ModuleSensor.ID_MANAGER_ACCELEROMETER;
            sensorFileType = ModuleSensor.ID_FILE____ACCELEROMETER;
        } else if (accType == 1002) {
            sensorManagerType = ModuleSensor.ID_MANAGER_SUB_ACCELEROMETER;
            sensorFileType = ModuleSensor.ID_FILE____SUB_ACCELEROMETER;
        } else {
            FtUtil.log_d(this.CLASS_NAME, "getXYZResult", "accType mismatch");
            return null;
        }
        FtUtil.log_d(this.CLASS_NAME, "getXYZResult", " sensorType : " + ModuleSensor.getString_ID(sensorManagerType));
        for (int i = 0; i < 15 && !mModuleSensor.isSensorReady(sensorManagerType); i++) {
            FtUtil.log_d(this.CLASS_NAME, "getXYZResult", "Waiting SensorReady");
            FtUtil.Sleep.sleep(100);
        }
        String[] result = mModuleSensor.getData(sensorFileType);
        if (result == null) {
            return null;
        }
        String returnData = !cmdType ? FtUtil.addDummyValue(result[2], 6, ' ') + FtUtil.addDummyValue(result[3], 6, ' ') + FtUtil.addDummyValue(result[4], 6, ' ') : result[2] + "," + result[3] + "," + result[4] + ",";
        FtUtil.log_d(this.CLASS_NAME, "getXYZResult", "returnData=[" + returnData + "]");
        return returnData;
    }

    private String getFlatness(int accType) {
        int POLLING_INTERVAL;
        String returnData = null;
        int POLLING_INTERVAL2 = Integer.parseInt(Support.TestCase.getString(Support.TestCase.INTERVAL_FOR_ACC_SENSOR_FLATNESS));
        int min_Y = 0;
        int max_X = 0;
        int min_Z = 0;
        int max_Y = 0;
        int min_Z2 = 0;
        int max_Z = 0;
        int i = 0;
        while (i < 3) {
            String str = this.CLASS_NAME;
            FtUtil.log_d(str, "getFlatness", "for[1] start / i = " + i);
            int[] mDataResult = {0, 0, 0};
            String mData = getXYZResult(true, accType);
            if (mData == null) {
                return returnData;
            }
            String mData2 = mData.replaceAll("\"", "");
            int j = 0;
            while (j < 3) {
                String str2 = this.CLASS_NAME;
                FtUtil.log_d(str2, "getFlatness", "for[2] start / j = " + j);
                mDataResult[j] = Integer.parseInt(mData2.split(",")[j].trim());
                String str3 = this.CLASS_NAME;
                FtUtil.log_d(str3, "getFlatness", "mDataResult[" + j + "] = " + mDataResult[j]);
                j++;
                returnData = returnData;
            }
            FtUtil.log_d(this.CLASS_NAME, "getFlatness", "for[2] end");
            if (i == 0) {
                String str4 = this.CLASS_NAME;
                StringBuilder sb = new StringBuilder();
                POLLING_INTERVAL = POLLING_INTERVAL2;
                sb.append("for[1]_i = ");
                sb.append(i);
                sb.append(" / min/max setting");
                FtUtil.log_d(str4, "getFlatness", sb.toString());
                int min_X = mDataResult[0];
                max_X = min_X;
                int min_Y2 = mDataResult[1];
                max_Y = min_Y2;
                int min_Z3 = mDataResult[2];
                max_Z = min_Z3;
                String str5 = this.CLASS_NAME;
                FtUtil.log_d(str5, "getFlatness", min_X + ", " + max_X + " / " + min_Y2 + ", " + max_Y + " / " + min_Z3 + ", " + max_Z);
                FtUtil.log_d(this.CLASS_NAME, "getFlatness", "for[1] end");
                min_Z2 = min_Z3;
                min_Z = min_Y2;
                min_Y = min_X;
            } else {
                POLLING_INTERVAL = POLLING_INTERVAL2;
                FtUtil.log_d(this.CLASS_NAME, "getFlatness", "min/max checking start");
                if (mDataResult[0] < min_Y) {
                    min_Y = mDataResult[0];
                }
                if (mDataResult[0] > max_X) {
                    max_X = mDataResult[0];
                }
                if (mDataResult[1] < min_Z) {
                    min_Z = mDataResult[1];
                }
                if (mDataResult[1] > max_Y) {
                    max_Y = mDataResult[1];
                }
                if (mDataResult[2] < min_Z2) {
                    min_Z2 = mDataResult[2];
                }
                if (mDataResult[2] > max_Z) {
                    max_Z = mDataResult[2];
                }
                String str6 = this.CLASS_NAME;
                FtUtil.log_d(str6, "getFlatness", min_Y + ", " + max_X + " / " + min_Z + ", " + max_Y + " / " + min_Z2 + ", " + max_Z);
                FtUtil.log_d(this.CLASS_NAME, "getFlatness", "for[1] end");
            }
            FtUtil.Sleep.sleep((long) POLLING_INTERVAL);
            i++;
            POLLING_INTERVAL2 = POLLING_INTERVAL;
            returnData = returnData;
        }
        String returnData2 = String.format("%d,%d,%d,", Integer.valueOf(max_X - min_Y), Integer.valueOf(max_Y - min_Z), Integer.valueOf(max_Z - min_Z2));
        String str7 = this.CLASS_NAME;
        FtUtil.log_d(str7, "getFlatness", "returnData = " + returnData2);
        return returnData2;
    }

    private String getSelfTestResult(boolean cmdType, int accType) {
        int sensorType;
        String filePath;
        String xyzDiffData;
        FtUtil.log_d(this.CLASS_NAME, "getSelfTestResult", "");
        if (accType == 1001) {
            filePath = Support.Kernel.ACCEL_SENSOR_SELFTEST;
            sensorType = ModuleSensor.ID_FILE____ACCELEROMETER_SELFTEST;
        } else if (accType == 1002) {
            filePath = Support.Kernel.SUB_ACCEL_SENSOR_SELFTEST;
            sensorType = ModuleSensor.ID_FILE____SUB_ACCELEROMETER_SELFTEST;
        } else {
            FtUtil.log_d(this.CLASS_NAME, "getSelfTestResult", "accType mismatch");
            return null;
        }
        FtUtil.log_d(this.CLASS_NAME, "getSelfTestResult", "filePath = " + filePath);
        FtUtil.log_d(this.CLASS_NAME, "getSelfTestResult", " sensorType : " + ModuleSensor.getString_ID(sensorType));
        if (!Support.Kernel.isExistFile(filePath)) {
            return "NA,";
        }
        if (!mModuleSensor.isSensorOn(sensorType)) {
            mModuleSensor.SensorOn(new int[]{sensorType});
        }
        String[] result = mModuleSensor.getData(sensorType);
        if (result != null) {
            int dataSize = Integer.parseInt(result[0]);
            String resultString = result[1];
            String str = result[2] + "," + result[3] + "," + result[4];
            if (dataSize == 7) {
                xyzDiffData = String.format("%s,%s,%s,%s,%s,%s", result[2], result[3], result[4], result[5], result[6], result[7]);
            } else {
                xyzDiffData = String.format("%s,%s,%s", result[2], result[3], result[4]);
            }
            if (!cmdType) {
                if (egis.client.api.EgisFingerprint.MAJOR_VERSION.equalsIgnoreCase(resultString)) {
                    return "OK_" + xyzDiffData;
                }
                return "NG_" + xyzDiffData;
            } else if (egis.client.api.EgisFingerprint.MAJOR_VERSION.equalsIgnoreCase(resultString)) {
                return xyzDiffData + ",";
            } else {
                return "NG_SELF TEST_" + xyzDiffData;
            }
        } else if (!cmdType) {
            return "NG_null";
        } else {
            return "NG_SELF TEST";
        }
    }

    private String checkIntPin() {
        String[] result;
        if (mModuleSensor.isSensorOn(ModuleSensor.ID_FILE____ACCELEROMETER_CAL) && (result = mModuleSensor.getData(ModuleSensor.ID_FILE____ACCELEROMETER_INTPIN)) != null && egis.client.api.EgisFingerprint.MAJOR_VERSION.equals(result[2])) {
            return "OK";
        }
        return null;
    }

    private String getVectorSUM(boolean cmdType, int accType) {
        int sensorTypeAngle;
        int sensorType;
        String[] mCoordinates;
        String returnData = null;
        if (accType == 1001) {
            sensorType = ModuleSensor.ID_MANAGER_ACCELEROMETER;
            sensorTypeAngle = ModuleSensor.ID_MANAGER_ACCELEROMETER_N_ANGLE;
        } else if (accType == 1002) {
            sensorType = ModuleSensor.ID_MANAGER_SUB_ACCELEROMETER;
            sensorTypeAngle = ModuleSensor.ID_MANAGER_SUB_ACCELEROMETER_N_ANGLE;
        } else {
            FtUtil.log_d(this.CLASS_NAME, "getVectorSUM", "accType mismatch");
            return null;
        }
        FtUtil.log_d(this.CLASS_NAME, "getVectorSUM", " sensorType : " + ModuleSensor.getString_ID(sensorType));
        FtUtil.log_d(this.CLASS_NAME, "getVectorSUM", " sensorTypeAngle : " + ModuleSensor.getString_ID(sensorTypeAngle));
        if (mModuleSensor.isSensorOn(sensorType) && (mCoordinates = mModuleSensor.getData(sensorTypeAngle)) != null) {
            double dVectorSum = getVectorSumToG(mCoordinates[2], mCoordinates[3], mCoordinates[4]);
            FtUtil.log_d(this.CLASS_NAME, "getVectorSUM", "VectorSUM = " + String.valueOf(dVectorSum));
            if (!cmdType) {
                if (dVectorSum < 0.8d || dVectorSum > 1.2d) {
                    returnData = "NG," + String.valueOf(dVectorSum);
                } else {
                    returnData = "OK," + String.valueOf(dVectorSum);
                }
            } else if (dVectorSum < 0.8d || dVectorSum > 1.2d) {
                returnData = "NG_VECTOR SUM_" + String.valueOf(dVectorSum);
            } else {
                returnData = String.valueOf(dVectorSum);
            }
        }
        if (returnData != null) {
            FtUtil.log_d(this.CLASS_NAME, "getVectorSUM", returnData);
        } else {
            FtUtil.log_d(this.CLASS_NAME, "getVectorSUM", "returnData is null");
        }
        return returnData;
    }
}
