package com.sec.factory.aporiented.athandler;

import android.content.Context;
import android.content.Intent;
import android.os.SystemProperties;
import android.provider.Settings;
import android.telephony.TelephonyManager;
import com.sec.factory.modules.ModuleTouchScreen;
import com.sec.factory.support.FtUtil;
import egis.client.api.EgisFingerprint;

public class AtAirpmode extends AtCommandHandler {
    private final int AIRPLANE_ERROR = -1;
    private int AIRPLANE_MODE_VALUE = -1;
    private final int AIRPLANE_OFF = 0;
    private final int AIRPLANE_ON = 1;
    private Context mContext;

    public AtAirpmode(Context context) {
        super(context);
        this.CMD_NAME = "AIRPMODE";
        this.CLASS_NAME = "AtAirpmode";
        this.NUM_ARGS = 4;
        this.writer = this.writer;
        this.mContext = context;
    }

    @Override // com.sec.factory.aporiented.athandler.AtCommandHandler
    public synchronized String handleCommand(String[] argu) {
        String resData;
        if (argu.length < this.NUM_ARGS) {
            FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME, "Fail - NUM_ARGS ERROR"));
            return responseNA();
        }
        if (checkArgu(argu, new String[]{"0", "0", "0", "0"})) {
            if (changeAirPlaneMode(0)) {
                resData = responseOK(argu[0]);
                String str = this.CLASS_NAME;
                FtUtil.log_d(str, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,0,0,0", "Pass - AIRPLANE_OFF"));
            } else {
                resData = responseNG(argu[0]);
                String str2 = this.CLASS_NAME;
                FtUtil.log_d(str2, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=0,0,0,1", "Fail - AIRPLANE_OFF ERROR"));
            }
        } else if (checkArgu(argu, new String[]{"0", "0", "0", EgisFingerprint.MAJOR_VERSION})) {
            if (changeAirPlaneMode(1)) {
                resData = responseOK(argu[0]);
                String str3 = this.CLASS_NAME;
                FtUtil.log_d(str3, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,0,0,0", "Pass - AIRPLANE_ON"));
            } else {
                resData = responseNG(argu[0]);
                String str4 = this.CLASS_NAME;
                FtUtil.log_d(str4, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=0,0,0,1", "Fail - AIRPLANE_ON ERROR"));
            }
        } else if (checkArgu(argu, new String[]{"0", "0", EgisFingerprint.MAJOR_VERSION, "0"})) {
            int firstApiLevel = SystemProperties.getInt("ro.product.first_api_level", 0);
            String str5 = this.CLASS_NAME;
            FtUtil.log_d(str5, "handleCommand", "firstApiLevel:" + firstApiLevel);
            if (firstApiLevel < 30) {
                return responseNA();
            }
            ((TelephonyManager) this.context.getSystemService(ModuleTouchScreen.TSP_DEVICE_TYPE__PHONE)).setRadioPower(false);
            resData = responseOK(argu[0]);
            String str6 = this.CLASS_NAME;
            FtUtil.log_d(str6, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,0,0,0", "Pass - Radio Off"));
        } else if (checkArgu(argu, new String[]{"0", "0", EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION})) {
            int firstApiLevel2 = SystemProperties.getInt("ro.product.first_api_level", 0);
            String str7 = this.CLASS_NAME;
            FtUtil.log_d(str7, "handleCommand", "firstApiLevel:" + firstApiLevel2);
            if (firstApiLevel2 < 30) {
                return responseNA();
            }
            ((TelephonyManager) this.context.getSystemService(ModuleTouchScreen.TSP_DEVICE_TYPE__PHONE)).setRadioPower(true);
            resData = responseOK(argu[0]);
            String str8 = this.CLASS_NAME;
            FtUtil.log_d(str8, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,0,0,0", "Pass - Radio on"));
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "0", "0", "0"})) {
            int result = Settings.Global.getInt(this.mContext.getContentResolver(), "airplane_mode_on", -1);
            if (result == 1) {
                resData = responseString(argu[0], "AIRPLANE");
                String str9 = this.CLASS_NAME;
                FtUtil.log_d(str9, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,0,0,0", "Pass - Read : AIRPLANE"));
            } else if (result == 0) {
                resData = responseString(argu[0], "NORMAL");
                String str10 = this.CLASS_NAME;
                FtUtil.log_d(str10, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,0,0,0", "Pass - Read : NORMAL"));
            } else {
                resData = responseNG(argu[0]);
                String str11 = this.CLASS_NAME;
                FtUtil.log_d(str11, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,0,0,0", "Fail - AIRPLANE_ERROR"));
            }
        } else {
            resData = responseNA();
            FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME, "Fail - NOT registerd index"));
        }
        return resData;
    }

    private boolean changeAirPlaneMode(int isEnabled) {
        Intent intent = new Intent("android.intent.action.AIRPLANE_MODE");
        boolean result = Settings.Global.putInt(this.mContext.getContentResolver(), "airplane_mode_on", isEnabled);
        boolean z = true;
        if (isEnabled != 1) {
            z = false;
        }
        intent.putExtra("state", z);
        this.mContext.sendBroadcast(intent);
        return result;
    }
}
