package com.sec.factory.aporiented.athandler;

import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.support.v4.app.NotificationCompat;
import com.sec.factory.app.ui.UIAdapterChargeCurrent;
import com.sec.factory.modules.ModuleCommunicationService;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.optical.client.api.EgisFingerprint;
import java.text.DateFormat;
import java.util.Date;
import java.util.Locale;

public class AtBatttest extends AtCommandHandler {
    private static final String ChipSetName = Support.Feature.getString(Support.Feature.CHIPSET_NAME);
    private static final String DISABLE_DISCHARGING = "0";
    private static final String ENABLE_DISCHARGING = "1";
    private Date date;
    private DateFormat df;
    private boolean isSM6150;
    private boolean isSM7150;
    public int mBatteryHealth = -1;
    public int mBatteryStatus = -1;
    private final Context mContext;

    public AtBatttest(Context context) {
        super(context);
        String str = ChipSetName;
        this.isSM6150 = "SM6150".equalsIgnoreCase(str);
        this.isSM7150 = "SM7150".equalsIgnoreCase(str);
        this.CMD_NAME = "BATTTEST";
        this.CLASS_NAME = "AtBatttest";
        this.NUM_ARGS = 2;
        this.mContext = context;
    }

    @Override // com.sec.factory.aporiented.athandler.AtCommandHandler
    public synchronized String handleCommand(String[] argu) {
        boolean isBattAsocInitSuccess;
        boolean isCisdDataInitSuccess;
        boolean isRtccDataInitSuccess;
        String returnValue;
        String returnValue2;
        String result;
        String resData = null;
        boolean z = true;
        if (argu.length != (STAGE_PARALLEL ? this.NUM_ARGS + 1 : this.NUM_ARGS)) {
            return responseNA();
        }
        if (checkArgu(argu, new String[]{"1", "2"})) {
            boolean isresetneeded = Support.TestCase.getEnabled(Support.TestCase.AT_BATTEST_RESET_WHEN_READ);
            FtUtil.log_i(this.CLASS_NAME, "handleCommand", "isresetneeded: " + isresetneeded);
            if (!this.isSM6150 && !this.isSM7150) {
                if (isresetneeded) {
                    mModulePower.resetFuelGaugeIC();
                } else {
                    Support.Kernel.write(Support.Kernel.BATTERY_UPDATE_BEFORE_READ, "1");
                }
            }
            FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,2", "Voltage Read"));
            resData = responseString(argu[0], mModulePower.readBatteryVoltage());
        } else if (checkArgu(argu, new String[]{"1", "6"})) {
            if (Support.Feature.getBoolean(Support.Feature.SUPPORT_IN_BATTERY_OCV)) {
                result = String.format(Locale.US, "%.3f", Float.valueOf(Float.valueOf(Support.Kernel.read(Support.Kernel.BATTERY_INBAT_VOLTAGE)).floatValue() / 1000.0f));
            } else {
                result = mModulePower.readInBatteryVoltage();
            }
            if (result == null || Float.parseFloat(result) <= 0.0f) {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,6", "Fail - IN-Battery Voltage Read"));
                resData = responseNG(argu[0]);
            } else {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,6", "Pass - IN-Battery Voltage Read"));
                resData = responseString(argu[0], result);
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "2"})) {
            Intent i = new Intent(this.context, UIAdapterChargeCurrent.class);
            i.addFlags(335544320);
            this.mContext.startActivity(i);
            FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=3,2", "Run Charge Current Check UI"));
            resData = responseOK(argu[0]);
        } else if (checkArgu(argu, new String[]{"4", DISABLE_DISCHARGING})) {
            Support.Kernel.write(Support.Kernel.BATTERY_SUB_ENB, "1");
            FtUtil.Sleep.sleep(500);
            Support.Kernel.write(Support.Kernel.BATTERY_MAIN_ENB, DISABLE_DISCHARGING);
            String result2 = String.format(Locale.US, "%.3f", Float.valueOf(Float.valueOf(Support.Kernel.read(Support.Kernel.BATTERY_MAIN_VOLTAGE)).floatValue() / 1000.0f));
            if (result2 == null || Float.parseFloat(result2) <= 0.0f) {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=4,0", "Fail - Dual IN-Battery Voltage Read(Main)"));
                resData = responseNG(argu[0]);
            } else {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=4,0", "Pass - Dual IN-Battery Voltage Read(Main)"));
                resData = responseString(argu[0], result2);
            }
        } else if (checkArgu(argu, new String[]{"4", "1"})) {
            Support.Kernel.write(Support.Kernel.BATTERY_MAIN_ENB, "1");
            FtUtil.Sleep.sleep(500);
            Support.Kernel.write(Support.Kernel.BATTERY_SUB_ENB, DISABLE_DISCHARGING);
            String result3 = String.format(Locale.US, "%.3f", Float.valueOf(Float.valueOf(Support.Kernel.read(Support.Kernel.BATTERY_SUB_VOLTAGE)).floatValue() / 1000.0f));
            if (result3 == null || Float.parseFloat(result3) <= 0.0f) {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=4,1", "Fail - Dual IN-Battery Voltage Read(Sub)"));
                resData = responseNG(argu[0]);
            } else {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=4,1", "Pass - Dual IN-Battery Voltage Read(Sub)"));
                resData = responseString(argu[0], result3);
            }
        }
        if (FtUtil.isFactoryBinary()) {
            if (checkArgu(argu, new String[]{DISABLE_DISCHARGING, "2"})) {
                if (!Support.Kernel.write(Support.Kernel.BATTERY_DISCHARGING_FORCE_SWITCH, "1") || !"1".equalsIgnoreCase(Support.Kernel.read(Support.Kernel.BATTERY_DISCHARGING_SWITCH_CHECK))) {
                    FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=0,2", "Fail - Discharging Testmode ON"));
                    resData = responseNG(argu[0]);
                } else {
                    FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=0,2", "Pass - Discharging Testmode ON"));
                    resData = responseOK(argu[0]);
                }
            } else if (checkArgu(argu, new String[]{DISABLE_DISCHARGING, EgisFingerprint.MAJOR_VERSION})) {
                if (!Support.Kernel.write(Support.Kernel.BATTERY_DISCHARGING_FORCE_SWITCH, DISABLE_DISCHARGING) || !DISABLE_DISCHARGING.equalsIgnoreCase(Support.Kernel.read(Support.Kernel.BATTERY_DISCHARGING_SWITCH_CHECK))) {
                    FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=0,3", "Fail - Discharging Testmode OFF"));
                    resData = responseNG(argu[0]);
                } else {
                    FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=0,3", "Pass - Discharging Testmode OFF"));
                    resData = responseOK(argu[0]);
                }
            } else if (checkArgu(argu, new String[]{DISABLE_DISCHARGING, "6"})) {
                if (Support.Kernel.write(Support.Kernel.BATTERY_AP_LOCKUP, "1")) {
                    FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=0,6", "Pass - AP Lockup for Charger IC"));
                    resData = responseOK(argu[0]);
                } else {
                    FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=0,6", "Fail - AP Lockup for Charger IC"));
                    resData = responseNG(argu[0]);
                }
            } else if (checkArgu(argu, new String[]{"1", "1"})) {
                resData = responseNA();
            } else if (checkArgu(argu, new String[]{"1", "4"})) {
                String data = Support.Kernel.read(Support.Kernel.BATTERY_CAPACITY);
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,4", "Read Battery Level Percentage"));
                resData = responseString(argu[0], data);
            } else if (checkArgu(argu, new String[]{"1", "5"})) {
                String data2 = Support.Kernel.read(Support.Kernel.BATT_BATTERY_ID);
                if (Support.Feature.getBoolean(Support.Feature.SUPPORT_BATT_CHECK_PHASE_1, false)) {
                    if (DISABLE_DISCHARGING.equals(data2)) {
                        returnValue2 = "LOW";
                    } else {
                        returnValue2 = "HIGH";
                    }
                    FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,5", "Read BATT_ID Check/Phase1, returnValue:" + returnValue2));
                } else {
                    returnValue2 = data2;
                    FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,5", "Read BATT_ID Check/Phase2, returnValue:" + returnValue2));
                }
                resData = responseString(argu[0], returnValue2);
            } else if (checkArgu(argu, new String[]{"1", "8"})) {
                String data3 = Support.Kernel.read(Support.Kernel.BATT_SUB_BATTERY_ID);
                if (Support.Feature.getBoolean(Support.Feature.SUPPORT_BATT_CHECK_PHASE_1, false)) {
                    if (DISABLE_DISCHARGING.equals(data3)) {
                        returnValue = "LOW";
                    } else {
                        returnValue = "HIGH";
                    }
                    FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,8", "Read SUB_BATT_ID Check/Phase1, returnValue:" + returnValue));
                } else {
                    returnValue = data3;
                    FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,8", "Read SUB_BATT_ID Check/Phase2, returnValue:" + returnValue));
                }
                resData = responseString(argu[0], returnValue);
            } else if (checkArgu(argu, new String[]{"2", "2"})) {
                String result4 = Support.Kernel.read(Support.Kernel.BATTERY_DISCHARGING_CHECK_ADC);
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=2,2", "Read Discharging ADC" + result4));
                resData = responseString(argu[0], result4);
            } else if (checkArgu(argu, new String[]{"2", EgisFingerprint.MAJOR_VERSION})) {
                String result5 = Support.Kernel.read(Support.Kernel.FUEL_GAUGE_CURRENT_NOW);
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=2,3", "Read Fuel Gauge Current Now : " + result5));
                resData = responseString(argu[0], result5);
            }
        }
        if (checkArgu(argu, new String[]{"1", "7"})) {
            FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,7", "NA - Read Fuel Gauge Current"));
            resData = responseNA();
        } else if (checkArgu(argu, new String[]{"1", EgisFingerprint.JAR_VERSION})) {
            if (getBatteryStatus() == 2) {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,9", "Pass - Detect Status of Battery Chagring : CHARGE"));
                resData = responseString(argu[0], "CHARGE");
            } else {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=1,9", "Fail - Detect Status of Battery Chagring : IDLE"));
                resData = responseString(argu[0], "IDLE");
            }
        } else if (checkArgu(argu, new String[]{"2", "1"})) {
            boolean supportASOC = false;
            try {
                if (Support.Kernel.isExistFileID(Support.Kernel.PATH_BATTERY_ASOC)) {
                    if (Integer.parseInt(Support.Kernel.read(Support.Kernel.PATH_BATTERY_ASOC)) < 0) {
                        z = false;
                    }
                    supportASOC = z;
                }
            } catch (NumberFormatException nfe) {
                supportASOC = false;
                FtUtil.log_e(this.CLASS_NAME, "handleCommand", nfe.getMessage());
            }
            boolean isChgCountInitSuccess = Support.Kernel.writeNsync(Support.Kernel.PATH_BATTERY_CHARGE_COUNT, DISABLE_DISCHARGING);
            if (supportASOC) {
                isBattAsocInitSuccess = Support.Kernel.write(Support.Kernel.PATH_BATTERY_ASOC, ModuleCommunicationService.SMD_OK);
            } else {
                isBattAsocInitSuccess = true;
            }
            if (Support.Kernel.isExistFileID(Support.Kernel.BATTERY_CISD_DATA)) {
                isCisdDataInitSuccess = Support.Kernel.writeNsync(Support.Kernel.BATTERY_CISD_DATA, ModuleCommunicationService.SMD_NOK);
            } else {
                isCisdDataInitSuccess = true;
            }
            if (Support.Kernel.isExistFileID(Support.Kernel.PATH_BATTERY_DISCON_COUNT)) {
                isRtccDataInitSuccess = Support.Kernel.writeNsync(Support.Kernel.PATH_BATTERY_DISCON_COUNT, DISABLE_DISCHARGING);
            } else {
                isRtccDataInitSuccess = true;
            }
            FtUtil.log_i(this.CLASS_NAME, "handleCommand", "isChgCountInitSuccess: " + isChgCountInitSuccess + " isBattAsocInitSuccess: " + isBattAsocInitSuccess + " isCisdDataInitSuccess: " + isCisdDataInitSuccess + " isRtccDataInitSuccess: " + isRtccDataInitSuccess);
            if (!isChgCountInitSuccess || !isBattAsocInitSuccess || !isCisdDataInitSuccess || !isRtccDataInitSuccess) {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=2,1", "Fail - Init IN-Battery Charging Count"));
                resData = responseNG(argu[0]);
            } else {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=2,1", "Pass - Init IN-Battery Charging Count"));
                resData = responseOK(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, DISABLE_DISCHARGING})) {
            String charge_count = Support.Kernel.read(Support.Kernel.PATH_BATTERY_CHARGE_COUNT);
            FtUtil.log_i(this.CLASS_NAME, "handleCommand", "Read Batt Charge Count= " + charge_count);
            if (charge_count != null) {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=3,0", "Pass - Read IN-Battery Charging Count"));
                resData = responseString(argu[0], String.valueOf(Integer.parseInt(charge_count) / 100));
            } else {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=3,0", "Fail - Read IN-Battery Charging Count"));
                resData = responseNG(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "1"})) {
            if (Support.Kernel.isExistFileID(Support.Kernel.PATH_BATTERY_ASOC)) {
                String result6 = Support.Kernel.read(Support.Kernel.PATH_BATTERY_ASOC);
                FtUtil.log_i(this.CLASS_NAME, "handleCommand", "Read Batt ASOC= " + result6);
                try {
                    if (Integer.parseInt(result6) >= 0) {
                        FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=3,1", "Pass - Read Batt ASOC"));
                        resData = responseString(argu[0], result6);
                        FtUtil.log_i(this.CLASS_NAME, "handleCommand", "Support ASOC");
                    } else {
                        FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=3,1", "Fail - Read Batt ASOC"));
                        resData = responseNA();
                        FtUtil.log_i(this.CLASS_NAME, "handleCommand", "Unsupport ASOC");
                    }
                } catch (NumberFormatException nfe2) {
                    FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=3,1", "Fail - Read Batt ASOC Format Exception"));
                    resData = responseNG(argu[0]);
                    FtUtil.log_e(this.CLASS_NAME, "handleCommand", nfe2.getMessage());
                }
            } else {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=3,1", "NA - Read Batt ASOC"));
                resData = responseNA();
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION})) {
            String result7 = String.format(Locale.US, "%.3f", Float.valueOf(Float.valueOf(Support.Kernel.read(Support.Kernel.BATTERY_INBAT_VOLTAGE_OCV)).floatValue() / 1000.0f));
            if (result7 == null || Float.parseFloat(result7) <= 0.0f) {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=4,2", "Fail - IN-Battery Voltage Read"));
                resData = responseNG(argu[0]);
            } else {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", FtUtil.setMspSeqMessage(3, this.CMD_NAME + "=4,2", "Pass - IN-Battery Voltage Read"));
                resData = responseString(argu[0], result7);
            }
        }
        if (resData == null) {
            resData = responseNA();
        }
        return resData;
    }

    public int getBatteryStatus() {
        return this.context.registerReceiver(null, new IntentFilter("android.intent.action.BATTERY_CHANGED")).getIntExtra(NotificationCompat.CATEGORY_STATUS, -1);
    }

    private String getTimeUsingSeconds(String Seconds) {
        String Time = String.valueOf(Integer.parseInt(Seconds) / 3600);
        if ((Integer.parseInt(Seconds) % 3600) / 60 < 10) {
            Time = Time + DISABLE_DISCHARGING;
        }
        String Time2 = Time + String.valueOf((Integer.parseInt(Seconds) % 3600) / 60);
        if ((Integer.parseInt(Seconds) % 3600) % 60 < 10) {
            Time2 = Time2 + DISABLE_DISCHARGING;
        }
        return Time2 + String.valueOf((Integer.parseInt(Seconds) % 3600) % 60);
    }

    private String getLatestUpdateTime(String Time) {
        if (DISABLE_DISCHARGING.equals(Time)) {
            return "00000000000000";
        }
        Date date2 = new Date(Long.parseLong(Time) * 1000);
        this.date = date2;
        return this.df.format(date2);
    }
}
