package com.sec.factory.aporiented.athandler;

import android.content.Context;
import android.os.SystemProperties;
import android.text.TextUtils;
import com.sec.factory.modules.ModuleCommunicationService;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.util.ArrayList;
import java.util.List;

public class AtConntest extends AtCommandHandler {
    private String[] AVAILABLE_PINS;
    private final int COL_CONNECT_NAME = 0;
    private final int COL_CONNECT_NODE = 1;
    private final String[][] CONNECTS = {new String[]{"UB_CONNECT", Support.Kernel.CABLE_DETECT_COUNT_OCTA}, new String[]{"CAM_CONNECT", Support.Kernel.CABLE_DETECT_COUNT_CAMERA}, new String[]{"SUB_CONNECT", Support.Kernel.CABLE_DETECT_COUNT_SUBPBA}, new String[]{"TSP_CONNECT", Support.Kernel.CABLE_DETECT_COUNT_TSP}, new String[]{"UPPER_C2C_DETECT", Support.Kernel.CABLE_DETECT_COUNT_UPPERPBA}, new String[]{"LOWER_C2C_DETECT", Support.Kernel.CABLE_DETECT_COUNT_LOWERPBA}, new String[]{"MAIN_BAT_DETECT", Support.Kernel.CABLE_DETECT_COUNT_MAINBATT}, new String[]{"SUB_BAT_DETECT", Support.Kernel.CABLE_DETECT_COUNT_SUBBATT}, new String[]{"UB_CONNECT_SUB", Support.Kernel.CABLE_DETECT_COUNT_SUBUB}, new String[]{"TOF_CONNECT", Support.Kernel.CABLE_DETECT_COUNT_TOFCAM}, new String[]{"MAIN_DIGITIZER_DETECT", Support.Kernel.CABLE_DETECT_COUNT_MAINDIGI}, new String[]{"SUB_LOWER_DETECT", Support.Kernel.CABLE_DETECT_COUNT_SUBDIGI}};
    private Context mContext;

    public AtConntest(Context context) {
        super(context);
        this.mContext = context;
        this.CMD_NAME = "CONNTEST";
        this.CLASS_NAME = "AtConntest";
        this.NUM_ARGS = 4;
        String AvailablePins = Support.Kernel.read(Support.Kernel.AVAILABLE_PIN_CHECK);
        String ubsupportdata = Support.Kernel.read(Support.Kernel.CABLE_DETECT_UB);
        if (ubsupportdata != null && !ModuleCommunicationService.SMD_NOK.equals(ubsupportdata)) {
            AvailablePins = "UB_CONNECT/" + AvailablePins;
        }
        String ubsupportdata2 = Support.Kernel.read(Support.Kernel.CABLE_DETECT_SUB_UB);
        if (ubsupportdata2 != null && !ModuleCommunicationService.SMD_NOK.equals(ubsupportdata2)) {
            AvailablePins = AvailablePins + "/UB_CONNECT_SUB";
        }
        if (AvailablePins != null) {
            this.AVAILABLE_PINS = AvailablePins.split("/");
        } else {
            this.AVAILABLE_PINS = null;
        }
    }

    @Override // com.sec.factory.aporiented.athandler.AtCommandHandler
    public synchronized String handleCommand(String[] argu) {
        String resData = null;
        char c = 0;
        int firstApiLevel = SystemProperties.getInt("ro.product.first_api_level", 0);
        FtUtil.log_d(this.CLASS_NAME, "handleCommand", "firstApiLevel:" + firstApiLevel);
        if (argu.length != (STAGE_PARALLEL ? this.NUM_ARGS + 1 : this.NUM_ARGS)) {
            return responseNA();
        }
        if (FtUtil.isFactoryBinary() && checkArgu(argu, new String[]{"0", "0", "0", "0"})) {
            FtUtil.log_i(this.CLASS_NAME, "Erase OCTA Count", "Start");
            resData = CheckAvaliablePin("UB_CONNECT") ? Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_OCTA, "0") ? responseOK(argu[0]) : responseNG(argu[0]) : responseNA();
        } else if (FtUtil.isFactoryBinary() && checkArgu(argu, new String[]{"0", "0", "0", EgisFingerprint.MAJOR_VERSION})) {
            FtUtil.log_i(this.CLASS_NAME, "Erase Camera Count", "Start");
            resData = CheckAvaliablePin("CAM_CONNECT") ? Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_CAMERA, "0") ? responseOK(argu[0]) : responseNG(argu[0]) : responseNA();
        } else if (FtUtil.isFactoryBinary() && checkArgu(argu, new String[]{"0", "0", "0", "2"})) {
            FtUtil.log_i(this.CLASS_NAME, "Erase SUB PBA Count", "Start");
            resData = CheckAvaliablePin("SUB_CONNECT") ? Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_SUBPBA, "0") ? responseOK(argu[0]) : responseNG(argu[0]) : responseNA();
        } else if (FtUtil.isFactoryBinary() && checkArgu(argu, new String[]{"0", EgisFingerprint.MAJOR_VERSION, "0", "0"})) {
            FtUtil.log_i(this.CLASS_NAME, "Start OCTA Cable Detect", "Start");
            if (!Support.Feature.getBoolean(Support.Feature.SUPPORT_CABLE_CONNECT_DETECT)) {
                return responseNA();
            } else if (CheckAvaliablePin("UB_CONNECT")) {
                try {
                    Support.Kernel.write(Support.Kernel.CABLE_DETECT_UB, EgisFingerprint.MAJOR_VERSION);
                    resData = responseOK(argu[0]);
                } catch (Exception e) {
                    resData = responseNG(argu[0]);
                }
            } else {
                resData = responseNA();
            }
        } else if (FtUtil.isFactoryBinary() && checkArgu(argu, new String[]{"0", EgisFingerprint.MAJOR_VERSION, "0", EgisFingerprint.MAJOR_VERSION})) {
            FtUtil.log_i(this.CLASS_NAME, "Start Camera Cable Detect", "Start");
            if (!Support.Feature.getBoolean(Support.Feature.SUPPORT_CABLE_CONNECT_DETECT)) {
                return responseNA();
            } else if (CheckAvaliablePin("CAM_CONNECT")) {
                try {
                    Support.Kernel.write(Support.Kernel.CABLE_DETECT_CONN, "CAM_CONNECT");
                    resData = responseOK(argu[0]);
                } catch (Exception e2) {
                    resData = responseNG(argu[0]);
                }
            } else {
                resData = responseNA();
            }
        } else if (FtUtil.isFactoryBinary() && checkArgu(argu, new String[]{"0", EgisFingerprint.MAJOR_VERSION, "0", "2"})) {
            FtUtil.log_i(this.CLASS_NAME, "Start SUB PBA Cable Detect", "Start");
            if (!Support.Feature.getBoolean(Support.Feature.SUPPORT_CABLE_CONNECT_DETECT)) {
                return responseNA();
            } else if (CheckAvaliablePin("SUB_CONNECT")) {
                try {
                    Support.Kernel.write(Support.Kernel.CABLE_DETECT_CONN, "SUB_CONNECT");
                    resData = responseOK(argu[0]);
                } catch (Exception e3) {
                    resData = responseNG(argu[0]);
                }
            } else {
                resData = responseNA();
            }
        } else if (FtUtil.isFactoryBinary() && checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION, "0", "0"})) {
            FtUtil.log_i(this.CLASS_NAME, "Read OCTA Count", "Start");
            if (CheckAvaliablePin("UB_CONNECT")) {
                String count = Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_OCTA, true);
                resData = count == null ? responseNG(argu[0]) : responseString(argu[0], count);
            } else {
                resData = responseNA();
            }
        } else if (FtUtil.isFactoryBinary() && checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION, "0", EgisFingerprint.MAJOR_VERSION})) {
            FtUtil.log_i(this.CLASS_NAME, "Read Camera Count", "Start");
            if (CheckAvaliablePin("CAM_CONNECT")) {
                String count2 = Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_CAMERA, true);
                resData = count2 == null ? responseNG(argu[0]) : responseString(argu[0], count2);
            } else {
                resData = responseNA();
            }
        } else if (FtUtil.isFactoryBinary() && checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION, "0", "2"})) {
            FtUtil.log_i(this.CLASS_NAME, "Read SUB PBA Count", "Start");
            if (CheckAvaliablePin("SUB_CONNECT")) {
                String count3 = Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_SUBPBA, true);
                resData = count3 == null ? responseNG(argu[0]) : responseString(argu[0], count3);
            } else {
                resData = responseNA();
            }
        } else if (FtUtil.isFactoryBinary() && checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "0", "0"})) {
            FtUtil.log_i(this.CLASS_NAME, "All Erase Count", "Start");
            boolean isFailed = false;
            for (String arg : argu[3].split("_")) {
                int nPinNum = -1;
                try {
                    nPinNum = Integer.parseInt(arg);
                } catch (NumberFormatException e4) {
                    FtUtil.log_e(e4);
                }
                String[][] strArr = this.CONNECTS;
                if (nPinNum > strArr.length || nPinNum < 0) {
                    FtUtil.log_i(this.CLASS_NAME, "All Read Count", "Wrong number " + nPinNum);
                    isFailed = true;
                } else if (CheckAvaliablePin(strArr[nPinNum][0])) {
                    FtUtil.log_i(this.CLASS_NAME, "All Erase Count", "Erase " + this.CONNECTS[nPinNum][0] + " Count");
                    if (!Support.Kernel.writeNsync(this.CONNECTS[nPinNum][1], "0")) {
                        isFailed = true;
                    }
                } else {
                    FtUtil.log_i(this.CLASS_NAME, "All Erase Count", "not available pin :" + nPinNum);
                }
            }
            resData = isFailed ? responseNG(argu[0]) : responseOK(argu[0]);
        } else if (FtUtil.isFactoryBinary() && checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "0", EgisFingerprint.MAJOR_VERSION})) {
            FtUtil.log_i(this.CLASS_NAME, "All Start Cable Detect", "Start");
            if (!Support.Feature.getBoolean(Support.Feature.SUPPORT_CABLE_CONNECT_DETECT)) {
                return responseNA();
            }
            boolean isFailed2 = false;
            for (String arg2 : argu[3].split("_")) {
                int nPinNum2 = -1;
                try {
                    nPinNum2 = Integer.parseInt(arg2);
                } catch (NumberFormatException e5) {
                    FtUtil.log_e(e5);
                }
                String[][] strArr2 = this.CONNECTS;
                if (nPinNum2 > strArr2.length || nPinNum2 < 0) {
                    FtUtil.log_i(this.CLASS_NAME, "All Read Count", "Wrong number " + nPinNum2);
                    isFailed2 = true;
                } else if (CheckAvaliablePin(strArr2[nPinNum2][0])) {
                    FtUtil.log_i(this.CLASS_NAME, "All Start Cable Detect", "Start " + this.CONNECTS[nPinNum2][0] + " Count");
                    try {
                        if ("UB_CONNECT".equals(this.CONNECTS[nPinNum2][0])) {
                            Support.Kernel.write(Support.Kernel.CABLE_DETECT_UB, EgisFingerprint.MAJOR_VERSION);
                        } else if ("UB_CONNECT_SUB".equals(this.CONNECTS[nPinNum2][0])) {
                            Support.Kernel.write(Support.Kernel.CABLE_DETECT_SUB_UB, EgisFingerprint.MAJOR_VERSION);
                        } else {
                            Support.Kernel.write(Support.Kernel.CABLE_DETECT_CONN, this.CONNECTS[nPinNum2][0]);
                        }
                    } catch (Exception e6) {
                        isFailed2 = true;
                    }
                } else {
                    FtUtil.log_i(this.CLASS_NAME, "All Start Cable Detect", "not available pin :" + nPinNum2);
                }
            }
            resData = isFailed2 ? responseNG(argu[0]) : responseOK(argu[0]);
        } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "0", "2"})) {
            if (!FtUtil.isFactoryBinary() && firstApiLevel < 28) {
                return responseNA();
            }
            FtUtil.log_i(this.CLASS_NAME, "All Read Count", "Start");
            List<String> counts = new ArrayList<>();
            String[] args = argu[3].split("_");
            StringBuffer resultData = new StringBuffer("");
            int length = args.length;
            int i = 0;
            while (i < length) {
                int nPinNum3 = -1;
                try {
                    nPinNum3 = Integer.parseInt(args[i]);
                } catch (NumberFormatException e7) {
                    FtUtil.log_e(e7);
                }
                String[][] strArr3 = this.CONNECTS;
                if (nPinNum3 > strArr3.length || nPinNum3 < 0) {
                    FtUtil.log_i(this.CLASS_NAME, "All Read Count", "Wrong number " + nPinNum3);
                } else if (CheckAvaliablePin(strArr3[nPinNum3][c])) {
                    FtUtil.log_i(this.CLASS_NAME, "All Read Count", "Start " + this.CONNECTS[nPinNum3][0] + " Count");
                    counts.add(Support.Kernel.read(this.CONNECTS[nPinNum3][1], true));
                } else {
                    FtUtil.log_i(this.CLASS_NAME, "All Read Count", "not available pin :" + nPinNum3);
                    counts.add("null");
                }
                i++;
                c = 0;
            }
            for (String count4 : counts) {
                resultData.append(count4);
                resultData.append(",");
            }
            if (TextUtils.isEmpty(resultData.toString())) {
                resData = responseNG(argu[0]);
            } else {
                resultData.deleteCharAt(resultData.length() - 1);
                resData = responseString(argu[0], resultData.toString().replace("null", "NA"));
            }
        } else if (FtUtil.isFactoryBinary() && checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.JAR_VERSION, egis.optical.client.api.EgisFingerprint.JAR_VERSION, "0"})) {
            FtUtil.log_i(this.CLASS_NAME, "Popup Enable", "Start");
            resData = Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_POPUP, "0") ? responseOK(argu[0]) : responseNG(argu[0]);
        } else if (FtUtil.isFactoryBinary() && checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.JAR_VERSION, egis.optical.client.api.EgisFingerprint.JAR_VERSION, EgisFingerprint.MAJOR_VERSION})) {
            FtUtil.log_i(this.CLASS_NAME, "Popup Disable", "Start");
            resData = Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_POPUP, EgisFingerprint.MAJOR_VERSION) ? responseOK(argu[0]) : responseNG(argu[0]);
        }
        return resData;
    }

    public boolean CheckAvaliablePin(String data) {
        String[] strArr = this.AVAILABLE_PINS;
        if (strArr == null) {
            return false;
        }
        for (String strAvailablePin : strArr) {
            if (TextUtils.equals(data, strAvailablePin)) {
                FtUtil.log_i(this.CLASS_NAME, "CheckAvaliablePin", "data=" + data + " / available=" + true);
                return true;
            }
        }
        return false;
    }
}
