package com.sec.factory.aporiented.athandler;

import android.app.ActivityManager;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.os.PowerManager;
import android.os.SystemProperties;
import android.provider.Settings;
import android.util.Log;
import com.sec.factory.aporiented.ResponseWriter;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.util.EnumMap;

public class AtDebugLvC extends AtCommandHandler {
    private static final String DEBUG_LEVEL_HIGH_STRING = "0x4948";
    private static final String DEBUG_LEVEL_LOW_STRING = "0x4f4c";
    private static final String DEBUG_LEVEL_MID_STRING = "0x494d";
    private static final String UNEXPECTED_OUTPUT = "-1";
    private String GPIO_DUMP_SYSFS;
    private String RESET_WAKE_SYSFS;
    private String RESET_WAKE_SYSFS_VALUE;
    private Context mContext;
    private EnumMap<SystemData, String> sysDataValueMap = new EnumMap<>(SystemData.class);

    public AtDebugLvC(Context context) {
        super(context);
        this.CMD_NAME = "DEBUGLVC";
        this.CLASS_NAME = "AtDebuglvc";
        this.NUM_ARGS = 2;
        this.mContext = context;
        setGpioDumpSysfsPath();
        setResetWakeSysfsPath();
    }

    public AtDebugLvC(Context context, ResponseWriter writer, int commandType) {
        super(context);
        this.CMD_NAME = "DEBUGLVC";
        this.CLASS_NAME = "AtDebuglvc";
        this.NUM_ARGS = 2;
        this.writer = writer;
        this.mCommandType = commandType;
        this.mContext = context;
        setGpioDumpSysfsPath();
        setResetWakeSysfsPath();
    }

    private void setGpioDumpSysfsPath() {
        if (Support.Kernel.isExistFilePath("/sys/module/lpm_levels/parameters/secdebug")) {
            this.GPIO_DUMP_SYSFS = "/sys/module/lpm_levels/parameters/secdebug";
        } else {
            this.GPIO_DUMP_SYSFS = "/sys/class/sec/ap_pmic/gpio_dump";
        }
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setGpioDumpSysfsPath", "GPIO_DUMP_SYSFS is " + this.GPIO_DUMP_SYSFS);
    }

    private void setResetWakeSysfsPath() {
        if (Support.Kernel.isExistFilePath("/sys/module/qpnp_power_on/parameters/wake_enabled")) {
            this.RESET_WAKE_SYSFS = "/sys/module/qpnp_power_on/parameters/wake_enabled";
            this.RESET_WAKE_SYSFS_VALUE = "Y";
        } else {
            this.RESET_WAKE_SYSFS = "/sys/class/sec/ap_pmic/wake_enabled";
            this.RESET_WAKE_SYSFS_VALUE = EgisFingerprint.MAJOR_VERSION;
        }
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setResetWakeSysfsPath", "RESET_WAKE_SYSFS is " + this.RESET_WAKE_SYSFS + ", RESET_WAKE_SYSFS_VALUE is " + this.RESET_WAKE_SYSFS_VALUE);
    }

    @Override // com.sec.factory.aporiented.athandler.AtCommandHandler
    public synchronized String handleCommand(String[] argu) {
        String resData = null;
        if (argu.length != (STAGE_PARALLEL ? this.NUM_ARGS + 1 : this.NUM_ARGS)) {
            return this.mCommandType == 1 ? "NA" : responseNA();
        }
        if (this.mCommandType == 1) {
            this.writer.write(echoString(argu));
        }
        String className = null;
        try {
            className = ((ActivityManager) this.context.getSystemService("activity")).getRunningTasks(1).get(0).topActivity.getClassName();
            String str = this.CMD_NAME;
            StringBuilder sb = new StringBuilder();
            sb.append("Top activity class name = ");
            sb.append(className == null ? "null" : className);
            Log.i(str, sb.toString());
        } catch (Exception e) {
            String str2 = this.CMD_NAME;
            Log.i(str2, "Exception : " + e);
        }
        if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "2"})) {
            String ramdumpValue = SystemProperties.get("ro.boot.debug_level", Support.Properties.PROPERTIES_DEFAULT_STRING);
            String uploadValue = SystemProperties.get("ro.boot.force_upload", Support.Properties.PROPERTIES_DEFAULT_STRING);
            String str3 = this.CMD_NAME;
            FtUtil.log_i(str3, "handleCommand", "Debug: " + ramdumpValue + "Upload: " + uploadValue);
            String ramdumpState = getDebugLevel(ramdumpValue);
            String uploadState = "0x5".equalsIgnoreCase(uploadValue) ? "ENABLE" : "DISABLE";
            String str4 = argu[0];
            return responseString(str4, ramdumpState + "," + uploadState);
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.MAJOR_VERSION})) {
            initSysDataMap();
            return responseString(argu[0], readAllSysData());
        } else {
            if ("factory".equalsIgnoreCase(Support.Properties.get(Support.Properties.BINARY_TYPE))) {
                if (checkArgu(argu, new String[]{"0", EgisFingerprint.MAJOR_VERSION})) {
                    reqestChangeLevel(DEBUG_LEVEL_MID_STRING);
                    resData = responseOK(argu[0]);
                } else if (checkArgu(argu, new String[]{"0", "2"})) {
                    reqestChangeLevel(DEBUG_LEVEL_HIGH_STRING);
                    resData = responseOK(argu[0]);
                } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "0"})) {
                    String ramdumpstate = SystemProperties.get("ro.boot.debug_level", Support.Properties.PROPERTIES_DEFAULT_STRING);
                    if (DEBUG_LEVEL_LOW_STRING.equals(ramdumpstate)) {
                        ramdumpstate = "LOW";
                    } else if (DEBUG_LEVEL_MID_STRING.equals(ramdumpstate)) {
                        ramdumpstate = "MID";
                    } else if (DEBUG_LEVEL_HIGH_STRING.equals(ramdumpstate)) {
                        ramdumpstate = "HIGH";
                    }
                    resData = responseString(argu[0], ramdumpstate);
                } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION})) {
                    String mode = Build.TYPE;
                    resData = mode != null ? responseString(argu[0], mode) : responseNG(argu[0]);
                } else if (checkArgu(argu, new String[]{"0", "5"})) {
                    Settings.Global.putInt(this.context.getContentResolver(), "development_settings_enabled", 1);
                    Settings.Global.putInt(this.context.getContentResolver(), "adb_enabled", 1);
                    resData = responseOK(argu[0]);
                } else if (checkArgu(argu, new String[]{"0", "6"})) {
                    Settings.Global.putInt(this.context.getContentResolver(), "development_settings_enabled", 1);
                    Settings.Global.putInt(this.context.getContentResolver(), "adb_enabled", 0);
                    resData = responseOK(argu[0]);
                } else if (checkArgu(argu, new String[]{"0", "7"})) {
                    Intent mIntent = new Intent("com.sec.modem.settings.cplogging.SilentLog.SILENT_LOG_START");
                    mIntent.addFlags(16777216);
                    this.mContext.sendBroadcast(mIntent);
                    FtUtil.Sleep.sleep(1000);
                    resData = "ON".equalsIgnoreCase(SystemProperties.get("dev.silentlog.on", Support.Properties.PROPERTIES_DEFAULT_STRING)) ? responseOK(argu[0]) : responseNG(argu[0]);
                } else if (checkArgu(argu, new String[]{"0", "8"})) {
                    Intent mIntent2 = new Intent("com.sec.modem.settings.cplogging.SilentLog.SILENT_LOG_STOP");
                    mIntent2.addFlags(16777216);
                    this.mContext.sendBroadcast(mIntent2);
                    FtUtil.Sleep.sleep(3000);
                    String str5 = this.CMD_NAME;
                    Log.i(str5, "Set debug: " + SystemProperties.get("dev.silentlog.on", Support.Properties.PROPERTIES_DEFAULT_STRING));
                    resData = "ON".equalsIgnoreCase(SystemProperties.get("dev.silentlog.on", Support.Properties.PROPERTIES_DEFAULT_STRING)) ? responseNG(argu[0]) : responseOK(argu[0]);
                } else {
                    resData = this.mCommandType == 1 ? "NA" : responseNA();
                }
            } else if (className != null && className.contains("com.sec.android.app.hwmoduletest.HwModuleTest")) {
                if (checkArgu(argu, new String[]{"0", "5"})) {
                    Settings.Global.putInt(this.context.getContentResolver(), "development_settings_enabled", 1);
                    Settings.Global.putInt(this.context.getContentResolver(), "adb_enabled", 1);
                    resData = responseOK(argu[0]);
                } else if (checkArgu(argu, new String[]{"0", "6"})) {
                    Settings.Global.putInt(this.context.getContentResolver(), "development_settings_enabled", 1);
                    Settings.Global.putInt(this.context.getContentResolver(), "adb_enabled", 0);
                    resData = responseOK(argu[0]);
                } else {
                    resData = this.mCommandType == 1 ? "NA" : responseNA();
                }
            }
            return resData;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void doRebootNSave(String state) {
        String androiddebug = "debug" + state;
        Log.i(this.CMD_NAME, "Set debug: " + androiddebug);
        ((PowerManager) this.context.getSystemService("power")).reboot(androiddebug);
    }

    public void reqestChangeLevel(final String level) {
        new Thread(new Runnable() {
            /* class com.sec.factory.aporiented.athandler.AtDebugLvC.AnonymousClass1 */

            public void run() {
                try {
                    Thread.sleep(500);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
                AtDebugLvC.this.doRebootNSave(level);
            }
        }).start();
    }

    private String getDebugLevel(String value) {
        if (DEBUG_LEVEL_LOW_STRING.equals(value)) {
            return "LOW";
        }
        if (DEBUG_LEVEL_MID_STRING.equals(value)) {
            return "MID";
        }
        if (DEBUG_LEVEL_HIGH_STRING.equals(value)) {
            return "HIGH";
        }
        return Support.Properties.PROPERTIES_DEFAULT_STRING;
    }

    /* access modifiers changed from: private */
    public enum SystemData {
        LOW_BATT_DUMP("Low Battery Dump", "0"),
        RESET_WO_WAKEUP("Reset without Wakeup", "0"),
        GPIO_DUMP("GPIO Dump", "0"),
        WLAN_UPLOAD_MODE("WLAN Upload Mode", "2"),
        BT_SCO_DUMP("Bluetooth SCO Dump", "0"),
        CHG_MODE("Charging Mode", "0"),
        UCS_MODE("UCS Mode", "0"),
        DEBUG_LEVEL("Debug Level", "LOW"),
        FORCE_UPLOAD("Force Upload", "Disable");
        
        private String dataName = "";
        private String requiredVal = "";

        private SystemData(String dataName2, String requiredVal2) {
            this.dataName = dataName2;
            this.requiredVal = requiredVal2;
        }

        public String getName() {
            return this.dataName;
        }

        public String getRequiredVal() {
            return this.requiredVal;
        }
    }

    private void initSysDataMap() {
        SystemData[] values = SystemData.values();
        for (SystemData systemdata : values) {
            if (!(systemdata == SystemData.DEBUG_LEVEL || systemdata == SystemData.FORCE_UPLOAD)) {
                this.sysDataValueMap.put(systemdata, convertReadValue(systemdata, getResultValue(systemdata).trim()));
            }
        }
    }

    private String getResultValue(SystemData systemdata) {
        String readValue = readValueFromSource(systemdata);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getResultValue", "SystemData: " + systemdata.getName() + " readValue: " + readValue);
        boolean isValueValid = readValue != null && !readValue.equalsIgnoreCase(Support.Properties.PROPERTIES_DEFAULT_STRING) && !readValue.matches("\\s*");
        if (!isSupported(systemdata)) {
            if (systemdata == SystemData.WLAN_UPLOAD_MODE) {
                return systemdata.getRequiredVal();
            }
            if (isValueValid) {
                return "-1";
            }
            return systemdata.getRequiredVal();
        } else if (isValueValid) {
            return readValue;
        } else {
            return "-1";
        }
    }

    /* access modifiers changed from: package-private */
    /* renamed from: com.sec.factory.aporiented.athandler.AtDebugLvC$2  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass2 {
        static final /* synthetic */ int[] $SwitchMap$com$sec$factory$aporiented$athandler$AtDebugLvC$SystemData;

        static {
            int[] iArr = new int[SystemData.values().length];
            $SwitchMap$com$sec$factory$aporiented$athandler$AtDebugLvC$SystemData = iArr;
            try {
                iArr[SystemData.RESET_WO_WAKEUP.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$com$sec$factory$aporiented$athandler$AtDebugLvC$SystemData[SystemData.BT_SCO_DUMP.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$com$sec$factory$aporiented$athandler$AtDebugLvC$SystemData[SystemData.GPIO_DUMP.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$com$sec$factory$aporiented$athandler$AtDebugLvC$SystemData[SystemData.WLAN_UPLOAD_MODE.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$com$sec$factory$aporiented$athandler$AtDebugLvC$SystemData[SystemData.LOW_BATT_DUMP.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$com$sec$factory$aporiented$athandler$AtDebugLvC$SystemData[SystemData.CHG_MODE.ordinal()] = 6;
            } catch (NoSuchFieldError e6) {
            }
            try {
                $SwitchMap$com$sec$factory$aporiented$athandler$AtDebugLvC$SystemData[SystemData.UCS_MODE.ordinal()] = 7;
            } catch (NoSuchFieldError e7) {
            }
            try {
                $SwitchMap$com$sec$factory$aporiented$athandler$AtDebugLvC$SystemData[SystemData.DEBUG_LEVEL.ordinal()] = 8;
            } catch (NoSuchFieldError e8) {
            }
            try {
                $SwitchMap$com$sec$factory$aporiented$athandler$AtDebugLvC$SystemData[SystemData.FORCE_UPLOAD.ordinal()] = 9;
            } catch (NoSuchFieldError e9) {
            }
        }
    }

    private String convertReadValue(SystemData systemdata, String readvalue) {
        switch (AnonymousClass2.$SwitchMap$com$sec$factory$aporiented$athandler$AtDebugLvC$SystemData[systemdata.ordinal()]) {
            case 1:
                if (readvalue.equalsIgnoreCase(this.RESET_WAKE_SYSFS_VALUE)) {
                    return systemdata.getRequiredVal();
                }
                return EgisFingerprint.MAJOR_VERSION;
            case 2:
                if (readvalue.equalsIgnoreCase("TRUE") || readvalue.equalsIgnoreCase("AUTO_TRUE")) {
                    return EgisFingerprint.MAJOR_VERSION;
                }
                return systemdata.getRequiredVal();
            default:
                return readvalue;
        }
    }

    private boolean isSupported(SystemData systemdata) {
        switch (AnonymousClass2.$SwitchMap$com$sec$factory$aporiented$athandler$AtDebugLvC$SystemData[systemdata.ordinal()]) {
            case 1:
            case 3:
                return "Qualcomm".equalsIgnoreCase(Support.Feature.getString(Support.Feature.CHIPSET_MANUFACTURE));
            case 2:
            default:
                return true;
            case 4:
                return "true".equals(SystemProperties.get("ro.product_ship", "false").trim());
        }
    }

    private String readValueFromSource(SystemData systemdata) {
        switch (AnonymousClass2.$SwitchMap$com$sec$factory$aporiented$athandler$AtDebugLvC$SystemData[systemdata.ordinal()]) {
            case 1:
                return Support.Kernel.readFromPath(this.RESET_WAKE_SYSFS, false);
            case 2:
                String result = Support.Properties.getProp("persist.bluetooth.scodump");
                String str = this.CLASS_NAME;
                FtUtil.log_d(str, "readValueFromSource()", systemdata.getName() + " : " + result);
                if (Support.Properties.PROPERTIES_DEFAULT_STRING.equalsIgnoreCase(result)) {
                    return systemdata.getRequiredVal();
                }
                return result;
            case 3:
                return Support.Kernel.readFromPath(this.GPIO_DUMP_SYSFS, false);
            case 4:
                return Support.Kernel.readFromPath("/sys/wifi/memdump", false);
            case 5:
                try {
                    return String.valueOf(Settings.System.getInt(this.mContext.getContentResolver(), "LOW_BATTERY_DUMP"));
                } catch (Settings.SettingNotFoundException e) {
                    FtUtil.log_d(this.CLASS_NAME, "readValueFromSource()", "Setting Not Found: Normal Operation");
                    return systemdata.getRequiredVal();
                }
            case 6:
                return Support.Kernel.read(Support.Kernel.AFC_DISABLE, false);
            case 7:
                return Support.Properties.getProp("ro.boot.ucs_mode");
            default:
                FtUtil.log_d(this.CLASS_NAME, "readValueFromSource()", "InValid system data");
                return "";
        }
    }

    private String readAllSysData() {
        StringBuilder strBuilder = new StringBuilder();
        for (SystemData systemdata : this.sysDataValueMap.keySet()) {
            strBuilder.append(this.sysDataValueMap.get(systemdata));
            strBuilder.append(",");
        }
        strBuilder.deleteCharAt(strBuilder.lastIndexOf(","));
        return strBuilder.toString();
    }
}
