package com.sec.factory.aporiented.athandler;

import android.content.Context;
import android.provider.Settings;
import com.sec.factory.aporiented.ResponseWriter;
import com.sec.factory.common.CommonFingerprintGoodix;
import com.sec.factory.modules.ModuleForceTouch;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.io.File;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Locale;

public class AtFpsensorGoodix extends AtCommandHandler {
    private CommonFingerprintGoodix mCommonFingerprintGoodix;
    private Context mContext;

    public AtFpsensorGoodix(Context context, ResponseWriter writer) {
        super(context);
        this.CMD_NAME = "FPSENSOR";
        this.CLASS_NAME = "AtFpsensorGoodix";
        this.NUM_ARGS = 3;
        this.writer = writer;
        this.mContext = context;
        this.mCommonFingerprintGoodix = CommonFingerprintGoodix.instance(context);
    }

    @Override // com.sec.factory.aporiented.athandler.AtCommandHandler
    public synchronized String handleCommand(String[] argu) {
        File[] arrFile;
        if (argu.length != (STAGE_PARALLEL ? this.NUM_ARGS + 1 : this.NUM_ARGS)) {
            return responseNA();
        }
        String resData = null;
        if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "2", "0"})) {
            String[] arrUserIdList = this.mCommonFingerprintGoodix.getUserIdList();
            if (arrUserIdList == null || arrUserIdList.length == 0) {
                resData = responseString(argu[0], "OFF");
            } else {
                resData = responseString(argu[0], "ON");
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "0"})) {
            ArrayList<CommonFingerprintGoodix.FpTestItem> listFpTestItemNormalScan = this.mCommonFingerprintGoodix.startNormalScan();
            StringBuilder sb = new StringBuilder();
            boolean isAllPass = true;
            Iterator<CommonFingerprintGoodix.FpTestItem> it = listFpTestItemNormalScan.iterator();
            while (it.hasNext()) {
                CommonFingerprintGoodix.FpTestItem item = it.next();
                if (!item.getIsPass()) {
                    isAllPass = false;
                }
                sb.append(item.getTestResult());
                sb.append(",");
            }
            sb.deleteCharAt(sb.lastIndexOf(","));
            if (isAllPass) {
                sb.insert(0, "OK_");
            } else {
                sb.insert(0, "NG_");
            }
            resData = responseString(argu[0], sb.toString());
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "4", "2"})) {
            String sensorUid = null;
            String efsUid = null;
            String calibration = null;
            Iterator<CommonFingerprintGoodix.FpTestItem> it2 = this.mCommonFingerprintGoodix.getSensorInfo().iterator();
            while (it2.hasNext()) {
                CommonFingerprintGoodix.FpTestItem item2 = it2.next();
                String testName = item2.getTestName();
                if ("Sensor UID".equalsIgnoreCase(testName)) {
                    sensorUid = item2.getTestResult();
                    if (sensorUid != null) {
                        sensorUid = sensorUid.replaceAll(" ", "").toUpperCase();
                    }
                } else if ("EFS UID".equalsIgnoreCase(testName)) {
                    efsUid = item2.getTestResult();
                    if (efsUid != null) {
                        efsUid = efsUid.replaceAll(" ", "").toUpperCase();
                    }
                } else if ("Calibration".equalsIgnoreCase(testName)) {
                    calibration = item2.getTestResult();
                }
            }
            String currCellId = Support.Kernel.read(Support.Kernel.OCTA_MANUFACTURE_CODE);
            String savedCellId = Support.Kernel.read(Support.Kernel.FINGERPRINT_CELL_ID_WHEN_CALIBRATION);
            if (currCellId != null) {
                currCellId = currCellId.toUpperCase(Locale.ENGLISH);
            }
            if (savedCellId != null) {
                savedCellId = savedCellId.toUpperCase(Locale.ENGLISH);
            }
            boolean isMatchedCellId = false;
            if (currCellId != null) {
                isMatchedCellId = currCellId.equals(savedCellId);
            }
            boolean isOk = false;
            if (sensorUid != null) {
                isOk = sensorUid.equals(efsUid) && "0".equals(calibration) && isMatchedCellId;
            }
            StringBuilder sb2 = new StringBuilder();
            sb2.append(isOk ? "OK" : "NG");
            sb2.append(",");
            sb2.append(sensorUid);
            sb2.append(",");
            sb2.append(efsUid);
            sb2.append(",");
            sb2.append("0".equals(calibration) ? EgisFingerprint.MAJOR_VERSION : "0");
            sb2.append(",");
            sb2.append(currCellId);
            sb2.append(",");
            sb2.append(savedCellId);
            resData = responseString(argu[0], sb2.toString());
        }
        if (!FtUtil.isFactoryBinary()) {
            if (resData == null) {
                resData = responseNA();
            }
            return resData;
        }
        if (checkArgu(argu, new String[]{"0", "2", EgisFingerprint.MAJOR_VERSION})) {
            boolean isErased = true;
            File fileCalDir = new File("/efs/biometrics/meta");
            if (fileCalDir.exists() && (arrFile = fileCalDir.listFiles()) != null) {
                for (File file : arrFile) {
                    if (!file.delete()) {
                        FtUtil.log_d(this.CLASS_NAME, "handleCommand", "can not delete : " + file.getName());
                        isErased = false;
                    }
                }
            }
            if (!isErased) {
                resData = responseString(argu[0], "NG_CALDATA");
            } else {
                resData = responseOK(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "0", "0"})) {
            String sensorUid2 = "0";
            String productId = "0";
            String moduleTest = "NG";
            Iterator<CommonFingerprintGoodix.FpTestItem> it3 = this.mCommonFingerprintGoodix.getSensorInfo().iterator();
            while (it3.hasNext()) {
                CommonFingerprintGoodix.FpTestItem item3 = it3.next();
                String testName2 = item3.getTestName();
                if ("Sensor UID".equalsIgnoreCase(testName2)) {
                    sensorUid2 = item3.getTestResult();
                    if (sensorUid2 != null) {
                        sensorUid2 = sensorUid2.replaceAll(" ", "").toUpperCase();
                    }
                } else if ("Product Id".equalsIgnoreCase(testName2) || "UI Product ID".equalsIgnoreCase(testName2)) {
                    productId = item3.getTestResult();
                } else if (("MT Check".equalsIgnoreCase(testName2) || "Module Test".equalsIgnoreCase(testName2)) && "0".equals(item3.getTestResult())) {
                    moduleTest = "OK";
                }
            }
            resData = responseString(argu[0], sensorUid2 + "_" + productId + "_" + "0" + "_" + moduleTest);
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "4", "0"})) {
            boolean isPassNormalScan = false;
            boolean isPassCalibration = false;
            boolean isExistNormalLog = Support.Kernel.isExistFilePath("/data/log/FingerNormalData.log");
            boolean isExistCalibrationLog = Support.Kernel.isExistFilePath("/data/log/FingerSNRData.log");
            String strNormalData = Support.Kernel.readFromPath("/data/log/FingerNormalData.log", true);
            String strCalibrationData = Support.Kernel.readFromPath("/data/log/FingerSNRData.log", true);
            if (strNormalData != null) {
                if (strNormalData.contains("PASS")) {
                    isPassNormalScan = true;
                }
                strNormalData = strNormalData.substring(5);
            }
            if (strCalibrationData != null) {
                if (strCalibrationData.contains("PASS")) {
                    isPassCalibration = true;
                }
                strCalibrationData = strCalibrationData.substring(5);
            }
            StringBuilder sb3 = new StringBuilder();
            sb3.append(Support.Kernel.read(Support.Kernel.FINGERPRINT_VENDOR));
            sb3.append(",");
            sb3.append(Support.Kernel.read(Support.Kernel.FINGERPRINT_CHIP_NAME));
            sb3.append(",");
            sb3.append(this.mCommonFingerprintGoodix.getConceptVersion());
            sb3.append("_");
            sb3.append(strNormalData);
            sb3.append("_");
            sb3.append(strCalibrationData);
            if (!isExistNormalLog || !isExistCalibrationLog) {
                sb3.insert(0, "NONE,");
            } else if (!isPassNormalScan || !isPassCalibration) {
                sb3.insert(0, "NG,");
            } else {
                sb3.insert(0, "OK,");
            }
            resData = responseString(argu[0], sb3.toString());
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "4", EgisFingerprint.MAJOR_VERSION})) {
            String step = Settings.System.getString(this.mContext.getContentResolver(), "fp_test_step");
            String status = Settings.System.getString(this.mContext.getContentResolver(), "fp_test_status");
            FtUtil.log_d(this.CLASS_NAME, "handleCommand", "step : " + step + "/ status : " + status);
            if (this.mCommonFingerprintGoodix.isOptical()) {
                if ("CHART".equals(step) && "READY".equals(status)) {
                    resData = responseString(argu[0], "OK");
                } else if (!"DARK".equals(step) || !ModuleForceTouch.RUNNING.equals(status)) {
                    resData = responseString(argu[0], "NG");
                } else {
                    resData = responseString(argu[0], "WAIT");
                }
            } else if ("NORMALSCAN".equals(step)) {
                resData = responseString(argu[0], "WAIT");
            } else if (!"SNR".equals(step) || !"READY".equals(status)) {
                resData = responseString(argu[0], "NG");
            } else {
                resData = responseString(argu[0], "OK");
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "4", egis.optical.client.api.EgisFingerprint.MAJOR_VERSION})) {
            String step2 = Settings.System.getString(this.mContext.getContentResolver(), "fp_test_step");
            String status2 = Settings.System.getString(this.mContext.getContentResolver(), "fp_test_status");
            FtUtil.log_d(this.CLASS_NAME, "handleCommand", "step : " + step2 + "/ status : " + status2);
            if ("NORMALSCAN".equals(step2)) {
                resData = responseString(argu[0], "WAIT");
            } else if (!"FLESH".equals(step2) || !"READY".equals(status2)) {
                resData = responseString(argu[0], "NG");
            } else {
                resData = responseString(argu[0], "OK");
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "4", "4"})) {
            String step3 = Settings.System.getString(this.mContext.getContentResolver(), "fp_test_step");
            String status3 = Settings.System.getString(this.mContext.getContentResolver(), "fp_test_status");
            FtUtil.log_d(this.CLASS_NAME, "handleCommand", "step : " + step3 + "/ status : " + status3);
            if ("DARK".equals(step3) && "READY".equals(status3)) {
                resData = responseString(argu[0], "OK");
            } else if (!"FLESH".equals(step3) || !ModuleForceTouch.RUNNING.equals(status3)) {
                resData = responseString(argu[0], "NG");
            } else {
                resData = responseString(argu[0], "WAIT");
            }
        }
        if (resData == null) {
            resData = responseNA();
        }
        return resData;
    }
}
