package com.sec.factory.aporiented.athandler;

import android.content.Context;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;

public class AtHwindick extends AtCommandHandler {
    public AtHwindick(Context context) {
        super(context);
        this.CMD_NAME = "HWINDICK";
        this.CLASS_NAME = "AtHwindick";
        this.NUM_ARGS = 2;
    }

    @Override // com.sec.factory.aporiented.athandler.AtCommandHandler
    public synchronized String handleCommand(String[] argu) {
        String resData;
        if (argu.length != (STAGE_PARALLEL ? this.NUM_ARGS + 1 : this.NUM_ARGS)) {
            return responseNA();
        }
        if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "0"})) {
            resData = responseString(argu[0], mModuleCommon.getHWRevision());
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION})) {
            resData = responseString(argu[0], mModuleCommon.readLcdType());
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "2"})) {
            resData = responseString(argu[0], mModuleCommon.readSubLcdType());
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.MAJOR_VERSION})) {
            if (FtUtil.isFactoryBinary()) {
                String slavePcbType = Support.Properties.get(Support.Properties.SLAVE_PCB_ID);
                if (!Support.Properties.PROPERTIES_DEFAULT_STRING.equalsIgnoreCase(slavePcbType)) {
                    resData = responseString(argu[0], slavePcbType);
                } else {
                    resData = "NOT_APPLICABLE";
                }
            } else {
                resData = "NOT_APPLICABLE";
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "4"})) {
            resData = responseString(argu[0], mModuleCommon.readOCTAManufactureCode());
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "5"})) {
            resData = "NOT_APPLICABLE";
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "6"})) {
            resData = "NOT_APPLICABLE";
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "7"})) {
            resData = "NOT_APPLICABLE";
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "8"})) {
            if (FtUtil.isFactoryBinary()) {
                String subPcbType = Support.Properties.get(Support.Properties.SUB_PCB_ID);
                if (!Support.Properties.PROPERTIES_DEFAULT_STRING.equalsIgnoreCase(subPcbType)) {
                    resData = responseString(argu[0], subPcbType);
                } else {
                    String sysfsSubPcbType = Support.Kernel.read(Support.Kernel.SUBFPCB_TYPE);
                    if (sysfsSubPcbType != null) {
                        resData = responseString(argu[0], sysfsSubPcbType);
                    } else {
                        resData = "NOT_APPLICABLE";
                    }
                }
            } else {
                resData = "NOT_APPLICABLE";
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.JAR_VERSION})) {
            resData = responseString(argu[0], mModuleCommon.readSubOCTAManufactureCode());
        } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "0"})) {
            if ("QUALCOMM".equalsIgnoreCase(Support.Feature.getString(Support.Feature.CHIPSET_MANUFACTURE))) {
                resData = responseString(argu[0], Support.Properties.get(Support.Properties.BACK_COVER_TYPE));
            } else {
                resData = "NOT_APPLICABLE";
            }
        } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION})) {
            String apPcbType = Support.Properties.get(Support.Properties.AP_PCB_ID);
            if (!Support.Properties.PROPERTIES_DEFAULT_STRING.equalsIgnoreCase(apPcbType)) {
                resData = responseString(argu[0], apPcbType);
            } else {
                resData = "NOT_APPLICABLE";
            }
        } else if (checkArgu(argu, new String[]{"4"})) {
            String[] numbers = argu[1].split("_");
            StringBuffer stringBuffer = new StringBuffer();
            for (String str : numbers) {
                String ret = mModuleDevice.readGPIO(str);
                if ("".equals(ret)) {
                    stringBuffer.append("NG");
                } else {
                    stringBuffer.append(ret);
                }
                stringBuffer.append(",");
            }
            if (stringBuffer.length() > 0) {
                stringBuffer.deleteCharAt(stringBuffer.length() - 1);
            }
            resData = responseString(argu[0], stringBuffer.toString());
        } else if (checkArgu(argu, new String[]{"5"})) {
            resData = "NOT_APPLICABLE";
        } else if (checkArgu(argu, new String[]{"6"})) {
            String[] numbers2 = argu[1].split("_");
            String result = "NG";
            new StringBuffer();
            for (String str2 : numbers2) {
                String ret2 = mModuleDevice.setGPIO(str2);
                if (!"OK".equals(ret2)) {
                    result = result + "," + ret2;
                }
            }
            if ("NG".equals(result)) {
                resData = responseOK(argu[0]);
            } else {
                resData = responseString(argu[0], result);
            }
        } else if (checkArgu(argu, new String[]{"7"})) {
            resData = "NOT_APPLICABLE";
        } else {
            resData = responseNA();
        }
        return resData;
    }
}
