package com.sec.factory.aporiented.athandler;

import android.content.Context;
import android.content.Intent;
import android.os.PowerManager;
import android.os.SystemClock;
import android.text.TextUtils;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.optical.client.api.EgisFingerprint;

public class AtSensorHb extends AtCommandHandler {
    private static final String ACTION_WAKE_UP = "com.sec.factory.aporiented.athandler.AtSensorHb.WakeUp";
    private static final String RTC_OFF = "android.intent.action.START_FACTORY_TEST";
    private static final String RTC_ON = "android.intent.action.STOP_FACTORY_TEST";

    public AtSensorHb(Context context) {
        super(context);
        this.CMD_NAME = "SENSORHB";
        this.CLASS_NAME = "AtSensorHb";
        this.NUM_ARGS = 3;
    }

    @Override // com.sec.factory.aporiented.athandler.AtCommandHandler
    public synchronized String handleCommand(String[] argu) {
        String resData;
        boolean isPreviousFullWakelock = false;
        if (argu.length != (STAGE_PARALLEL ? this.NUM_ARGS + 1 : this.NUM_ARGS)) {
            return responseNA();
        }
        if (checkArgu(argu, new String[]{"0", "0", "0"})) {
            FtUtil.log_i(this.CLASS_NAME, "handleCommand", "start SensorHub test");
            boolean isAcquireWakelock = mModulePower.isHeldWakeLock();
            isPreviousFullWakelock = isAcquireWakelock;
            String str = this.CLASS_NAME;
            FtUtil.log_i(str, "handleCommand", "isAcquireWakelock: " + isAcquireWakelock);
            this.context.sendBroadcast(new Intent(RTC_ON));
            FtUtil.log_i(this.CLASS_NAME, "handleCommand", "AlarmManager Enable");
            mModulePower.doPartialWakeLock(true);
            mModulePower.doWakeLock(false);
            if (Support.Feature.getBoolean(Support.Feature.NEED_LPA_MODE_SET)) {
                mModuleDevice.setLPAmode(ModuleDevice.LPA_MODE_DISABLE);
            }
            mModuleDevice.startSensorHubTest();
            ((PowerManager) this.context.getSystemService("power")).goToSleep(SystemClock.uptimeMillis());
            try {
                Thread.sleep(5000);
            } catch (InterruptedException e) {
            }
            if (Support.Feature.getBoolean(Support.Feature.NEED_LPA_MODE_SET)) {
                mModuleDevice.setLPAmode(ModuleDevice.LPA_MODE_ENABLE);
            }
            this.context.sendBroadcast(new Intent(RTC_OFF));
            FtUtil.log_i(this.CLASS_NAME, "handleCommand", "AlarmManager disable");
            String[] result = new String[3];
            result[1] = "NG";
            result[2] = "OK";
            try {
                String sensorHubResult = mModuleDevice.readSensorHubResult();
                if (sensorHubResult != null) {
                    result = sensorHubResult.split(",");
                } else {
                    FtUtil.log_i(this.CLASS_NAME, "handleCommand", "Firmware is broken - no sysfs");
                }
            } catch (Exception e2) {
                FtUtil.log_e(e2);
            }
            String str2 = this.CLASS_NAME;
            FtUtil.log_i(str2, "handleCommand", "MCU name: " + result[0] + "  /  Selftest: " + result[1] + "  /  INT pin: " + result[2]);
            resData = responseString(argu[0], "NG_SELF");
            if ("OK".equals(result[1]) && "OK".equals(result[2])) {
                String str3 = argu[0];
                resData = responseString(str3, "OK_" + result[0]);
            } else if ("NG".equals(result[0])) {
                resData = responseString(argu[0], "NG_SELF");
            } else if ("NG".equals(result[1]) && "NG".equals(result[2])) {
                resData = responseString(argu[0], "NG_INT");
            } else if ("OK".equals(result[1]) && "NG".equals(result[2])) {
                resData = responseString(argu[0], "NG_INT");
            } else if ("NG".equals(result[1]) && "OK".equals(result[2])) {
                resData = responseString(argu[0], "NG_SELF");
            }
        } else if (checkArgu(argu, new String[]{"0", "0", EgisFingerprint.MAJOR_VERSION})) {
            FtUtil.log_i(this.CLASS_NAME, "handleCommand", "start SensorHub SLPI reset");
            resData = Support.Kernel.write(Support.Kernel.SLPI_RESET, "4") ? responseOK(argu[0]) : responseNG(argu[0]);
        } else if (checkArgu(argu, new String[]{egis.client.api.EgisFingerprint.MAJOR_VERSION, "0", "0"})) {
            FtUtil.log_i(this.CLASS_NAME, "handleCommand", "start SensorHub ddi spi check");
            Support.Kernel.write(Support.Kernel.DDI_MIPI_CONTROL, egis.client.api.EgisFingerprint.MAJOR_VERSION);
            FtUtil.Sleep.sleep(100);
            String value = Support.Kernel.read(Support.Kernel.SENSORHUB_DDI_SPI_CHECK);
            Support.Kernel.write(Support.Kernel.DDI_MIPI_CONTROL, "0");
            resData = TextUtils.isEmpty(value) ? responseNG(argu[0]) : responseString(argu[0], value);
        } else {
            resData = responseNA();
        }
        mModulePower.doWakeLock(true);
        mModulePower.doPartialWakeLock(false);
        if (!isPreviousFullWakelock) {
            FtUtil.log_i(this.CLASS_NAME, "handleCommand", "Restore Wakelock State");
            mModulePower.doPartialWakeLock(true);
            mModulePower.doWakeLock(false);
        }
        return resData;
    }
}
