package com.sec.factory.aporiented.athandler;

import android.content.Context;
import android.os.SystemProperties;
import android.provider.Settings;
import com.samsung.android.service.EngineeringMode.EngineeringModeManager;
import com.sec.factory.support.FtUtil;
import egis.client.api.EgisFingerprint;

public class AtUsbdebug extends AtCommandHandler {
    private static final int USBDEBUG_ERROR = -1;
    private static final int USBDEBUG_OFF = 0;
    private static final int USBDEBUG_ON = 1;

    public AtUsbdebug(Context context) {
        super(context);
        this.CMD_NAME = "USBDEBUG";
        this.CLASS_NAME = "AtUsbdebug";
        this.NUM_ARGS = 1;
    }

    @Override // com.sec.factory.aporiented.athandler.AtCommandHandler
    public synchronized String handleCommand(String[] argu) {
        String resData;
        if (argu.length != (STAGE_PARALLEL ? this.NUM_ARGS + 1 : this.NUM_ARGS)) {
            return responseNA();
        }
        if (checkArgu(argu, new String[]{"0"})) {
            if (checkEmToken()) {
                SystemProperties.set("persist.sys.auto_confirm", "0");
                Settings.Global.putInt(this.context.getContentResolver(), "adb_enabled", 0);
                if (checkUsbdebugMode(argu[0]) == 0) {
                    resData = responseOK(argu[0]);
                } else {
                    resData = responseNG(argu[0]);
                }
            } else {
                resData = responseString(argu[0], "NG_NONE");
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION})) {
            if (checkEmToken()) {
                SystemProperties.set("persist.sys.auto_confirm", EgisFingerprint.MAJOR_VERSION);
                Settings.Global.putInt(this.context.getContentResolver(), "adb_enabled", 1);
                if (checkUsbdebugMode(argu[0]) == 1) {
                    resData = responseOK(argu[0]);
                } else {
                    resData = responseNG(argu[0]);
                }
            } else {
                resData = responseString(argu[0], "NG_NONE");
            }
        } else if (!checkArgu(argu, new String[]{"2"})) {
            FtUtil.log_d(this.CLASS_NAME, "handleCommand", "USB DEBUG Unknown");
            resData = responseString(argu[0], "NA");
        } else if (checkUsbdebugMode(argu[0]) == 1) {
            resData = responseString(argu[0], "ON");
        } else if (checkUsbdebugMode(argu[0]) == 0) {
            resData = responseString(argu[0], "OFF");
        } else {
            resData = responseNG(argu[0]);
        }
        return resData;
    }

    private int checkUsbdebugMode(String enable) {
        int result = Settings.Global.getInt(this.context.getContentResolver(), "adb_enabled", -1);
        if (result == 0) {
            String str = this.CLASS_NAME;
            FtUtil.log_d(str, "checkUsbdebugMode", "arg : " + enable + ", result : USBDEBUG_OFF");
        } else if (result == 1) {
            String str2 = this.CLASS_NAME;
            FtUtil.log_d(str2, "checkUsbdebugMode", "arg : " + enable + ", result : USBDEBUG_ON");
        } else {
            String str3 = this.CLASS_NAME;
            FtUtil.log_d(str3, "checkUsbdebugMode", "arg : " + enable + ", result : USBDEBUG_ERROR");
        }
        return result;
    }

    private boolean checkEmToken() {
        EngineeringModeManager mEMMgr = new EngineeringModeManager(this.context);
        if (!mEMMgr.isConnected()) {
            FtUtil.log_d(this.CLASS_NAME, "checkEmToken", "Not Connected");
            return false;
        } else if (mEMMgr.getStatus(1) == 1) {
            FtUtil.log_d(this.CLASS_NAME, "checkEmToken", "is Allowed");
            return true;
        } else {
            FtUtil.log_d(this.CLASS_NAME, "checkEmToken", "Nothing");
            return false;
        }
    }
}
