package com.sec.factory.app.factorytest;

import android.app.AlertDialog;
import android.app.Dialog;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.graphics.drawable.ColorDrawable;
import android.os.Handler;
import android.view.KeyEvent;
import android.view.View;
import android.widget.Button;
import com.sec.factory.app.ui.UiHallICTest;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;

public class FactoryTestDialog implements DialogInterface.OnClickListener, DialogInterface.OnKeyListener, DialogInterface.OnDismissListener {
    public static final int ENTRY_TEST = 5;
    public static final int FAIL = 2;
    public static final int FINISH = 0;
    public static final int MODULE_NFC = 101;
    public static final int MODULE_UNKNOWN = 100;
    public static final int PASS = 1;
    public static final int REBOOT = 4;
    public static final int RESET = 3;
    public static final int TYPE_ALERT_DIALOG = 1;
    public static final int TYPE_CONFIRM_ENTRY_TEST_DIALOG = 8;
    public static final int TYPE_CONFIRM_FINISH_DIALOG = 3;
    public static final int TYPE_CUSTOM_DIALOG = 4;
    public static final int TYPE_NOTI_DIALOG = 6;
    public static final int TYPE_PROGRESS_DIALOG = 0;
    public static final int TYPE_REBOOT_DIALOG = 7;
    public static final int TYPE_RESET_DIALOG = 5;
    public static final int TYPE_TRANSPARENT_DIALOG = 2;
    private String CLASS_NAME;
    private Context mContext;
    private Dialog mDialog;
    private int mDialogModule;
    private int mDialogType;
    private Handler mHandler;
    private Thread mProgressBarThread;
    private int mProgressBarTimeout;
    private String mText;
    private String mTitle;

    public FactoryTestDialog(Context context, String title, String text, Handler handler, int type, int module) {
        this(context, title, text, handler, type);
        this.mDialogModule = module;
    }

    public FactoryTestDialog(Context context, String title, String text, Handler handler, int type) {
        this.CLASS_NAME = "FactoryTestDialog";
        this.mProgressBarTimeout = 10;
        this.mDialogType = 1;
        this.mDialogModule = 100;
        this.mContext = context;
        this.mTitle = title;
        this.mText = text;
        this.mHandler = handler;
        this.mDialogType = type;
        if (type == 1) {
            AlertDialog.Builder builder = new AlertDialog.Builder(context);
            builder.setTitle(title);
            builder.setMessage(text);
            builder.setCancelable(false);
            builder.setPositiveButton("OK", this);
            builder.setOnKeyListener(this);
            this.mDialog = builder.create();
        } else if (type == 6) {
            AlertDialog.Builder builder2 = new AlertDialog.Builder(context);
            builder2.setTitle(title);
            builder2.setMessage(text);
            builder2.setCancelable(false);
            builder2.setPositiveButton("OK", this);
            builder2.setOnKeyListener(new DialogInterface.OnKeyListener() {
                /* class com.sec.factory.app.factorytest.FactoryTestDialog.AnonymousClass1 */

                public boolean onKey(DialogInterface dInterface, int keyCode, KeyEvent event) {
                    if (keyCode != 4) {
                        return true;
                    }
                    FactoryTestDialog.this.dismiss();
                    return true;
                }
            });
            this.mDialog = builder2.create();
        } else if (type == 8) {
            AlertDialog.Builder builder3 = new AlertDialog.Builder(context);
            builder3.setTitle(title);
            builder3.setMessage(text);
            builder3.setCancelable(false);
            builder3.setPositiveButton("OK", this);
            builder3.setNegativeButton("EXIT", this);
            builder3.setOnKeyListener(new DialogInterface.OnKeyListener() {
                /* class com.sec.factory.app.factorytest.FactoryTestDialog.AnonymousClass2 */

                public boolean onKey(DialogInterface dInterface, int keyCode, KeyEvent event) {
                    if (keyCode != 4) {
                        return true;
                    }
                    FactoryTestDialog.this.dismiss();
                    return true;
                }
            });
            AlertDialog alertDialog = builder3.create();
            alertDialog.requestWindowFeature(1);
            alertDialog.getWindow().setBackgroundDrawable(new ColorDrawable(-16777216));
            alertDialog.setOnShowListener(new DialogInterface.OnShowListener() {
                /* class com.sec.factory.app.factorytest.FactoryTestDialog.AnonymousClass3 */

                public void onShow(DialogInterface dialog) {
                    Button positive = ((AlertDialog) dialog).getButton(-1);
                    positive.setTextColor(UiHallICTest.FONT_COLOR_PASS);
                    positive.setTextSize(20.0f);
                    Button nagative = ((AlertDialog) dialog).getButton(-2);
                    nagative.setTextColor(-65536);
                    nagative.setTextSize(20.0f);
                }
            });
            this.mDialog = alertDialog;
        } else if (type == 3) {
            AlertDialog.Builder builder4 = new AlertDialog.Builder(context);
            builder4.setTitle(title);
            builder4.setMessage(text);
            builder4.setCancelable(false);
            builder4.setPositiveButton("OK", this);
            builder4.setNegativeButton("CANCEL", this);
            builder4.setOnKeyListener(new DialogInterface.OnKeyListener() {
                /* class com.sec.factory.app.factorytest.FactoryTestDialog.AnonymousClass4 */

                public boolean onKey(DialogInterface dInterface, int keyCode, KeyEvent event) {
                    if (keyCode != 4) {
                        return true;
                    }
                    FactoryTestDialog.this.dismiss();
                    return true;
                }
            });
            this.mDialog = builder4.create();
        } else if (type == 2) {
            AlertDialog.Builder builder5 = new AlertDialog.Builder(context);
            builder5.setTitle(title);
            builder5.setMessage(text);
            builder5.setCancelable(false);
            builder5.setPositiveButton("PASS", this);
            builder5.setNegativeButton("FAIL", this);
            builder5.setOnKeyListener(this);
            AlertDialog alertDialog2 = builder5.create();
            alertDialog2.requestWindowFeature(1);
            alertDialog2.getWindow().setBackgroundDrawable(new ColorDrawable(0));
            alertDialog2.setOnShowListener(new DialogInterface.OnShowListener() {
                /* class com.sec.factory.app.factorytest.FactoryTestDialog.AnonymousClass5 */

                public void onShow(DialogInterface dialog) {
                    Button positive = ((AlertDialog) dialog).getButton(-1);
                    positive.setTextColor(UiHallICTest.FONT_COLOR_PASS);
                    positive.setTextSize(20.0f);
                    Button nagative = ((AlertDialog) dialog).getButton(-2);
                    nagative.setTextColor(-65536);
                    nagative.setTextSize(20.0f);
                }
            });
            this.mDialog = alertDialog2;
        } else if (type == 5) {
            AlertDialog.Builder builder6 = new AlertDialog.Builder(context);
            builder6.setTitle(title);
            builder6.setMessage(text);
            builder6.setCancelable(false);
            builder6.setPositiveButton("YES", this);
            builder6.setNegativeButton("NO", this);
            builder6.setOnKeyListener(new DialogInterface.OnKeyListener() {
                /* class com.sec.factory.app.factorytest.FactoryTestDialog.AnonymousClass6 */

                public boolean onKey(DialogInterface dInterface, int keyCode, KeyEvent event) {
                    if (keyCode != 4) {
                        return true;
                    }
                    FactoryTestDialog.this.dismiss();
                    return true;
                }
            });
            this.mDialog = builder6.create();
        } else if (type == 7) {
            AlertDialog.Builder builder7 = new AlertDialog.Builder(context);
            builder7.setTitle(title);
            builder7.setMessage(text);
            builder7.setCancelable(false);
            builder7.setPositiveButton("REBOOT", this);
            builder7.setOnKeyListener(this);
            this.mDialog = builder7.create();
        } else {
            ProgressDialog progressDialog = new ProgressDialog(context);
            progressDialog.setTitle(title);
            progressDialog.setMessage(text);
            progressDialog.setCancelable(false);
            progressDialog.setButton("OK", this);
            progressDialog.setOnKeyListener(this);
            progressDialog.setOnDismissListener(this);
            progressDialog.setProgressStyle(1);
            progressDialog.setMax(this.mProgressBarTimeout);
            progressDialog.setProgressNumberFormat("%d/%d(sec)");
            progressDialog.setProgress(0);
            this.mDialog = progressDialog;
        }
    }

    public FactoryTestDialog(Context context, String title, String text, Handler handler, int type, View view) {
        this.CLASS_NAME = "FactoryTestDialog";
        this.mProgressBarTimeout = 10;
        this.mDialogType = 1;
        this.mDialogModule = 100;
        this.mContext = context;
        this.mTitle = title;
        this.mText = text;
        this.mHandler = handler;
        this.mDialogType = type;
        if (type == 4) {
            AlertDialog.Builder builder = new AlertDialog.Builder(context, 16973939);
            builder.setView(view);
            builder.setCancelable(true);
            AlertDialog create = builder.create();
            this.mDialog = create;
            create.setCanceledOnTouchOutside(true);
        }
    }

    public void onClick(DialogInterface dialog, int which) {
        FtUtil.log_d(this.CLASS_NAME, "onClick", "which=" + which + ", type : " + this.mDialogType);
        int i = this.mDialogType;
        boolean isNfcModule = true;
        if (i == 2) {
            switch (which) {
                case -2:
                    Handler handler = this.mHandler;
                    if (handler != null) {
                        handler.sendEmptyMessage(2);
                        return;
                    }
                    return;
                case -1:
                    Handler handler2 = this.mHandler;
                    if (handler2 != null) {
                        handler2.sendEmptyMessage(1);
                        return;
                    }
                    return;
                default:
                    return;
            }
        } else if (i == 3) {
            switch (which) {
                case -2:
                default:
                    return;
                case -1:
                    if (this.mHandler != null) {
                        FtUtil.log_d(this.CLASS_NAME, "onClick", "BUTTON_POSITIVE");
                        this.mHandler.sendEmptyMessage(0);
                        return;
                    }
                    return;
            }
        } else if (i == 8) {
            switch (which) {
                case -2:
                default:
                    return;
                case -1:
                    if (this.mHandler != null) {
                        FtUtil.log_d(this.CLASS_NAME, "onClick", "BUTTON_POSITIVE");
                        this.mHandler.sendEmptyMessage(5);
                        return;
                    }
                    return;
            }
        } else if (i == 5) {
            switch (which) {
                case -2:
                default:
                    return;
                case -1:
                    Handler handler3 = this.mHandler;
                    if (handler3 != null) {
                        handler3.sendEmptyMessage(3);
                        return;
                    }
                    return;
            }
        } else if (i == 6) {
            switch (which) {
                case -1:
                default:
                    return;
            }
        } else if (i == 7) {
            switch (which) {
                case -1:
                    Handler handler4 = this.mHandler;
                    if (handler4 != null) {
                        handler4.sendEmptyMessage(4);
                        return;
                    }
                    return;
                default:
                    return;
            }
        } else if (this.mHandler != null) {
            if (this.mDialogModule != 101) {
                isNfcModule = false;
            }
            boolean isTestMode = "tester".equals(Support.Properties.get(Support.Properties.FTL_GADGET_MODE));
            boolean isSuperMode = "super".equals(Support.Properties.get(Support.Properties.FTL_GADGET_MODE));
            if (!isNfcModule || (!isTestMode && !isSuperMode)) {
                FtUtil.log_d(this.CLASS_NAME, "onClick", "else finish");
                this.mHandler.sendEmptyMessage(0);
            }
        }
    }

    public boolean onKey(DialogInterface dialog, int keyCode, KeyEvent event) {
        if (this.mHandler == null) {
            return true;
        }
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "onKey", "keyCode : " + keyCode);
        this.mHandler.sendEmptyMessage(0);
        return true;
    }

    public void onDismiss(DialogInterface dialog) {
        if (this.mDialogType == 0) {
            stoptProgressBarThread();
        }
    }

    public void show() {
        FtUtil.log_d(this.CLASS_NAME, "show dialog", this.mTitle);
        Dialog dialog = this.mDialog;
        if (dialog != null) {
            dialog.getWindow().setGravity(17);
            this.mDialog.show();
            if (this.mDialogType == 0) {
                startProgressBarThread();
                return;
            }
            return;
        }
        FtUtil.log_w(this.CLASS_NAME, "mDialog is null");
    }

    public void startProgressBarThread() {
        FtUtil.log_d(this.CLASS_NAME, "startProgressBarThread");
        Thread thread = new Thread(new Runnable() {
            /* class com.sec.factory.app.factorytest.FactoryTestDialog.AnonymousClass7 */
            int progressStatus = 0;

            public void run() {
                while (this.progressStatus < FactoryTestDialog.this.mProgressBarTimeout) {
                    try {
                        Thread.sleep(1000);
                        this.progressStatus++;
                        if (FactoryTestDialog.this.mDialog != null) {
                            ((ProgressDialog) FactoryTestDialog.this.mDialog).setProgress(this.progressStatus);
                        }
                    } catch (InterruptedException e) {
                        FtUtil.log_e(e);
                        return;
                    }
                }
                if (FactoryTestDialog.this.mDialog != null) {
                    FactoryTestDialog.this.mDialog.dismiss();
                }
                if (FactoryTestDialog.this.mHandler != null) {
                    FtUtil.log_d(FactoryTestDialog.this.CLASS_NAME, "startProgressBarThread", "finish");
                    FactoryTestDialog.this.mHandler.sendEmptyMessage(0);
                }
            }
        });
        this.mProgressBarThread = thread;
        thread.start();
    }

    public void stoptProgressBarThread() {
        FtUtil.log_d(this.CLASS_NAME, "stoptProgressBarThread");
        Thread thread = this.mProgressBarThread;
        if (thread != null && !thread.isInterrupted()) {
            this.mProgressBarThread.interrupt();
        }
    }

    public void dismiss() {
        FtUtil.log_d(this.CLASS_NAME, "dismiss dialog", this.mTitle);
        Dialog dialog = this.mDialog;
        if (dialog != null) {
            dialog.dismiss();
        } else {
            FtUtil.log_w(this.CLASS_NAME, "mDialog is null");
        }
    }

    public String getTitle() {
        return this.mTitle;
    }

    public void setClassName(String name) {
        this.CLASS_NAME = name;
    }

    public void progressBarTimeout(int ms) {
        this.mProgressBarTimeout = ms;
    }
}
