package com.sec.factory.app.factorytest;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Handler;
import android.os.SystemProperties;
import android.widget.ListView;
import com.sec.factory.R;
import com.sec.factory.app.ui.UiHallICTest;
import com.sec.factory.modules.ModuleAudio;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.util.ArrayList;
import java.util.Iterator;

public class FactoryTestMainInner {
    private final String CLASS_NAME = "FactoryTestMainInner";
    private final int PLAYING_LEFT = 1;
    private final int PLAYING_RIGHT = 2;
    private BroadcastReceiver mBroadcastReceiver = new BroadcastReceiver() {
        /* class com.sec.factory.app.factorytest.FactoryTestMainInner.AnonymousClass2 */

        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            FtUtil.log_d("FactoryTestMainInner", "mBroadcastReceiver.onReceive", "action=" + action);
            if (FactoryTestManager.getAllitemPass()) {
                FactoryTestMainInner.this.mListView.setBackgroundColor(UiHallICTest.FONT_COLOR_PASS);
                FactoryTestMainAdapter.ALL_PASS_STATE = true;
            } else {
                FactoryTestMainInner.this.mListView.setBackgroundColor(FactoryTestMainInner.this.mContext.getResources().getColor(R.color.background_gray));
                FactoryTestMainAdapter.ALL_PASS_STATE = false;
            }
            FactoryTestManager.notifyDataSetChanged();
        }
    };
    private Context mContext;
    private Handler mHandlerFeedback;
    private Handler mHandlerResult;
    private ListView mListView;
    private int mPlayingSpeaker = 0;
    private BroadcastReceiver mSimCardTestBroadcastReceiver = null;
    private ArrayList<FunctionCallback> mSimCardTestCallback = null;

    public FactoryTestMainInner(Context context, Handler result, Handler feedback, ListView listView) {
        this.mContext = context;
        this.mHandlerResult = result;
        this.mHandlerFeedback = feedback;
        this.mListView = listView;
        registerTestReceiver();
    }

    public void startLowFrequency() {
        if (ModuleAudio.instance(this.mContext).isPlayingSound()) {
            startLowFrequency(false);
            return;
        }
        startLowFrequency(true);
        sendMessageTestResult(FactoryTestMain.WHAT_RESULT, (byte) 33, (byte) 80);
    }

    public void startLowFrequency(boolean onoff) {
        if (onoff) {
            FtUtil.log_d("FactoryTestMainInner", "startLowFrequency", "Start sound");
            try {
                Thread.sleep(20);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            this.mListView.setSoundEffectsEnabled(false);
            ModuleAudio.instance(this.mContext).setAudioPath(1);
            ModuleAudio.instance(this.mContext).setStreamMusicVolumeMax();
            playSound(R.raw.ver1_rcv_200hz_48000, true);
            return;
        }
        FtUtil.log_d("FactoryTestMainInner", "startLowFrequency", "Stop sound");
        stopSound();
        try {
            Thread.sleep(500);
        } catch (InterruptedException e2) {
            e2.printStackTrace();
        }
        ModuleAudio.instance(this.mContext).setAudioPath(4);
        this.mListView.setSoundEffectsEnabled(true);
    }

    public boolean startSDCard(int testID) {
        String resultText;
        FtUtil.log_d("FactoryTestMainInner", "startSDCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Start"));
        byte result = 78;
        String hostSpeed = Support.Kernel.read(Support.Kernel.HOST_SPEED_MODE);
        String sdSpeed = Support.Kernel.read(Support.Kernel.SD_SPEED_MODE);
        ModuleDevice mModuleDevice = ModuleDevice.instance(this.mContext);
        String testcase = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML((byte) 3));
        FtUtil.log_d("FactoryTestMainInner", "startSDCard", "testcase : " + testcase);
        if (testcase.contains("BUS_SPEED")) {
            if (hostSpeed == null || sdSpeed == null) {
                FtUtil.log_d("FactoryTestMainInner", "startSDCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Fail - " + "SD Card Speed is null"));
                resultText = "SD Card Speed is null";
            } else if (hostSpeed.equals(sdSpeed)) {
                if (!"INSERT".equalsIgnoreCase(mModuleDevice.getStateExternalMemory()) || !mModuleDevice.isMountedStorage(1)) {
                    resultText = "SD card Mount FAIL";
                    FtUtil.log_d("FactoryTestMainInner", "startSDCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Fail - SD card Mount"));
                } else {
                    result = 80;
                    resultText = "SD card test is PASS";
                    ((FactoryTestMain) this.mContext).setTestResult(testID, (byte) 80);
                    sendMessageTestResult(FactoryTestMain.WHAT_RESULT_WITHOUT_NV, testID, (byte) 80);
                    FtUtil.log_d("FactoryTestMainInner", "startSDCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Pass"));
                }
            } else if (!"INSERT".equalsIgnoreCase(mModuleDevice.getStateExternalMemory()) || !mModuleDevice.isMountedStorage(1)) {
                String resultText2 = "SD card Matching FAIL\n(Phone : " + hostSpeed + " / Card : " + sdSpeed + ")\nSD card Mount FAIL";
                FtUtil.log_d("FactoryTestMainInner", "startSDCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Fail - " + resultText2));
                resultText = resultText2;
            } else {
                String resultText3 = "SD card Matching FAIL\n(Phone : " + hostSpeed + " / Card : " + sdSpeed + ")";
                FtUtil.log_d("FactoryTestMainInner", "startSDCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Fail - " + resultText3));
                resultText = resultText3;
            }
        } else if (mModuleDevice.checkSDCardMount()) {
            result = 80;
            resultText = "SD card test is PASS";
            ((FactoryTestMain) this.mContext).setTestResult(testID, (byte) 80);
            sendMessageTestResult(FactoryTestMain.WHAT_RESULT_WITHOUT_NV, testID, (byte) 80);
            FtUtil.log_d("FactoryTestMainInner", "startSDCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Pass"));
        } else {
            resultText = "SD card test is FAIL";
            FtUtil.log_d("FactoryTestMainInner", "startSDCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Fail - SD Card"));
        }
        Handler handler = this.mHandlerFeedback;
        handler.sendMessage(handler.obtainMessage(2, resultText));
        FtUtil.log_d("FactoryTestMainInner", "startSDCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "End"));
        if (result == 80) {
            return true;
        }
        return false;
    }

    public boolean startSIMCard(int testID) {
        String resultText;
        FtUtil.log_d("FactoryTestMainInner", "startSIMCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Start"));
        byte result = 78;
        int switchStat = SystemProperties.getInt("ril.simslottype1", 0);
        if (!ModuleDevice.instance(this.mContext).isSimCardExist() || switchStat != 0) {
            FtUtil.log_d("FactoryTestMainInner", "startSIMCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Fail - SIM Card"));
            resultText = "SIM card test is FAIL!";
        } else {
            result = 80;
            resultText = "SIM card test is PASS!";
            ((FactoryTestMain) this.mContext).setTestResult(testID, (byte) 80);
            sendMessageTestResult(FactoryTestMain.WHAT_RESULT_WITHOUT_NV, testID, (byte) 80);
        }
        FtUtil.log_d("FactoryTestMainInner", "startSIMCard", resultText);
        Handler handler = this.mHandlerFeedback;
        handler.sendMessage(handler.obtainMessage(2, resultText));
        FtUtil.log_d("FactoryTestMainInner", "startSIMCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "End"));
        if (result == 80) {
            return true;
        }
        return false;
    }

    public boolean startSIMCard2(int testID) {
        String resultText;
        FtUtil.log_d("FactoryTestMainInner", "startSIMCard2", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Start"));
        byte result = 78;
        int switchStat = SystemProperties.getInt("ril.simslottype2", 0);
        if (!ModuleDevice.instance(this.mContext).isSimCardExist2() || switchStat != 0) {
            FtUtil.log_d("FactoryTestMainInner", "startSIMCard2", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Fail - SIM Card 2"));
            resultText = "SIM card test 2 is FAIL!";
        } else {
            result = 80;
            resultText = "SIM card test 2 is PASS!";
            ((FactoryTestMain) this.mContext).setTestResult(testID, (byte) 80);
            sendMessageTestResult(FactoryTestMain.WHAT_RESULT_WITHOUT_NV, testID, (byte) 80);
        }
        FtUtil.log_d("FactoryTestMainInner", "startSIMCard2", resultText);
        Handler handler = this.mHandlerFeedback;
        handler.sendMessage(handler.obtainMessage(2, resultText));
        FtUtil.log_d("FactoryTestMainInner", "startSIMCard2", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "End"));
        if (result == 80) {
            return true;
        }
        return false;
    }

    public boolean startSwitchedSIMCard(int testID) {
        String resultText;
        FtUtil.log_d("FactoryTestMainInner", "startSwitchedSIMCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Start"));
        boolean isExist = this.mContext.getSharedPreferences("SIM_SWITCH_PREF", 0).getBoolean("SWITCHED_ESIM_STAT", false);
        int simSwitchSlot = ModuleDevice.instance(this.mContext).getSupportSimSwitch();
        boolean isUpdatedESim = Boolean.parseBoolean(SystemProperties.get("ro.factory.switchsimupdated", "false"));
        FtUtil.log_d("FactoryTestMainInner", "startSwitchedSIMCard", "SWITCHED_ESIM_STAT - " + isExist);
        if (simSwitchSlot == 0) {
            return false;
        }
        byte result = 78;
        if (!isUpdatedESim || !isExist) {
            FtUtil.log_d("FactoryTestMainInner", "startSwitchedSIMCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "Fail - Switched SIM Card"));
            resultText = "Switched SIM Card test is FAIL!";
        } else {
            result = 80;
            resultText = "Switched SIM Card test is PASS!";
            ((FactoryTestMain) this.mContext).setTestResult(testID, (byte) 80);
            sendMessageTestResult(FactoryTestMain.WHAT_RESULT_WITHOUT_NV, testID, (byte) 80);
        }
        FtUtil.log_d("FactoryTestMainInner", "startSwitchedSIMCard", resultText);
        Handler handler = this.mHandlerFeedback;
        handler.sendMessage(handler.obtainMessage(2, resultText));
        FtUtil.log_d("FactoryTestMainInner", "startSwitchedSIMCard", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(testID), "End"));
        if (result == 80) {
            return true;
        }
        return false;
    }

    private void registerTestReceiver() {
        this.mContext.registerReceiver(this.mBroadcastReceiver, new IntentFilter());
    }

    public void registerSimCardTestReceiver(FunctionCallback cb) {
        FtUtil.log_d("FactoryTestMainInner", "registerSimCardTestReceiver = " + cb.tag());
        if (cb == null) {
            FtUtil.log_e("FactoryTestMainInner", "registerSimCardTestReceiver no callback");
            return;
        }
        if (this.mSimCardTestCallback == null) {
            FtUtil.log_d("FactoryTestMainInner", "mSimCardTestCallback register receiver");
            this.mSimCardTestCallback = new ArrayList<>();
        }
        if (!this.mSimCardTestCallback.isEmpty()) {
            Iterator<FunctionCallback> it = this.mSimCardTestCallback.iterator();
            while (it.hasNext()) {
                FunctionCallback callback = it.next();
                if (callback.tag().equals(cb.tag())) {
                    this.mSimCardTestCallback.remove(callback);
                }
            }
        }
        FtUtil.log_d("FactoryTestMainInner", "mSimCardTestCallback added Callback");
        this.mSimCardTestCallback.add(cb);
        if (this.mSimCardTestBroadcastReceiver == null) {
            FtUtil.log_d("FactoryTestMainInner", "registerSimCardTestReceiver register receiver");
            this.mSimCardTestBroadcastReceiver = new BroadcastReceiver() {
                /* class com.sec.factory.app.factorytest.FactoryTestMainInner.AnonymousClass1 */
                final String CLASS_NAME = "FactoryTestMainInner.mSimCardTestBroadcastReceiver";

                public void onReceive(Context context, Intent intent) {
                    if (FactoryTestMainInner.this.mSimCardTestCallback == null || FactoryTestMainInner.this.mSimCardTestCallback.isEmpty()) {
                        FtUtil.log_d("FactoryTestMainInner.mSimCardTestBroadcastReceiver", "onReceive", "not registered callback");
                    }
                    Iterator<FunctionCallback> it = FactoryTestMainInner.this.mSimCardTestCallback.iterator();
                    while (it.hasNext()) {
                        FunctionCallback cb = it.next();
                        if (!isInitialStickyBroadcast() && cb.onRun()) {
                            FtUtil.log_d("FactoryTestMainInner.mSimCardTestBroadcastReceiver", "onReceive", "onRun return true remove callback");
                            it.remove();
                        }
                    }
                }
            };
            IntentFilter filter = new IntentFilter();
            filter.addAction("android.intent.action.SIM_STATE_CHANGED");
            this.mContext.registerReceiver(this.mSimCardTestBroadcastReceiver, filter);
        }
    }

    public void unregisterTestReceiver() {
        BroadcastReceiver broadcastReceiver = this.mBroadcastReceiver;
        if (broadcastReceiver != null) {
            this.mContext.unregisterReceiver(broadcastReceiver);
            this.mBroadcastReceiver = null;
            FtUtil.log_i("FactoryTestMainInner", "unregisterTestReceiver", null);
        }
        BroadcastReceiver broadcastReceiver2 = this.mSimCardTestBroadcastReceiver;
        if (broadcastReceiver2 != null) {
            this.mContext.unregisterReceiver(broadcastReceiver2);
            this.mSimCardTestBroadcastReceiver = null;
            FtUtil.log_i("FactoryTestMainInner", "unregister mSimCardTestBroadcastReceiver", null);
        }
        this.mSimCardTestCallback = null;
    }

    private void playSound(int resID, boolean isDisplayedProgressFeedback) {
        String feedbackText;
        ModuleAudio moduleAudio = ModuleAudio.instance(this.mContext);
        if (!moduleAudio.isPlayingSound()) {
            moduleAudio.stopMedia();
        }
        moduleAudio.playMedia(resID, true);
        if (isDisplayedProgressFeedback) {
            switch (resID) {
                case R.raw.ver1_rcv_200hz_48000:
                    FtUtil.log_d("FactoryTestMainInner", "playSound", "RCV 200");
                    feedbackText = "RCV 200 On";
                    break;
                default:
                    FtUtil.log_e("FactoryTestMainInner", "playSound", "resID is not exist");
                    feedbackText = "Media playing";
                    break;
            }
            Handler handler = this.mHandlerFeedback;
            handler.sendMessage(handler.obtainMessage(3, feedbackText));
        }
    }

    private void stopSound() {
        ModuleAudio moduleAudio = ModuleAudio.instance(this.mContext);
        if (moduleAudio.isPlayingSound()) {
            moduleAudio.stopMedia();
            this.mHandlerFeedback.sendEmptyMessage(4);
        }
    }

    private void sendMessageTestResult(int what, byte id, byte result) {
        FtUtil.log_d("FactoryTestMainInner", "sendTestResultMessage", "what=" + what + " , id=" + ((int) id) + " , result=" + ((int) result));
        this.mHandlerResult.sendMessage(this.mHandlerResult.obtainMessage(what, id, result));
    }

    private void sendMessageTestResult(int what, int id, byte result) {
        FtUtil.log_d("FactoryTestMainInner", "sendTestResultMessage", "what=" + what + " , id=" + id + " , result=" + ((int) result));
        this.mHandlerResult.sendMessage(this.mHandlerResult.obtainMessage(what, id, result));
    }
}
