package com.sec.factory.app.factorytest;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Handler;
import android.widget.ListView;
import com.sec.factory.R;
import com.sec.factory.app.ui.UiHallICTest;
import com.sec.factory.modules.ModuleCommunication;
import com.sec.factory.support.FtUtil;

public class FactoryTestMainInnerBT {
    private final String CLASS_NAME = "FactoryTestMainInnerBT";
    private int currSeqNum;
    private BroadcastReceiver mBroadcastReceiver = null;
    private Context mContext;
    boolean mEnable = false;
    private Handler mHandlerFeedback;
    private Handler mHandlerResult;
    private String mItemName;
    private ListView mListView;
    private int mTestID;

    public FactoryTestMainInnerBT(Context context, Handler result, Handler feedback, ListView listView) {
        this.mContext = context;
        this.mHandlerResult = result;
        this.mHandlerFeedback = feedback;
        this.mListView = listView;
    }

    public void startBluetooth(int testID) {
        if (testID == 2) {
            this.currSeqNum = 1;
            this.mItemName = FactoryTestManager.getItemName_RequestCode(2);
        }
        FtUtil.log_d("FactoryTestMainInnerBT", "startBluetooth", FtUtil.setMspSeqMessage(this.currSeqNum, this.mItemName, "Start"));
        this.mTestID = testID;
        setEnable(true);
        if (this.mBroadcastReceiver != null) {
            FtUtil.log_d("FactoryTestMainInnerBT", "###### BT receiver is already registerred!!!!!! ######", null);
        } else {
            registerTestReceiver();
        }
        ModuleCommunication moduleCommunication = ModuleCommunication.instance(this.mContext);
        if (!moduleCommunication.isEnabledBtDevice()) {
            FtUtil.log_d("FactoryTestMainInnerBT", "startBluetooth", "BT Enable : FALSE => BT Activation");
            moduleCommunication.btActivation();
            Handler handler = this.mHandlerFeedback;
            handler.sendMessage(handler.obtainMessage(2, "Bluetooth state is changed to On!!"));
            return;
        }
        FtUtil.log_d("FactoryTestMainInnerBT", "startBluetooth", "BT Enable : TRUE => BT Discoverable");
        moduleCommunication.btSetDiscoverable();
        changeBluetoothState("ON");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void changeBluetoothState(String result) {
        FtUtil.log_d("FactoryTestMainInnerBT", "changeBluetoothState", "result : " + result);
        if (result.equals("ON")) {
            sendMessageTestResult(FactoryTestMain.WHAT_RESULT, this.mTestID, (byte) 80);
            setEnable(false);
            return;
        }
        FtUtil.log_d("FactoryTestMainInnerBT", "changeBluetoothState", FtUtil.setMspSeqMessage(this.currSeqNum, this.mItemName, "Fail - Not turn ON"));
        sendMessageTestResultFailCase(FactoryTestMain.WHAT_RESULT_FAIL_CASE, this.mTestID);
    }

    public void stopBluetooth() {
        ModuleCommunication moduleCommunication = ModuleCommunication.instance(this.mContext);
        if (moduleCommunication.isEnabledBtDevice()) {
            moduleCommunication.btDeactivation();
            Handler handler = this.mHandlerFeedback;
            handler.sendMessage(handler.obtainMessage(2, "Bluetooth state is changed to Off!!"));
        }
        if (this.mBroadcastReceiver != null) {
            unregisterTestReceiver();
        } else {
            FtUtil.log_d("FactoryTestMainInnerBT", "###### BT receiver is not registerred!!!!!! ######", null);
        }
    }

    private void registerTestReceiver() {
        FtUtil.log_d("FactoryTestMainInnerBT", "registerTestReceiver", null);
        if (FactoryTestManager.getEnable(2)) {
            FtUtil.log_d("FactoryTestMainInnerBT", "registerTestReceiver", ModuleCommunication.ACTION_BT_SERVICE_RESPONSE);
            if (this.mBroadcastReceiver == null) {
                this.mBroadcastReceiver = new BroadcastReceiver() {
                    /* class com.sec.factory.app.factorytest.FactoryTestMainInnerBT.AnonymousClass1 */

                    public void onReceive(Context context, Intent intent) {
                        String action = intent.getAction();
                        FtUtil.log_d("FactoryTestMainInnerBT", "mBroadcastReceiver.onReceive", "action=" + action);
                        if (ModuleCommunication.ACTION_BT_SERVICE_RESPONSE.equals(action)) {
                            FtUtil.log_i("FactoryTestMainInnerBT", "mBroadcastReceiver.onReceive", "ACTION_BT_RESPONSE");
                            FactoryTestMainInnerBT.this.changeBluetoothState(intent.getStringExtra("result"));
                        }
                        if (FactoryTestManager.getAllitemPass()) {
                            FactoryTestMainInnerBT.this.mListView.setBackgroundColor(UiHallICTest.FONT_COLOR_PASS);
                            FactoryTestMainAdapter.ALL_PASS_STATE = true;
                        } else {
                            FactoryTestMainInnerBT.this.mListView.setBackgroundColor(FactoryTestMainInnerBT.this.mContext.getResources().getColor(R.color.background_gray));
                            FactoryTestMainAdapter.ALL_PASS_STATE = false;
                        }
                        FactoryTestManager.notifyDataSetChanged();
                    }
                };
            }
            IntentFilter filter = new IntentFilter();
            filter.addAction(ModuleCommunication.ACTION_BT_SERVICE_RESPONSE);
            this.mContext.registerReceiver(this.mBroadcastReceiver, filter);
        }
    }

    private void unregisterTestReceiver() {
        FtUtil.log_d("FactoryTestMainInnerBT", "unregisterTestReceiver", "mBroadcastReceiver : " + this.mBroadcastReceiver);
        if (this.mBroadcastReceiver != null) {
            FtUtil.log_d("FactoryTestMainInnerBT", "unregisterTestReceiver", ModuleCommunication.ACTION_BT_SERVICE_RESPONSE);
            this.mContext.unregisterReceiver(this.mBroadcastReceiver);
            this.mBroadcastReceiver = null;
        }
    }

    public boolean getEnable() {
        FtUtil.log_d("FactoryTestMainInnerBT", "getEnable", "mEnable=" + this.mEnable);
        return this.mEnable;
    }

    public void setEnable(boolean enable) {
        this.mEnable = enable;
        FtUtil.log_d("FactoryTestMainInnerBT", "setEnable", "mEnable=" + this.mEnable);
    }

    private void sendMessageTestResult(int what, int id, byte result) {
        FtUtil.log_d("FactoryTestMainInnerBT", "sendTestResultMessage", "what=" + what + " , id=" + id + " , result=" + ((int) result));
        this.mHandlerResult.sendMessage(this.mHandlerResult.obtainMessage(what, id, result));
    }

    private void sendMessageTestResultFailCase(int what, int id) {
        FtUtil.log_d("FactoryTestMainInnerBT", "sendTestResultMessage", "what=" + what + " , id=" + id);
        this.mHandlerResult.sendMessage(this.mHandlerResult.obtainMessage(what, id, -1));
    }
}
