package com.sec.factory.app.factorytest;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.hardware.usb.UsbDevice;
import android.os.Handler;
import android.os.storage.StorageManager;
import android.os.storage.VolumeInfo;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;

public class FactoryTestMainInnerOTG {
    private final String CLASS_NAME = "FactoryTestMainInnerOTG";
    private Context mContext;
    private Handler mHandlerFeedback;
    private Handler mHandlerResult;
    public boolean mIsDoingOTGtest = false;
    private BroadcastReceiver mOTGMouseReceiver = null;
    private BroadcastReceiver mOTGStorageReceiver = null;
    private StorageManager mStorageManager = null;

    public FactoryTestMainInnerOTG(Context context, Handler result, Handler feedback) {
        this.mContext = context;
        this.mHandlerResult = result;
        this.mHandlerFeedback = feedback;
    }

    public void startOTG() {
        FtUtil.log_d("FactoryTestMainInnerOTG", "startOTG", "Start OTG");
        this.mStorageManager = (StorageManager) this.mContext.getSystemService("storage");
        if (Support.Kernel.isExistFilePath(Support.Kernel.getFilePath(Support.Kernel.USB_CTRL))) {
            Support.Kernel.writeToPath(Support.Kernel.getFilePath(Support.Kernel.USB_CTRL), "0");
        }
        changeOTGState();
    }

    public void startOTG2() {
        FtUtil.log_d("FactoryTestMainInnerOTG", "startOTG2", "Start OTG2");
        if (Support.Kernel.isExistFilePath(Support.Kernel.getFilePath(Support.Kernel.USB_CTRL))) {
            Support.Kernel.writeToPath(Support.Kernel.getFilePath(Support.Kernel.USB_CTRL), "0");
        }
        if (this.mOTGStorageReceiver == null) {
            changeOTGState();
        } else {
            FtUtil.log_d("FactoryTestMainInnerOTG", "startOTG2", "already OTG Test was started...");
        }
    }

    public void stopOTG() {
        FtUtil.log_d("FactoryTestMainInnerOTG", "stopOTG", "Stop OTG");
        unregisterOTGReceiver();
        this.mHandlerFeedback.sendEmptyMessage(4);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void changeOTGState() {
        if (this.mOTGStorageReceiver == null) {
            String mTestCase = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML((byte) 24));
            if (mTestCase != null && mTestCase.contains("USBHID_MOUSE")) {
                IntentFilter filter = new IntentFilter();
                OtgMouseHandle otgMouseHandle = new OtgMouseHandle(filter);
                this.mOTGMouseReceiver = otgMouseHandle;
                this.mContext.registerReceiver(otgMouseHandle, filter);
            }
            this.mIsDoingOTGtest = true;
            IntentFilter filter2 = new IntentFilter();
            OtgStorageHandle otgStorageHandle = new OtgStorageHandle(filter2);
            this.mOTGStorageReceiver = otgStorageHandle;
            this.mContext.registerReceiver(otgStorageHandle, filter2);
            Handler handler = this.mHandlerFeedback;
            handler.sendMessage(handler.obtainMessage(3, "Waiting OTG"));
            return;
        }
        unregisterOTGReceiver();
        this.mHandlerFeedback.sendEmptyMessage(4);
    }

    public void unregisterOTGReceiver() {
        this.mIsDoingOTGtest = false;
        BroadcastReceiver broadcastReceiver = this.mOTGStorageReceiver;
        if (broadcastReceiver != null) {
            this.mContext.unregisterReceiver(broadcastReceiver);
            this.mOTGStorageReceiver = null;
            FtUtil.log_i("FactoryTestMainInnerOTG", "unregistermOTGStorageReceiver", null);
        }
        BroadcastReceiver broadcastReceiver2 = this.mOTGMouseReceiver;
        if (broadcastReceiver2 != null) {
            this.mContext.unregisterReceiver(broadcastReceiver2);
            this.mOTGMouseReceiver = null;
            FtUtil.log_i("FactoryTestMainInnerOTG", "unregistermOTGMouseReceiver", null);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sendMessageTestResult(int what, byte id, byte result) {
        FtUtil.log_d("FactoryTestMainInnerOTG", "sendTestResultMessage", "what=" + what + " , id=" + ((int) id) + " , result=" + ((int) result));
        this.mHandlerResult.sendMessage(this.mHandlerResult.obtainMessage(what, id, result));
    }

    private void sendMessageTestResultFailCase(int what, byte id) {
        FtUtil.log_e("FactoryTestMainInnerOTG", "sendTestResultMessage", "what=" + what + " , id=" + ((int) id));
        this.mHandlerResult.sendMessage(this.mHandlerResult.obtainMessage(what, Byte.valueOf(id)));
    }

    public boolean isDoingOTGtest() {
        return this.mIsDoingOTGtest;
    }

    /* access modifiers changed from: private */
    public class OtgStorageHandle extends BroadcastReceiver {
        public OtgStorageHandle(IntentFilter filter) {
            FtUtil.log_i("FactoryTestMainInnerOTG", "OtgStorageHandle", null);
            filter.addAction(ModuleDevice.ACTION_USB_STORAGE_MOUNTED);
            filter.addAction(ModuleDevice.ACTION_USB_STORAGE_UNMOUNTED);
        }

        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            if (action.equals(ModuleDevice.ACTION_USB_STORAGE_MOUNTED)) {
                FtUtil.log_i("FactoryTestMainInnerOTG", "mOTGReceiver.onReceive", "ACTION_USB_STORAGE_MOUNTED");
                final VolumeInfo vol = FactoryTestMainInnerOTG.this.mStorageManager.findVolumeById(intent.getStringExtra("android.os.storage.extra.VOLUME_ID"));
                FtUtil.log_i("FactoryTestMainInnerOTG", "mOTGReceiver.onReceive", "VolumeInfo vol : " + vol);
                new Thread(new Runnable() {
                    /* class com.sec.factory.app.factorytest.FactoryTestMainInnerOTG.OtgStorageHandle.AnonymousClass1 */

                    public void run() {
                        FactoryTestMainInnerOTG.this.mHandlerFeedback.sendMessage(FactoryTestMainInnerOTG.this.mHandlerFeedback.obtainMessage(3, "Unmounting"));
                        FactoryTestMainInnerOTG.this.mStorageManager.unmount(vol.getId());
                        FtUtil.log_i("FactoryTestMainInnerOTG", "mOTGReceiver.onReceive", "UnMountedStorage : Passed");
                    }
                }).start();
            } else if (action.equals(ModuleDevice.ACTION_USB_STORAGE_UNMOUNTED)) {
                FtUtil.log_i("FactoryTestMainInnerOTG", "mOTGReceiver.onReceive", "ACTION_USB_STORAGE_UNMOUNTED");
                FactoryTestMainInnerOTG.this.sendMessageTestResult(FactoryTestMain.WHAT_RESULT, (byte) 24, (byte) 80);
                FactoryTestMainInnerOTG.this.changeOTGState();
            }
        }
    }

    /* access modifiers changed from: private */
    public class OtgMouseHandle extends BroadcastReceiver {
        private boolean mMouseIsAttached = false;

        public OtgMouseHandle(IntentFilter filter) {
            FtUtil.log_i("FactoryTestMainInnerOTG", "OtgMouseHandle", null);
            filter.addAction("android.hardware.usb.action.USB_DEVICE_ATTACHED");
            filter.addAction("android.hardware.usb.action.USB_DEVICE_DETACHED");
        }

        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            FtUtil.log_i("FactoryTestMainInnerOTG", "mOTGReceiver.onReceive", action);
            if ("android.hardware.usb.action.USB_DEVICE_ATTACHED".equals(action)) {
                if (ModuleDevice.instance(context).isUSBMouseAttached((UsbDevice) intent.getParcelableExtra("device"))) {
                    FtUtil.log_i("FactoryTestMainInnerOTG", "mOTGReceiver.onReceive", "mouse attached");
                    FactoryTestMainInnerOTG.this.sendMessageTestResult(FactoryTestMain.WHAT_RESULT, (byte) 24, (byte) 80);
                    FactoryTestMainInnerOTG.this.changeOTGState();
                }
            } else if ("android.hardware.usb.action.USB_DEVICE_DETACHED".equals(action)) {
                if (!ModuleDevice.instance(context).isUSBMouseAttached((UsbDevice) intent.getParcelableExtra("device")) && this.mMouseIsAttached) {
                    this.mMouseIsAttached = false;
                    FtUtil.log_i("FactoryTestMainInnerOTG", "mOTGReceiver.onReceive", "mouse detached");
                    FactoryTestMainInnerOTG.this.sendMessageTestResult(FactoryTestMain.WHAT_RESULT, (byte) 24, (byte) 80);
                    FactoryTestMainInnerOTG.this.changeOTGState();
                }
            }
        }
    }
}
