package com.sec.factory.app.factorytest;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.hardware.usb.UsbDevice;
import android.os.Handler;
import android.os.storage.StorageManager;
import android.os.storage.VolumeInfo;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;

public class FactoryTestMainInnerOTG3 {
    private final String CLASS_NAME = "FactoryTestMainInnerOTG3";
    private final int TEST_STATE_CHECK_USB3_HOST;
    private final int TEST_STATE_CHECK_USB_HOST_END;
    private final int TEST_STATE_WAIT_USB3_HOST;
    private int hostDummy = 0;
    private Context mContext;
    private Handler mHandlerFeedback;
    private Handler mHandlerResult;
    private int mHostCheckState;
    public boolean mIsDoingOTGtest = false;
    private BroadcastReceiver mOTGMouseReceiver = null;
    private BroadcastReceiver mOTGStorageReceiver = null;
    private StorageManager mStorageManager = null;

    public FactoryTestMainInnerOTG3(Context context, Handler result, Handler feedback) {
        int i = 0 + 1;
        this.hostDummy = i;
        this.TEST_STATE_WAIT_USB3_HOST = 0;
        int i2 = i + 1;
        this.hostDummy = i2;
        this.TEST_STATE_CHECK_USB3_HOST = i;
        this.hostDummy = i2 + 1;
        this.TEST_STATE_CHECK_USB_HOST_END = i2;
        this.mHostCheckState = 0;
        this.mContext = context;
        this.mHandlerResult = result;
        this.mHandlerFeedback = feedback;
    }

    public void startOTG() {
        FtUtil.log_d("FactoryTestMainInnerOTG3", "startOTG", "Start OTG");
        this.mStorageManager = (StorageManager) this.mContext.getSystemService("storage");
        changeOTGState();
    }

    public void stopOTG() {
        FtUtil.log_d("FactoryTestMainInnerOTG3", "stopOTG", "Stop OTG");
        unregisterOTGReceiver();
        this.mHandlerFeedback.sendEmptyMessage(4);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void changeOTGState() {
        if (this.mOTGStorageReceiver == null) {
            String mTestCase = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML((byte) FactoryTestManager.TEST_OTG3));
            if (mTestCase != null && mTestCase.contains("USBHID_MOUSE")) {
                IntentFilter filter = new IntentFilter();
                OtgMouseHandle otgMouseHandle = new OtgMouseHandle(filter);
                this.mOTGMouseReceiver = otgMouseHandle;
                this.mContext.registerReceiver(otgMouseHandle, filter);
            }
            this.mIsDoingOTGtest = true;
            IntentFilter filter2 = new IntentFilter();
            OtgStorageHandle otgStorageHandle = new OtgStorageHandle(filter2);
            this.mOTGStorageReceiver = otgStorageHandle;
            this.mContext.registerReceiver(otgStorageHandle, filter2);
            Handler handler = this.mHandlerFeedback;
            handler.sendMessage(handler.obtainMessage(3, "Waiting OTG3.1"));
            return;
        }
        unregisterOTGReceiver();
        this.mHandlerFeedback.sendEmptyMessage(4);
    }

    public void unregisterOTGReceiver() {
        this.mIsDoingOTGtest = false;
        BroadcastReceiver broadcastReceiver = this.mOTGStorageReceiver;
        if (broadcastReceiver != null) {
            this.mContext.unregisterReceiver(broadcastReceiver);
            this.mOTGStorageReceiver = null;
            FtUtil.log_i("FactoryTestMainInnerOTG3", "unregisterOTGReceiver", "Unregistered OTG Storage Receiver...");
        }
        BroadcastReceiver broadcastReceiver2 = this.mOTGMouseReceiver;
        if (broadcastReceiver2 != null) {
            this.mContext.unregisterReceiver(broadcastReceiver2);
            this.mOTGMouseReceiver = null;
            FtUtil.log_i("FactoryTestMainInnerOTG3", "unregisterOTGReceiver", "Unregistered OTG Mouse Receiver...");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sendMessageTestResult(int what, byte id, byte result) {
        FtUtil.log_d("FactoryTestMainInnerOTG3", "sendTestResultMessage", "what=" + what + " , id=" + ((int) id) + " , result=" + ((int) result));
        this.mHandlerResult.sendMessage(this.mHandlerResult.obtainMessage(what, id, result));
    }

    private void sendMessageTestResultFailCase(int what, byte id) {
        FtUtil.log_e("FactoryTestMainInnerOTG3", "sendTestResultMessage", "what=" + what + " , id=" + ((int) id));
        this.mHandlerResult.sendMessage(this.mHandlerResult.obtainMessage(what, Byte.valueOf(id)));
    }

    public boolean isDoingOTGtest() {
        return this.mIsDoingOTGtest;
    }

    /* access modifiers changed from: private */
    public class OtgStorageHandle extends BroadcastReceiver {
        public OtgStorageHandle(IntentFilter filter) {
            FtUtil.log_i("FactoryTestMainInnerOTG3", "OtgStorageHandle", null);
            filter.addAction(ModuleDevice.ACTION_USB_STORAGE_MOUNTED);
            filter.addAction(ModuleDevice.ACTION_USB_STORAGE_UNMOUNTED);
        }

        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            FtUtil.log_i("FactoryTestMainInnerOTG3", "OtgStorageHandle.onReceive", "action : " + action);
            if (action.equals(ModuleDevice.ACTION_USB_STORAGE_MOUNTED)) {
                final VolumeInfo vol = FactoryTestMainInnerOTG3.this.mStorageManager.findVolumeById(intent.getStringExtra("android.os.storage.extra.VOLUME_ID"));
                FtUtil.log_i("FactoryTestMainInnerOTG3", "OtgStorageHandle.onReceive", "VolumeInfo vol : " + vol);
                if (FactoryTestMainInnerOTG3.this.mHostCheckState == FactoryTestMainInnerOTG3.this.TEST_STATE_WAIT_USB3_HOST) {
                    FtUtil.log_i("FactoryTestMainInnerOTG3", "OtgStorageHandle.onReceive", "SEQUENCE : TEST_STATE_WAIT_USB3_HOST");
                    new Thread(new Runnable() {
                        /* class com.sec.factory.app.factorytest.FactoryTestMainInnerOTG3.OtgStorageHandle.AnonymousClass1 */

                        public void run() {
                            FtUtil.log_i("FactoryTestMainInnerOTG3", "OtgStorageHandle.onReceive", "isMountedStorage : Passed");
                            if ("SUPER".equals(Support.Kernel.read(Support.Kernel.USB3_OTG_TYPE_CHECK))) {
                                FtUtil.log_i("FactoryTestMainInnerOTG3", "OtgStorageHandle.onReceive", "CHANGED SEQUENCE : TEST_STATE_CHECK_USB3_HOST");
                                FactoryTestMainInnerOTG3.this.mHostCheckState = FactoryTestMainInnerOTG3.this.TEST_STATE_CHECK_USB3_HOST;
                                FactoryTestMainInnerOTG3.this.mHandlerFeedback.sendMessage(FactoryTestMainInnerOTG3.this.mHandlerFeedback.obtainMessage(3, "Unmounting"));
                                FactoryTestMainInnerOTG3.this.mStorageManager.unmount(vol.getId());
                                FtUtil.log_i("FactoryTestMainInnerOTG3", "OtgStorageHandle.onReceive", "UnMountedStorage : Passed");
                            }
                        }
                    }).start();
                }
            } else if (action.equals(ModuleDevice.ACTION_USB_STORAGE_UNMOUNTED) && FactoryTestMainInnerOTG3.this.mHostCheckState == FactoryTestMainInnerOTG3.this.TEST_STATE_CHECK_USB3_HOST) {
                FtUtil.log_i("FactoryTestMainInnerOTG3", "OtgStorageHandle.onReceive", "SEQUENCE : TEST_STATE_CHECK_USB3_HOST");
                FactoryTestMainInnerOTG3.this.sendMessageTestResult(FactoryTestMain.WHAT_RESULT, FactoryTestManager.TEST_OTG3, (byte) 80);
                FactoryTestMainInnerOTG3.this.changeOTGState();
                FactoryTestMainInnerOTG3 factoryTestMainInnerOTG3 = FactoryTestMainInnerOTG3.this;
                factoryTestMainInnerOTG3.mHostCheckState = factoryTestMainInnerOTG3.TEST_STATE_WAIT_USB3_HOST;
            }
        }
    }

    /* access modifiers changed from: private */
    public class OtgMouseHandle extends BroadcastReceiver {
        private boolean mMouseIsAttached = false;

        public OtgMouseHandle(IntentFilter filter) {
            FtUtil.log_i("FactoryTestMainInnerOTG3", "OtgMouseHandle", null);
            filter.addAction("android.hardware.usb.action.USB_DEVICE_ATTACHED");
            filter.addAction("android.hardware.usb.action.USB_DEVICE_DETACHED");
        }

        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            FtUtil.log_i("FactoryTestMainInnerOTG3", "mOTGReceiver.onReceive", action);
            if ("android.hardware.usb.action.USB_DEVICE_ATTACHED".equals(action)) {
                if (ModuleDevice.instance(context).isUSBMouseAttached((UsbDevice) intent.getParcelableExtra("device"))) {
                    FtUtil.log_i("FactoryTestMainInnerOTG3", "mOTGReceiver.onReceive", "mouse attached");
                    if ("SUPER".equals(Support.Kernel.read(Support.Kernel.USB3_OTG_TYPE_CHECK))) {
                        this.mMouseIsAttached = true;
                        FactoryTestMainInnerOTG3.this.sendMessageTestResult(FactoryTestMain.WHAT_RESULT, FactoryTestManager.TEST_OTG3, (byte) 80);
                        FactoryTestMainInnerOTG3.this.changeOTGState();
                    }
                }
            } else if ("android.hardware.usb.action.USB_DEVICE_DETACHED".equals(action)) {
                if (!ModuleDevice.instance(context).isUSBMouseAttached((UsbDevice) intent.getParcelableExtra("device")) && this.mMouseIsAttached) {
                    this.mMouseIsAttached = false;
                    FtUtil.log_i("FactoryTestMainInnerOTG3", "mOTGReceiver.onReceive", "mouse detached");
                    FactoryTestMainInnerOTG3.this.sendMessageTestResult(FactoryTestMain.WHAT_RESULT, FactoryTestManager.TEST_OTG3, (byte) 80);
                    FactoryTestMainInnerOTG3.this.changeOTGState();
                }
            }
        }
    }
}
