package com.sec.factory.app.factorytest;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Handler;
import android.widget.Toast;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.support.FtUtil;

public class FactoryTestMainInnerUSB3 {
    private final String CLASS_NAME = "FactoryTestMainInnerUSB3";
    IntentFilter filter;
    private Context mContext;
    private Handler mHandlerFeedback;
    private Handler mHandlerResult;
    private boolean mIsDoingUSB3test = false;
    private String mTestName = "USB 3";
    private BroadcastReceiver mUSB3MouseReceiver = null;
    private BroadcastReceiver mUSB3StorageReceiver = null;

    public FactoryTestMainInnerUSB3(Context context, Handler result, Handler feedback) {
        this.mContext = context;
        this.mHandlerResult = result;
        this.mHandlerFeedback = feedback;
        IntentFilter intentFilter = new IntentFilter();
        this.filter = intentFilter;
        intentFilter.addAction("android.hardware.usb.action.USB_STATE");
    }

    public void startUSB3() {
        FtUtil.log_d("FactoryTestMainInnerUSB3", "startUSB3", "Start USB3");
        changeUSB3State();
    }

    public void stopUSB3() {
        FtUtil.log_d("FactoryTestMainInnerUSB3", "stopUSB3", FtUtil.setMspSeqMessage(1, this.mTestName, "End"));
        unregisterUSB3Receiver();
        this.mHandlerFeedback.sendEmptyMessage(4);
    }

    private void changeUSB3State() {
        String itemName_RequestCode = FactoryTestManager.getItemName_RequestCode(70);
        this.mTestName = itemName_RequestCode;
        this.mTestName = itemName_RequestCode.substring(0, itemName_RequestCode.length() - 4);
        if (this.mUSB3StorageReceiver == null) {
            this.mIsDoingUSB3test = true;
            Usb3Handle usb3Handle = new Usb3Handle(this.filter);
            this.mUSB3StorageReceiver = usb3Handle;
            this.mContext.registerReceiver(usb3Handle, this.filter);
            Handler handler = this.mHandlerFeedback;
            handler.sendMessage(handler.obtainMessage(3, "Waiting " + this.mTestName));
            return;
        }
        unregisterUSB3Receiver();
        this.mHandlerFeedback.sendEmptyMessage(4);
    }

    public void unregisterUSB3Receiver() {
        this.mIsDoingUSB3test = false;
        BroadcastReceiver broadcastReceiver = this.mUSB3StorageReceiver;
        if (broadcastReceiver != null) {
            this.mContext.unregisterReceiver(broadcastReceiver);
            this.mUSB3StorageReceiver = null;
            FtUtil.log_i("FactoryTestMainInnerUSB3", "unregistermUSB3StorageReceiver", null);
        }
        BroadcastReceiver broadcastReceiver2 = this.mUSB3MouseReceiver;
        if (broadcastReceiver2 != null) {
            this.mContext.unregisterReceiver(broadcastReceiver2);
            this.mUSB3MouseReceiver = null;
            FtUtil.log_i("FactoryTestMainInnerUSB3", "unregistermUSB3MouseReceiver", null);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sendMessageTestResult(int what, byte id, byte result) {
        FtUtil.log_d("FactoryTestMainInnerUSB3", "sendTestResultMessage", "what=" + what + " , id=" + ((int) id) + " , result=" + ((int) result));
        this.mHandlerResult.sendMessage(this.mHandlerResult.obtainMessage(what, id, result));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sendMessageTestResultFailCase(int what, byte id) {
        FtUtil.log_e("FactoryTestMainInnerUSB3", "sendTestResultMessage", "what=" + what + " , id=" + ((int) id));
        this.mHandlerResult.sendMessage(this.mHandlerResult.obtainMessage(what, Byte.valueOf(id)));
    }

    public boolean isDoingUSB3test() {
        return this.mIsDoingUSB3test;
    }

    /* access modifiers changed from: private */
    public class Usb3Handle extends BroadcastReceiver {
        public Usb3Handle(IntentFilter filter) {
            FtUtil.log_i("FactoryTestMainInnerUSB3", "Usb3Handle", null);
        }

        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            FtUtil.log_d("FactoryTestMainInnerUSB3", "mBroadcastReceiver.onReceive", "action=" + action);
            if ("android.hardware.usb.action.USB_STATE".equals(action)) {
                boolean connected = intent.getExtras().getBoolean("connected");
                boolean configured = intent.getExtras().getBoolean("configured");
                FtUtil.log_d("FactoryTestMainInnerUSB3", "USB State: " + connected);
                if (!connected || !configured) {
                    if (!connected && !configured) {
                        FtUtil.log_d("FactoryTestMainInnerUSB3", "onReceive", FtUtil.setMspSeqMessage(1, FactoryTestMainInnerUSB3.this.mTestName, "Fail / Reason : Unstable connectivity usb3"));
                    } else if (!connected) {
                        FtUtil.log_d("FactoryTestMainInnerUSB3", "onReceive", FtUtil.setMspSeqMessage(1, FactoryTestMainInnerUSB3.this.mTestName, "Fail / Reason : USB3 not connected"));
                    } else if (!configured) {
                        FtUtil.log_d("FactoryTestMainInnerUSB3", "onReceive", FtUtil.setMspSeqMessage(1, FactoryTestMainInnerUSB3.this.mTestName, "Fail / Reason : USB3 not configured"));
                    }
                } else if ("0310".equals(ModuleDevice.instance(context).getUSBType())) {
                    FactoryTestMainInnerUSB3.this.sendMessageTestResult(FactoryTestMain.WHAT_RESULT, (byte) 70, (byte) 80);
                    FactoryTestMainInnerUSB3.this.stopUSB3();
                } else {
                    FactoryTestMainInnerUSB3.this.sendMessageTestResultFailCase(FactoryTestMain.WHAT_RESULT_FAIL_CASE, (byte) 70);
                    Toast.makeText(context, "USB type isn't " + FactoryTestMainInnerUSB3.this.mTestName, 1).show();
                    FactoryTestMainInnerUSB3.this.stopUSB3();
                    FtUtil.log_d("FactoryTestMainInnerUSB3", "onReceive", FtUtil.setMspSeqMessage(1, FactoryTestMainInnerUSB3.this.mTestName, "Fail / Reason : incorrect USB3 Type"));
                }
            }
        }
    }
}
