package com.sec.factory.app.factorytest;

import android.app.Service;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.IBinder;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.NVAccessor;
import java.util.HashMap;
import java.util.Locale;

public class FactoryTestNvObserver extends Service {
    private static final String CLASS_NAME = "FactoryTestNvObserver";
    private static final String INTENT_NV_INFORMATION = "com.sec.factory.CMD_NV_INFORMATION";
    private static final HashMap<Integer, String> mNvDataTable = new HashMap<Integer, String>() {
        /* class com.sec.factory.app.factorytest.FactoryTestNvObserver.AnonymousClass1 */

        {
            put(1, "SMD F/T");
            put(2, "SMD CAL");
            put(7, "RF CAL1");
            put(8, "RF CAL2");
            put(9, "RST");
            put(10, "LTE CAL");
            put(11, "FINAL 1");
            put(13, "NON RF TEST");
            put(15, "FINAL 2");
            put(16, "IMEI WRITE");
            put(31, "MAIN F/T");
            put(284, "RF CAL 5G");
            put(285, "FINAL 5G");
        }
    };
    private BroadcastReceiver mBroadcastReceiver = new BroadcastReceiver() {
        /* class com.sec.factory.app.factorytest.FactoryTestNvObserver.AnonymousClass2 */

        public void onReceive(Context context, Intent intent) {
            if ("com.sec.factory.CMD_NV_INFORMATION".equals(intent.getAction())) {
                int nv = intent.getIntExtra("nv", -1);
                String testName = FactoryTestManager.getItemName_NV(nv);
                String specificTestName = FactoryTestNvObserver.this.searchNvNameAboutNvInt(nv);
                String nvValueStr = FactoryTestNvObserver.this.convertNvValueToStrValue(NVAccessor.getNV(nv));
                if (testName != null) {
                    FtUtil.log_d(FactoryTestNvObserver.CLASS_NAME, "onReceive", FtUtil.setMspSeqMessage(0, " NV(" + nv + ") ", " " + testName + " : " + nvValueStr));
                } else if (specificTestName != null) {
                    FtUtil.log_d(FactoryTestNvObserver.CLASS_NAME, "onReceive", FtUtil.setMspSeqMessage(0, " NV(" + nv + ") ", " " + specificTestName + " : " + nvValueStr));
                } else {
                    FtUtil.log_d(FactoryTestNvObserver.CLASS_NAME, "onReceive", FtUtil.setMspSeqMessage(0, " NV(" + nv + ") ", " No Info : " + nvValueStr));
                }
            }
        }
    };

    public IBinder onBind(Intent arg0) {
        return null;
    }

    public void onCreate() {
        FtUtil.log_i(CLASS_NAME, "onCreate", null);
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("com.sec.factory.CMD_NV_INFORMATION");
        registerReceiver(this.mBroadcastReceiver, intentFilter);
    }

    public int onStartCommand(Intent intent, int flags, int startId) {
        FtUtil.log_i(CLASS_NAME, "onStartCommand", null);
        return 1;
    }

    public void onDestroy() {
        FtUtil.log_i(CLASS_NAME, "onDestroy", null);
        unregisterReceiver(this.mBroadcastReceiver);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String searchNvNameAboutNvInt(int nv) {
        HashMap<Integer, String> hashMap = mNvDataTable;
        if (hashMap.containsKey(Integer.valueOf(nv))) {
            FtUtil.log_d(CLASS_NAME, String.format(Locale.US, "NV %d : %s", Integer.valueOf(nv), hashMap.get(Integer.valueOf(nv))));
            return hashMap.get(Integer.valueOf(nv));
        }
        FtUtil.log_d(CLASS_NAME, String.format(Locale.US, "Nv %d : No Name", Integer.valueOf(nv)));
        return null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String convertNvValueToStrValue(byte nvValue) {
        switch (nvValue) {
            case 69:
                return "E";
            case 70:
                return "F";
            case 78:
                return "N";
            case 80:
                return "P";
            default:
                return "";
        }
    }
}
