package com.sec.factory.app.factorytest;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Bundle;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.os.Messenger;
import android.os.RemoteException;
import com.sec.factory.aporiented.athandler.AtFunctest;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.util.Iterator;
import java.util.Stack;
import java.util.concurrent.ConcurrentLinkedQueue;

public class FactoryTestRemoteController {
    public static final String CLASS_NAME = "FactoryTestRemoteController";
    public static final String COMMAND = "command";
    public static final String DATA = "data";
    public static final String FAIL = "FAIL";
    public static final String PASS = "PASS";
    public static final int WHAT_DONE = 10004;
    public static final int WHAT_INDEX_BASE = 10000;
    public static final int WHAT_INIT = 10006;
    public static final int WHAT_RESULT = 10007;
    public static final int WHAT_RUNNING = 10003;
    public static final int WHAT_START = 10002;
    public static final int WHAT_UPDATE = 10005;
    public static final int WHAT_WAIT = 10001;
    private Context mContext = null;
    public FactoryTestMainAdapter mFactoryTestMainAdapter;
    public Handler mFeedBackHandler;
    private Messenger mIncomingMessenger;
    public Handler mIncommingHandler;
    private boolean mIsReturnMsg = false;
    private ConcurrentLinkedQueue<TestItemInfo> mItemQueue = null;
    private Messenger mOutgoingMessenger = null;
    protected Stack<FactoryTestRemoteServiceConnetion> mRemoteServiceConnetionList = new Stack<>();
    public Handler mResultHandler;

    public static class TestItemInfo {
        public static final int BACKGROUND = 1;
        private static final int FAIL = 0;
        public static final int FOREGROUND = 0;
        private static final int PASS = -1;
        private ComponentName mComponent;
        private int mComponentType;
        private int mResult = 0;
        private int mTestID;
        private TEST_METHOD mTestMethod = TEST_METHOD.HUMAN_SENSORY;
        private int mTestNV;
        private String mTestName;
        private int mTestPosition;

        TestItemInfo(String name, int testID, int testPosition, int testNV, ComponentName component, int componentType) {
            this.mTestName = name;
            this.mTestID = testID;
            this.mTestPosition = testPosition;
            this.mTestNV = testNV;
            this.mComponent = component;
            this.mComponentType = componentType;
        }

        /* access modifiers changed from: package-private */
        public String getTestName() {
            return this.mTestName;
        }

        /* access modifiers changed from: package-private */
        public int getTestID() {
            return this.mTestID;
        }

        /* access modifiers changed from: package-private */
        public int getTestNV() {
            return this.mTestNV;
        }

        /* access modifiers changed from: package-private */
        public int getTestPosition() {
            return this.mTestPosition;
        }

        /* access modifiers changed from: package-private */
        public ComponentName getComponentName() {
            return this.mComponent;
        }

        /* access modifiers changed from: package-private */
        public int getComponentType() {
            return this.mComponentType;
        }

        public String toString() {
            return this.mTestName;
        }

        public int getResult() {
            return this.mResult;
        }

        public void setResultToPass() {
            this.mResult = -1;
        }

        public void setTestMethod(TEST_METHOD method) {
            FtUtil.log_d(FactoryTestRemoteController.CLASS_NAME, "setTestMethod", "TEST_NAME : " + this.mTestName + "(ID:" + this.mTestID + ") method : " + method.name());
            this.mTestMethod = method;
        }

        public TEST_METHOD getTestMethod() {
            return this.mTestMethod;
        }

        /* access modifiers changed from: package-private */
        public enum TEST_METHOD {
            PHONE_SELF("self"),
            HUMAN_SENSORY("human");
            
            private String _tag = "none";

            private TEST_METHOD(String tag) {
                this._tag = tag;
            }

            private String getTag() {
                return this._tag;
            }

            public static TEST_METHOD parseTag(String arg) {
                if (arg == null) {
                    return HUMAN_SENSORY;
                }
                TEST_METHOD[] values = values();
                for (TEST_METHOD method : values) {
                    if (arg.contains(method.getTag())) {
                        return method;
                    }
                }
                return HUMAN_SENSORY;
            }
        }
    }

    public FactoryTestRemoteController(Context context, Handler feedbackHandler, Handler resultHandler, FactoryTestMainAdapter adapter) {
        this.mContext = context;
        this.mFeedBackHandler = feedbackHandler;
        this.mResultHandler = resultHandler;
        this.mFactoryTestMainAdapter = adapter;
        this.mItemQueue = new ConcurrentLinkedQueue<>();
        this.mIncommingHandler = new Handler(this.mContext.getMainLooper()) {
            /* class com.sec.factory.app.factorytest.FactoryTestRemoteController.AnonymousClass1 */

            public void handleMessage(Message msg) {
                FtUtil.log_d(FactoryTestRemoteController.CLASS_NAME, "handleMessage", "get message from FactoryTestRemoteService, what : " + msg.what);
                int what = msg.what;
                Bundle bundle = msg.getData();
                switch (what) {
                    case 10001:
                        FactoryTestRemoteController.this.terminateTestService(msg.arg1);
                        return;
                    case 10004:
                        FactoryTestRemoteServiceConnetion conn = FactoryTestRemoteController.this.mRemoteServiceConnetionList.peek();
                        if (conn != null) {
                            FactoryTestRemoteController.this.mContext.unbindService(conn);
                            FactoryTestRemoteController.this.mRemoteServiceConnetionList.pop();
                        }
                        FactoryTestRemoteController.this.terminateTestService(msg.arg1);
                        return;
                    case 10007:
                        String data = bundle != null ? bundle.getString("data", "FAIL") : "FAIL";
                        if (data.equals("PASS")) {
                            if (FactoryTestRemoteController.this.mItemQueue != null && !FactoryTestRemoteController.this.mItemQueue.isEmpty() && ((TestItemInfo) FactoryTestRemoteController.this.mItemQueue.peek()).getTestID() == msg.arg1) {
                                FtUtil.log_d(FactoryTestRemoteController.CLASS_NAME, "handleMessage", "The automatic test is ongoing, id=" + msg.arg1);
                                ((TestItemInfo) FactoryTestRemoteController.this.mItemQueue.peek()).setResultToPass();
                            }
                            if (FactoryTestRemoteController.this.mResultHandler != null) {
                                FactoryTestRemoteController.this.mResultHandler.sendMessage(FactoryTestRemoteController.this.mResultHandler.obtainMessage(FactoryTestMain.WHAT_RESULT, msg.arg1, 80));
                                return;
                            }
                            return;
                        } else if (data.equals("FAIL")) {
                            FtUtil.log_d(FactoryTestRemoteController.CLASS_NAME, "handleMessage", "Update the FactoryTestMainAdapter when the automatic semi test is failed. id =" + msg.arg1);
                            FactoryTestManager.notifyDataSetChanged();
                            return;
                        } else {
                            return;
                        }
                    default:
                        FtUtil.log_w(FactoryTestRemoteController.CLASS_NAME, "get", "wrong message");
                        return;
                }
            }
        };
        this.mIncomingMessenger = new Messenger(this.mIncommingHandler);
    }

    public void cleanWithService() {
        FtUtil.log_d(CLASS_NAME, "cleanWithService");
        Iterator<FactoryTestRemoteServiceConnetion> it = this.mRemoteServiceConnetionList.iterator();
        while (it.hasNext()) {
            try {
                this.mContext.unbindService(it.next());
            } catch (IllegalArgumentException e) {
            }
        }
        this.mRemoteServiceConnetionList.clear();
        this.mItemQueue = null;
        this.mOutgoingMessenger = null;
        this.mIncommingHandler = null;
        this.mIncomingMessenger = null;
    }

    public void clean() {
        FtUtil.log_d(CLASS_NAME, "clean");
        this.mItemQueue = null;
        this.mOutgoingMessenger = null;
        this.mIncommingHandler = null;
        this.mIncomingMessenger = null;
    }

    /* access modifiers changed from: protected */
    public class FactoryTestRemoteServiceConnetion implements ServiceConnection {
        protected FactoryTestRemoteServiceConnetion() {
        }

        public void onServiceConnected(ComponentName className, IBinder service) {
            FtUtil.log_d(FactoryTestRemoteController.CLASS_NAME, "onServiceConnected", "* onServiceConnected()");
            FactoryTestRemoteController.this.mOutgoingMessenger = new Messenger(service);
            FactoryTestRemoteController.this.onStartTest();
        }

        public void onServiceDisconnected(ComponentName className) {
            FtUtil.log_d(FactoryTestRemoteController.CLASS_NAME, "onServiceDisconnected", "* onServiceDisconnected()");
            FactoryTestRemoteController.this.mOutgoingMessenger = null;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onStartTest() {
        FtUtil.log_d(CLASS_NAME, "onStartTest", "testName : " + this.mItemQueue.peek().getTestName());
        send(10006, String.valueOf(10006));
        Handler handler = this.mFeedBackHandler;
        if (handler != null) {
            handler.sendMessage(handler.obtainMessage(3, (this.mItemQueue.peek().getTestPosition() + 1) + ". " + this.mItemQueue.peek().getTestName()));
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void terminateTestService(int testID) {
        setInvisibleItems(null);
        Handler handler = this.mFeedBackHandler;
        if (handler != null) {
            handler.sendEmptyMessage(4);
        }
        ConcurrentLinkedQueue<TestItemInfo> concurrentLinkedQueue = this.mItemQueue;
        if (concurrentLinkedQueue != null && !concurrentLinkedQueue.isEmpty()) {
            FtUtil.log_d(CLASS_NAME, "terminateTestService", "testName : " + this.mItemQueue.peek().getTestName());
            int result = this.mItemQueue.peek().getResult();
            FtUtil.log_d(CLASS_NAME, "terminateTestService", "testID=" + testID + ", result : " + result);
            onEndTest(testID, result);
        }
    }

    public boolean connectToFactoryTestRemoteService(Intent intent) {
        FtUtil.log_i(CLASS_NAME, "connectToFactoryTestRemoteService : " + intent.toString());
        FactoryTestRemoteServiceConnetion connection = new FactoryTestRemoteServiceConnetion();
        this.mRemoteServiceConnetionList.add(connection);
        FtUtil.log_i(CLASS_NAME, "connectToFactoryTestRemoteService mRemoteServiceConnetionList size " + this.mRemoteServiceConnetionList.size());
        return this.mContext.bindService(intent, connection, 1);
    }

    public void startTest() {
        checkReturnOK();
        ConcurrentLinkedQueue<TestItemInfo> concurrentLinkedQueue = this.mItemQueue;
        if (concurrentLinkedQueue != null && !concurrentLinkedQueue.isEmpty()) {
            TestItemInfo item = this.mItemQueue.peek();
            int itemID = item.mTestID;
            FtUtil.log_i(CLASS_NAME, "startTest Running", "itemName : " + FactoryTestManager.getItemName_RequestCode(itemID));
            FactoryTestMain.CURRENT_TEST_ID = itemID;
            if (FactoryTestManager.isForegroundTest(item.getTestPosition())) {
                ((FactoryTestMain) this.mContext).launchTest(itemID);
            }
        }
    }

    public void onEndTest(int requestCode, int resultCode) {
        FtUtil.log_i(CLASS_NAME, "onEndTest", "itemName : " + FactoryTestManager.getItemName_RequestCode(requestCode));
        ConcurrentLinkedQueue<TestItemInfo> concurrentLinkedQueue = this.mItemQueue;
        if (concurrentLinkedQueue != null && !concurrentLinkedQueue.isEmpty()) {
            int itemID = this.mItemQueue.peek().mTestID;
            FtUtil.log_i(CLASS_NAME, "onEndTest", "top item itemName : " + FactoryTestManager.getItemName_RequestCode(itemID));
            if (itemID == requestCode && resultCode == -1) {
                FtUtil.log_i(CLASS_NAME, "onEndTest", "Test completed, result = " + resultCode);
                this.mItemQueue.poll();
                if (this.mItemQueue.isEmpty()) {
                    Handler handler = this.mResultHandler;
                    handler.sendMessage(handler.obtainMessage(FactoryTestMain.WHAT_SELECT_ITEM, -1, FactoryTestManager.getItemPosition_ID(requestCode) + 1));
                    return;
                }
                startTest();
            } else if (getCountTestMethodSelfItemInQueue() >= 0) {
                int nvKey = FactoryTestManager.getItemNVKey(FactoryTestManager.getItemPosition_ID(requestCode));
                sendResponseSemiResultToAtFunctest("NG_" + nvKey);
                Handler handler2 = this.mResultHandler;
                handler2.sendMessage(handler2.obtainMessage(FactoryTestMain.WHAT_SELECT_ITEM, requestCode, FactoryTestManager.getItemPosition_ID(requestCode)));
                this.mItemQueue.clear();
                FtUtil.log_w(CLASS_NAME, "onEndTest", "Not matched item finished or test result is not OK");
            }
        }
    }

    public boolean addToQueue(int itemID, int itemPosition) {
        int componentType;
        String itemName = FactoryTestManager.getItemName_RequestCode(itemID);
        int itemNV = FactoryTestManager.getItemNVKey(itemPosition);
        if (FactoryTestManager.isBackgroundTest(itemPosition)) {
            componentType = 1;
        } else {
            componentType = 0;
        }
        TestItemInfo item = new TestItemInfo(itemName, itemID, itemPosition, itemNV, null, componentType);
        item.setTestMethod(TestItemInfo.TEST_METHOD.parseTag(Support.FactoryTestMenu.getExtra(itemID)));
        ConcurrentLinkedQueue<TestItemInfo> concurrentLinkedQueue = this.mItemQueue;
        if (concurrentLinkedQueue == null || !concurrentLinkedQueue.add(item)) {
            return false;
        }
        FtUtil.log_i(CLASS_NAME, "addToQueue", "TEST_NAME : " + itemName + "(ID:" + itemID + ")");
        return true;
    }

    public boolean send(int what, String data) {
        FtUtil.log_d(CLASS_NAME, "send", "what:" + what + ", data:" + data);
        if (this.mOutgoingMessenger != null) {
            Bundle req = new Bundle();
            req.putString(COMMAND, data);
            Message msg = new Message();
            msg.what = what;
            msg.setData(req);
            msg.replyTo = this.mIncomingMessenger;
            try {
                this.mOutgoingMessenger.send(msg);
                return true;
            } catch (RemoteException e) {
                FtUtil.log_e(e);
                return true;
            }
        } else {
            FtUtil.log_w(CLASS_NAME, "send", "No connection with DIAtCommandService");
            return false;
        }
    }

    public void setInvisibleItems(int[] items) {
        if (items == null) {
            FtUtil.log_d(CLASS_NAME, "setInvisibleItems", "set clear");
            this.mFactoryTestMainAdapter.setInvisibleItems(items);
        } else {
            FtUtil.log_d(CLASS_NAME, "setInvisibleItems", "set items");
            int[] pos = new int[items.length];
            for (int i = 0; i < items.length; i++) {
                pos[i] = FactoryTestManager.getItemPosition_ID(items[i]);
            }
            this.mFactoryTestMainAdapter.setInvisibleItems(pos);
        }
        FactoryTestManager.notifyDataSetChanged();
    }

    public String getCurrentTestedItemName() {
        if (isRunningTestAutoMatcTest()) {
            return this.mItemQueue.peek().getTestName();
        }
        return null;
    }

    public int getCurrentTestedItemID() {
        if (isRunningTestAutoMatcTest()) {
            return this.mItemQueue.peek().getTestID();
        }
        return -1;
    }

    public boolean isRunningTestAutoMatcTest() {
        ConcurrentLinkedQueue<TestItemInfo> concurrentLinkedQueue = this.mItemQueue;
        if (concurrentLinkedQueue == null || concurrentLinkedQueue.isEmpty()) {
            return false;
        }
        return true;
    }

    public boolean interruptAutoTest(int testID) {
        boolean ret = false;
        if (isRunningTestAutoMatcTest() && testID != getCurrentTestedItemID()) {
            ret = true;
            while (!this.mItemQueue.isEmpty()) {
                TestItemInfo item = this.mItemQueue.peek();
                if (item.getTestID() != testID) {
                    FtUtil.log_d(CLASS_NAME, "interruptAutoTest", "Removed : " + item.getTestName());
                    this.mItemQueue.poll();
                } else {
                    FtUtil.log_d(CLASS_NAME, "interruptAutoTest", "Continue automation test from = " + item.getTestName());
                    return true;
                }
            }
        }
        FtUtil.log_d(CLASS_NAME, "interruptAutoTest", "ret : " + ret);
        return ret;
    }

    private int getCountTestMethodSelfItemInQueue() {
        ConcurrentLinkedQueue<TestItemInfo> concurrentLinkedQueue = this.mItemQueue;
        if (concurrentLinkedQueue == null || concurrentLinkedQueue.isEmpty()) {
            return -1;
        }
        int count = 0;
        Iterator<TestItemInfo> it = this.mItemQueue.iterator();
        while (it.hasNext()) {
            TestItemInfo item = it.next();
            if (item.getTestMethod() == TestItemInfo.TEST_METHOD.PHONE_SELF) {
                FtUtil.log_d(CLASS_NAME, "getCountTestMethodSelfItemInQueue", "remain in queue, PHONE_SELF testName: " + item.getTestName());
                count++;
            }
        }
        FtUtil.log_d(CLASS_NAME, "getCountTestMethodSelfItemInQueue", "count: " + count);
        return count;
    }

    public void sendResponseSemiResultToAtFunctest(String response) {
        if (this.mContext != null) {
            FtUtil.log_d(CLASS_NAME, "sendResponseSemiResultToAtFunctest", "response: " + response);
            this.mContext.sendBroadcast(new Intent(AtFunctest.ACTION_SEMI_FUNCTION_TEST_RESULT).putExtra("response", response));
        }
    }

    public void checkReturnOK() {
        if (!this.mIsReturnMsg) {
            ConcurrentLinkedQueue<TestItemInfo> concurrentLinkedQueue = this.mItemQueue;
            if (concurrentLinkedQueue == null) {
                sendResponseSemiResultToAtFunctest("OK");
                this.mIsReturnMsg = true;
                FtUtil.log_d(CLASS_NAME, "checkReturnOK", EgisFingerprint.MAJOR_VERSION);
            } else if (concurrentLinkedQueue != null && !concurrentLinkedQueue.isEmpty() && this.mItemQueue.peek().getTestMethod() == TestItemInfo.TEST_METHOD.HUMAN_SENSORY) {
                sendResponseSemiResultToAtFunctest("OK");
                this.mIsReturnMsg = true;
                FtUtil.log_d(CLASS_NAME, "checkReturnOK", egis.optical.client.api.EgisFingerprint.MAJOR_VERSION);
            }
        }
    }
}
