package com.sec.factory.app.factorytest;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.SystemProperties;
import android.widget.TextView;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;

public class FactoryTestStatus {
    private final String CLASS_NAME = "FactoryTestStatus";
    private int mBattLevel = -1;
    private BroadcastReceiver mBroadcastReceiverBatteryStatusChanged;
    private Context mContext;
    private int mMemorySize = -1;
    private ModuleDevice mModuleDevice;
    private String mRamSize = "NA";
    private TextView mTestResultText;

    public FactoryTestStatus(Context context, TextView view) {
        this.mContext = context;
        this.mTestResultText = view;
        this.mModuleDevice = ModuleDevice.instance(context);
        if (Support.Feature.getInt(Support.Feature.STATUS_BAR_SIZE) > 0) {
            this.mTestResultText.setTextSize((float) Support.Feature.getInt(Support.Feature.STATUS_BAR_SIZE));
        } else if (FactoryTestMainAdapter.FONT_SIZE != 0.0f) {
            this.mTestResultText.setTextSize(FactoryTestMainAdapter.FONT_SIZE);
        }
        getRamInfo();
        getMemoryInfo();
    }

    public void registerStatusCheckModule() {
        AnonymousClass1 r0 = new BroadcastReceiver() {
            /* class com.sec.factory.app.factorytest.FactoryTestStatus.AnonymousClass1 */

            public void onReceive(Context context, Intent intent) {
                String action = intent.getAction();
                FtUtil.log_d("FactoryTestStatus", "checkStatus, onReceive", "action=" + action);
                if ("android.intent.action.BATTERY_CHANGED".equals(intent.getAction())) {
                    FactoryTestStatus.this.mBattLevel = intent.getIntExtra("level", -1);
                    FactoryTestStatus.this.updateUI();
                }
            }
        };
        this.mBroadcastReceiverBatteryStatusChanged = r0;
        this.mBattLevel = this.mContext.registerReceiver(r0, new IntentFilter("android.intent.action.BATTERY_CHANGED")).getIntExtra("level", -1);
    }

    public void unRegisterStatusCheckModule() {
        BroadcastReceiver broadcastReceiver = this.mBroadcastReceiverBatteryStatusChanged;
        if (broadcastReceiver != null) {
            this.mContext.unregisterReceiver(broadcastReceiver);
            this.mBroadcastReceiverBatteryStatusChanged = null;
            FtUtil.log_i("FactoryTestStatus", "unRegisterStatusCheckModule", null);
        }
    }

    public void getRamInfo() {
        String data = SystemProperties.get("ro.boot.dram_info");
        FtUtil.log_d("FactoryTestStatus", "getRamInfo", "data : " + data);
        if (data == null || data.isEmpty()) {
            FtUtil.log_e("FactoryTestStatus", "getRamInfo", "NG: property read failed");
            this.mRamSize = "NA";
            return;
        }
        FtUtil.log_d("FactoryTestStatus", "getRamInfo", "OK: cmd result=" + data);
        this.mRamSize = data.split(",")[3];
    }

    public void getMemoryInfo() {
        FtUtil.log_d("FactoryTestStatus", "getMemoryInfo");
        if (Support.Feature.getBoolean(Support.Feature.NEED_IMEM_CHECK_DEVICESIZE)) {
            float totalSize = (float) ((long) (((float) this.mModuleDevice.getInnerMemoryDevSize(1024)) / 1048576.0f));
            if (totalSize <= 4.0f) {
                this.mMemorySize = 4;
            } else if (totalSize <= 8.0f) {
                this.mMemorySize = 8;
            } else if (totalSize <= 16.0f) {
                this.mMemorySize = 16;
            } else if (totalSize <= 32.0f) {
                this.mMemorySize = 32;
            } else if (totalSize <= 64.0f) {
                this.mMemorySize = 64;
            } else if (totalSize <= 128.0f) {
                this.mMemorySize = 128;
            } else if (totalSize <= 256.0f) {
                this.mMemorySize = 256;
            } else if (totalSize <= 512.0f) {
                this.mMemorySize = 512;
            } else if (totalSize <= 1024.0f) {
                this.mMemorySize = 1024;
            } else if (totalSize <= 1536.0f) {
                this.mMemorySize = 1536;
            } else if (totalSize <= 2048.0f) {
                this.mMemorySize = 2048;
            } else if (totalSize <= 3072.0f) {
                this.mMemorySize = 3072;
            } else if (totalSize <= 4096.0f) {
                this.mMemorySize = 4096;
            } else {
                this.mMemorySize = 5120;
            }
        } else {
            float totalSize2 = ((float) this.mModuleDevice.getSize(0, 1024)) / 1048576.0f;
            if (totalSize2 <= 4.0f) {
                this.mMemorySize = 4;
            } else if (totalSize2 <= 8.0f) {
                this.mMemorySize = 8;
            } else if (totalSize2 <= 16.0f) {
                this.mMemorySize = 16;
            } else if (totalSize2 <= 32.0f) {
                this.mMemorySize = 32;
            } else if (totalSize2 <= 64.0f) {
                this.mMemorySize = 64;
            } else if (totalSize2 <= 128.0f) {
                this.mMemorySize = 128;
            } else if (totalSize2 <= 256.0f) {
                this.mMemorySize = 256;
            } else if (totalSize2 <= 512.0f) {
                this.mMemorySize = 512;
            } else if (totalSize2 <= 1024.0f) {
                this.mMemorySize = 1024;
            } else if (totalSize2 <= 1536.0f) {
                this.mMemorySize = 1536;
            } else if (totalSize2 <= 2048.0f) {
                this.mMemorySize = 2048;
            } else if (totalSize2 <= 3072.0f) {
                this.mMemorySize = 3072;
            } else if (totalSize2 <= 4096.0f) {
                this.mMemorySize = 4096;
            } else {
                this.mMemorySize = 5120;
            }
        }
    }

    public void updateUI() {
        String result = ((" " + this.mBattLevel + "% ") + " / " + this.mRamSize) + " / " + this.mMemorySize + "G";
        if (this.mBattLevel <= 49) {
            this.mTestResultText.setTextColor(-65536);
        } else {
            this.mTestResultText.setTextColor(-16777216);
        }
        this.mTestResultText.setText(result);
    }
}
