package com.sec.factory.app.factorytest;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.KeyCharacterMap;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;
import com.sec.factory.R;
import com.sec.factory.app.ui.UIBase;
import com.sec.factory.modules.ModuleCommunicationService;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.modules.ModuleTouchScreen;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.NVAccessor;
import com.sec.xmldata.support.Support;
import java.io.File;

public class TSPCal extends UIBase {
    private static final String CLASS_NAME = "TSPCal";
    private static final int KEYCODE_WINK = 1082;
    private static final int MSG_START_CALIBRATION = 1;
    public static final byte NOTEST = 78;
    public static final int NV_TSP_SELFTEST = 287;
    public static final int NV_TSP_SELFTEST2 = 288;
    public static final byte PASS = 80;
    private final long VOL_KEY_EVENT_TIMELAG = 2000;
    private boolean calIsUnderway = false;
    private boolean hasBackKey = true;
    private boolean isKeyPressed = false;
    private boolean isPass = false;
    private boolean isTouched = false;
    private LinearLayout mBackground;
    public Handler mHandler = new Handler() {
        /* class com.sec.factory.app.factorytest.TSPCal.AnonymousClass1 */

        public void handleMessage(Message msg) {
            FtUtil.log_d(TSPCal.CLASS_NAME, "mHandler.handleMessage", "msg.what : " + ModuleTouchScreen.convertorTSPWhat(msg.what));
            FtUtil.log_d(TSPCal.CLASS_NAME, "mHandler.handleMessage", "msg.arg1 : " + ModuleTouchScreen.convertorTSPID(msg.arg1));
            FtUtil.log_d(TSPCal.CLASS_NAME, "mHandler.handleMessage", "msg.arg2 : " + ModuleTouchScreen.convertorTSPID(msg.arg2));
            StringBuilder sb = new StringBuilder();
            sb.append("msg.obj : ");
            sb.append(msg.obj != null ? msg.obj.toString() : "null");
            FtUtil.log_d(TSPCal.CLASS_NAME, "mHandler.handleMessage", sb.toString());
            TSPCal.this.mBackground.setBackgroundColor(TSPCal.this.getResources().getColor(R.color.white));
            if (TSPCal.this.isTouched) {
                FtUtil.log_d(TSPCal.CLASS_NAME, "TSPCalibration", "cal fail (touch event occured)");
                TSPCal.this.calResultMessage("Fail (Touch event occured)");
            } else if (TSPCal.this.isKeyPressed) {
                FtUtil.log_d(TSPCal.CLASS_NAME, "TSPCalibration", "cal fail (key event occured)");
                TSPCal.this.calResultMessage("Fail (key event occured)");
            } else if (msg.what == ModuleTouchScreen.TSP_WHAT_STATUS_OK) {
                FtUtil.log_d(TSPCal.CLASS_NAME, "mHandler.handleMessage", "TSP_WHAT_STATUS_OK");
                FtUtil.log_d(TSPCal.CLASS_NAME, "TSPCalibration", "cal success");
                TSPCal.this.isPass = true;
                TSPCal.this.calResultMessage("OK");
            } else if (msg.what == ModuleTouchScreen.TSP_WHAT_STATUS_NG) {
                FtUtil.log_d(TSPCal.CLASS_NAME, "mHandler.handleMessage", "TSP_WHAT_STATUS_NG");
                FtUtil.log_d(TSPCal.CLASS_NAME, "TSPCalibration", "cal fail");
                TSPCal.this.calResultMessage("Fail");
            } else if (msg.what == ModuleTouchScreen.TSP_WHAT_STATUS_NA) {
                FtUtil.log_d(TSPCal.CLASS_NAME, "mHandler.handleMessage", "TSP_WHAT_STATUS_NA");
                FtUtil.log_d(TSPCal.CLASS_NAME, "TSPCalibration", "cal fail");
                TSPCal.this.calResultMessage("Not Available");
            }
        }
    };
    private ModuleDevice mModuleDevice;
    public ModuleTouchScreen mModuleTouchScreen;
    private long mPrevVolKeyEventTime = -1;
    private Handler mStateHander = new Handler() {
        /* class com.sec.factory.app.factorytest.TSPCal.AnonymousClass3 */

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    FtUtil.log_d(TSPCal.CLASS_NAME, "mStateHander", "MSG_START_CALIBRATION");
                    TSPCal.this.startTSPCalibration();
                    return;
                default:
                    return;
            }
        }
    };
    private TextView mTSPCalDonottouch;
    private TextView mTSPCalReady;
    private TextView mTSPCalSelect;
    private TextView mTSPCalStatus;
    private TextView mTSPCalTitle;
    private int numberOfTSP = 1;
    private int selectedTSP = 1;

    public TSPCal() {
        super(CLASS_NAME);
    }

    private void changeTSP() {
        int i = this.selectedTSP;
        if (i < this.numberOfTSP) {
            this.selectedTSP = i + 1;
        } else {
            this.selectedTSP = 1;
        }
        TextView textView = this.mTSPCalSelect;
        textView.setText("Selected TSP : " + this.selectedTSP + "\n(Press 'Volume up' to change)");
    }

    private int checkNumberOfTSP() {
        int count = 1;
        while (true) {
            if (!new File("/sys/class/sec/tsp" + count).exists()) {
                break;
            }
            count++;
        }
        if (count > 1) {
            count--;
        }
        FtUtil.log_d(CLASS_NAME, "checkNumberOfTSP", "Number of TSP : " + count);
        return count;
    }

    private void initUI() {
        this.mBackground = (LinearLayout) findViewById(R.id.background);
        FtUtil.setSystemKeyBlock(getComponentName(), 3);
        this.mTSPCalTitle = (TextView) findViewById(R.id.tspcal_title);
        this.mTSPCalSelect = (TextView) findViewById(R.id.tspcal_select);
        this.mTSPCalReady = (TextView) findViewById(R.id.tspcal_ready);
        this.mTSPCalStatus = (TextView) findViewById(R.id.tspcal_status);
        this.mTSPCalDonottouch = (TextView) findViewById(R.id.tspcal_donottouch);
        boolean deviceHasKey = KeyCharacterMap.deviceHasKey(4);
        this.hasBackKey = deviceHasKey;
        if (!deviceHasKey) {
            this.mTSPCalReady.setText(R.string.tspcal_ready_vol_down);
        }
        int checkNumberOfTSP = checkNumberOfTSP();
        this.numberOfTSP = checkNumberOfTSP;
        if (checkNumberOfTSP > 1) {
            this.mTSPCalSelect.setVisibility(0);
            TextView textView = this.mTSPCalSelect;
            textView.setText("Selected TSP : " + this.selectedTSP + "\n(Press 'Volume up' to change)");
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        this.TEST_ID = getIntent().getIntExtra("testID", -1);
        FtUtil.log_d(CLASS_NAME, "onCreate", "TEST_ID: " + this.TEST_ID);
        if (this.TEST_ID == -1) {
            mUIOrientation = null;
        }
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ui_tspcal);
        initUI();
        if (!Support.Feature.getBoolean(Support.Feature.SUPPORT_TSPCAL_APP, false)) {
            showCustomToast("Not Supported");
            finish();
        }
        FtUtil.setRemoveSystemUI(getWindow(), true);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        this.mModuleDevice = ModuleDevice.instance(this);
        this.mModuleTouchScreen = ModuleTouchScreen.instance(this);
        this.mModuleDevice.startTSPTest("dead_zone_enable,0");
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        this.mModuleDevice.startTSPTest("dead_zone_enable,1");
        if (this.numberOfTSP > 1) {
            this.mModuleTouchScreen.getTSPResult(ModuleTouchScreen.TSP_ID__SELECT_TSP, ModuleCommunicationService.SMD_NOK);
        }
        super.onPause();
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        ModuleDevice moduleDevice = this.mModuleDevice;
        if (moduleDevice != null) {
            moduleDevice.setEPenDisableMode(false);
        }
        FtUtil.setPressureTouchStatus("0");
        super.onDestroy();
    }

    private void showCustomToast(String text) {
        FtUtil.log_d(CLASS_NAME, "showCustomToast", "text = " + text);
        View layout = getLayoutInflater().inflate(R.layout.custom_toast_boot_completed_check, (ViewGroup) findViewById(R.id.llToast));
        ((TextView) layout.findViewById(R.id.text)).setText(text);
        Toast toast = new Toast(getApplicationContext());
        toast.setGravity(16, 0, 0);
        toast.setDuration(0);
        toast.setView(layout);
        toast.show();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startTSPCalibration() {
        if (this.numberOfTSP > 1) {
            ModuleTouchScreen moduleTouchScreen = this.mModuleTouchScreen;
            int i = ModuleTouchScreen.TSP_ID__SELECT_TSP;
            moduleTouchScreen.getTSPResult(i, "" + (this.selectedTSP - 1));
        }
        if (ModuleTouchScreen.TSP_VENDOR_NAME__SEC.equals(this.mModuleTouchScreen.getTSPVendorName()) || ModuleTouchScreen.TSP_VENDOR_NAME__STM.equals(this.mModuleTouchScreen.getTSPVendorName()) || ModuleTouchScreen.TSP_VENDOR_NAME__ZINITIX.equals(this.mModuleTouchScreen.getTSPVendorName()) || ModuleTouchScreen.TSP_VENDOR_NAME__IMAGIS.equals(this.mModuleTouchScreen.getTSPVendorName()) || ModuleTouchScreen.TSP_VENDOR_NAME__SYNAPTICS.equals(this.mModuleTouchScreen.getTSPVendorName())) {
            this.mModuleDevice.setEPenDisableMode(true);
            this.mModuleTouchScreen.getTSPResult(ModuleTouchScreen.TSP_ID__RUN_FORCE_CALIBRATION_FACT, this.mHandler);
            return;
        }
        showCustomToast("Vendor Not Supported");
        finish();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void calResultMessage(String message) {
        AlertDialog alert = new AlertDialog.Builder(this).setTitle("TSP Cal Result").setMessage(message).setPositiveButton(R.string.ok, new DialogInterface.OnClickListener() {
            /* class com.sec.factory.app.factorytest.TSPCal.AnonymousClass2 */

            public void onClick(DialogInterface dialog, int which) {
                TSPCal.this.finish();
            }
        }).create();
        alert.setCancelable(false);
        alert.getWindow().setGravity(17);
        alert.show();
    }

    public void setTSPTestNV(int nv, byte itemResult) {
        FtUtil.log_d(CLASS_NAME, "setTSPTestNV", "NV = " + nv + ", itemResult = " + ((int) itemResult));
        NVAccessor.setNV(nv, itemResult);
    }

    public boolean onTouchEvent(MotionEvent event) {
        super.onTouchEvent(event);
        FtUtil.log_d(CLASS_NAME, "onTouchEvent", null);
        this.isTouched = true;
        return true;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x004f  */
    @Override // com.sec.factory.app.ui.UIBase
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        switch (keyCode) {
            case 3:
                if (!this.calIsUnderway) {
                    int i = this.selectedTSP;
                    if (i == 1) {
                        setTSPTestNV(287, (byte) 78);
                    } else if (i == 2) {
                        setTSPTestNV(288, (byte) 78);
                    }
                    this.mTSPCalReady.setVisibility(8);
                    this.mTSPCalDonottouch.setVisibility(8);
                    FtUtil.log_d(CLASS_NAME, "startTSPCalibration", "cal start");
                    if (Support.Feature.getBoolean(Support.Feature.SUPPORT_TSPCAL_WHITE)) {
                        this.mBackground.setBackgroundColor(getResources().getColor(R.color.white));
                        this.mTSPCalTitle.setVisibility(8);
                        this.mTSPCalSelect.setVisibility(8);
                    } else {
                        this.mBackground.setBackgroundColor(getResources().getColor(R.color.black));
                    }
                    if (!this.isKeyPressed && !this.isTouched) {
                        startTSPCalibration();
                        this.calIsUnderway = true;
                        break;
                    } else {
                        calResultMessage("Fail ( Touch event occured & key event occured ) ");
                        break;
                    }
                }
                break;
            case 4:
            case 187:
                FtUtil.log_d(CLASS_NAME, "onKeyDown", "Key Pressed!");
                this.mPrevVolKeyEventTime = -1;
                this.isKeyPressed = true;
                break;
            case 24:
                if (this.numberOfTSP > 1) {
                    changeTSP();
                    break;
                }
                break;
            case 25:
                if (!this.hasBackKey) {
                    if (this.mPrevVolKeyEventTime == -1) {
                        this.mPrevVolKeyEventTime = event.getEventTime();
                        break;
                    } else {
                        if (event.getEventTime() - this.mPrevVolKeyEventTime > 2000) {
                            this.mPrevVolKeyEventTime = event.getEventTime();
                            break;
                        }
                        if (!this.calIsUnderway) {
                        }
                    }
                }
                break;
            default:
                this.mPrevVolKeyEventTime = -1;
                break;
        }
        return super.onKeyDown(keyCode, event);
    }

    @Override // com.sec.factory.app.ui.UIBase
    public boolean onKeyLongPress(int keyCode, KeyEvent event) {
        switch (keyCode) {
            case 3:
                return true;
            default:
                return true;
        }
    }
}
