package com.sec.factory.app.service;

import android.os.Bundle;
import android.os.Message;
import android.os.Messenger;
import android.os.RemoteException;
import com.sec.factory.support.FtUtil;

public class MessageSender {
    public static final String CLASS_NAME = "MessageSender";
    private Messenger mResponseMessenger;
    private int mTestID;

    public MessageSender(Messenger messenger) {
        this.mTestID = -1;
        FtUtil.log_d(CLASS_NAME, CLASS_NAME, "Create MessageSender");
        this.mResponseMessenger = messenger;
    }

    public MessageSender(Messenger messenger, int ID) {
        this(messenger);
        FtUtil.log_d(CLASS_NAME, CLASS_NAME, "Create MessageSender, ID=" + ID);
        this.mTestID = ID;
    }

    public Messenger getMessageSenderMessenger() {
        return this.mResponseMessenger;
    }

    public boolean setMessenger(Messenger messenger) {
        if (messenger == null) {
            FtUtil.log_w(CLASS_NAME, "setMessenger", "messenger is null");
            return false;
        }
        this.mResponseMessenger = messenger;
        return true;
    }

    public boolean write(int what, String data) {
        FtUtil.log_i(CLASS_NAME, "write", "what=" + what);
        if (this.mResponseMessenger != null) {
            Message msg = new Message();
            msg.what = what;
            msg.arg1 = this.mTestID;
            if (data != null) {
                Bundle req = new Bundle();
                req.putString("data", data);
                msg.setData(req);
            }
            try {
                this.mResponseMessenger.send(msg);
                return false;
            } catch (RemoteException e) {
                FtUtil.log_e(e);
                return false;
            }
        } else {
            FtUtil.log_w(CLASS_NAME, "send", "No connection with FactoryTestRemoteController");
            return false;
        }
    }

    public boolean writeResult(String result) {
        return write(10007, result);
    }

    public boolean requestFinish() {
        return write(10004, null);
    }

    public boolean requestWait() {
        return write(10001, null);
    }

    public void close() {
        if (this.mResponseMessenger != null) {
            this.mResponseMessenger = null;
        }
    }
}
