package com.sec.factory.app.service;

import android.content.Context;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;

public class ServiceScreenSaver extends Thread {
    public static final int BRIGHTNESS_DIM = 20;
    private static final String CLASS_NAME = "ServiceScreenSaver";
    public static final int DIMMING_MODE = 1;
    public static final int FULL_MODE = 0;
    public static final int LCD_OFF_MODE = 2;
    private boolean isInitialized = false;
    private boolean isRunning = true;
    private Context mContext;
    private long mCurrentTime;
    private int mLcdTimeOut;
    private long mPreviousTime;
    private int mScreenSaverSleepTime;
    private long mStartTime;
    private int mStatus;
    private int mTimeOut;

    public ServiceScreenSaver(Context context) {
        this.mContext = context;
    }

    public void run() {
        this.mTimeOut = Support.Feature.getInt(Support.Feature.FACTORY_TEST_MAIN_DIMMING_TIME_OUT) * 60000;
        this.mLcdTimeOut = Support.Feature.getInt(Support.Feature.FACTORY_TEST_MAIN_LCD_OFF_TIME_OUT) * 60000;
        this.mScreenSaverSleepTime = Support.Spec.getInt(Support.Spec.SYS_SCREEN_SAVER_SLEEP);
        if (this.mTimeOut >= 0) {
            FtUtil.log_d(CLASS_NAME, "run", "Screen Saver thread start... \nDimming Time Out : " + (this.mTimeOut / 60000) + " minute\nLCD off Time Out : " + (this.mLcdTimeOut / 60000) + " minute\nScreen Saver Sleep Time : " + this.mScreenSaverSleepTime + " ms");
            this.mStatus = 0;
            try {
                Thread.sleep((long) this.mScreenSaverSleepTime);
                this.isInitialized = true;
                while (this.isRunning) {
                    long currentTimeMillis = System.currentTimeMillis();
                    this.mCurrentTime = currentTimeMillis;
                    long j = this.mPreviousTime;
                    if (currentTimeMillis - j < 0 || currentTimeMillis - j >= 10000) {
                        FtUtil.log_d(CLASS_NAME, "run", "Unexpected time changed, reset current time");
                        updateCurrentTime();
                    } else {
                        this.mPreviousTime = currentTimeMillis;
                        long j2 = this.mStartTime;
                        int i = this.mTimeOut;
                        if (currentTimeMillis - j2 >= ((long) i)) {
                            int i2 = this.mStatus;
                            if (i2 == 0) {
                                if (currentTimeMillis - j2 > ((long) i)) {
                                    this.mStatus = 1;
                                    ModulePower.instance(this.mContext).setBrightness(20);
                                    FtUtil.log_d(CLASS_NAME, "run", "Enter dimming mode...");
                                }
                            } else if (i2 == 1 && currentTimeMillis - j2 > ((long) this.mLcdTimeOut)) {
                                this.mStatus = 2;
                                ModulePower.instance(this.mContext).setLCDState(false);
                                FtUtil.log_d(CLASS_NAME, "run", "Enter LCD off mode...");
                            }
                        } else if (this.mStatus != 0) {
                            this.mStatus = 0;
                            ModulePower.instance(this.mContext).setBrightness(255);
                            ModulePower.instance(this.mContext).setLCDState(true);
                            FtUtil.log_d(CLASS_NAME, "run", "Enter full mode...");
                        }
                    }
                    Thread.sleep(100);
                }
            } catch (InterruptedException e) {
                e.printStackTrace();
            } catch (Throwable th) {
                FtUtil.log_d(CLASS_NAME, "run", "Screen Saver Thread stop...");
                this.isInitialized = false;
                throw th;
            }
            FtUtil.log_d(CLASS_NAME, "run", "Screen Saver Thread stop...");
            this.isInitialized = false;
        }
    }

    public void updateCurrentTime() {
        long currentTimeMillis = System.currentTimeMillis();
        this.mStartTime = currentTimeMillis;
        this.mPreviousTime = currentTimeMillis;
        this.mCurrentTime = currentTimeMillis;
    }

    public void setRunningStatus(boolean status) {
        this.isRunning = status;
    }

    public boolean getRunningStatus() {
        return this.isRunning;
    }

    public void setLCDState(int state) {
        this.mStatus = state;
    }

    public void lcdOff() {
        FtUtil.log_d(CLASS_NAME, "lcdOff", "isInitialized: " + this.isInitialized + " mStatus: " + this.mStatus);
        if (ModulePower.instance(this.mContext).isScreenOn()) {
            FtUtil.log_d(CLASS_NAME, "lcdOff", "Screen is on");
            this.mStatus = 0;
        }
        if (this.isInitialized && this.mStatus != 2) {
            FtUtil.log_d(CLASS_NAME, "lcdOff", "Lcd Off");
            ModulePower.instance(this.mContext).setLCDState(false);
        }
    }
}
