package com.sec.factory.app.service.hwparam;

import android.content.Context;
import android.os.Handler;
import com.sec.factory.app.uicommander.UICommanderService;
import com.sec.factory.modules.ModuleCommon;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.io.File;
import java.io.FileReader;
import java.util.Iterator;
import javax.xml.parsers.DocumentBuilderFactory;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.xml.sax.InputSource;

public class ParseHwparamThread extends Thread {
    private static final String CLASS_NAME = "ParseHwparamThread";
    private final String CONDITION_INFO = "condition_info";
    private final String HQM_LOG_PATH = "/data/system/hqmlog/";
    private final String HQM_PARAM_XML_PATH = "/vendor/etc/hqm_device.xml";
    private final String SYSFS_NODE = "sysfs_node";
    private Context mContext;
    private Handler mHandler;

    public ParseHwparamThread(Handler _handler, Context _context) {
        this.mHandler = _handler;
        this.mContext = _context;
    }

    public void run() {
        if (parse()) {
            FtUtil.log_d(CLASS_NAME, "run", "parse success");
            this.mHandler.sendEmptyMessage(1);
            return;
        }
        FtUtil.log_d(CLASS_NAME, "run", "parse fail");
    }

    private boolean parse() {
        FtUtil.log_d(CLASS_NAME, "parse", "");
        File file = new File("/vendor/etc/hqm_device.xml");
        if (!file.exists()) {
            FtUtil.log_d(CLASS_NAME, "parse", "not exist list files");
            return false;
        }
        boolean parseResult = parseHwParamXML(file);
        FtUtil.log_d(CLASS_NAME, "parse", "Hw Param Data Parse Res : " + parseResult);
        return parseResult;
    }

    private boolean parseHwParamXML(File _fileHqmXml) {
        Element elementRoot = getElementFromXml(_fileHqmXml);
        if (elementRoot == null) {
            FtUtil.log_d(CLASS_NAME, "parseHwParamXML", "elementRoot is null");
            return false;
        } else if (!"hwparam_document".equals(elementRoot.getNodeName())) {
            FtUtil.log_d(CLASS_NAME, "parseHwParamXML", "not hwparam_document");
            return false;
        } else {
            NodeList hwparamInfoList = elementRoot.getChildNodes();
            FtUtil.log_d(CLASS_NAME, "parseHwParamXML", "hwparamInfoList len : " + hwparamInfoList.getLength());
            JSONObject objRoot = new JSONObject();
            JSONArray jarrResult = new JSONArray();
            parseHwParamInfoList(hwparamInfoList, jarrResult);
            parseHQMLog(jarrResult);
            try {
                objRoot.put("PARAMDATA", jarrResult);
            } catch (JSONException e) {
                FtUtil.log_e(e);
            }
            Support.Kernel.writeNsync(Support.Kernel.FAC_HW_PARAM_DATA, getHwParamResult(objRoot));
            return true;
        }
    }

    private Element getElementFromXml(File _fileHqmXml) {
        try {
            FtUtil.log_d(CLASS_NAME, "getElementFromXml", "path : " + _fileHqmXml);
            return DocumentBuilderFactory.newInstance().newDocumentBuilder().parse(new InputSource(new FileReader(_fileHqmXml))).getDocumentElement();
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    private void parseHwParamInfoList(NodeList _hwparamInfoList, JSONArray _jarrRoot) {
        for (int i = 0; i < _hwparamInfoList.getLength(); i++) {
            if (_hwparamInfoList.item(i).getNodeType() == 1) {
                Element hwparamInfo = (Element) _hwparamInfoList.item(i);
                if ("hwparam_info".equals(hwparamInfo.getNodeName())) {
                    String strCompId = hwparamInfo.getAttribute("compID");
                    String strFeature = hwparamInfo.getAttribute("feature");
                    FtUtil.log_d(CLASS_NAME, "parseHwParamInfoList", "ID : " + strCompId + " Feature : " + strFeature);
                    NodeList sysfsInfoList = hwparamInfo.getChildNodes();
                    if (sysfsInfoList.getLength() == 0) {
                        FtUtil.log_d(CLASS_NAME, "parseHwParamInfoList", "there are no child nodes");
                    } else {
                        JSONObject objSysfsInfoList = new JSONObject();
                        getHwParamInfo(sysfsInfoList, objSysfsInfoList);
                        if (objSysfsInfoList.length() == 0) {
                            FtUtil.log_d(CLASS_NAME, "parseHwParamInfoList", "len 0");
                        } else {
                            try {
                                JSONObject objHwParamInfo = new JSONObject();
                                objHwParamInfo.put("COMPID", strCompId);
                                objHwParamInfo.put("FEATURE", strFeature);
                                objHwParamInfo.put("ATVAL", objSysfsInfoList);
                                _jarrRoot.put(objHwParamInfo);
                            } catch (JSONException e) {
                                FtUtil.log_e(e);
                            }
                        }
                    }
                }
            }
        }
    }

    private void getHwParamInfo(NodeList _sysfsInfoList, JSONObject _objSysfsInfoList) {
        for (int j = 0; j < _sysfsInfoList.getLength(); j++) {
            if (_sysfsInfoList.item(j).getNodeType() == 1) {
                Element sysfsInfo = (Element) _sysfsInfoList.item(j);
                if (sysfsInfo.getNodeName().contains("condition_info")) {
                    FtUtil.log_d(CLASS_NAME, "getHwParamInfo", "condition_info -> into one more depth");
                    getHwParamInfo(sysfsInfo.getChildNodes(), _objSysfsInfoList);
                } else if (sysfsInfo.getNodeName().contains("sysfs_node")) {
                    readSysfsInfo(sysfsInfo, _objSysfsInfoList);
                }
            }
        }
    }

    private void readSysfsInfo(Element _sysfsInfo, JSONObject objSysfsInfoList) {
        String type = _sysfsInfo.getAttribute(UICommanderService.UI_UPDATE_HASHMAP_KEY_3);
        String key = _sysfsInfo.getAttribute("key");
        String res = Support.Kernel.readFromPath(_sysfsInfo.getAttribute("value"), true);
        if (res == null) {
            res = "";
        }
        if ("null".equalsIgnoreCase(res)) {
            res = "NULL";
        }
        if ("M".equals(type)) {
            try {
                JSONObject objMulti = new JSONObject("{" + res + "}");
                Iterator<String> iterMultiKeys = objMulti.keys();
                while (iterMultiKeys.hasNext()) {
                    String strMultiKey = iterMultiKeys.next().toString();
                    objSysfsInfoList.put(strMultiKey, objMulti.get(strMultiKey).toString());
                }
            } catch (JSONException e) {
                FtUtil.log_e(e);
            }
        } else {
            try {
                objSysfsInfoList.put(key, res);
            } catch (JSONException e2) {
                FtUtil.log_e(e2);
            }
        }
    }

    private String getHwParamResult(JSONObject _objRoot) {
        FtUtil.log_d(CLASS_NAME, "getHwParamResult", "");
        String strJsonInfo = _objRoot.toString();
        StringBuilder output = new StringBuilder();
        output.append("[HEAD]\n");
        output.append(strJsonInfo.toString() + "\n");
        output.append("[TAIL]\n");
        output.append(ModuleCommon.instance(this.mContext).createChecksum(strJsonInfo.toString()));
        return output.toString();
    }

    private boolean parseHQMLog(JSONArray _jarrRoot) {
        File[] fileHQMLogs = new File("/data/system/hqmlog/").listFiles();
        if (fileHQMLogs == null || fileHQMLogs.length == 0) {
            FtUtil.log_d(CLASS_NAME, "parseHQMLog", "there is no files in hqmlog");
            return false;
        }
        for (int i = 0; i < fileHQMLogs.length; i++) {
            FtUtil.log_d(CLASS_NAME, "parseHQMLog", fileHQMLogs[i].toString());
            JSONObject objHQMLogInfo = new JSONObject();
            String strHQMLog = Support.Kernel.readFromPath(fileHQMLogs[i].getPath(), true);
            String[] strHQMLogs = strHQMLog.split(",");
            String strHQMValue = strHQMLog.substring(strHQMLog.indexOf("{"), strHQMLog.length());
            try {
                objHQMLogInfo.put("COMPID", strHQMLogs[0]);
                objHQMLogInfo.put("FEATURE", strHQMLogs[1]);
                FtUtil.log_d(CLASS_NAME, "parseHQMLog", "COMPID : " + strHQMLogs[0] + ", FEATURE : " + strHQMLogs[1]);
                objHQMLogInfo.put("ATVAL", new JSONObject(strHQMValue));
                _jarrRoot.put(objHQMLogInfo);
            } catch (JSONException e) {
                FtUtil.log_e(e);
            }
            fileHQMLogs[i].delete();
        }
        return true;
    }
}
