package com.sec.factory.app.service.hwparam;

import android.content.Context;
import android.os.Handler;
import android.telephony.TelephonyManager;
import com.sec.factory.modules.ModuleCommon;
import com.sec.factory.modules.ModuleTouchScreen;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.io.File;
import java.io.FileReader;
import java.util.Hashtable;
import java.util.Iterator;
import javax.xml.parsers.DocumentBuilderFactory;
import org.json.JSONException;
import org.json.JSONObject;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.xml.sax.InputSource;

public class ParseHwpartThread extends Thread {
    private static final String CLASS_NAME = "ParseHwpartThread";
    private final String HW_PART_XML_PATH = "/system/factory/hqm_partinfo_fac.xml";
    private Context mContext;
    private Handler mHandler;
    private String mStrRFPA;
    private String mStrTranceiver;
    private Hashtable<String, String> mTablePartInfo = new Hashtable<>();

    public ParseHwpartThread(Handler _handler, Context _context, String _strTranceiver, String _strRFPA) {
        this.mHandler = _handler;
        this.mContext = _context;
        this.mStrTranceiver = _strTranceiver;
        this.mStrRFPA = _strRFPA;
    }

    public void run() {
        if (parse()) {
            FtUtil.log_d(CLASS_NAME, "run", "parse success");
            this.mHandler.sendEmptyMessage(2);
            return;
        }
        FtUtil.log_d(CLASS_NAME, "run", "parse fail");
    }

    public void backupHwPartInform() {
        if (Support.Kernel.isExistFile(Support.Kernel.FAC_HW_PART_INFORM_DATA)) {
            try {
                JSONObject objHwPartInfo = (JSONObject) new JSONObject(Support.Kernel.readNsyncContinuous(Support.Kernel.FAC_HW_PART_INFORM_DATA, true).split("\n")[1]).get("PARTINFO");
                Iterator<String> iterPartInform = objHwPartInfo.keys();
                while (iterPartInform.hasNext()) {
                    String strKey = iterPartInform.next();
                    FtUtil.log_d(CLASS_NAME, "backupHwPartInform", strKey + " " + objHwPartInfo.get(strKey));
                    this.mTablePartInfo.put(strKey, (String) objHwPartInfo.get(strKey));
                }
            } catch (Exception e) {
                FtUtil.log_e(e);
            }
        } else {
            FtUtil.log_d(CLASS_NAME, "backupHwPartInform", "not exist file");
        }
    }

    private boolean parse() {
        FtUtil.log_d(CLASS_NAME, "parse", "");
        backupHwPartInform();
        File file = new File("/system/factory/hqm_partinfo_fac.xml");
        if (!file.exists()) {
            FtUtil.log_d(CLASS_NAME, "parse", "not exist list Files");
            return false;
        }
        boolean parseResult = parseHwPartXML(file);
        FtUtil.log_d(CLASS_NAME, "parse", "Hw Part Data Parse Res : " + parseResult);
        return parseResult;
    }

    public boolean parseHwPartXML(File _fileHqmXml) {
        Document document;
        String value;
        String value2;
        String res;
        String res2;
        FtUtil.log_d(CLASS_NAME, "parseHwPartXML", "");
        try {
            FtUtil.log_d(CLASS_NAME, "parseHwPartXML", "path : " + _fileHqmXml);
            Document document2 = DocumentBuilderFactory.newInstance().newDocumentBuilder().parse(new InputSource(new FileReader(_fileHqmXml)));
            Element elementRoot = document2.getDocumentElement();
            JSONObject objRoot = new JSONObject();
            if (elementRoot == null) {
                FtUtil.log_d(CLASS_NAME, "parseHwPartXML", "elementRoot is null");
                return false;
            } else if (!"hwpartinform_document".equals(elementRoot.getNodeName())) {
                FtUtil.log_d(CLASS_NAME, "parseHwPartXML", "not hwpartinform_document");
                return false;
            } else {
                StringBuilder output = new StringBuilder();
                JSONObject objHwPartInfo = new JSONObject();
                NodeList hwpartInfoList = elementRoot.getChildNodes();
                int i = 0;
                while (i < hwpartInfoList.getLength()) {
                    if (hwpartInfoList.item(i).getNodeType() != 1) {
                        document = document2;
                    } else {
                        Element hwpartInfo = (Element) hwpartInfoList.item(i);
                        if (hwpartInfo.getNodeName().contains("sysfs_node")) {
                            String key = hwpartInfo.getAttribute("key");
                            String path = hwpartInfo.getAttribute("path");
                            document = document2;
                            String chipsetType = hwpartInfo.getAttribute("chipset_type");
                            String res3 = Support.Kernel.readFromPath(path, true);
                            if (res3 == null) {
                                res3 = "";
                            }
                            if ("null".equalsIgnoreCase(res3)) {
                                res2 = "NULL";
                            } else {
                                res2 = res3;
                            }
                            if (checkChipType(chipsetType)) {
                                try {
                                    objHwPartInfo.put(key, res2);
                                } catch (JSONException e) {
                                    FtUtil.log_e(e);
                                }
                            }
                        } else {
                            document = document2;
                            if (hwpartInfo.getNodeName().contains("sysprop_node")) {
                                String key2 = hwpartInfo.getAttribute("key");
                                String res4 = Support.Properties.getProp(hwpartInfo.getAttribute("path"));
                                if (res4 == null) {
                                    res = "";
                                } else {
                                    res = res4;
                                }
                                try {
                                    objHwPartInfo.put(key2, res);
                                } catch (JSONException e2) {
                                    FtUtil.log_e(e2);
                                }
                            } else if (hwpartInfo.getNodeName().contains("handwriting_node")) {
                                String key3 = hwpartInfo.getAttribute("key");
                                String value3 = hwpartInfo.getAttribute("value");
                                String strOriginVal = this.mTablePartInfo.get(key3);
                                if (strOriginVal != null && !"NA".equals(strOriginVal)) {
                                    value3 = strOriginVal;
                                    FtUtil.log_d(CLASS_NAME, "parseHwPartXML", "already exist origin val : " + value3);
                                }
                                if (value3 == null || "".equals(value3)) {
                                    FtUtil.log_d(CLASS_NAME, "parseHwPartXML", "value blank!");
                                    value2 = "NA";
                                } else {
                                    value2 = value3;
                                }
                                try {
                                    objHwPartInfo.put(key3, value2);
                                } catch (JSONException e3) {
                                    FtUtil.log_e(e3);
                                }
                            } else if (hwpartInfo.getNodeName().contains("function_node")) {
                                String key4 = hwpartInfo.getAttribute("key");
                                String value4 = getFuncVal(key4);
                                if (value4 == null) {
                                    value = "";
                                } else {
                                    value = value4;
                                }
                                if (!"IMEI".equals(key4) && !"SLAVE_IMEI".equals(key4)) {
                                    try {
                                        objHwPartInfo.put(key4, value);
                                    } catch (JSONException e4) {
                                        FtUtil.log_e(e4);
                                    }
                                }
                            }
                        }
                    }
                    i++;
                    document2 = document;
                }
                try {
                    objRoot.put("PARTINFO", objHwPartInfo);
                } catch (JSONException e5) {
                    FtUtil.log_e(e5);
                }
                output.append("[HEAD]\n");
                output.append(objRoot.toString() + "\n");
                output.append("[TAIL]\n");
                output.append(ModuleCommon.instance(this.mContext).createChecksum(objRoot.toString()));
                Support.Kernel.writeNsync(Support.Kernel.FAC_HW_PART_INFORM_DATA, output.toString());
                return true;
            }
        } catch (Exception e6) {
            e6.printStackTrace();
            return false;
        }
    }

    public String getFuncVal(String _strKey) {
        String strVal = null;
        if ("IMEI".equals(_strKey)) {
            strVal = ((TelephonyManager) this.mContext.getSystemService(ModuleTouchScreen.TSP_DEVICE_TYPE__PHONE)).getImei(0);
        } else if ("SLAVE_IMEI".equals(_strKey)) {
            TelephonyManager tm = (TelephonyManager) this.mContext.getSystemService(ModuleTouchScreen.TSP_DEVICE_TYPE__PHONE);
            if (tm.getPhoneCount() == 2) {
                strVal = tm.getImei(1);
            }
        } else if ("TRANCEIVER".equals(_strKey)) {
            strVal = this.mStrTranceiver;
        } else if ("RF_PA".equals(_strKey)) {
            strVal = this.mStrRFPA;
        }
        FtUtil.log_d(CLASS_NAME, "getFuncVal", "key : " + _strKey + " val : " + strVal);
        return strVal;
    }

    public boolean checkChipType(String _strTargetChiptype) {
        String strMainChipType = ModuleCommon.instance(this.mContext).getMainChipType();
        if ("".equals(_strTargetChiptype)) {
            return true;
        }
        if ("QC".equals(strMainChipType)) {
            if (!"QUALCOMM".equals(_strTargetChiptype)) {
                return false;
            }
            FtUtil.log_d(CLASS_NAME, "checkChipType", "qc");
            return true;
        } else if (!"LSI".equals(strMainChipType) || !"LSI".equals(_strTargetChiptype)) {
            return false;
        } else {
            FtUtil.log_d(CLASS_NAME, "checkChipType", "lsi");
            return true;
        }
    }
}
