package com.sec.factory.app.ui;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.CornerPathEffect;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.PathEffect;
import android.util.AttributeSet;
import android.view.View;
import android.view.WindowManager;
import com.sec.factory.support.FtUtil;
import java.util.ArrayList;

public class ChargeGraph extends View {
    private String CLASS_NAME = "ChargeGraph";
    private final boolean DEBUG = true;
    private float GRAPH_SCALING_COOR;
    private int GRID_COUNT = 4;
    private final int INCREASING_COOR = 10;
    private final int INIT_COOR_X = 10;
    private int INIT_COOR_Y = 0;
    private int LIST_SIZE;
    private final float TEXT_SCALING_COOR = 57.32484f;
    private Paint mBaseLinePaint;
    private Context mContext;
    private Paint mDataPaint;
    private PathEffect mEffects;
    private int mMultipleNumber = 1000;
    private Path mPathData = new Path();
    private Path mPathTime = new Path();
    private int mScreenHeight;
    private int mScreenWidth;
    private Paint mTextPaint;
    private Paint mTimePaint;
    private ArrayList<Float> mValueData = new ArrayList<>();
    private ArrayList<Integer> mValueTime = new ArrayList<>();
    private Paint mXPaint;
    private float rate;
    private String textData;

    public ChargeGraph(Context context) {
        super(context);
        init(context);
    }

    public ChargeGraph(Context context, AttributeSet attrs, int defStyle) {
        super(context, attrs, defStyle);
        init(context);
    }

    public ChargeGraph(Context context, AttributeSet attrs) {
        super(context, attrs);
        init(context);
    }

    public void setTestAttr(String type) {
        this.textData = type;
        if ("Volt".equals(type)) {
            this.mXPaint.setColor(-65536);
        } else {
            this.mXPaint.setColor(-16711936);
        }
    }

    public void setTime() {
        this.mValueTime.add(Integer.valueOf(this.mValueData.size()));
    }

    public void setMultiple(int number, int count) {
        this.mMultipleNumber = number;
        this.GRID_COUNT = count;
    }

    private void init(Context context) {
        this.mContext = context;
        this.rate = 1.5f;
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "init", "rate : " + this.rate);
        WindowManager mWm = (WindowManager) this.mContext.getSystemService("window");
        this.mScreenWidth = mWm.getDefaultDisplay().getWidth();
        this.mScreenHeight = mWm.getDefaultDisplay().getHeight();
        this.INIT_COOR_Y = 250;
        this.LIST_SIZE = 60;
        initPaint();
        setSpecGraphScale(0.05f);
        invalidate();
    }

    private void initPaint() {
        this.mEffects = new CornerPathEffect(10.0f);
        Paint paint = new Paint(1);
        this.mXPaint = paint;
        paint.setStyle(Paint.Style.STROKE);
        this.mXPaint.setStrokeWidth(3.0f);
        this.mXPaint.setColor(-65536);
        this.mXPaint.setPathEffect(this.mEffects);
        Paint paint2 = new Paint(1);
        this.mTimePaint = paint2;
        paint2.setStyle(Paint.Style.STROKE);
        this.mTimePaint.setStrokeWidth(6.0f);
        this.mTimePaint.setColor(UiHallICTest.FONT_COLOR_PASS);
        this.mTimePaint.setPathEffect(this.mEffects);
        Paint paint3 = new Paint(1);
        this.mBaseLinePaint = paint3;
        paint3.setStyle(Paint.Style.STROKE);
        this.mBaseLinePaint.setStrokeWidth(1.0f);
        this.mBaseLinePaint.setColor(-16777216);
        this.mBaseLinePaint.setTextSize(30.0f);
        Paint paint4 = new Paint(1);
        this.mTextPaint = paint4;
        paint4.setStyle(Paint.Style.STROKE);
        this.mTextPaint.setStrokeWidth(1.0f);
        this.mTextPaint.setColor(-16777216);
        this.mTextPaint.setTextSize(40.0f);
        Paint paint5 = new Paint(1);
        this.mDataPaint = paint5;
        paint5.setStyle(Paint.Style.FILL_AND_STROKE);
        this.mDataPaint.setStrokeWidth(1.0f);
        this.mDataPaint.setColor(-16777216);
        this.mDataPaint.setTextSize(20.0f);
    }

    /* access modifiers changed from: protected */
    public void onDraw(Canvas canvas) {
        float textx;
        try {
            ArrayList<Float> arrayList = this.mValueData;
            textx = arrayList.get(arrayList.size() - 1).floatValue();
        } catch (Exception e) {
            FtUtil.log_i(this.CLASS_NAME, "onDraw", "get value fail");
            FtUtil.log_i(this.CLASS_NAME, "onDraw", "Size of X, Y, Z : " + this.mValueData.size() + ", " + this.mValueTime.size());
            String str = this.CLASS_NAME;
            StringBuilder sb = new StringBuilder();
            sb.append("LIST_SIZE value : ");
            sb.append(this.LIST_SIZE);
            FtUtil.log_i(str, "onDraw", sb.toString());
            textx = 0.0f;
        }
        float textx2 = this.rate;
        canvas.scale(textx2, textx2);
        canvas.drawColor(-1);
        canvas.drawText(this.textData, 20.0f, 50.0f, this.mBaseLinePaint);
        canvas.drawLine(140.0f, 40.0f, 170.0f, 40.0f, this.mXPaint);
        canvas.drawText(String.valueOf(textx), 230.0f, 50.0f, this.mTextPaint);
        int i = this.INIT_COOR_Y;
        canvas.drawLine(10.0f, (float) (i - 300), 10.0f, (float) (i + 200), this.mBaseLinePaint);
        int i2 = this.INIT_COOR_Y;
        canvas.drawLine(10.0f, (float) (i2 + 100), (float) (this.mScreenWidth - 10), (float) (i2 + 100), this.mBaseLinePaint);
        for (int i3 = 1; i3 <= 60; i3 += 2) {
            int i4 = this.INIT_COOR_Y;
            canvas.drawLine((float) (((i3 + 1) * 10) + 10), (float) (i4 + 90), (float) (((i3 + 1) * 10) + 10), (float) (i4 + 110), this.mBaseLinePaint);
        }
        for (int index = 1; index <= this.GRID_COUNT; index++) {
            int i5 = this.INIT_COOR_Y;
            int i6 = this.mMultipleNumber;
            float f = this.GRAPH_SCALING_COOR;
            canvas.drawLine(10.0f, ((float) (i5 + 100)) - (((float) (index * i6)) * f), 40.0f, ((float) (i5 + 100)) - (((float) (i6 * index)) * f), this.mBaseLinePaint);
        }
        canvas.drawPath(this.mPathData, this.mXPaint);
        canvas.drawPath(this.mPathTime, this.mTimePaint);
    }

    public void addValue(int data) {
        addValue((float) data);
    }

    public void addValue(float data) {
        this.mValueData.add(Float.valueOf(data));
        if (this.mValueData.size() > this.LIST_SIZE) {
            this.mValueData.remove(0);
        }
        setPath();
    }

    private void setPath() {
        this.mPathData.reset();
        this.mPathTime.reset();
        this.mPathData.moveTo(10.0f, ((float) (this.INIT_COOR_Y + 100)) - (this.mValueData.get(0).floatValue() * this.GRAPH_SCALING_COOR));
        for (int i = 1; i < this.mValueData.size(); i++) {
            this.mPathData.lineTo((float) ((i * 10) + 10), ((float) (this.INIT_COOR_Y + 100)) - (this.mValueData.get(i).floatValue() * this.GRAPH_SCALING_COOR));
        }
        invalidate();
    }

    public void reset() {
        this.mPathData.reset();
        this.mPathTime.reset();
        this.mValueData.clear();
        this.mValueTime.clear();
    }

    public void setSpecGraphScale(float scale) {
        this.GRAPH_SCALING_COOR = scale;
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setSpecGraphScale", "GRAPH_SCALING_COOR :" + String.valueOf(this.GRAPH_SCALING_COOR));
    }
}
