package com.sec.factory.app.ui;

import android.app.Activity;
import android.content.Context;
import android.hardware.Camera;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.SeekBar;
import android.widget.ToggleButton;
import com.sec.factory.R;
import com.sec.factory.modules.ModuleSensor;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;

public class IrisLEDLight extends Activity implements CompoundButton.OnCheckedChangeListener, SeekBar.OnSeekBarChangeListener {
    private static final String CLASS_NAME = "IrisLEDLight";
    private static final String LED_LOW_POWER_MODE_OFF = "0";
    private static final String LED_LOW_POWER_MODE_ON = "1";
    private static final String LED_OFF = "0";
    private static final String LED_ON = "255";
    private static final int PULSE_MAX = 1000;
    private SeekBar barLight;
    private ToggleButton btnBlue;
    private ToggleButton btnGreen;
    private ToggleButton btnProx;
    private ToggleButton btnRed;
    private Camera mCamera;
    private Context mContext;
    private ModuleSensor mModuleSensor;
    private Camera.Parameters mParam;
    private int[] mSensorID;
    private EditText textPulse;

    /* access modifiers changed from: protected */
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        FtUtil.log_i(CLASS_NAME, "onCreate", "onCreate");
        setContentView(R.layout.iris_led_light);
        Support.Kernel.write(Support.Kernel.LED_LOWPOWER, "0");
        Camera open = Camera.open(102);
        this.mCamera = open;
        this.mParam = open.getParameters();
        Context applicationContext = getApplicationContext();
        this.mContext = applicationContext;
        if (this.mModuleSensor == null) {
            this.mModuleSensor = ModuleSensor.instance(applicationContext);
        }
        this.mSensorID = new int[]{ModuleSensor.ID_MANAGER_PROXIMITY};
        this.btnRed = (ToggleButton) findViewById(R.id.iris_button_led_red);
        this.btnGreen = (ToggleButton) findViewById(R.id.iris_button_led_green);
        this.btnBlue = (ToggleButton) findViewById(R.id.iris_button_led_blue);
        this.btnProx = (ToggleButton) findViewById(R.id.iris_button_prox);
        this.barLight = (SeekBar) findViewById(R.id.iris_seekbar_light);
        this.textPulse = (EditText) findViewById(R.id.iris_textbox_pulse);
        this.btnRed.setOnCheckedChangeListener(this);
        this.btnGreen.setOnCheckedChangeListener(this);
        this.btnBlue.setOnCheckedChangeListener(this);
        this.btnProx.setOnCheckedChangeListener(this);
        this.barLight.setOnSeekBarChangeListener(this);
        this.barLight.setMax(1000);
        EditText editText = this.textPulse;
        editText.setSelection(editText.length());
        this.textPulse.addTextChangedListener(new TextWatcher() {
            /* class com.sec.factory.app.ui.IrisLEDLight.AnonymousClass1 */

            public void beforeTextChanged(CharSequence charSequence, int i, int i1, int i2) {
            }

            public void onTextChanged(CharSequence charSequence, int i, int i1, int i2) {
                int num;
                try {
                    num = Integer.valueOf(charSequence.toString()).intValue();
                } catch (NumberFormatException e) {
                    num = 0;
                }
                if (num > 1000) {
                    IrisLEDLight.this.textPulse.setText(String.valueOf(1000));
                }
                IrisLEDLight.this.barLight.setProgress(num);
                IrisLEDLight.this.textPulse.setSelection(IrisLEDLight.this.textPulse.length());
                IrisLEDLight.this.mParam.set("pulse-width", num);
                IrisLEDLight.this.mCamera.setParameters(IrisLEDLight.this.mParam);
            }

            public void afterTextChanged(Editable editable) {
            }
        });
    }

    /* access modifiers changed from: protected */
    public void onResume() {
        super.onResume();
    }

    /* access modifiers changed from: protected */
    public void onPause() {
        super.onPause();
    }

    /* access modifiers changed from: protected */
    public void onDestroy() {
        super.onDestroy();
        Support.Kernel.write(Support.Kernel.LED_LOWPOWER, "1");
    }

    public void onCheckedChanged(CompoundButton button, boolean isChecked) {
        switch (button.getId()) {
            case R.id.iris_button_led_blue:
                FtUtil.log_i(CLASS_NAME, "onCheckedChanged", "Blue clicked, isChecked: " + isChecked);
                if (isChecked) {
                    Support.Kernel.write(Support.Kernel.LED_BLUE, LED_ON);
                    return;
                } else {
                    Support.Kernel.write(Support.Kernel.LED_BLUE, "0");
                    return;
                }
            case R.id.iris_button_led_green:
                FtUtil.log_i(CLASS_NAME, "onCheckedChanged", "Green clicked, isChecked: " + isChecked);
                if (isChecked) {
                    Support.Kernel.write(Support.Kernel.LED_GREEN, LED_ON);
                    return;
                } else {
                    Support.Kernel.write(Support.Kernel.LED_GREEN, "0");
                    return;
                }
            case R.id.iris_button_led_red:
                FtUtil.log_i(CLASS_NAME, "onCheckedChanged", "Red clicked, isChecked: " + isChecked);
                if (isChecked) {
                    Support.Kernel.write(Support.Kernel.LED_RED, LED_ON);
                    return;
                } else {
                    Support.Kernel.write(Support.Kernel.LED_RED, "0");
                    return;
                }
            case R.id.iris_button_prox:
                FtUtil.log_i(CLASS_NAME, "onCheckedChanged", "Proximity clicked, isChecked: " + isChecked);
                if (isChecked) {
                    this.mModuleSensor.SensorOn(this.mSensorID);
                    return;
                } else {
                    this.mModuleSensor.SensorOff(this.mSensorID);
                    return;
                }
            default:
                return;
        }
    }

    public void onProgressChanged(SeekBar seekBar, int i, boolean b) {
        this.textPulse.setText(String.valueOf(i));
    }

    public void onStartTrackingTouch(SeekBar seekBar) {
    }

    public void onStopTrackingTouch(SeekBar seekBar) {
        FtUtil.log_i(CLASS_NAME, "onStopTrackingTouch", "getProgress: " + seekBar.getProgress());
        this.mParam.set("pulse-width", seekBar.getProgress());
        this.mCamera.setParameters(this.mParam);
    }
}
