package com.sec.factory.app.ui;

import android.content.Context;
import android.content.res.Resources;
import android.util.ArrayMap;
import android.util.Log;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;

public class SoundTriggerEnrollmentUtil {
    private static final String TAG = "SoundTriggerEnrollmentUtil";

    public static byte[] readNewWakeupResource(Context context, String phrase, String locale) {
        Log.d(TAG, "phrase " + phrase + " locale " + locale);
        StringBuilder sb = new StringBuilder();
        sb.append("_dsp_inv_");
        ArrayMap<String, Integer> arrayMap = Constants.SUPPORTED_LOCALES;
        sb.append(arrayMap.get(phrase + "_" + locale).toString());
        Log.d(TAG, sb.toString());
        try {
            Resources resources = context.getResources();
            ArrayMap<String, Integer> arrayMap2 = Constants.SUPPORTED_LOCALES;
            InputStream is = resources.openRawResource(arrayMap2.get(phrase + "_" + locale).intValue());
            if (is != null) {
                try {
                    ByteBuffer buffer = ByteBuffer.allocate(is.available()).order(ByteOrder.nativeOrder());
                    while (is.available() > 0) {
                        buffer.put((byte) is.read());
                    }
                    Log.d(TAG, "readNewWakeupResource: " + buffer.array().length);
                    byte[] array = buffer.array();
                    if (is != null) {
                        is.close();
                    }
                    return array;
                } catch (Throwable th) {
                    th.addSuppressed(th);
                }
            } else {
                if (is != null) {
                    is.close();
                }
                Log.e(TAG, "Failed to load the wakeup data from resources");
                return new byte[4];
            }
            throw th;
        } catch (IOException e) {
            Log.e(TAG, e.getMessage());
        }
    }

    public static byte[] readWakeupResource(Context context, String phrase, String locale) {
        InputStream isNet = null;
        InputStream isGram = null;
        ByteArrayOutputStream osNet = null;
        ByteArrayOutputStream osGram = null;
        byte[] data = null;
        try {
            Resources resources = context.getResources();
            ArrayMap<String, Integer> arrayMap = Constants.SUPPORTED_LOCALES;
            isNet = resources.openRawResource(arrayMap.get(phrase + "_net_" + locale).intValue());
            osNet = new ByteArrayOutputStream();
            while (true) {
                int read = isNet.read();
                if (read == -1) {
                    break;
                }
                osNet.write(read);
            }
            Resources resources2 = context.getResources();
            ArrayMap<String, Integer> arrayMap2 = Constants.SUPPORTED_LOCALES;
            isGram = resources2.openRawResource(arrayMap2.get(phrase + "_grammar_" + locale).intValue());
            osGram = new ByteArrayOutputStream();
            while (true) {
                int read2 = isGram.read();
                if (read2 == -1) {
                    break;
                }
                osGram.write(read2);
            }
            byte[] net = osNet.toByteArray();
            byte[] gram = osGram.toByteArray();
            int netSize = net.length;
            int gramSize = gram.length;
            Log.d(TAG, "netSize : " + netSize + ", gramSize : " + gramSize);
            byte[] netSizeByte = ByteBuffer.allocate(4).order(ByteOrder.nativeOrder()).putInt(netSize).array();
            byte[] gramSizeByte = ByteBuffer.allocate(4).order(ByteOrder.nativeOrder()).putInt(gramSize).array();
            data = new byte[(netSizeByte.length + netSize + gramSizeByte.length + gramSize)];
            System.arraycopy(netSizeByte, 0, data, 0, netSizeByte.length);
            int offset = netSizeByte.length + 0;
            System.arraycopy(net, 0, data, offset, netSize);
            int offset2 = offset + netSize;
            System.arraycopy(gramSizeByte, 0, data, offset2, gramSizeByte.length);
            System.arraycopy(gram, 0, data, gramSizeByte.length + offset2, gramSize);
        } catch (Resources.NotFoundException e) {
            Log.e(TAG, "NotFoundException while trying to read wakeup data", e);
        } catch (IOException e2) {
            Log.e(TAG, "IOException while reading wakeup data", e2);
        }
        if (isNet != null) {
            try {
                isNet.close();
            } catch (IOException e3) {
            }
        }
        if (isGram != null) {
            try {
                isGram.close();
            } catch (IOException e4) {
            }
        }
        if (osNet != null) {
            try {
                osNet.close();
            } catch (IOException e5) {
            }
        }
        if (osGram != null) {
            try {
                osGram.close();
            } catch (IOException e6) {
            }
        }
        if (data == null) {
            Log.e(TAG, "Failed to load the wakeup data from resources");
        }
        return data;
    }

    public static byte[] getExtraData() {
        return "voice_trig=1800;wakeup_mode=1".getBytes();
    }
}
