package com.sec.factory.app.ui;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModuleTouchScreen;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hssf.record.UnknownRecord;

public class SpenBluetoothTestEntry extends UIBase implements View.OnClickListener {
    public static final String CLASS_NAME = "SpenBluetoothTestEntry";
    private Button mButtonExit;
    private Button mButtonOK;
    private TextView mColorViewBody;
    private TextView mColorViewTip;
    private String mSeletedColorCode = null;

    public SpenBluetoothTestEntry() {
        super(CLASS_NAME);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.spenbluetoothtest_entry);
        init();
    }

    private void init() {
        FtUtil.log_d(CLASS_NAME, "initUi", "initUi");
        this.mColorViewBody = (TextView) findViewById(R.id.selected_color_body);
        this.mColorViewTip = (TextView) findViewById(R.id.selected_color_tip);
        this.mButtonOK = (Button) findViewById(R.id.ok_button);
        this.mButtonExit = (Button) findViewById(R.id.exit_button);
        this.mColorViewBody.setOnClickListener(this);
        this.mColorViewTip.setOnClickListener(this);
        this.mButtonOK.setOnClickListener(this);
        this.mButtonExit.setOnClickListener(this);
        this.mSeletedColorCode = null;
    }

    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.exit_button:
                FtUtil.log_i(CLASS_NAME, "onClick", "exit button click");
                finish();
                return;
            case R.id.ok_button:
                FtUtil.log_i(CLASS_NAME, "onClick", "ok button click");
                startBLETest();
                finish();
                return;
            case R.id.selected_color_body:
            case R.id.selected_color_tip:
                FtUtil.log_i(CLASS_NAME, "onClick", "Color select button click");
                createSelectDialog().show();
                return;
            default:
                return;
        }
    }

    private void startBLETest() {
        Intent intent;
        if (this.mSeletedColorCode != null) {
            if (Support.Feature.getBoolean(Support.Feature.SUPPORT_SPEN_BLE_ACCGYRO, false)) {
                intent = new Intent(this, UISpenBluetoothAccGyroTest.class);
            } else {
                intent = new Intent(this, UISpenBluetoothTest.class);
            }
            intent.putExtra("colorCode", this.mSeletedColorCode);
            startActivity(intent);
        }
    }

    private AlertDialog createSelectDialog() {
        String colorCodeList = "NA," + Support.Spec.getString(Support.Spec.SPEN_COLOR_CODE_LIST);
        final String[] colorCodeListArr = colorCodeList.split(",");
        FtUtil.log_d(CLASS_NAME, "createSelectDialog", "colorCodeListCnt: " + colorCodeListArr.length + " ,colorCodeList: " + colorCodeList);
        List<String> items = new ArrayList<>();
        for (String colorCode : colorCodeListArr) {
            items.add(ColorSet.colorNameFromCode(colorCode));
        }
        AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(this);
        alertDialogBuilder.setTitle("Select Spen Color");
        alertDialogBuilder.setCancelable(true);
        alertDialogBuilder.setItems((CharSequence[]) items.toArray(new String[items.size()]), new DialogInterface.OnClickListener() {
            /* class com.sec.factory.app.ui.SpenBluetoothTestEntry.AnonymousClass1 */

            public void onClick(DialogInterface dialog, int which) {
                FtUtil.log_d(SpenBluetoothTestEntry.CLASS_NAME, "createSelectDialog_onClick", "selectedIdx: " + which + " ,colorCode: " + colorCodeListArr[which]);
                SpenBluetoothTestEntry.this.mSeletedColorCode = colorCodeListArr[which];
                SpenBluetoothTestEntry.this.mColorViewBody.setBackgroundColor(ColorSet.colorBodyFromCode(colorCodeListArr[which]));
                SpenBluetoothTestEntry.this.mColorViewTip.setBackgroundColor(ColorSet.colorTipFromCode(colorCodeListArr[which]));
            }
        });
        return alertDialogBuilder.create();
    }

    public enum ColorSet {
        DEFAULT("DEFAULT", Color.rgb(0, 0, 0), Color.rgb(0, 0, 0), "NA"),
        YELLOWGREEN("YELLOW GREEN", Color.rgb(251, (int) FactoryTestManager.TEST_ECHO_PARALLEL, 86), Color.rgb(1, 0, 255), "YZ"),
        LAVENDER("LAVENDER(PURPLE)", Color.rgb((int) UnknownRecord.PHONETICPR_00EF, 170, 215), Color.rgb((int) UnknownRecord.PHONETICPR_00EF, 170, 215), "LP"),
        TITANSILVER("TITAN SILVER", Color.rgb(166, 166, 166), Color.rgb(103, 153, 255), "VS"),
        COPPER("COPPER(BROWN)", Color.rgb(192, 127, 101), Color.rgb(192, 127, 101), "PN"),
        OCEANSILVER("OCEAN SILVER", Color.rgb(166, 166, 166), Color.rgb(1, 0, 255), "BS"),
        LAVENDERSILVER("LAVENDER SILVER", Color.rgb(166, 166, 166), Color.rgb((int) UnknownRecord.PHONETICPR_00EF, 170, 215), "AS"),
        WHITE_SW("WHITE", -1, -1, "SW"),
        WHITESILVER("WHITESILVER", Color.rgb(146, 176, (int) FactoryTestManager.TEST_MIC_GAIN_PARALLEL), Color.rgb(146, 176, (int) FactoryTestManager.TEST_MIC_GAIN_PARALLEL), "WS"),
        BLACK("BLACK", Color.rgb(0, 0, 0), Color.rgb(128, 128, 128), "ZK"),
        WHITE_ZW("WHITE", Color.rgb(255, 255, 255), Color.rgb(192, 192, 192), "ZW"),
        BLUESILVER_ZS("BLUE SILVER", Color.rgb(0, 0, 255), Color.rgb(211, 211, 211), "ZS"),
        BLUE_ZB("BLUE", Color.rgb(0, 0, 255), Color.rgb(0, 0, 255), "ZB"),
        PINK("PINK", Color.rgb(255, 102, 204), Color.rgb(255, 102, 204), ModuleTouchScreen.TSP_VENDOR_NAME__ZI),
        RED("RED", Color.rgb(255, 0, 0), Color.rgb(255, 0, 0), "ZR"),
        GRAY("GRAY", Color.rgb(166, 166, 166), Color.rgb(166, 166, 166), "ZA"),
        BLUE_YB("BLUE", Color.rgb(0, 0, 255), Color.rgb(0, 0, 255), "YB"),
        BROWN("BROWN", Color.rgb(165, 42, 42), Color.rgb(165, 42, 42), "ZN");
        
        private final String code;
        private final int color_body;
        private final int color_tip;
        private final String name;

        private ColorSet(String _name, int _color_body, int _color_tip, String _code) {
            this.name = _name;
            this.color_body = _color_body;
            this.color_tip = _color_tip;
            this.code = _code;
        }

        public static int colorBodyFromCode(String colorCode) {
            ColorSet[] values = values();
            for (ColorSet s : values) {
                if (s.code.equalsIgnoreCase(colorCode)) {
                    return s.color_body;
                }
            }
            FtUtil.log_e(SpenBluetoothTestEntry.CLASS_NAME, "colorBodyFromCode", "Non-existent Color Code");
            return -1;
        }

        public static int colorTipFromCode(String colorCode) {
            ColorSet[] values = values();
            for (ColorSet s : values) {
                if (s.code.equalsIgnoreCase(colorCode)) {
                    return s.color_tip;
                }
            }
            FtUtil.log_e(SpenBluetoothTestEntry.CLASS_NAME, "colorTipFromCode", "Non-existent Color Code");
            return -1;
        }

        public static String colorNameFromCode(String colorCode) {
            ColorSet[] values = values();
            for (ColorSet s : values) {
                if (s.code.equalsIgnoreCase(colorCode)) {
                    return s.name;
                }
            }
            FtUtil.log_e(SpenBluetoothTestEntry.CLASS_NAME, "colorNameFromCode", "Non-existent Color Code");
            return null;
        }
    }
}
