package com.sec.factory.app.ui;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.GridView;
import android.widget.LinearLayout;
import android.widget.ListAdapter;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;

public class SvcCalItemViewer extends Activity {
    private static final String CLASS_NAME = "SvcCalItemViewer";
    private final int MAX_ITEM_COUNT = 40;
    private SvcNvViewerAdapter mAdaptor;
    private Button mNvControlAllClearButton;
    private Button mNvControlToggleHexaButton;
    private String[] mSvcCalItemResult = {"N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N", "N"};
    private String[] mSvcCalItemTitle = {"TSP Cal", "Speaker Cal", "Force Touch Cal", "Optical Fingerprint Cal", "TOF Camera Cal", "Digital Hall IC Cal", "mmWave RF Cal", "Multi Camera Cal", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", ""};
    private TextView mTitle;

    private void initialize() {
        TextView textView = (TextView) findViewById(R.id.title);
        this.mTitle = textView;
        textView.setText(R.string.svc_cal_item_viewer);
        Button button = (Button) findViewById(R.id.btn_nv_control_all_clear);
        this.mNvControlAllClearButton = button;
        button.setVisibility(8);
        Button button2 = (Button) findViewById(R.id.btn_nv_control_toggle_hexa);
        this.mNvControlToggleHexaButton = button2;
        button2.setVisibility(8);
        GridView gridview = (GridView) findViewById(R.id.nv_control_view);
        gridview.setNumColumns(5);
        SvcNvViewerAdapter svcNvViewerAdapter = new SvcNvViewerAdapter(this);
        this.mAdaptor = svcNvViewerAdapter;
        gridview.setAdapter((ListAdapter) svcNvViewerAdapter);
    }

    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.nv_control);
        initialize();
    }

    public void onResume() {
        super.onResume();
        parseNVData();
    }

    /* access modifiers changed from: protected */
    public void onStop() {
        super.onStop();
        finish();
    }

    private void parseNVData() {
        String nvData = Support.Kernel.read(Support.Kernel.SVC_CAL_NV);
        if (nvData == null || nvData.length() == 0) {
            FtUtil.log_d(CLASS_NAME, "parseNVData", "No Item");
            return;
        }
        FtUtil.log_d(CLASS_NAME, "parseNVData", "[Data] size: " + nvData.length() + ", value: " + nvData);
        for (int i = 0; i < nvData.length(); i++) {
            this.mSvcCalItemResult[i] = nvData.substring(i, i + 1);
        }
        this.mAdaptor.notifyDataSetChanged();
    }

    /* access modifiers changed from: private */
    public class SvcNvViewerAdapter extends BaseAdapter {
        private Context mContext;

        public SvcNvViewerAdapter(Context c) {
            this.mContext = c;
        }

        public int getCount() {
            return SvcCalItemViewer.this.mSvcCalItemResult.length;
        }

        public Object getItem(int position) {
            return SvcCalItemViewer.this.mSvcCalItemResult[position];
        }

        public long getItemId(int position) {
            return (long) position;
        }

        public View getView(int position, View convertView, ViewGroup parent) {
            View view = convertView;
            if (convertView == null) {
                view = ((LayoutInflater) this.mContext.getSystemService("layout_inflater")).inflate(R.layout.nv_control_item, parent, false);
            }
            if (convertView != null) {
                view.setLayoutParams(new LinearLayout.LayoutParams(-1, -1));
            }
            TextView textView = (TextView) view.findViewById(R.id.tv_nv_control_item);
            textView.setPadding(2, 2, 2, 2);
            textView.setText(SvcCalItemViewer.this.mSvcCalItemTitle[position] + "\n" + String.valueOf(position + 1) + " : " + SvcCalItemViewer.this.mSvcCalItemResult[position]);
            if ("P".equals(SvcCalItemViewer.this.mSvcCalItemResult[position])) {
                textView.setTextColor(-1);
                textView.setBackgroundColor(UiHallICTest.FONT_COLOR_PASS);
            } else if ("N".equals(SvcCalItemViewer.this.mSvcCalItemResult[position])) {
                textView.setTextColor(-16777216);
                textView.setBackgroundColor(this.mContext.getResources().getColor(R.color.background_gray));
            } else {
                textView.setTextColor(-1);
                textView.setBackgroundColor(-65536);
            }
            return view;
        }
    }
}
