package com.sec.factory.app.ui;

import android.content.Context;
import android.media.AudioAttributes;
import android.media.AudioManager;
import android.media.MediaPlayer;
import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.goodix.fingerprint.BuildConfig;
import com.sec.factory.R;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.support.FtUtil;

public class UIACHMotorSound extends UIBase implements View.OnClickListener {
    public static final int AUDIO_PATH_EAR = 2;
    public static final int AUDIO_PATH_HDMI = 3;
    public static final int AUDIO_PATH_OFF = 4;
    public static final int AUDIO_PATH_RCV = 1;
    public static final int AUDIO_PATH_SPK = 0;
    private static final int MSG_EXIT_ACTIVITY = 2;
    private static final int MSG_SHOW_BUTTONS = 1;
    private static final String TAG = "UIACHMotorSound";
    private final String[] AUDIO_PATH = {"spk", "rcv", "ear", "hdmi", "off"};
    private final int[] FEED_BACK_AMPLITUDE = {0, -1};
    private final long[] FEED_BACK_PATTERN = {0, 5000};
    private AudioAttributes mAudioAttributes = new AudioAttributes.Builder().setUsage(4).setHapticChannelsMuted(false).build();
    private AudioManager mAudioManager;
    private Button mButtonFail;
    private Button mButtonPass;
    private Context mContext;
    private Handler mHandler = new Handler() {
        /* class com.sec.factory.app.ui.UIACHMotorSound.AnonymousClass1 */

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    FtUtil.log_d(UIACHMotorSound.this.CLASS_NAME, "Handler", "MSG_SHOW_BUTTONS");
                    UIACHMotorSound.this.mLinearLayoutButtonDepot.setVisibility(0);
                    return;
                case 2:
                    FtUtil.log_d(UIACHMotorSound.this.CLASS_NAME, "Handler", "MSG_EXIT_ACTIVITY");
                    UIACHMotorSound.this.setAudioPath(4);
                    UIACHMotorSound.this.stopMedia();
                    UIACHMotorSound.this.finish();
                    return;
                default:
                    return;
            }
        }
    };
    private LinearLayout mLinearLayoutButtonDepot;
    private MediaPlayer mMediaPlayer;
    private ModuleDevice mModuleDevice;
    private TextView mTextViewTitle;

    public UIACHMotorSound() {
        super(TAG);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        FtUtil.log_d(this.CLASS_NAME, "onCreate", "");
        this.mModuleDevice = ModuleDevice.instance(this);
        Context applicationContext = getApplicationContext();
        this.mContext = applicationContext;
        this.mAudioManager = (AudioManager) applicationContext.getSystemService("audio");
        FtUtil.setRemoveSystemUI(getWindow(), true);
        this.TEST_ID = getIntent().getIntExtra("testid", -1);
        setContentView(R.layout.ui_ach_motor_sound);
        initUi();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        FtUtil.log_d(this.CLASS_NAME, "onResume", "");
        setAudioPath(0);
        startMedia(R.raw.ach_test_sweep_linear_145_175hz_2s_on_1s_off);
        this.mHandler.sendEmptyMessageDelayed(1, 4000);
        this.mHandler.sendEmptyMessageDelayed(2, 60000);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        setAudioPath(4);
        stopMedia();
        super.onPause();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        super.onDestroy();
    }

    private void initUi() {
        this.mTextViewTitle = (TextView) findViewById(R.id.title);
        this.mLinearLayoutButtonDepot = (LinearLayout) findViewById(R.id.bottom_btn_depot);
        Button button = (Button) findViewById(R.id.pass);
        this.mButtonPass = button;
        button.setOnClickListener(this);
        Button button2 = (Button) findViewById(R.id.fail);
        this.mButtonFail = button2;
        button2.setOnClickListener(this);
    }

    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.fail:
                FtUtil.log_d(this.CLASS_NAME, "onClick", "fail");
                setAudioPath(4);
                stopMedia();
                finish();
                return;
            case R.id.pass:
                FtUtil.log_d(this.CLASS_NAME, "onClick", "pass");
                setAudioPath(4);
                stopMedia();
                setTestResult((byte) 80);
                setResult(-1);
                finish();
                return;
            default:
                return;
        }
    }

    private void startMedia(int resId) {
        FtUtil.log_d(this.CLASS_NAME, "startMedia", null);
        release();
        try {
            MediaPlayer mediaPlayer = new MediaPlayer();
            this.mMediaPlayer = mediaPlayer;
            mediaPlayer.reset();
            this.mMediaPlayer.setLooping(true);
            MediaPlayer mediaPlayer2 = this.mMediaPlayer;
            Context applicationContext = this.mContext.getApplicationContext();
            mediaPlayer2.setDataSource(applicationContext, Uri.parse("android.resource://" + this.mContext.getApplicationContext().getPackageName() + "/" + resId));
            this.mMediaPlayer.setAudioAttributes(this.mAudioAttributes);
            this.mMediaPlayer.prepare();
            this.mMediaPlayer.start();
        } catch (Exception e) {
            FtUtil.log_e(e);
            release();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void stopMedia() {
        FtUtil.log_d(this.CLASS_NAME, "stopMedia", null);
        MediaPlayer mediaPlayer = this.mMediaPlayer;
        if (mediaPlayer != null) {
            mediaPlayer.stop();
            release();
        }
    }

    private void release() {
        FtUtil.log_d(this.CLASS_NAME, BuildConfig.BUILD_TYPE, null);
        MediaPlayer mediaPlayer = this.mMediaPlayer;
        if (mediaPlayer != null) {
            mediaPlayer.release();
            this.mMediaPlayer = null;
        }
    }

    public void setAudioPath(int path) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setMode", "setAudioPath : factory_test_route=" + this.AUDIO_PATH[path]);
        AudioManager audioManager = this.mAudioManager;
        audioManager.setParameters("factory_test_route=" + this.AUDIO_PATH[path]);
    }
}
