package com.sec.factory.app.ui;

import android.app.BarBeamException;
import android.app.BarBeamFactory;
import android.app.Hop;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Point;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.Display;
import android.view.KeyEvent;
import android.view.View;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.RelativeLayout;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;

public class UIBarcodeEmulator extends UIBase {
    private static final String TAG = "UIBarcodeEmulator";
    public static final int TEST_FINISH = 1;
    private static BarBeamFactory barbeamFactory = null;
    private final long BACK_KEY_EVENT_TIMELAG = 2000;
    protected int ONPASS_FINISH_DELAY = 1000;
    private byte[] barcodeByte = {-1, -83, -112, -79, 78, -11, -70, -83, -59, -115, FactoryTestManager.TEST_BARCODE_EMUL, 77, -70, -1};
    private Hop[] hopSequenceArray = {new Hop(0, 50, 50, 20, 31), new Hop(20, 20, 50, 10, 31), new Hop(2, 50, 50, 12, 31), new Hop(8, 50, 50, 10, 31), new Hop(12, 30, 50, 10, 31), new Hop(1, 50, 50, 16, 31), new Hop(14, 30, 50, 10, 31), new Hop(4, 50, 50, 10, 31), new Hop(10, 40, 50, 10, 31), new Hop(6, 50, 50, 10, 31)};
    private Button mExitButton;
    private boolean mIsLongPress = false;
    private boolean mIsPass = false;
    private long mPrevBackKeyEventTime = -1;
    private int mTestID = 0;
    protected Handler mTimerHandler = new Handler() {
        /* class com.sec.factory.app.ui.UIBarcodeEmulator.AnonymousClass1 */

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    UIBarcodeEmulator.this.finish();
                    return;
                default:
                    return;
            }
        }
    };
    private BarcodeTestView mView = null;

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void finishOnPassWithTimer() {
        this.mTimerHandler.sendEmptyMessageDelayed(1, (long) this.ONPASS_FINISH_DELAY);
    }

    public UIBarcodeEmulator() {
        super(TAG, 50);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        BarcodeTestView barcodeTestView = new BarcodeTestView(this);
        this.mView = barcodeTestView;
        setContentView(barcodeTestView);
        this.mTestID = getIntent().getIntExtra("testID", 0);
        Log.d(TAG, "mTestID :" + this.mTestID);
        this.TEST_ID = this.mTestID;
        Button button = new Button(this);
        this.mExitButton = button;
        button.setTextSize(25.0f);
        this.mExitButton.setText("Exit");
        this.mExitButton.setOnClickListener(new View.OnClickListener() {
            /* class com.sec.factory.app.ui.UIBarcodeEmulator.AnonymousClass2 */

            public void onClick(View arg0) {
                if (UIBarcodeEmulator.this.mIsPass) {
                    UIBarcodeEmulator.this.mIsPass = false;
                    UIBarcodeEmulator.this.setTestResult((byte) 80);
                }
                UIBarcodeEmulator.this.finish();
            }
        });
        RelativeLayout lContainerLayout = new RelativeLayout(this);
        lContainerLayout.setLayoutParams(new RelativeLayout.LayoutParams(-1, -1));
        Point outpoint = new Point();
        ((WindowManager) getApplication().getSystemService("window")).getDefaultDisplay().getSize(outpoint);
        RelativeLayout.LayoutParams lButtonParams = new RelativeLayout.LayoutParams(outpoint.x / 3, outpoint.y / 8);
        lButtonParams.addRule(12);
        lButtonParams.addRule(14);
        lButtonParams.bottomMargin = outpoint.y / 8;
        this.mExitButton.setLayoutParams(lButtonParams);
        lContainerLayout.addView(this.mExitButton);
        addContentView(lContainerLayout, new RelativeLayout.LayoutParams(-1, -1));
        Log.i(TAG, "onCreate");
    }

    public void StartBeaming() {
        boolean result = false;
        try {
            barbeamFactory = new BarBeamFactory(this, this.hopSequenceArray);
        } catch (BarBeamException e1) {
            e1.printStackTrace();
        }
        try {
            BarBeamException e12 = barbeamFactory;
            if (e12 != null) {
                result = e12.StartBarBeamFactory(this.barcodeByte);
            } else {
                Log.d(TAG, "Cannot get BarBeamFactory instance");
            }
        } catch (BarBeamException e) {
            e.printStackTrace();
        }
        Log.d(TAG, "StartBarBeamFactory-- : " + result);
        if (result) {
            this.mIsPass = true;
        } else {
            this.mView.drawResultText(false);
        }
    }

    public void StopBeaming() {
        boolean result = false;
        Log.d(TAG, "StopBarBeamFactory ++ " + false);
        try {
            BarBeamFactory barBeamFactory = barbeamFactory;
            if (barBeamFactory != null) {
                result = barBeamFactory.StopBarBeamFactory();
            } else {
                Log.d(TAG, "barbeamFactory is null");
            }
        } catch (BarBeamException e) {
            Log.d(TAG, "exception in StopBarBeamFactory", e);
        }
        Log.d(TAG, "StopBarBeamFactory -- " + result);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        super.onPause();
        StopBeaming();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        StartBeaming();
    }

    public class BarcodeTestView extends View {
        private int gapfromtop = 90;
        private Bitmap mBitmap;
        private Canvas mCanvas;
        private Paint mEmptyPaint;
        private int mHeight;
        private Paint mInfoPaint;
        private final int mMargin = 15;
        private int mWidth;

        public BarcodeTestView(Context context) {
            super(context);
            setKeepScreenOn(true);
            Display mDisplay = ((WindowManager) context.getSystemService("window")).getDefaultDisplay();
            Point outpoint = new Point();
            mDisplay.getSize(outpoint);
            this.mWidth = outpoint.x / 8;
            this.mHeight = outpoint.y / 8;
            Log.i(UIBarcodeEmulator.TAG, "size: " + this.mWidth + " x " + this.mHeight);
            Paint paint = new Paint();
            this.mEmptyPaint = paint;
            paint.setAntiAlias(false);
            this.mEmptyPaint.setColor(-1);
            Paint paint2 = new Paint();
            this.mInfoPaint = paint2;
            paint2.setAntiAlias(true);
            this.mInfoPaint.setStyle(Paint.Style.FILL);
            this.mInfoPaint.setColor(-16777216);
            this.mInfoPaint.setTextSize(70.0f);
            this.mInfoPaint.setTextAlign(Paint.Align.CENTER);
            this.mBitmap = Bitmap.createBitmap(this.mWidth * 8, this.mHeight * 8, Bitmap.Config.ARGB_8888);
            Canvas canvas = new Canvas(this.mBitmap);
            this.mCanvas = canvas;
            canvas.drawRect(0.0f, 0.0f, (float) (this.mWidth * 8), (float) (this.mHeight * 8), this.mEmptyPaint);
            this.mCanvas.drawText("1234567890128", (float) (this.mWidth * 4), (float) (((this.mHeight * 1) - 15) + this.gapfromtop), this.mInfoPaint);
            this.mCanvas.drawText("BARCODE EMUL", (float) (this.mWidth * 4), (float) ((this.mHeight * 3) - 15), this.mInfoPaint);
            Drawable d = getResources().getDrawable(R.drawable.ean13_barcode);
            int i = this.gapfromtop;
            d.setBounds(0, i, this.mWidth * 8, ((this.mHeight / 5) * 2) + i);
            d.draw(this.mCanvas);
        }

        /* access modifiers changed from: protected */
        public void onDraw(Canvas canvas) {
            super.onDraw(canvas);
            try {
                canvas.drawBitmap(this.mBitmap, 0.0f, 0.0f, (Paint) null);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void drawResultText(boolean result) {
            String ResultText;
            Paint paint = new Paint();
            if (result) {
                ResultText = getResources().getString(R.string.PASS);
                paint.setColor(UiHallICTest.FONT_COLOR_PASS);
            } else {
                ResultText = getResources().getString(R.string.FAIL);
                paint.setColor(-65536);
            }
            paint.setTextAlign(Paint.Align.CENTER);
            paint.setAntiAlias(true);
            paint.setTextSize(150.0f);
            this.mCanvas.drawText(ResultText, (float) (this.mWidth * 4), (float) (this.mHeight * 5), paint);
            invalidate();
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public boolean onKeyUp(int keyCode, KeyEvent event) {
        this.mIsLongPress = false;
        Log.d(TAG, "onKeyUp return true");
        return true;
    }

    @Override // com.sec.factory.app.ui.UIBase
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (!this.mIsLongPress) {
            this.mIsLongPress = event.isLongPress();
        }
        if (!this.mIsLongPress) {
            switch (keyCode) {
                case 4:
                    Log.d(TAG, "KEYCODE_BACK => Prev : " + this.mPrevBackKeyEventTime + ", Curr : " + event.getEventTime() + " => Time Lag : " + (event.getEventTime() - this.mPrevBackKeyEventTime) + " [" + 2000L + "]");
                    if (this.mPrevBackKeyEventTime == -1) {
                        this.mPrevBackKeyEventTime = event.getEventTime();
                    } else if (event.getEventTime() - this.mPrevBackKeyEventTime < 2000) {
                        finish();
                    } else {
                        this.mPrevBackKeyEventTime = event.getEventTime();
                    }
                    Log.d(TAG, "KEYCODE_BACK = return true");
                    return true;
                default:
                    this.mPrevBackKeyEventTime = -1;
                    break;
            }
        }
        Log.d(TAG, "onKeyDown return true");
        return true;
    }
}
