package com.sec.factory.app.ui;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.View;
import android.widget.Button;
import android.widget.RadioGroup;
import com.sec.factory.R;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.util.Timer;
import java.util.TimerTask;

public class UICharge extends UIBase {
    private final String CLASS_NAME = "UICharge";
    private final int MSG_LCD_OFF = 1;
    private final int MSG_LCD_ON = 2;
    private final int MSG_STOP_READING_DATA = 3;
    private final int MSG_UPDATE_VALUE = 0;
    private final int SYSFS_PERIOD = 500;
    private BroadcastReceiver mBroadcastReceiver = new BroadcastReceiver() {
        /* class com.sec.factory.app.ui.UICharge.AnonymousClass2 */

        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            FtUtil.log_d("UICharge", "mBroadcastReceiver.onReceive", "action=" + action);
            if ("android.intent.action.BATTERY_CHANGED".equals(action)) {
                int plugged = intent.getIntExtra("plugged", 0);
                if ((plugged == 1 || plugged == 4) && UICharge.this.mTestStatus == TestStatus.FIRST) {
                    FtUtil.log_d("UICharge", "Battery State: " + plugged);
                    UICharge.this.mHandler.sendEmptyMessage(1);
                }
            }
        }
    };
    private ChargeGraph mCurrentGraph;
    private final Handler mHandler = new Handler() {
        /* class com.sec.factory.app.ui.UICharge.AnonymousClass1 */

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 0:
                    UICharge.this.mVoltGraph.addValue(UICharge.this.mRawData.mVoltage.floatValue());
                    UICharge.this.mCurrentGraph.addValue(UICharge.this.mRawData.mCurrent);
                    return;
                case 1:
                    UICharge.this.setWakeLock(false);
                    UICharge.this.mTestStatus = TestStatus.SECOND;
                    return;
                case 2:
                    UICharge.this.mTestStatus = TestStatus.THIRD;
                    UICharge.this.setWakeLock(true);
                    return;
                case 3:
                    UICharge uICharge = UICharge.this;
                    TestStatus unused = uICharge.mTestStatus;
                    uICharge.mTestStatus = TestStatus.FIRST;
                    if (UICharge.this.mTimer != null) {
                        UICharge.this.mTimer.cancel();
                        return;
                    }
                    return;
                default:
                    return;
            }
        }
    };
    private ModulePower mModulePower;
    private ChargeData mRawData = new ChargeData();
    private Button mResetBtn;
    private int mStatus = 0;
    private Button mStopBtn;
    private int mStopCount = 0;
    private TimerTask mTask;
    private RadioGroup mTestGroup;
    private TestStatus mTestStatus = TestStatus.FIRST;
    private TestType mTestType = TestType.CABLE;
    private Timer mTimer;
    private ChargeGraph mVoltGraph;

    /* access modifiers changed from: private */
    public enum TestStatus {
        FIRST,
        SECOND,
        THIRD
    }

    /* access modifiers changed from: private */
    public enum TestType {
        CABLE,
        WIRELESS
    }

    public UICharge() {
        super("UICharge");
    }

    /* access modifiers changed from: private */
    public class ChargeData {
        public int mCurrent;
        public Boolean mStatus;
        public Float mVoltage;

        private ChargeData() {
            this.mCurrent = 0;
            this.mVoltage = Float.valueOf(0.0f);
            this.mStatus = false;
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        FtUtil.log_d("UICharge", "onCreate", "");
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ui_charge);
        initialize();
    }

    private void initialize() {
        this.mModulePower = ModulePower.instance(this);
        ChargeGraph chargeGraph = (ChargeGraph) findViewById(R.id.charge_graph_volt);
        this.mVoltGraph = chargeGraph;
        chargeGraph.setTestAttr("Volt");
        this.mVoltGraph.setSpecGraphScale(15.0f);
        this.mVoltGraph.setMultiple(2, 8);
        ChargeGraph chargeGraph2 = (ChargeGraph) findViewById(R.id.charge_graph_current);
        this.mCurrentGraph = chargeGraph2;
        chargeGraph2.setTestAttr("Current");
        this.mCurrentGraph.setSpecGraphScale(0.05f);
        this.mCurrentGraph.setMultiple(1000, 6);
        this.mTestGroup = (RadioGroup) findViewById(R.id.radio_g);
        this.mResetBtn = (Button) findViewById(R.id.reset_button);
        this.mStopBtn = (Button) findViewById(R.id.stop_button);
        this.mTestGroup.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            /* class com.sec.factory.app.ui.UICharge.AnonymousClass3 */

            public void onCheckedChanged(RadioGroup radioGroup, int id) {
                if (id == R.id.check_cable) {
                    FtUtil.log_d("UICharge", "onClick", "Test Type is changed to cable... ");
                    UICharge.this.mTestType = TestType.CABLE;
                } else if (id == R.id.check_wireless) {
                    FtUtil.log_d("UICharge", "onClick", "Test Type is changed to wireless... ");
                    UICharge.this.mTestType = TestType.WIRELESS;
                }
            }
        });
        this.mResetBtn.setOnClickListener(new View.OnClickListener() {
            /* class com.sec.factory.app.ui.UICharge.AnonymousClass4 */

            public void onClick(View view) {
                FtUtil.log_d("UICharge", "onClick", "Click reset button");
                if (UICharge.this.mCurrentGraph != null) {
                    UICharge.this.mCurrentGraph.reset();
                }
                if (UICharge.this.mVoltGraph != null) {
                    UICharge.this.mVoltGraph.reset();
                }
            }
        });
        this.mStopBtn.setOnClickListener(new View.OnClickListener() {
            /* class com.sec.factory.app.ui.UICharge.AnonymousClass5 */

            public void onClick(View view) {
                FtUtil.log_d("UICharge", "onClick", "Click stop button");
                UICharge.this.mHandler.sendEmptyMessage(3);
            }
        });
    }

    public void onWindowFocusChanged(boolean hasFocus) {
        super.onWindowFocusChanged(hasFocus);
        FtUtil.log_d("UICharge", "onWindowFocusChanged", "focused : " + hasFocus);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        setTask();
        registerIntent();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setWakeLock(boolean on) {
        if (on) {
            this.mModulePower.doWakeLock(true);
            return;
        }
        this.mModulePower.doPartialWakeLock(true);
        this.mModulePower.doWakeLock(false);
        this.mModulePower.gotosleep();
    }

    private void registerIntent() {
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("android.intent.action.BATTERY_CHANGED");
        registerReceiver(this.mBroadcastReceiver, intentFilter);
    }

    private void setTask() {
        this.mTimer = new Timer();
        AnonymousClass6 r2 = new TimerTask() {
            /* class com.sec.factory.app.ui.UICharge.AnonymousClass6 */

            public void run() {
                UICharge.this.readCurrent();
                UICharge.this.readVolt();
                UICharge.this.updateUI();
            }
        };
        this.mTask = r2;
        this.mTimer.schedule(r2, 0, 500);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        super.onPause();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        super.onDestroy();
        Timer timer = this.mTimer;
        if (timer != null) {
            timer.cancel();
        }
        unregisterReceiver(this.mBroadcastReceiver);
        this.mModulePower.doPartialWakeLock(false);
        this.mModulePower.doWakeLock(false);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void readCurrent() {
        if (this.mTestStatus != TestStatus.FIRST) {
            try {
                String strCurrent = Support.Kernel.read(Support.Kernel.HV_CHARGE_CURRENT, 0);
                this.mRawData.mCurrent = Integer.parseInt(strCurrent.trim()) / 1000;
                FtUtil.log_d("UICharge", "readCurrent", "read current : " + this.mRawData.mCurrent);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void readVolt() {
        FtUtil.log_d("UICharge", "readVolt", "read volt");
        if (this.mTestStatus != TestStatus.FIRST) {
            String strVolt = null;
            try {
                if (this.mTestType == TestType.CABLE) {
                    strVolt = Support.Kernel.read(Support.Kernel.SEC_CHARGING_VOLTAGE, 0).replace("V", "");
                    this.mRawData.mVoltage = Float.valueOf(Float.parseFloat(strVolt.trim()));
                } else if (this.mTestType == TestType.WIRELESS) {
                    strVolt = Support.Kernel.read(Support.Kernel.WIRELESS_VOUT, 0);
                    this.mRawData.mVoltage = Float.valueOf(Float.parseFloat(strVolt.trim()) / 1000.0f);
                }
                FtUtil.log_d("UICharge", "readVolt", "read volt : " + strVolt);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private synchronized void updateUI() {
        if (this.mTestStatus != TestStatus.FIRST) {
            this.mHandler.sendEmptyMessage(0);
            if (this.mTestStatus != TestStatus.THIRD) {
                int i = this.mStopCount;
                this.mStopCount = i + 1;
                if (i == 20) {
                    this.mHandler.sendEmptyMessage(2);
                }
            }
        }
    }
}
