package com.sec.factory.app.ui;

import android.app.Activity;
import android.app.Presentation;
import android.content.Context;
import android.content.Intent;
import android.hardware.display.DisplayManager;
import android.net.Uri;
import android.os.Bundle;
import android.view.Display;
import android.widget.ImageView;
import com.sec.factory.R;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.support.FtUtil;
import java.io.File;

public class UIDisplayBG extends Activity {
    private static final String CLASS_NAME = "UIDisplayBG";
    private static final int DISPLAY_BLACK = 2;
    private static final int DISPLAY_LCD_1 = 3;
    private static final int DISPLAY_LCD_2 = 4;
    private static final int DISPLAY_WHITE = 1;
    private static Activity mActivity;
    private static int subScreenOption = 0;
    private File file;
    private String filePath;
    private DisplayManager mDisplayManager = null;
    private ImageView mImageView;
    private SubPresentation mPresentation;
    private int mTestDisplayId = -1;
    private int mode = 0;

    /* access modifiers changed from: protected */
    public void onCreate(Bundle arg0) {
        super.onCreate(arg0);
        mActivity = this;
        setContentView(R.layout.ui_displaybg);
        ImageView imageView = (ImageView) findViewById(R.id.disptest_imageview);
        this.mImageView = imageView;
        imageView.setScaleType(ImageView.ScaleType.FIT_XY);
        FtUtil.setRemoveSystemUI(getWindow(), true);
        int testType = getIntent().getIntExtra("TEST_TYPE", -1);
        this.filePath = getIntent().getStringExtra("FILE_PATH");
        FtUtil.log_d(CLASS_NAME, "onCreate", "testType: " + testType);
        performRequest(testType);
        FtUtil.disableDisplayCutOutMode(getWindow(), true);
    }

    public static Activity getInstance() {
        return mActivity;
    }

    private void performRequest(int testtype) {
        switch (testtype) {
            case 1:
                this.mImageView.setBackgroundColor(-1);
                return;
            case 2:
                this.mImageView.setBackgroundColor(-16777216);
                return;
            case 3:
                File file2 = new File(this.filePath);
                this.file = file2;
                if (file2.exists()) {
                    this.mImageView.setImageURI(Uri.fromFile(this.file));
                    return;
                }
                return;
            case 4:
                if (subScreenOption == 0) {
                    setPresentationMode();
                }
                showSubDisplay();
                File file3 = new File(this.filePath);
                this.file = file3;
                if (file3.exists()) {
                    this.mPresentation.setPresentationImage(Uri.fromFile(this.file));
                    return;
                }
                return;
            default:
                return;
        }
    }

    private void setPresentationMode() {
        DisplayManager displayManager = (DisplayManager) getApplicationContext().getSystemService("display");
        this.mDisplayManager = displayManager;
        Display[] presentationDisplays = displayManager.getDisplays("com.samsung.android.hardware.display.category.BUILTIN");
        FtUtil.log_i(CLASS_NAME, "setPresentationMode", "presentationDisplays.length : " + presentationDisplays.length);
        if (presentationDisplays.length > 0) {
            for (Display iterDisplay : presentationDisplays) {
                if (iterDisplay.getDisplayId() != 0) {
                    if ((iterDisplay.getFlags() & 8) != 8) {
                        FtUtil.log_i(CLASS_NAME, "setPresentationMode", "Read Display presentation #" + iterDisplay + " is false.");
                        subScreenOption = 2;
                    } else {
                        FtUtil.log_i(CLASS_NAME, "setPresentationMode", "Read Display presentation #" + iterDisplay + " is true.");
                        subScreenOption = 1;
                    }
                }
            }
        }
        FtUtil.log_i(CLASS_NAME, "setPresentationMode", "subScreenOption : " + subScreenOption);
    }

    private void showSubDisplay() {
        FtUtil.log_i(CLASS_NAME, "showSubDisplay", "");
        Display selectedDisplay = null;
        DisplayManager displayManager = (DisplayManager) getApplicationContext().getSystemService("display");
        this.mDisplayManager = displayManager;
        if (displayManager != null) {
            Display[] presentationDisplays = displayManager.getDisplays("com.samsung.android.hardware.display.category.BUILTIN");
            FtUtil.log_i(CLASS_NAME, "showSubDisplay", "presentationDisplays.length : " + presentationDisplays.length);
            if (presentationDisplays.length > 0) {
                for (Display iterDisplay : presentationDisplays) {
                    FtUtil.log_i(CLASS_NAME, "showSubDisplay", "Display #" + iterDisplay + " is founded.");
                    selectedDisplay = iterDisplay;
                }
                FtUtil.log_i(CLASS_NAME, "showSubDisplay", "Start SubDisplay number : " + selectedDisplay.getDisplayId());
                if (subScreenOption == 1) {
                    showPresentation(selectedDisplay);
                }
            }
        }
    }

    private void showPresentation(Display display) {
        FtUtil.log_i(CLASS_NAME, "showPresentation", "Show presentation to sub display.");
        if (this.mPresentation == null) {
            this.mTestDisplayId = display.getDisplayId();
            SubPresentation subPresentation = new SubPresentation(getApplicationContext(), display);
            this.mPresentation = subPresentation;
            subPresentation.show();
            FtUtil.setRemoveSystemUI(getWindow(), true);
        }
    }

    /* access modifiers changed from: protected */
    public void onPause() {
        FtUtil.log_d(CLASS_NAME, "onPause", null);
        super.onPause();
        sendBroadcast(new Intent("com.samsung.android.aircommandmanager.START_MONITORING"));
        ModulePower.instance(this).setScreenBrightnessMode(this.mode);
        finish();
    }

    /* access modifiers changed from: protected */
    public void onDestroy() {
        if (subScreenOption == 1) {
            dismissPresentation();
        } else {
            Intent i = new Intent("com.android.samsungtest.SCREEN_BACKGROUND");
            i.putExtra("control", "FINISH");
            sendBroadcast(i);
        }
        super.onDestroy();
    }

    private void dismissPresentation() {
        if (this.mPresentation != null) {
            FtUtil.log_i(CLASS_NAME, "dismissPresentation", "mPresentation is not null");
            this.mPresentation.dismiss();
            this.mPresentation = null;
            this.mTestDisplayId = -1;
        }
    }

    /* access modifiers changed from: protected */
    public void onResume() {
        FtUtil.log_d(CLASS_NAME, "onResume", null);
        super.onResume();
        sendBroadcast(new Intent("com.samsung.android.aircommandmanager.STOP_MONITORING"));
        this.mode = ModulePower.instance(this).getScreenBrightnessMode();
        ModulePower.instance(this).setScreenBrightnessMode(0);
    }

    public static class SubPresentation extends Presentation {
        private static final String CLASS_NAME = "UIDisplayBG.SubPresentation";
        private ImageView mImageView;

        public SubPresentation(Context context, Display display) {
            super(context, display);
        }

        /* access modifiers changed from: protected */
        public void onCreate(Bundle savedInstanceState) {
            FtUtil.log_i(CLASS_NAME, "onCreate", "Create presentation for UIDisplayBG");
            super.onCreate(savedInstanceState);
            setContentView(R.layout.ui_displaybg_sub);
            ImageView imageView = (ImageView) findViewById(R.id.disptest_imageview_sub);
            this.mImageView = imageView;
            imageView.setScaleType(ImageView.ScaleType.FIT_XY);
            FtUtil.log_i(CLASS_NAME, "onCreate", "Color : RED");
            getWindow().addFlags(2097152);
            FtUtil.setRemoveSystemUI(getWindow(), true);
        }

        public void setPresentationImage(Uri uri) {
            this.mImageView.setImageURI(uri);
        }
    }
}
