package com.sec.factory.app.ui;

import android.app.Activity;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.lang.ref.WeakReference;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class UIDisplayLinearTest extends UIBase implements View.OnTouchListener, View.OnClickListener {
    private static final int IGNORE_TOUCH_DELAY = 1000;
    private static final int IGNORE_TOUCH_END = 0;
    private static final String MODE_OFF = "0";
    private static final String MODE_ON = "1";
    private static final int STOP_TEST = 1;
    private LinearLayout mBgLayout;
    private Button mBtnFail;
    private Button mBtnPass;
    private boolean mIsShowBtnEnabled = false;
    private boolean mIsTesting = false;
    private final WeakReferenceTestHandler mNotiHandler = new WeakReferenceTestHandler(this);
    private TextView mTxtTitle;
    private ExecutorService threadExecutor = Executors.newSingleThreadExecutor();

    public UIDisplayLinearTest() {
        super("UIDisplayLinearTest", FactoryTestManager.TEST_DISPLAY_LINEAR_TEST);
    }

    private static class WeakReferenceTestHandler extends Handler {
        private final WeakReference<Activity> ref;

        public WeakReferenceTestHandler(Activity act) {
            this.ref = new WeakReference<>(act);
        }

        public void handleMessage(Message msg) {
            UIDisplayLinearTest act = (UIDisplayLinearTest) this.ref.get();
            if (act != null) {
                switch (msg.what) {
                    case 0:
                        FtUtil.log_d(act.CLASS_NAME, "handleMessage", "IGNORE_TOUCH_END");
                        act.mIsShowBtnEnabled = true;
                        return;
                    case 1:
                        FtUtil.log_d(act.CLASS_NAME, "handleMessage", "STOP_TEST");
                        act.stopTest();
                        return;
                    default:
                        return;
                }
            }
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        FtUtil.log_d(this.CLASS_NAME, "onCreate", "onCreate");
        setContentView(R.layout.ui_display_linear_test);
        FtUtil.setSystemKeyBlock(getComponentName(), 26);
        FtUtil.setRemoveStatusBar(getWindow());
        FtUtil.setRemoveSystemUI(getWindow(), true);
        this.mBtnPass = (Button) findViewById(R.id.pass_btn);
        this.mBtnFail = (Button) findViewById(R.id.fail_btn);
        this.mTxtTitle = (TextView) findViewById(R.id.tv_display_linear);
        this.mBgLayout = (LinearLayout) findViewById(R.id.background);
        initTest();
    }

    private void initTest() {
        FtUtil.log_d(this.CLASS_NAME, "initTest", "init test setting");
        this.mIsShowBtnEnabled = false;
        this.mBgLayout.setOnTouchListener(this);
        this.mBtnPass.setOnClickListener(this);
        this.mBtnFail.setOnClickListener(this);
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        FtUtil.log_d(this.CLASS_NAME, "onResume", "");
        startTest();
    }

    private void startTest() {
        FtUtil.log_d(this.CLASS_NAME, "startTest", "Test start");
        this.mIsShowBtnEnabled = false;
        this.mIsTesting = true;
        resultScreenVisible(false);
        this.threadExecutor.execute(new UIDisplayLinearTest$$ExternalSyntheticLambda0(this));
    }

    public /* synthetic */ void lambda$startTest$0$UIDisplayLinearTest() {
        Support.Kernel.write(Support.Kernel.DISPLAY_LINEAR_TEST_NODE, "1");
        this.mNotiHandler.sendEmptyMessageDelayed(0, 1000);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void stopTest() {
        FtUtil.log_d(this.CLASS_NAME, "stopTest", "Test stop");
        this.threadExecutor.execute(UIDisplayLinearTest$$ExternalSyntheticLambda1.INSTANCE);
        this.mIsTesting = false;
        resultScreenVisible(true);
    }

    private void resultScreenVisible(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "resultScreenVisible", "Visible : " + flag);
        btnVisible(flag);
        displayTitle(flag);
    }

    private void btnVisible(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "btnVisible", "Visible : " + flag);
        if (flag) {
            this.mBtnPass.setVisibility(0);
            this.mBtnFail.setVisibility(0);
            return;
        }
        this.mBtnPass.setVisibility(4);
        this.mBtnFail.setVisibility(4);
    }

    private void displayTitle(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "displayTitle", "Visible : " + flag);
        if (flag) {
            this.mTxtTitle.setVisibility(0);
        } else {
            this.mTxtTitle.setVisibility(4);
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        super.onPause();
        this.mNotiHandler.removeCallbacksAndMessages(null);
    }

    public boolean onTouch(View view, MotionEvent event) {
        switch (event.getAction()) {
            case 0:
                FtUtil.log_i(this.CLASS_NAME, "onTouch", "Touch down");
                if (this.mIsShowBtnEnabled && this.mIsTesting) {
                    this.mNotiHandler.sendEmptyMessage(1);
                    break;
                }
        }
        return true;
    }

    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.fail_btn:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "FAIL");
                finish();
                return;
            case R.id.pass_btn:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "PASS");
                setTestResult((byte) 80);
                finish();
                return;
            default:
                return;
        }
    }
}
