package com.sec.factory.app.ui;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.os.SystemClock;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.LinearLayout;
import android.widget.ListAdapter;
import android.widget.ListView;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.NVAccessor;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.util.ArrayList;
import java.util.List;

public class UIFactoryHistory extends Activity {
    private static final String CLASS_NAME = "UIFactoryHistory";
    private HistoryAdaptor mAdaptor;
    private final List<HistoryItem> mHistoryList = new ArrayList();
    private ListView mListView;

    /* access modifiers changed from: private */
    public class HistoryItem {
        private String mItemName;
        private String mNVKey;
        private final String mNVValue;

        public HistoryItem(String nvKey, String nvValue) {
            String itemIDforPGM = UIFactoryHistory.this.getItemIDforPGM(nvKey);
            this.mItemName = itemIDforPGM;
            if ("NA".equals(itemIDforPGM)) {
                this.mNVKey = Integer.toHexString(Integer.parseInt(nvKey, 16)).toUpperCase();
                this.mItemName = Support.FactoryTestMenu.getFactoryTestName("nv", "0x" + this.mNVKey);
            }
            if (nvKey.equals("e")) {
                this.mNVKey = Integer.toHexString(Integer.parseInt(nvKey, 16)).toUpperCase();
                this.mItemName = "Wlan";
            }
            this.mNVKey = String.valueOf(Integer.parseInt(nvKey, 16)).toUpperCase();
            if (this.mItemName == null) {
                this.mItemName = "UNKNOWN";
            }
            this.mNVValue = nvValue;
            FtUtil.log_i(UIFactoryHistory.CLASS_NAME, "HistoryItem-HistoryItem", "NV Key (Hexa/Decimal) : " + nvKey + "/" + this.mNVKey + ", Name : " + this.mItemName + ", NV Value : " + nvValue);
        }
    }

    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ui_nvhistory);
        this.mAdaptor = new HistoryAdaptor(this, R.layout.ui_nvhistory_item, this.mHistoryList);
        ListView listView = (ListView) findViewById(R.id.hist_nv_list);
        this.mListView = listView;
        listView.setAdapter((ListAdapter) this.mAdaptor);
    }

    /* access modifiers changed from: protected */
    public void onResume() {
        super.onResume();
        this.mHistoryList.clear();
        FtUtil.log_d(CLASS_NAME, "onResume", "Request (NV History) : " + SystemClock.uptimeMillis() + " millisecond");
        parseNVHistory();
    }

    /* access modifiers changed from: protected */
    public void onStop() {
        super.onStop();
        FtUtil.log_d(CLASS_NAME, "onStop");
        finish();
    }

    private void parseNVHistory() {
        FtUtil.log_i(CLASS_NAME, "parseNVHistory", "Response (NV History) : " + SystemClock.uptimeMillis() + " millisecond");
        String history = NVAccessor.getNVHistory();
        if (history == null || history.length() == 0) {
            FtUtil.log_e(CLASS_NAME, "parseNVHistory", "No Item");
            return;
        }
        FtUtil.log_i(CLASS_NAME, "parseNVHistory", "[Data] size: " + history.length() + ", value: " + history);
        FtUtil.log_i(CLASS_NAME, "parseNVHistory", "NV XXX");
        for (int i = 0; i < history.length(); i += 4) {
            String NVKey = history.substring(i, i + 3);
            String NVValue = history.substring(i + 3, i + 4);
            FtUtil.log_i(CLASS_NAME, "parseNVHistory", "NVKey : " + NVKey + ", NVValue : " + NVValue);
            this.mHistoryList.add(new HistoryItem(Integer.toHexString(Integer.parseInt(NVKey, 10)), NVValue));
        }
        this.mAdaptor.notifyDataSetChanged();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getItemIDforPGM(String result) {
        String ret = "NA";
        if (EgisFingerprint.MAJOR_VERSION.equalsIgnoreCase(result)) {
            ret = "SMD FUNCTION";
        } else if ("4".equalsIgnoreCase(result)) {
            ret = "PBA TEST";
        } else if ("7".equalsIgnoreCase(result)) {
            ret = "RF CAL";
        } else if ("8".equalsIgnoreCase(result)) {
            ret = "RF CAL2";
        } else if ("A".equalsIgnoreCase(result)) {
            ret = "LTE CAL";
        } else if ("B".equalsIgnoreCase(result)) {
            ret = "FINAL 1";
        } else if ("C".equalsIgnoreCase(result)) {
            ret = "LTE FINAL";
        } else if ("E".equalsIgnoreCase(result)) {
            ret = "WLAN";
        } else if ("F".equalsIgnoreCase(result)) {
            ret = "FINAL 2";
        } else if ("10".equalsIgnoreCase(result)) {
            ret = "IMEI WRITE";
        } else if ("12".equalsIgnoreCase(result)) {
            ret = "FUNC 3";
        } else if ("13".equalsIgnoreCase(result)) {
            ret = "FUNC 1";
        } else if ("14".equalsIgnoreCase(result)) {
            ret = "FUNC 2";
        } else if ("62".equalsIgnoreCase(result)) {
            ret = "PBA Repair";
        } else if ("63".equalsIgnoreCase(result)) {
            ret = "MAIN Repair";
        } else if ("1F".equalsIgnoreCase(result)) {
            ret = "MAIN FUNCTION";
        } else if ("41".equalsIgnoreCase(result)) {
            ret = "MOT TEST";
        } else if ("42".equalsIgnoreCase(result)) {
            ret = "CAMERA MAIN";
        } else if ("B1".equalsIgnoreCase(result)) {
            ret = "S_CAL";
        } else if ("5A".equalsIgnoreCase(result)) {
            ret = "Pre_FINAL";
        } else if ("69".equalsIgnoreCase(result)) {
            ret = "Pre_WLAN";
        } else if ("96".equalsIgnoreCase(result)) {
            ret = "FORCE PASS SMD";
        } else if ("90".equalsIgnoreCase(result)) {
            ret = "W AFC EFFICIENCY";
        } else if ("39".equalsIgnoreCase(result)) {
            ret = "FELICA CAL";
        } else if ("FD".equalsIgnoreCase(result)) {
            ret = "TVOC";
        } else if ("11C".equalsIgnoreCase(result)) {
            ret = "RF CAL 5G MMWAVE";
        } else if ("11D".equalsIgnoreCase(result)) {
            ret = "FINAL 5G MMWAVE";
        }
        FtUtil.log_i(CLASS_NAME, "getItemIDforPGM", "result NV : " + result + ", Name : " + ret);
        return ret;
    }

    /* access modifiers changed from: private */
    public class HistoryAdaptor extends ArrayAdapter<HistoryItem> {
        public HistoryAdaptor(Context context, int resource, List<HistoryItem> items) {
            super(context, resource, items);
        }

        public View getView(int position, View convertView, ViewGroup parent) {
            LinearLayout layout;
            if (convertView == null) {
                layout = (LinearLayout) LayoutInflater.from(getContext()).inflate(R.layout.ui_nvhistory_item, parent, false);
            } else {
                layout = (LinearLayout) convertView;
            }
            HistoryItem item = (HistoryItem) UIFactoryHistory.this.mHistoryList.get(position);
            ((TextView) layout.findViewById(R.id.id)).setText(item.mNVKey);
            ((TextView) layout.findViewById(R.id.item)).setText(item.mItemName);
            ((TextView) layout.findViewById(R.id.result)).setText(item.mNVValue);
            FtUtil.log_i(UIFactoryHistory.CLASS_NAME, "HistoryAdaptor-getView", "[" + position + "] 'NV Key' / 'Name' / 'NV Value' : " + item.mNVKey + " / " + item.mItemName + " / " + item.mNVValue);
            return layout;
        }
    }
}
