package com.sec.factory.app.ui;

import android.app.Activity;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.nfc.NdefRecord;
import android.nfc.NfcAdapter;
import android.nfc.Tag;
import android.nfc.tech.Ndef;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.widget.Toast;
import com.qualcomm.qti.biometrics.fingerprint.QFSEvent;
import com.sec.factory.R;
import com.sec.factory.aporiented.AtParser;
import com.sec.factory.aporiented.ResponseWriter;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.NVAccessor;
import com.sec.xmldata.support.XMLDataStorage;
import java.io.UnsupportedEncodingException;
import java.lang.ref.WeakReference;

public class UIFactoryTag extends Activity {
    private static final String CLASS_NAME = "UIFactoryTag";
    private static final String MIME_TEXT_PLAIN = "application/com.aircmd.tag";
    private static final int MSG_ACTIVITY_CLOSE = 0;
    private static final int MSG_TOAST_MESSAGE = 1;
    private final BroadcastReceiver mBroadcastReceiver = new BroadcastReceiver() {
        /* class com.sec.factory.app.ui.UIFactoryTag.AnonymousClass1 */

        public void onReceive(Context context, Intent intent) {
            String cmdData;
            String action = intent.getAction();
            FtUtil.log_d(UIFactoryTag.CLASS_NAME, "BroadcaseReceiver onReceive", "Action :" + action);
            if (action.equals("com.sec.factory.intent.action.DEVICE_CMD_RSP") && (cmdData = intent.getStringExtra("COMMAND")) != null) {
                UIFactoryTag.this.displayToast(cmdData);
                UIFactoryTag.this.mHandler.sendEmptyMessageDelayed(0, 500);
            }
        }
    };
    private final FactoryTagHandler mHandler = new FactoryTagHandler(this);
    private NfcAdapter mNfcAdapter;
    private AtParser parser;
    private ResponseWriter writer;

    /* access modifiers changed from: private */
    public static class FactoryTagHandler extends Handler {
        private final WeakReference<UIFactoryTag> mActivity;

        public FactoryTagHandler(UIFactoryTag activity) {
            this.mActivity = new WeakReference<>(activity);
        }

        public void handleMessage(Message msg) {
            UIFactoryTag activity = this.mActivity.get();
            switch (msg.what) {
                case 0:
                    if (activity != null) {
                        activity.finish();
                        return;
                    }
                    return;
                default:
                    return;
            }
        }
    }

    /* access modifiers changed from: protected */
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ui_factory_tag);
        FtUtil.log_d(CLASS_NAME, "onCreate", "Init...");
        if (!XMLDataStorage.instance().parseXML(getApplicationContext())) {
            FtUtil.log_d(CLASS_NAME, "onCreate", "XML data parsing was failed.");
            finish();
        }
        this.mNfcAdapter = NfcAdapter.getDefaultAdapter(this);
        if (this.writer == null) {
            this.writer = new ResponseWriter(this, true);
        }
        if (this.parser == null) {
            AtParser atParser = new AtParser();
            this.parser = atParser;
            atParser.registerAllHandler(this, this.writer);
        }
        if (this.mNfcAdapter == null) {
            finish();
        }
        handleIntent(getIntent());
    }

    /* access modifiers changed from: protected */
    public void onResume() {
        super.onResume();
        IntentFilter intent = new IntentFilter();
        intent.addAction("com.sec.factory.intent.action.DEVICE_CMD_RSP");
        registerReceiver(this.mBroadcastReceiver, intent);
        FtUtil.log_d(CLASS_NAME, "onResume", "Success registerReceiver");
        setupForegroundDispatch(this, this.mNfcAdapter);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void displayToast(String data) {
        Toast.makeText(this, data, 1).show();
    }

    private void handleIntent(Intent intent) {
        if (!"android.nfc.action.NDEF_DISCOVERED".equals(intent.getAction()) || !FtUtil.isFactoryBinary()) {
            finish();
            return;
        }
        FtUtil.log_d(CLASS_NAME, "handleIntent", "catch NDEF Intent");
        if (MIME_TEXT_PLAIN.equals(intent.getType())) {
            displayToast("Pass - Find NDEF_DISCOVERED intent");
            new NdefReaderTask().execute((Tag) intent.getParcelableExtra("android.nfc.extra.TAG"));
            return;
        }
        finish();
    }

    /* access modifiers changed from: protected */
    public void onPause() {
        FtUtil.log_d(CLASS_NAME, "onPause", "onPause");
        stopForegroundDispatch(this, this.mNfcAdapter);
        unregisterReceiver(this.mBroadcastReceiver);
        finish();
        super.onPause();
    }

    /* access modifiers changed from: protected */
    public void onNewIntent(Intent intent) {
        handleIntent(intent);
    }

    public static void setupForegroundDispatch(Activity activity, NfcAdapter adapter) {
        Intent intent = new Intent(activity.getApplicationContext(), activity.getClass());
        intent.setFlags(536870912);
        PendingIntent pendingIntent = PendingIntent.getActivity(activity.getApplicationContext(), 0, intent, QFSEvent.QUALITY_PARTIAL_TOUCH);
        String[][] techList = new String[0][];
        IntentFilter[] filters = {new IntentFilter()};
        filters[0].addAction("android.nfc.action.NDEF_DISCOVERED");
        filters[0].addCategory("android.intent.category.DEFAULT");
        try {
            filters[0].addDataType(MIME_TEXT_PLAIN);
            adapter.enableForegroundDispatch(activity, pendingIntent, filters, techList);
        } catch (IntentFilter.MalformedMimeTypeException e) {
            throw new RuntimeException("Check your mime type.");
        }
    }

    public static void stopForegroundDispatch(Activity activity, NfcAdapter adapter) {
        adapter.disableForegroundDispatch(activity);
    }

    /* access modifiers changed from: private */
    public class NdefReaderTask extends AsyncTask<Tag, Void, String> {
        private NdefReaderTask() {
        }

        /* access modifiers changed from: protected */
        public String doInBackground(Tag... params) {
            Ndef ndef;
            Tag tag;
            int cmdIdx;
            UnsupportedEncodingException e;
            InterruptedException ie;
            String[] data;
            NumberFormatException Ne;
            int i = null;
            Tag tag2 = params[0];
            Ndef ndef2 = Ndef.get(tag2);
            if (ndef2 == null) {
                FtUtil.log_d(UIFactoryTag.CLASS_NAME, "NdefReaderTask", "Sorry, this tag was not supported ndef");
                return null;
            }
            NdefRecord[] records = ndef2.getCachedNdefMessage().getRecords();
            int length = records.length;
            int i2 = 0;
            while (i2 < length) {
                try {
                    String[] data2 = readText(records[i2]);
                    try {
                        int length2 = data2.length;
                        int i3 = i;
                        while (i3 < length2) {
                            String cmd = data2[i3];
                            try {
                                if (cmd.contains("DELAY")) {
                                    try {
                                        int delay = Integer.parseInt(cmd.substring(5));
                                        StringBuilder sb = new StringBuilder();
                                        tag = tag2;
                                        try {
                                            sb.append("existed delay : ");
                                            sb.append(delay);
                                            FtUtil.log_d(UIFactoryTag.CLASS_NAME, "NdefReaderTask", sb.toString());
                                            ndef = ndef2;
                                        } catch (UnsupportedEncodingException e2) {
                                            e = e2;
                                            ndef = ndef2;
                                            cmdIdx = null;
                                            e.printStackTrace();
                                            i2++;
                                            i = cmdIdx;
                                            tag2 = tag;
                                            ndef2 = ndef;
                                        } catch (InterruptedException e3) {
                                            ie = e3;
                                            ndef = ndef2;
                                            cmdIdx = null;
                                            ie.printStackTrace();
                                            i2++;
                                            i = cmdIdx;
                                            tag2 = tag;
                                            ndef2 = ndef;
                                        }
                                        try {
                                            Thread.sleep((long) delay);
                                            data = data2;
                                            cmdIdx = null;
                                        } catch (UnsupportedEncodingException e4) {
                                            e = e4;
                                            cmdIdx = null;
                                            e.printStackTrace();
                                            i2++;
                                            i = cmdIdx;
                                            tag2 = tag;
                                            ndef2 = ndef;
                                        } catch (InterruptedException e5) {
                                            ie = e5;
                                            cmdIdx = null;
                                            ie.printStackTrace();
                                            i2++;
                                            i = cmdIdx;
                                            tag2 = tag;
                                            ndef2 = ndef;
                                        }
                                    } catch (UnsupportedEncodingException e6) {
                                        e = e6;
                                        tag = tag2;
                                        ndef = ndef2;
                                        cmdIdx = null;
                                        e.printStackTrace();
                                        i2++;
                                        i = cmdIdx;
                                        tag2 = tag;
                                        ndef2 = ndef;
                                    } catch (InterruptedException e7) {
                                        ie = e7;
                                        tag = tag2;
                                        ndef = ndef2;
                                        cmdIdx = null;
                                        ie.printStackTrace();
                                        i2++;
                                        i = cmdIdx;
                                        tag2 = tag;
                                        ndef2 = ndef;
                                    }
                                } else {
                                    tag = tag2;
                                    ndef = ndef2;
                                    try {
                                        if (cmd.contains("SETTESTNV")) {
                                            cmdIdx = cmd.substring(13).split(",");
                                            if (cmdIdx[1].length() == 1) {
                                                data = data2;
                                                try {
                                                    if (!"N".equals(cmdIdx[1])) {
                                                        try {
                                                            if (!"E".equals(cmdIdx[1]) && !"P".equals(cmdIdx[1]) && !"F".equals(cmdIdx[1])) {
                                                                cmdIdx = null;
                                                            }
                                                        } catch (UnsupportedEncodingException e8) {
                                                            e = e8;
                                                            cmdIdx = null;
                                                            e.printStackTrace();
                                                            i2++;
                                                            i = cmdIdx;
                                                            tag2 = tag;
                                                            ndef2 = ndef;
                                                        } catch (InterruptedException e9) {
                                                            ie = e9;
                                                            cmdIdx = null;
                                                            ie.printStackTrace();
                                                            i2++;
                                                            i = cmdIdx;
                                                            tag2 = tag;
                                                            ndef2 = ndef;
                                                        }
                                                    }
                                                } catch (UnsupportedEncodingException e10) {
                                                    e = e10;
                                                    cmdIdx = null;
                                                    e.printStackTrace();
                                                    i2++;
                                                    i = cmdIdx;
                                                    tag2 = tag;
                                                    ndef2 = ndef;
                                                } catch (InterruptedException e11) {
                                                    ie = e11;
                                                    cmdIdx = null;
                                                    ie.printStackTrace();
                                                    i2++;
                                                    i = cmdIdx;
                                                    tag2 = tag;
                                                    ndef2 = ndef;
                                                }
                                                try {
                                                    try {
                                                        try {
                                                            NVAccessor.setNV(Integer.parseInt(cmdIdx[0]), cmdIdx[1].getBytes()[0]);
                                                            FtUtil.log_d(UIFactoryTag.CLASS_NAME, "NdefReaderTask", "success  nv cmd : " + cmd);
                                                            cmdIdx = null;
                                                            try {
                                                                UIFactoryTag.this.mHandler.sendEmptyMessageDelayed(0, 500);
                                                            } catch (NumberFormatException e12) {
                                                                Ne = e12;
                                                            }
                                                        } catch (NumberFormatException e13) {
                                                            Ne = e13;
                                                            cmdIdx = null;
                                                            try {
                                                                Ne.printStackTrace();
                                                                i3++;
                                                                i = cmdIdx;
                                                                tag2 = tag;
                                                                ndef2 = ndef;
                                                                data2 = data;
                                                            } catch (UnsupportedEncodingException e14) {
                                                                e = e14;
                                                                e.printStackTrace();
                                                                i2++;
                                                                i = cmdIdx;
                                                                tag2 = tag;
                                                                ndef2 = ndef;
                                                            } catch (InterruptedException e15) {
                                                                ie = e15;
                                                                ie.printStackTrace();
                                                                i2++;
                                                                i = cmdIdx;
                                                                tag2 = tag;
                                                                ndef2 = ndef;
                                                            }
                                                        } catch (UnsupportedEncodingException e16) {
                                                            e = e16;
                                                            cmdIdx = null;
                                                            e.printStackTrace();
                                                            i2++;
                                                            i = cmdIdx;
                                                            tag2 = tag;
                                                            ndef2 = ndef;
                                                        } catch (InterruptedException e17) {
                                                            ie = e17;
                                                            cmdIdx = null;
                                                            ie.printStackTrace();
                                                            i2++;
                                                            i = cmdIdx;
                                                            tag2 = tag;
                                                            ndef2 = ndef;
                                                        }
                                                    } catch (NumberFormatException e18) {
                                                        Ne = e18;
                                                        cmdIdx = null;
                                                        Ne.printStackTrace();
                                                        i3++;
                                                        i = cmdIdx;
                                                        tag2 = tag;
                                                        ndef2 = ndef;
                                                        data2 = data;
                                                    }
                                                } catch (NumberFormatException e19) {
                                                    Ne = e19;
                                                    cmdIdx = null;
                                                    Ne.printStackTrace();
                                                    i3++;
                                                    i = cmdIdx;
                                                    tag2 = tag;
                                                    ndef2 = ndef;
                                                    data2 = data;
                                                } catch (UnsupportedEncodingException e20) {
                                                    e = e20;
                                                    cmdIdx = null;
                                                    e.printStackTrace();
                                                    i2++;
                                                    i = cmdIdx;
                                                    tag2 = tag;
                                                    ndef2 = ndef;
                                                } catch (InterruptedException e21) {
                                                    ie = e21;
                                                    cmdIdx = null;
                                                    ie.printStackTrace();
                                                    i2++;
                                                    i = cmdIdx;
                                                    tag2 = tag;
                                                    ndef2 = ndef;
                                                }
                                            } else {
                                                data = data2;
                                                cmdIdx = null;
                                            }
                                        } else {
                                            data = data2;
                                            cmdIdx = null;
                                            FtUtil.log_d(UIFactoryTag.CLASS_NAME, "NdefReaderTask", "existed cmd : " + cmd);
                                            UIFactoryTag.this.parser.process(cmd, UIFactoryTag.this.writer);
                                        }
                                    } catch (UnsupportedEncodingException e22) {
                                        e = e22;
                                        cmdIdx = 0;
                                        e.printStackTrace();
                                        i2++;
                                        i = cmdIdx;
                                        tag2 = tag;
                                        ndef2 = ndef;
                                    } catch (InterruptedException e23) {
                                        ie = e23;
                                        cmdIdx = null;
                                        ie.printStackTrace();
                                        i2++;
                                        i = cmdIdx;
                                        tag2 = tag;
                                        ndef2 = ndef;
                                    }
                                }
                                i3++;
                                i = cmdIdx;
                                tag2 = tag;
                                ndef2 = ndef;
                                data2 = data;
                            } catch (UnsupportedEncodingException e24) {
                                e = e24;
                                tag = tag2;
                                ndef = ndef2;
                                cmdIdx = 0;
                                e.printStackTrace();
                                i2++;
                                i = cmdIdx;
                                tag2 = tag;
                                ndef2 = ndef;
                            } catch (InterruptedException e25) {
                                ie = e25;
                                tag = tag2;
                                ndef = ndef2;
                                cmdIdx = null;
                                ie.printStackTrace();
                                i2++;
                                i = cmdIdx;
                                tag2 = tag;
                                ndef2 = ndef;
                            }
                        }
                        tag = tag2;
                        ndef = ndef2;
                        cmdIdx = i;
                    } catch (UnsupportedEncodingException e26) {
                        e = e26;
                        tag = tag2;
                        ndef = ndef2;
                        cmdIdx = i;
                        e.printStackTrace();
                        i2++;
                        i = cmdIdx;
                        tag2 = tag;
                        ndef2 = ndef;
                    } catch (InterruptedException e27) {
                        ie = e27;
                        tag = tag2;
                        ndef = ndef2;
                        cmdIdx = i;
                        ie.printStackTrace();
                        i2++;
                        i = cmdIdx;
                        tag2 = tag;
                        ndef2 = ndef;
                    }
                } catch (UnsupportedEncodingException e28) {
                    e = e28;
                    tag = tag2;
                    ndef = ndef2;
                    cmdIdx = i;
                    e.printStackTrace();
                    i2++;
                    i = cmdIdx;
                    tag2 = tag;
                    ndef2 = ndef;
                } catch (InterruptedException e29) {
                    ie = e29;
                    tag = tag2;
                    ndef = ndef2;
                    cmdIdx = i;
                    ie.printStackTrace();
                    i2++;
                    i = cmdIdx;
                    tag2 = tag;
                    ndef2 = ndef;
                }
                i2++;
                i = cmdIdx;
                tag2 = tag;
                ndef2 = ndef;
            }
            return null;
        }

        private String[] readText(NdefRecord record) throws UnsupportedEncodingException {
            return new String(record.getPayload(), "UTF-8").split("/");
        }

        /* access modifiers changed from: protected */
        public void onPostExecute(String result) {
            if (result != null) {
                UIFactoryTag.this.displayToast(result);
            }
        }
    }
}
