package com.sec.factory.app.ui;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Color;
import android.graphics.Point;
import android.graphics.drawable.GradientDrawable;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.provider.Settings;
import android.util.DisplayMetrics;
import android.util.TypedValue;
import android.view.Display;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.AbsoluteLayout;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.common.CommonFingerprintEgis;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.lang.ref.WeakReference;
import java.nio.channels.FileChannel;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Locale;

public class UIFingerprintCalTestEgis extends UIFingerprintCalTest implements View.OnClickListener {
    private static final String PATH_HW_LIGHT = "/sys/class/lcd/panel/fp_green_circle";
    private static final String PATH_SNR_IMAGE = "/data/egis_after_rubber.bmp";
    private String UTOPIA_TAG = "[UTOPIA_FINGERPRINT]";
    private String failReason = "NONE";
    private Button mButtonExit;
    private Button mButtonStart;
    private CommonFingerprintEgis mCommonFingerprintEgis;
    private GradientDrawable mDrawableCircle;
    private final StatusHandler mHandler = new StatusHandler(this);
    private int mIntColorCircle = -16711936;
    private ImageView mIvFingerCircle;
    private ImageView mIvFingerRect;
    private ImageView mIvSnrImage;
    private ArrayList<CommonFingerprintEgis.FpTestItem> mListFpTestItemCalibration;
    private BroadcastReceiver mReceiver = null;
    private FingerPrintTestResultView mResultView;
    private CommonFingerprintEgis.STEP mSTEP = CommonFingerprintEgis.STEP.NOTEST;
    private int mScreenHeight;
    private int mScreenWidth;
    private String mStringBrightnessHigh;
    private String mStringBrightnessPrev;
    private String mStringNodeIdBrightness;
    private boolean mSupportHwLightSource = false;
    private TextView mTvCalStatus;
    private TextView mTvCurrentStep;

    public UIFingerprintCalTestEgis() {
        super("UIFingerprintCalTestEgis");
        this.ONPASS_FINISH_DELAY = 2000;
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIFingerprintCalTest, com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        FtUtil.log_d(this.CLASS_NAME, "onCreate", "");
        super.onCreate(savedInstanceState);
        this.TEST_ID = 67;
        setContentView(R.layout.ui_fingerprint_cal_egis_optical);
        FtUtil.setRemoveSystemUI(getWindow(), true);
        CommonFingerprintEgis instance = CommonFingerprintEgis.instance(this);
        this.mCommonFingerprintEgis = instance;
        instance.setHandler(this.mHandler);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIFingerprintCalTest, com.sec.factory.app.ui.UIBase
    public void onResume() {
        FtUtil.log_d(this.CLASS_NAME, "onResume", "");
        super.onResume();
        initialize();
        sendBroadcast(new Intent("com.samsung.android.aircommandmanager.STOP_MONITORING"));
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIFingerprintCalTest, com.sec.factory.app.ui.UIBase
    public void onPause() {
        FtUtil.log_d(this.CLASS_NAME, "onPause", "");
        super.onPause();
        if (this.mSupportHwLightSource) {
            Support.Kernel.writeToPath(PATH_HW_LIGHT, "0");
        }
        sendBroadcast(new Intent("com.samsung.android.aircommandmanager.START_MONITORING"));
        UnregisterReceiver();
        setPrevBrightness();
        Settings.System.putString(getContentResolver(), "fp_test_step", CommonFingerprintEgis.STEP.NOTEST.name());
        Settings.System.putString(getContentResolver(), "fp_test_status", CommonFingerprintEgis.STATUS.NOTEST.name());
        this.mHandler.removeCallbacksAndMessages(null);
        this.mCommonFingerprintEgis.setHandler(null);
        this.mCommonFingerprintEgis.cancel();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIFingerprintCalTest, com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        FtUtil.log_d(this.CLASS_NAME, "onDestroy", "");
        super.onDestroy();
    }

    private void initialize() {
        FtUtil.log_d(this.CLASS_NAME, "initialize", "");
        this.mIvFingerCircle = (ImageView) findViewById(R.id.fingerprint_area_image);
        this.mDrawableCircle = (GradientDrawable) getResources().getDrawable(R.drawable.circle_solid, null);
        this.mIvFingerRect = (ImageView) findViewById(R.id.fingerprint_area_rect);
        this.mButtonStart = (Button) findViewById(R.id.button_start);
        this.mButtonExit = (Button) findViewById(R.id.button_exit);
        this.mTvCurrentStep = (TextView) findViewById(R.id.current_step);
        this.mTvCalStatus = (TextView) findViewById(R.id.cal_status);
        this.mResultView = (FingerPrintTestResultView) findViewById(R.id.fingerprint_resultview);
        this.mIvSnrImage = (ImageView) findViewById(R.id.fingerprint_snrimage);
        this.mButtonStart.setOnClickListener(this);
        this.mButtonExit.setOnClickListener(this);
        loadBrightnessNode();
        loadTargetNitAndColor();
        loadDisplaySize();
        this.mStringBrightnessPrev = Support.Kernel.read(this.mStringNodeIdBrightness);
        setBrightnessHigh();
        if (!checkBatteryTemp() || !drawFingerprintArea()) {
            updateStep(CommonFingerprintEgis.STEP.RESULT);
            showResult();
            return;
        }
        RegisterReceiver();
        this.mCommonFingerprintEgis.initCalibration();
    }

    private void loadTargetNitAndColor() {
        String strCircleInfo = Support.Kernel.read(Support.Kernel.FINGERPRINT_TEST_TARGET_NIT);
        if (strCircleInfo != null) {
            String[] arrStrCircleInfo = strCircleInfo.split(",");
            if (arrStrCircleInfo.length == 4) {
                try {
                    this.mIntColorCircle = Color.parseColor("#" + arrStrCircleInfo[3]);
                } catch (IllegalArgumentException e) {
                    FtUtil.log_e(e);
                }
            }
        }
    }

    private void loadBrightnessNode() {
        String buildHardware = Build.HARDWARE;
        if (buildHardware == null || !buildHardware.contains("qcom")) {
            this.mStringNodeIdBrightness = Support.Kernel.LCD_BACKLIGHT_BRIGHTNESS_LSI;
            this.mStringBrightnessHigh = Support.Kernel.read(Support.Kernel.LCD_BACKLIGHT_BRIGHTNESS_LSI_MAX);
        } else {
            this.mStringNodeIdBrightness = Support.Kernel.LCD_BACKLIGHT_BRIGHTNESS_QUALCOMM;
            this.mStringBrightnessHigh = Support.Kernel.read(Support.Kernel.LCD_BACKLIGHT_BRIGHTNESS_QUALCOMM_MAX);
        }
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "loadBrightnessNode", "max_brightness : " + this.mStringBrightnessHigh);
    }

    private void loadDisplaySize() {
        Display mDisplay = ((WindowManager) getSystemService("window")).getDefaultDisplay();
        Point outpoint = new Point();
        mDisplay.getRealSize(outpoint);
        this.mScreenWidth = outpoint.x;
        this.mScreenHeight = outpoint.y;
    }

    private void setBrightnessHigh() {
        Support.Kernel.write(this.mStringNodeIdBrightness, this.mStringBrightnessHigh);
    }

    private void setPrevBrightness() {
        String str = this.mStringBrightnessPrev;
        if (str != null) {
            Support.Kernel.write(this.mStringNodeIdBrightness, str);
        }
    }

    public boolean checkBrightness() {
        String currBrightness = Support.Kernel.read(this.mStringNodeIdBrightness);
        String str = this.mStringBrightnessHigh;
        if (str != null && str.equals(currBrightness)) {
            return true;
        }
        this.failReason = "Brightness check FAIL";
        return false;
    }

    private void updateStep(CommonFingerprintEgis.STEP step) {
        this.mSTEP = step;
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "updateStep", "mSTEP : " + this.mSTEP);
        Settings.System.putString(getContentResolver(), "fp_test_step", this.mSTEP.name());
        String title = null;
        if (step == CommonFingerprintEgis.STEP.WKBOX) {
            title = "WHITE Calibration";
        } else if (step == CommonFingerprintEgis.STEP.BKBOX) {
            title = "BLACK Calibration";
        } else if (step == CommonFingerprintEgis.STEP.CHART) {
            title = "CHARTER Calibration";
        } else if (step == CommonFingerprintEgis.STEP.RESULT) {
            title = "SNR Test";
        }
        this.mTvCurrentStep.setText(title);
        updateCalStatus(CommonFingerprintEgis.STATUS.READY);
    }

    private void updateCalStatus(CommonFingerprintEgis.STATUS status) {
        this.mTvCalStatus.setText(status.name());
        Settings.System.putString(getContentResolver(), "fp_test_status", status.name());
        switch (AnonymousClass3.$SwitchMap$com$sec$factory$common$CommonFingerprintEgis$STATUS[status.ordinal()]) {
            case 1:
                this.mButtonStart.setVisibility(0);
                this.mIvFingerRect.setVisibility(0);
                return;
            case 2:
                this.mButtonStart.setVisibility(4);
                this.mIvFingerRect.setVisibility(4);
                return;
            case 3:
                this.mButtonStart.setVisibility(4);
                this.mTvCalStatus.setTextColor(UiHallICTest.FONT_COLOR_PASS);
                return;
            case 4:
                if (!"NONE".equals(this.failReason)) {
                    TextView textView = this.mTvCalStatus;
                    textView.setTextSize(0, textView.getTextSize() * 0.5f);
                    this.mTvCalStatus.setText(this.failReason);
                }
                this.mButtonStart.setVisibility(4);
                this.mTvCalStatus.setTextColor(-65536);
                setTestResultFailCase(this.TEST_ID);
                return;
            default:
                return;
        }
    }

    /* access modifiers changed from: package-private */
    /* renamed from: com.sec.factory.app.ui.UIFingerprintCalTestEgis$3  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass3 {
        static final /* synthetic */ int[] $SwitchMap$com$sec$factory$common$CommonFingerprintEgis$STATUS;

        static {
            int[] iArr = new int[CommonFingerprintEgis.STATUS.values().length];
            $SwitchMap$com$sec$factory$common$CommonFingerprintEgis$STATUS = iArr;
            try {
                iArr[CommonFingerprintEgis.STATUS.READY.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$com$sec$factory$common$CommonFingerprintEgis$STATUS[CommonFingerprintEgis.STATUS.RUNNING.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$com$sec$factory$common$CommonFingerprintEgis$STATUS[CommonFingerprintEgis.STATUS.PASS.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$com$sec$factory$common$CommonFingerprintEgis$STATUS[CommonFingerprintEgis.STATUS.FAIL.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    private void showResult() {
        FtUtil.log_d(this.CLASS_NAME, "showResult", "");
        setPrevBrightness();
        ViewGroup.LayoutParams params = this.mIvSnrImage.getLayoutParams();
        int i = 6;
        params.height = this.mScreenHeight / 6;
        this.mIvSnrImage.setLayoutParams(params);
        Bitmap bitmap = BitmapFactory.decodeFile(PATH_SNR_IMAGE);
        this.mIvSnrImage.setVisibility(0);
        this.mIvSnrImage.setImageBitmap(bitmap);
        if (this.mSupportHwLightSource) {
            Support.Kernel.writeToPath(PATH_HW_LIGHT, "0");
        }
        ((TextView) findViewById(R.id.touchGuide)).setVisibility(8);
        ((AbsoluteLayout) findViewById(R.id.fingerprint_area)).setVisibility(8);
        ((FrameLayout) findViewById(R.id.background)).setBackgroundColor(-1);
        ((TextView) findViewById(R.id.main_title)).setTextColor(-16777216);
        this.mTvCurrentStep.setTextColor(-16777216);
        this.mResultView.setVisibility(0);
        this.mResultView.setCanvasSize(this.mScreenWidth, this.mScreenHeight / 2);
        ArrayList<CommonFingerprintEgis.FpTestItem> arrayList = this.mListFpTestItemCalibration;
        if (arrayList != null) {
            this.mResultView.setRowCol(arrayList.size() + 1, 10);
            this.mResultView.setTextData(0, 0, "Item");
            this.mResultView.setTextData(0, 3, "Spec");
            this.mResultView.setTextData(0, 6, "Value");
            this.mResultView.setTextData(0, 8, "Result");
            boolean isAllPass = true;
            int i2 = 0;
            while (i2 < this.mListFpTestItemCalibration.size()) {
                String str = this.CLASS_NAME;
                FtUtil.log_d(str, "showResult", this.UTOPIA_TAG + this.mListFpTestItemCalibration.get(i2).toString());
                String testName = this.mListFpTestItemCalibration.get(i2).getTestName();
                String testSpec = this.mListFpTestItemCalibration.get(i2).getTestSpec();
                String testResult = this.mListFpTestItemCalibration.get(i2).getTestResult();
                boolean itemPass = this.mListFpTestItemCalibration.get(i2).getIsPass();
                if (!itemPass) {
                    isAllPass = false;
                }
                this.mResultView.setTextData(i2 + 1, 0, testName);
                this.mResultView.setTextData(i2 + 1, 3, testSpec);
                this.mResultView.setTextData(i2 + 1, i, testResult);
                this.mResultView.setTextData(i2 + 1, 8, itemPass ? "PASS" : "FAIL");
                i2++;
                i = 6;
            }
            if (!isAllPass || this.mListFpTestItemCalibration.size() == 0) {
                updateCalStatus(CommonFingerprintEgis.STATUS.FAIL);
                copySnrFailImage();
                return;
            }
            updateCalStatus(CommonFingerprintEgis.STATUS.PASS);
            saveCellId();
            setTestResult((byte) 80);
            finishOnPassWithTimer();
            return;
        }
        updateCalStatus(CommonFingerprintEgis.STATUS.FAIL);
    }

    private boolean drawFingerprintArea() {
        FtUtil.log_d(this.CLASS_NAME, "drawFingerprintArea", "");
        String raw_pos = Support.Kernel.read(Support.Kernel.ULTRASONIC_FP_POSITION);
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "drawFingerprintArea", " raw value for pos(mm):" + raw_pos);
        String[] pos = raw_pos.split(",");
        DisplayMetrics mDisplayMetrics = getResources().getDisplayMetrics();
        try {
            float btmToBtm = TypedValue.applyDimension(5, Float.parseFloat(pos[0]), mDisplayMetrics);
            float xOffset = TypedValue.applyDimension(5, Float.parseFloat(pos[1]), mDisplayMetrics);
            TypedValue.applyDimension(5, Float.parseFloat(pos[2]), mDisplayMetrics);
            float fpHeight = TypedValue.applyDimension(5, Float.parseFloat(pos[3]), mDisplayMetrics);
            float uiCircleWidth = TypedValue.applyDimension(5, Float.parseFloat(pos[6]), mDisplayMetrics);
            float uiCircleHeight = TypedValue.applyDimension(5, Float.parseFloat(pos[7]), mDisplayMetrics);
            float outerBoxSize = TypedValue.applyDimension(5, 22.0f, mDisplayMetrics);
            TypedValue.applyDimension(5, 14.0f, mDisplayMetrics);
            String str2 = this.CLASS_NAME;
            FtUtil.log_d(str2, "drawFingerprintArea", "fpFeature : " + "google_touch_display_optical,settings=3");
            boolean contains = "google_touch_display_optical,settings=3".contains("hw_light_source");
            this.mSupportHwLightSource = contains;
            if (contains) {
                FtUtil.log_d(this.CLASS_NAME, "drawFingerprintArea", "Use Self Mask");
                Support.Kernel.writeToPath(PATH_HW_LIGHT, EgisFingerprint.MAJOR_VERSION);
            } else {
                AbsoluteLayout.LayoutParams ivFingerCircleParams = (AbsoluteLayout.LayoutParams) this.mIvFingerCircle.getLayoutParams();
                ivFingerCircleParams.width = (int) uiCircleWidth;
                ivFingerCircleParams.height = (int) uiCircleHeight;
                ivFingerCircleParams.x = (int) (((((float) this.mScreenWidth) * 0.5f) - (uiCircleWidth * 0.5f)) + xOffset);
                ivFingerCircleParams.y = (int) (((float) this.mScreenHeight) - (((uiCircleHeight * 0.5f) + btmToBtm) + (fpHeight * 0.5f)));
                this.mIvFingerCircle.setLayoutParams(ivFingerCircleParams);
                this.mIvFingerCircle.requestLayout();
                this.mDrawableCircle.setColor(this.mIntColorCircle);
                this.mIvFingerCircle.setImageDrawable(this.mDrawableCircle);
            }
            AbsoluteLayout.LayoutParams ivFingerRectParams = (AbsoluteLayout.LayoutParams) this.mIvFingerRect.getLayoutParams();
            ivFingerRectParams.width = (int) outerBoxSize;
            ivFingerRectParams.height = (int) outerBoxSize;
            ivFingerRectParams.x = (int) (((((float) this.mScreenWidth) * 0.5f) - (outerBoxSize * 0.5f)) + xOffset);
            ivFingerRectParams.y = (int) (((float) this.mScreenHeight) - (((outerBoxSize * 0.5f) + btmToBtm) + (0.5f * fpHeight)));
            this.mIvFingerRect.setLayoutParams(ivFingerRectParams);
            this.mIvFingerRect.requestLayout();
            return true;
        } catch (IndexOutOfBoundsException | NumberFormatException ne) {
            FtUtil.log_e(ne);
            this.failReason = "Can not read fingerprint position";
            return false;
        }
    }

    private boolean checkBatteryTemp() {
        String strBattTemp = "";
        try {
            strBattTemp = ModulePower.instance(this).readBatteryTemp();
            if (Integer.parseInt(strBattTemp) > 0) {
                return true;
            }
        } catch (NumberFormatException ne) {
            FtUtil.log_e(ne);
        }
        this.failReason = "Temperature Fail (" + strBattTemp + ")";
        return false;
    }

    /* JADX WARNING: Removed duplicated region for block: B:23:0x00fa  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x00ff  */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x0104  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x0109  */
    /* JADX WARNING: Removed duplicated region for block: B:33:0x0112 A[SYNTHETIC, Splitter:B:33:0x0112] */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x011a A[Catch:{ IOException -> 0x0116 }] */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x011f A[Catch:{ IOException -> 0x0116 }] */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x0124 A[Catch:{ IOException -> 0x0116 }] */
    /* JADX WARNING: Removed duplicated region for block: B:47:? A[RETURN, SYNTHETIC] */
    private void copySnrFailImage() {
        Throwable th;
        IOException ie;
        FtUtil.log_d(this.CLASS_NAME, "copySnrFailImage", "");
        Calendar cal = Calendar.getInstance();
        DecimalFormat df = new DecimalFormat("00", DecimalFormatSymbols.getInstance(Locale.US));
        String destinationPath = "/data/log/SNR_Fail_Image_" + (cal.get(1) + df.format((long) (cal.get(2) + 1)) + df.format((long) cal.get(5)) + df.format((long) cal.get(11)) + df.format((long) cal.get(12))) + ".bmp";
        FileInputStream fis = null;
        FileOutputStream fos = null;
        FileChannel fcin = null;
        FileChannel fcout = null;
        try {
            try {
                fis = new FileInputStream(new File(PATH_SNR_IMAGE));
                fos = new FileOutputStream(new File(destinationPath));
                fcin = fis.getChannel();
                fcout = fos.getChannel();
                fcin.transferTo(0, fcin.size(), fcout);
                fos.getFD().sync();
                FtUtil.log_d(this.CLASS_NAME, "copySnrFailImage", "SNR image was saved : " + destinationPath);
                if (fcout != null) {
                    try {
                        fcout.close();
                    } catch (IOException ie2) {
                        FtUtil.log_e(ie2);
                        return;
                    }
                }
                if (fcin != null) {
                    fcin.close();
                }
                fos.close();
                fis.close();
            } catch (IOException e) {
                ie = e;
                try {
                    FtUtil.log_e(ie);
                    if (fcout != null) {
                        fcout.close();
                    }
                    if (fcin != null) {
                        fcin.close();
                    }
                    if (fos != null) {
                        fos.close();
                    }
                    if (fis == null) {
                        fis.close();
                    }
                } catch (Throwable th2) {
                    th = th2;
                    if (fcout != null) {
                    }
                    if (fcin != null) {
                    }
                    if (fos != null) {
                    }
                    if (fis != null) {
                    }
                    throw th;
                }
            }
        } catch (IOException e2) {
            ie = e2;
            FtUtil.log_e(ie);
            if (fcout != null) {
            }
            if (fcin != null) {
            }
            if (fos != null) {
            }
            if (fis == null) {
            }
        } catch (Throwable th3) {
            th = th3;
            if (fcout != null) {
                try {
                    fcout.close();
                } catch (IOException ie3) {
                    FtUtil.log_e(ie3);
                    throw th;
                }
            }
            if (fcin != null) {
                fcin.close();
            }
            if (fos != null) {
                fos.close();
            }
            if (fis != null) {
                fis.close();
            }
            throw th;
        }
    }

    private void saveCellId() {
        FtUtil.log_d(this.CLASS_NAME, "saveCellId", "");
        String cell_id = Support.Kernel.read(Support.Kernel.OCTA_MANUFACTURE_CODE);
        if (cell_id != null) {
            cell_id = cell_id.replace(" ", "");
            Support.Kernel.writeNsync(Support.Kernel.FINGERPRINT_CELL_ID_WHEN_CALIBRATION, cell_id);
        }
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "saveCellId", "cell_id :" + cell_id);
    }

    private void RegisterReceiver() {
        FtUtil.log_d(this.CLASS_NAME, "RegisterReceiver", "RegisterReceiver");
        IntentFilter filter = new IntentFilter();
        filter.addAction("com.sec.factory.aporiented.athandler.ACTION_SNR_CAL_OPTICAL");
        filter.addAction("com.sec.factory.aporiented.athandler.ACTION_SNR_CAL_OPTICAL_STOP");
        AnonymousClass1 r1 = new BroadcastReceiver() {
            /* class com.sec.factory.app.ui.UIFingerprintCalTestEgis.AnonymousClass1 */

            public void onReceive(Context context, Intent intent) {
                String action = intent.getAction();
                String str = UIFingerprintCalTestEgis.this.CLASS_NAME;
                FtUtil.log_d(str, "onReceive", " Action:" + action);
                if ("com.sec.factory.aporiented.athandler.ACTION_SNR_CAL_OPTICAL".equals(action)) {
                    FtUtil.log_d(UIFingerprintCalTestEgis.this.CLASS_NAME, "onReceive", "performClick by broadcasting");
                    UIFingerprintCalTestEgis.this.setAtCmd(true);
                    UIFingerprintCalTestEgis.this.mButtonStart.performClick();
                } else if ("com.sec.factory.aporiented.athandler.ACTION_SNR_CAL_OPTICAL_STOP".equals(action)) {
                    FtUtil.log_d(UIFingerprintCalTestEgis.this.CLASS_NAME, "onReceive", "ACTION_SNR_CAL_OPTICAL_STOP, finish");
                    UIFingerprintCalTestEgis.this.setAtCmd(false);
                    UIFingerprintCalTestEgis.this.finish();
                }
            }
        };
        this.mReceiver = r1;
        registerReceiver(r1, filter);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleMessage(Message msg) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "handleMessage", "" + msg.what);
        switch (msg.what) {
            case 200:
                FtUtil.log_d(this.CLASS_NAME, "handleMessage", "READY_WKBOX");
                updateStep(CommonFingerprintEgis.STEP.WKBOX);
                return;
            case 202:
                FtUtil.log_d(this.CLASS_NAME, "handleMessage", "READY_BKBOX");
                updateStep(CommonFingerprintEgis.STEP.BKBOX);
                return;
            case 204:
                updateStep(CommonFingerprintEgis.STEP.CHART);
                return;
            case 1001:
                this.mCommonFingerprintEgis.setIsCalBrightnessNormal(checkBrightness());
                return;
            case 1004:
                FtUtil.log_d(this.CLASS_NAME, "handleMessage", "Cal Finished and get data");
                this.mListFpTestItemCalibration = (ArrayList) msg.obj;
                updateStep(CommonFingerprintEgis.STEP.RESULT);
                showResult();
                return;
            default:
                return;
        }
    }

    private void UnregisterReceiver() {
        if (this.mReceiver != null) {
            FtUtil.log_d(this.CLASS_NAME, "UnregisterReceiver", "UnregisterReceiver");
            unregisterReceiver(this.mReceiver);
            this.mReceiver = null;
        }
    }

    public void onClick(View view) {
        switch (view.getId()) {
            case R.id.button_exit:
                FtUtil.log_d(this.CLASS_NAME, "onClick", "exit button");
                finish();
                return;
            case R.id.button_start:
                FtUtil.log_d(this.CLASS_NAME, "onClick", "start button");
                updateCalStatus(CommonFingerprintEgis.STATUS.RUNNING);
                this.mHandler.postDelayed(new Runnable() {
                    /* class com.sec.factory.app.ui.UIFingerprintCalTestEgis.AnonymousClass2 */

                    public void run() {
                        if (UIFingerprintCalTestEgis.this.mSTEP == CommonFingerprintEgis.STEP.WKBOX) {
                            UIFingerprintCalTestEgis.this.mCommonFingerprintEgis.startWkboxTest();
                        } else if (UIFingerprintCalTestEgis.this.mSTEP == CommonFingerprintEgis.STEP.BKBOX) {
                            UIFingerprintCalTestEgis.this.mCommonFingerprintEgis.startBkboxTest();
                        } else if (UIFingerprintCalTestEgis.this.mSTEP == CommonFingerprintEgis.STEP.CHART) {
                            UIFingerprintCalTestEgis.this.mCommonFingerprintEgis.startChartTest();
                        }
                    }
                }, 500);
                return;
            default:
                return;
        }
    }

    private static class StatusHandler extends Handler {
        private final WeakReference<UIFingerprintCalTestEgis> mActivity;

        public StatusHandler(UIFingerprintCalTestEgis activity) {
            this.mActivity = new WeakReference<>(activity);
        }

        public void handleMessage(Message msg) {
            UIFingerprintCalTestEgis activity = this.mActivity.get();
            if (activity != null) {
                activity.handleMessage(msg);
            }
        }
    }
}
