package com.sec.factory.app.ui;

import android.graphics.Bitmap;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.common.CommonFingerprintEgis;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.support.FtUtil;
import java.lang.ref.WeakReference;

public class UIFingerprintEnrollTestEgis extends UIBase {
    private CommonFingerprintEgis mCommonFingerprintEgis;
    private final StatusHandler mHandler = new StatusHandler(this);
    private ImageView mIvEnroll;
    private ImageView mIvVerify;
    private ModulePower mModulePower;
    private CommonFingerprintEgis.STATUS mSTATUS = CommonFingerprintEgis.STATUS.NOTEST;
    private CommonFingerprintEgis.STEP mSTEP = CommonFingerprintEgis.STEP.ENROLL;
    private TextView mTvCurrentStep;
    private TextView mTvDirection;
    private TextView mTvResult;

    public UIFingerprintEnrollTestEgis() {
        super("UIFingerprintEnrollTestEgis", 120);
        this.ONPASS_FINISH_DELAY = 1000;
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        FtUtil.log_d(this.CLASS_NAME, "onCreate", "");
        this.TEST_ID = getIntent().getIntExtra("testID", 120);
        setContentView(R.layout.fingerprint_enroll_test);
        CommonFingerprintEgis instance = CommonFingerprintEgis.instance(this);
        this.mCommonFingerprintEgis = instance;
        instance.setHandler(this.mHandler);
        this.mModulePower = ModulePower.instance(this);
        initLayout();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        FtUtil.log_d(this.CLASS_NAME, "onResume", "");
        super.onResume();
        if (this.mSTEP == CommonFingerprintEgis.STEP.ENROLL) {
            this.mCommonFingerprintEgis.setEnrollSession(false);
            this.mCommonFingerprintEgis.setEnrollSession(true);
            this.mCommonFingerprintEgis.enroll();
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        FtUtil.log_d(this.CLASS_NAME, "onPause", "");
        super.onPause();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        FtUtil.log_d(this.CLASS_NAME, "onDestroy", "");
        this.mHandler.removeCallbacksAndMessages(null);
        this.mCommonFingerprintEgis.cancel();
        super.onDestroy();
    }

    private void initLayout() {
        FtUtil.log_d(this.CLASS_NAME, "initLayout", "");
        ((Button) findViewById(R.id.fingerprint_ok_button)).setVisibility(4);
        ((TextView) findViewById(R.id.fingerprint_arrow)).setVisibility(4);
        ((TextView) findViewById(R.id.fingerprint_enroll_title1)).setText("(WOF) Fingerprint");
        ((LinearLayout) findViewById(R.id.fingerprint_background_bottom)).setBackgroundColor(-1);
        this.mTvCurrentStep = (TextView) findViewById(R.id.fingerprint_step);
        this.mTvDirection = (TextView) findViewById(R.id.fingerprint_msg);
        this.mTvResult = (TextView) findViewById(R.id.fingerprint_result);
        this.mIvEnroll = (ImageView) findViewById(R.id.fingerprint_image_enroll);
        this.mIvVerify = (ImageView) findViewById(R.id.fingerprint_image);
    }

    private void setSTEP(CommonFingerprintEgis.STEP step) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setSTEP", "set step to : " + step);
        this.mSTEP = step;
        if (step == CommonFingerprintEgis.STEP.RESULT) {
            if (!this.mModulePower.isScreenOn()) {
                this.mModulePower.setLCDState(true);
            }
            this.mHandler.removeCallbacksAndMessages(null);
            this.mCommonFingerprintEgis.cancel();
            return;
        }
        this.mTvCurrentStep.setText(this.mSTEP.name());
        this.mTvResult.setText("");
    }

    private void setStatus(CommonFingerprintEgis.STATUS status) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setStatus", "set status to : " + status);
        this.mSTATUS = status;
        if (status == CommonFingerprintEgis.STATUS.PASS) {
            this.mTvResult.setTextColor(UiHallICTest.FONT_COLOR_PASS);
            this.mTvResult.setText(status.name());
        } else if (status == CommonFingerprintEgis.STATUS.FAIL) {
            this.mTvResult.setTextColor(-65536);
            this.mTvResult.setText(status.name());
            this.mTvDirection.setText("");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleMessage(Message msg) {
        switch (msg.what) {
            case 301:
                if (this.mSTEP == CommonFingerprintEgis.STEP.ENROLL) {
                    setSTEP(CommonFingerprintEgis.STEP.ENROLL);
                    this.mTvDirection.setText("Ready to scan");
                    return;
                } else if (this.mSTEP == CommonFingerprintEgis.STEP.VERIFY) {
                    this.mHandler.postDelayed(new Runnable() {
                        /* class com.sec.factory.app.ui.UIFingerprintEnrollTestEgis.AnonymousClass1 */

                        public void run() {
                            UIFingerprintEnrollTestEgis.this.mModulePower.setLCDState(false);
                        }
                    }, 100);
                    return;
                } else {
                    return;
                }
            case 303:
                return;
            case 309:
                Bitmap fpImage = (Bitmap) msg.obj;
                if (this.mSTEP == CommonFingerprintEgis.STEP.ENROLL) {
                    this.mIvEnroll.setImageBitmap(fpImage);
                    return;
                } else if (this.mSTEP == CommonFingerprintEgis.STEP.VERIFY) {
                    this.mIvVerify.setImageBitmap(fpImage);
                    return;
                } else {
                    return;
                }
            case 310:
                setSTEP(CommonFingerprintEgis.STEP.RESULT);
                setStatus(CommonFingerprintEgis.STATUS.FAIL);
                return;
            case 313:
                this.mCommonFingerprintEgis.setEnrollSession(false);
                this.mTvDirection.setText("Fingerprint registered");
                setStatus(CommonFingerprintEgis.STATUS.PASS);
                return;
            case 314:
                setSTEP(CommonFingerprintEgis.STEP.RESULT);
                setStatus(CommonFingerprintEgis.STATUS.FAIL);
                return;
            case 317:
                setSTEP(CommonFingerprintEgis.STEP.RESULT);
                setStatus(CommonFingerprintEgis.STATUS.PASS);
                this.mTvDirection.setText("Fingerprint registered");
                setTestResult((byte) 80);
                finishOnPassWithTimer();
                return;
            case 318:
                setSTEP(CommonFingerprintEgis.STEP.RESULT);
                setStatus(CommonFingerprintEgis.STATUS.FAIL);
                return;
            case 320:
                if (this.mSTEP == CommonFingerprintEgis.STEP.ENROLL) {
                    setSTEP(CommonFingerprintEgis.STEP.VERIFY);
                    this.mHandler.postDelayed(new Runnable() {
                        /* class com.sec.factory.app.ui.UIFingerprintEnrollTestEgis.AnonymousClass2 */

                        public void run() {
                            UIFingerprintEnrollTestEgis.this.mTvDirection.setText("LCD off after 100 ms");
                            UIFingerprintEnrollTestEgis.this.mCommonFingerprintEgis.identify();
                        }
                    }, 100);
                    return;
                }
                return;
            default:
                String str = this.CLASS_NAME;
                FtUtil.log_d(str, "handleMessage", "Unknown : " + msg.what);
                return;
        }
    }

    /* access modifiers changed from: private */
    public static class StatusHandler extends Handler {
        private final WeakReference<UIFingerprintEnrollTestEgis> mActivity;

        public StatusHandler(UIFingerprintEnrollTestEgis activity) {
            this.mActivity = new WeakReference<>(activity);
        }

        public void handleMessage(Message msg) {
            UIFingerprintEnrollTestEgis activity = this.mActivity.get();
            if (activity != null) {
                activity.handleMessage(msg);
            }
        }
    }
}
