package com.sec.factory.app.ui;

import android.graphics.Bitmap;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.common.CommonFingerprintGoodix;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.support.FtUtil;
import java.lang.ref.WeakReference;

public class UIFingerprintEnrollTestGoodix extends UIBase {
    private CommonFingerprintGoodix mCommonFingerprintGoodix;
    private final StatusHandler mHandler = new StatusHandler(this);
    private boolean mIsGoodQuality = false;
    private ImageView mIvEnroll;
    private ImageView mIvVerify;
    private ModulePower mModulePower;
    private CommonFingerprintGoodix.STATUS mSTATUS = CommonFingerprintGoodix.STATUS.NOTEST;
    private CommonFingerprintGoodix.STEP mSTEP = CommonFingerprintGoodix.STEP.ENROLL;
    private TextView mTvCurrentStep;
    private TextView mTvDirection;
    private TextView mTvResult;

    public UIFingerprintEnrollTestGoodix() {
        super("UIFingerprintEnrollTestGoodix", 120);
        this.ONPASS_FINISH_DELAY = 1000;
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        FtUtil.log_d(this.CLASS_NAME, "onCreate", "");
        this.TEST_ID = getIntent().getIntExtra("testID", 120);
        setContentView(R.layout.fingerprint_enroll_test);
        CommonFingerprintGoodix instance = CommonFingerprintGoodix.instance(this);
        this.mCommonFingerprintGoodix = instance;
        instance.setHandler(this.mHandler);
        this.mModulePower = ModulePower.instance(this);
        initLayout();
        setSTEP(CommonFingerprintGoodix.STEP.ENROLL);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        FtUtil.log_d(this.CLASS_NAME, "onResume", "");
        super.onResume();
        if (this.mSTEP == CommonFingerprintGoodix.STEP.ENROLL) {
            this.mCommonFingerprintGoodix.enroll();
            this.mTvDirection.setText("Ready to scan");
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        FtUtil.log_d(this.CLASS_NAME, "onPause", "");
        super.onPause();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        FtUtil.log_d(this.CLASS_NAME, "onDestroy", "");
        this.mHandler.removeCallbacksAndMessages(null);
        this.mCommonFingerprintGoodix.setHandler(null);
        this.mCommonFingerprintGoodix.cancelTest();
        super.onDestroy();
    }

    private void initLayout() {
        FtUtil.log_d(this.CLASS_NAME, "initLayout", "");
        ((Button) findViewById(R.id.fingerprint_ok_button)).setVisibility(4);
        ((TextView) findViewById(R.id.fingerprint_arrow)).setVisibility(4);
        ((TextView) findViewById(R.id.fingerprint_enroll_title1)).setText("(WOF) Fingerprint");
        ((LinearLayout) findViewById(R.id.fingerprint_background_bottom)).setBackgroundColor(-1);
        this.mTvCurrentStep = (TextView) findViewById(R.id.fingerprint_step);
        this.mTvDirection = (TextView) findViewById(R.id.fingerprint_msg);
        this.mTvResult = (TextView) findViewById(R.id.fingerprint_result);
        this.mIvEnroll = (ImageView) findViewById(R.id.fingerprint_image_enroll);
        this.mIvVerify = (ImageView) findViewById(R.id.fingerprint_image);
    }

    private void setSTEP(CommonFingerprintGoodix.STEP step) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setSTEP", "set step to : " + step);
        this.mSTEP = step;
        if (step == CommonFingerprintGoodix.STEP.RESULT) {
            if (!this.mModulePower.isScreenOn()) {
                this.mModulePower.setLCDState(true);
            }
            this.mHandler.removeCallbacksAndMessages(null);
            this.mCommonFingerprintGoodix.cancelTest();
            return;
        }
        this.mTvCurrentStep.setText(this.mSTEP.name());
        this.mTvResult.setText("");
    }

    private void setStatus(CommonFingerprintGoodix.STATUS status) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setStatus", "set status to : " + status);
        this.mSTATUS = status;
        if (status == CommonFingerprintGoodix.STATUS.PASS) {
            this.mTvResult.setTextColor(UiHallICTest.FONT_COLOR_PASS);
            this.mTvResult.setText(status.name());
        } else if (status == CommonFingerprintGoodix.STATUS.FAIL) {
            this.mTvResult.setTextColor(-65536);
            this.mTvResult.setText(status.name());
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleMessage(Message msg) {
        switch (msg.what) {
            case 309:
                if (this.mSTEP == CommonFingerprintGoodix.STEP.VERIFY) {
                    Bitmap fpImage = (Bitmap) msg.obj;
                    this.mIsGoodQuality = msg.arg1 == 0;
                    String str = this.CLASS_NAME;
                    FtUtil.log_d(str, "handleMessage", "mIsGoodQuality : " + this.mIsGoodQuality + ",msg.arg1 : " + msg.arg1);
                    this.mIvVerify.setImageBitmap(fpImage);
                    return;
                }
                return;
            case 310:
                setSTEP(CommonFingerprintGoodix.STEP.RESULT);
                setStatus(CommonFingerprintGoodix.STATUS.FAIL);
                this.mTvDirection.setText("Capture Fail");
                return;
            case 313:
                this.mTvDirection.setText("Fingerprint registered");
                this.mIvEnroll.setImageBitmap((Bitmap) msg.obj);
                setStatus(CommonFingerprintGoodix.STATUS.PASS);
                return;
            case 317:
            case 318:
                setSTEP(CommonFingerprintGoodix.STEP.RESULT);
                if (this.mIsGoodQuality) {
                    setStatus(CommonFingerprintGoodix.STATUS.PASS);
                    this.mTvDirection.setText("Fingerprint registered");
                    setTestResult((byte) 80);
                    finishOnPassWithTimer();
                    return;
                }
                this.mTvDirection.setText("Identify Fail");
                setStatus(CommonFingerprintGoodix.STATUS.FAIL);
                return;
            case 402:
                if (this.mSTEP == CommonFingerprintGoodix.STEP.ENROLL) {
                    setSTEP(CommonFingerprintGoodix.STEP.VERIFY);
                    this.mTvDirection.setText("LCD off after 100 ms");
                    this.mHandler.postDelayed(new Runnable() {
                        /* class com.sec.factory.app.ui.UIFingerprintEnrollTestGoodix.AnonymousClass1 */

                        public void run() {
                            UIFingerprintEnrollTestGoodix.this.mModulePower.setLCDState(false);
                            UIFingerprintEnrollTestGoodix.this.mCommonFingerprintGoodix.identify();
                        }
                    }, 100);
                    return;
                }
                return;
            default:
                String str2 = this.CLASS_NAME;
                FtUtil.log_d(str2, "handleMessage", "Unknown : " + msg.what);
                return;
        }
    }

    /* access modifiers changed from: private */
    public static class StatusHandler extends Handler {
        private final WeakReference<UIFingerprintEnrollTestGoodix> mActivity;

        public StatusHandler(UIFingerprintEnrollTestGoodix activity) {
            this.mActivity = new WeakReference<>(activity);
        }

        public void handleMessage(Message msg) {
            UIFingerprintEnrollTestGoodix activity = this.mActivity.get();
            if (activity != null) {
                activity.handleMessage(msg);
            }
        }
    }
}
