package com.sec.factory.app.ui;

import android.content.Intent;
import android.os.Bundle;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.NVAccessor;
import com.sec.xmldata.support.Support;
import java.io.File;

public class UIForceTouchController extends UIBase {
    private static final String PATH_CAL_DATA_FILE = "/data/log/ForceCalData.log";
    private static final String PATH_CAL_FAIL_DATA_FILE = "/data/log/ForceCalDataFail.log";
    private final int FINISH_FORCE_TOUCH_AUTO_TUNE = 0;
    private final int FINISH_FORCE_TOUCH_CALIBRATION = 2;
    private final int FINISH_FORCE_TOUCH_PRESS = 3;
    private final int FINISH_FORCE_TOUCH_SELF_TEST = 1;
    private final int LAUNCH_FORCE_TOUCH_AUTO_TUNE = 0;
    private final int LAUNCH_FORCE_TOUCH_CALIBRATION = 2;
    private final int LAUNCH_FORCE_TOUCH_PRESS = 3;
    private final int LAUNCH_FORCE_TOUCH_SELF_TEST = 1;
    private boolean mIsCmd = false;
    private String mStringTestChannel = "";
    private int mTestID = 0;

    public UIForceTouchController() {
        super("UIForceTouchController");
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        FtUtil.setRemoveSystemUI(getWindow(), true);
        this.mTestID = getIntent().getIntExtra("testid", 152);
        this.mIsCmd = getIntent().getBooleanExtra("isCmd", false);
        if (Support.TestCase.getEnabled(Support.TestCase.FORCE_TOUCH_TEST_LEFT)) {
            this.mStringTestChannel += "left,";
        }
        if (Support.TestCase.getEnabled(Support.TestCase.FORCE_TOUCH_TEST_CENTER)) {
            this.mStringTestChannel += "center,";
        }
        if (Support.TestCase.getEnabled(Support.TestCase.FORCE_TOUCH_TEST_RIGHT)) {
            this.mStringTestChannel += "right";
        }
        int i = this.mTestID;
        if (i == 152) {
            launchTest(0);
        } else if (i != 153) {
        } else {
            if (80 != NVAccessor.getNV(237)) {
                FtUtil.log_d(this.CLASS_NAME, "onCreate", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(this.mTestID), "End - Force Calibration was not passed"));
                finish();
                return;
            }
            launchTest(3);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        super.onDestroy();
    }

    private void launchTest(int testNum) {
        Intent i = new Intent();
        switch (testNum) {
            case 0:
                FtUtil.log_d(this.CLASS_NAME, "launchTest", "FINISH_FORCE_TOUCH_AUTO_TUNE");
                i.setClassName("com.sec.factory", "com.sec.factory.app.ui.UIForceTouchAutoTune");
                i.putExtra("isCmd", this.mIsCmd);
                if (this.mStringTestChannel.contains("left")) {
                    i.putExtra("touchPoint", "left");
                } else {
                    i.putExtra("touchPoint", "center");
                }
                startActivityForResult(i, 0);
                return;
            case 1:
                FtUtil.log_d(this.CLASS_NAME, "launchTest", "LAUNCH_FORCE_TOUCH_SELF_TEST");
                i.setClassName("com.sec.factory", "com.sec.factory.app.ui.UIForceTouchSelfTest");
                startActivityForResult(i, 1);
                return;
            case 2:
                FtUtil.log_d(this.CLASS_NAME, "launchTest", "LAUNCH_FORCE_TOUCH_CALIBRATION");
                i.putExtra("testid", 152);
                i.setClassName("com.sec.factory", "com.sec.factory.app.ui.UIForceTouchNew");
                i.putExtra("testChannel", this.mStringTestChannel);
                startActivityForResult(i, 2);
                return;
            case 3:
                FtUtil.log_d(this.CLASS_NAME, "launchTest", "LAUNCH_FORCE_TOUCH_PRESS");
                i.putExtra("testid", 153);
                i.setClassName("com.sec.factory", "com.sec.factory.app.ui.UIForceTouchNew");
                i.putExtra("testChannel", this.mStringTestChannel);
                startActivityForResult(i, 3);
                return;
            default:
                return;
        }
    }

    /* access modifiers changed from: protected */
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        switch (requestCode) {
            case 0:
                FtUtil.log_d(this.CLASS_NAME, "onActivityResult", "FINISH_FORCE_TOUCH_AUTO_TUNE");
                if (resultCode == -1) {
                    launchTest(1);
                    return;
                } else {
                    finish();
                    return;
                }
            case 1:
                FtUtil.log_d(this.CLASS_NAME, "onActivityResult", "FINISH_FORCE_TOUCH_SELF_TEST");
                if (resultCode == -1) {
                    File logFile = new File(PATH_CAL_DATA_FILE);
                    File failLogFile = new File(PATH_CAL_FAIL_DATA_FILE);
                    if (logFile.exists()) {
                        logFile.delete();
                    }
                    if (failLogFile.exists()) {
                        failLogFile.delete();
                    }
                    launchTest(2);
                    return;
                }
                finish();
                return;
            case 2:
                FtUtil.log_d(this.CLASS_NAME, "onActivityResult", "FINISH_FORCE_TOUCH_CALIBRATION");
                if (resultCode == -1) {
                    setTestResult(152, (byte) 80);
                    launchTest(3);
                    return;
                }
                finish();
                return;
            case 3:
                FtUtil.log_d(this.CLASS_NAME, "onActivityResult", "FINISH_FORCE_TOUCH_PRESS");
                if (resultCode == -1) {
                    setTestResult(153, (byte) 80);
                }
                finish();
                return;
            default:
                finish();
                return;
        }
    }
}
