package com.sec.factory.app.ui;

import android.content.res.Resources;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ForceTouchSelfTestHandler;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.support.FtUtil;

public class UIForceTouchSelfTest extends UIBase {
    private static final int MSG_RUN_SELF_TEST = 1;
    private static final int MSG_TEST_PASS = 2;
    private static final String STRING_NA = "NA";
    private final String CLASS_NAME = "UIForceTouchSelfTest";
    private boolean[] mArrIsEnabledChannel;
    private String[] mArrItemName;
    private View[] mArrViewItem;
    private ForceTouchSelfTestHandler mForceTouchSelfTestHandler;
    private Handler mHandler = new Handler() {
        /* class com.sec.factory.app.ui.UIForceTouchSelfTest.AnonymousClass1 */

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    UIForceTouchSelfTest.this.runSelfTest();
                    UIForceTouchSelfTest.this.endTest();
                    return;
                case 2:
                    UIForceTouchSelfTest.this.setResult(-1);
                    UIForceTouchSelfTest.this.finish();
                    return;
                default:
                    return;
            }
        }
    };
    private int mIntItemCnt = 0;
    private boolean mIsEndTest = false;
    private boolean mIsNoException = true;
    private boolean mIsTouch = false;
    private ModuleDevice mModuleDevice;
    private TextView mTextViewResult;

    public UIForceTouchSelfTest() {
        super("UIForceTouchSelfTest");
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.TEST_ID = getIntent().getIntExtra("testid", 152);
        FtUtil.log_d("UIForceTouchSelfTest", "onCreate", "TEST_ID: " + this.TEST_ID);
        setContentView(R.layout.ui_force_touch_selftest);
        this.mForceTouchSelfTestHandler = new ForceTouchSelfTestHandler(this);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        ModuleDevice instance = ModuleDevice.instance(this);
        this.mModuleDevice = instance;
        instance.setEPenDisableMode(true);
        initDisplay();
        this.mHandler.sendEmptyMessageDelayed(1, 200);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        this.mModuleDevice.setEPenDisableMode(false);
        super.onPause();
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        super.onDestroy();
    }

    private void initDisplay() {
        LinearLayout mLinearLayoutDepot = (LinearLayout) findViewById(R.id.item_depot);
        String[] split = this.mForceTouchSelfTestHandler.getStringSelfTestItems().split(",");
        this.mArrItemName = split;
        int length = split.length;
        this.mIntItemCnt = length;
        this.mArrViewItem = new View[length];
        for (int i = 0; i < this.mIntItemCnt; i++) {
            this.mArrViewItem[i] = getLayoutInflater().inflate(R.layout.force_touch_selftest_item, (ViewGroup) null);
            mLinearLayoutDepot.addView((LinearLayout) this.mArrViewItem[i].findViewById(R.id.item_layout));
            ((TextView) this.mArrViewItem[i].findViewById(R.id._title)).setText(this.mArrItemName[i]);
            ((TextView) this.mArrViewItem[i].findViewById(R.id._spec)).setText(this.mForceTouchSelfTestHandler.getSpecString(this.mArrItemName[i]));
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void runSelfTest() {
        this.mForceTouchSelfTestHandler.runSelfTest();
        this.mArrIsEnabledChannel = this.mForceTouchSelfTestHandler.getArrEnabledChannel();
        for (int i = 0; i < this.mIntItemCnt; i++) {
            try {
                String[] arrTempResult = this.mForceTouchSelfTestHandler.getStringItemResult(this.mArrItemName[i]).split(",");
                int j = 0;
                while (true) {
                    boolean[] zArr = this.mArrIsEnabledChannel;
                    if (j >= zArr.length) {
                        break;
                    }
                    if (!zArr[j]) {
                        arrTempResult[j] = "NA";
                    }
                    View view = this.mArrViewItem[i];
                    Resources resources = getResources();
                    ((TextView) view.findViewById(resources.getIdentifier("_" + j, "id", getPackageName()))).setText(arrTempResult[j]);
                    j++;
                }
            } catch (ArrayIndexOutOfBoundsException e) {
                this.mIsNoException = false;
                FtUtil.log_e(e);
                return;
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void endTest() {
        FtUtil.log_d("UIForceTouchSelfTest", "endTest", "");
        this.mTextViewResult = (TextView) findViewById(R.id.result);
        if (!this.mIsNoException || !this.mForceTouchSelfTestHandler.getIsSelfTestPass() || this.mIsTouch) {
            if (this.mIsTouch) {
                FtUtil.log_d("UIForceTouchSelfTest", "endTest", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(this.TEST_ID), "Fail - Touched"));
                this.mTextViewResult.setText("FAIL-Touched");
            } else {
                FtUtil.log_d("UIForceTouchSelfTest", "endTest", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(this.TEST_ID), "Fail - Self Test"));
                this.mTextViewResult.setText(R.string.FAIL);
            }
            this.mTextViewResult.setTextColor(-65536);
            this.mIsEndTest = true;
            return;
        }
        FtUtil.log_d("UIForceTouchSelfTest", "endTest", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(this.TEST_ID), "Pass - Self Test"));
        this.mTextViewResult.setText(R.string.PASS);
        this.mTextViewResult.setTextColor(UiHallICTest.FONT_COLOR_PASS);
        this.mHandler.sendEmptyMessageDelayed(2, 1000);
    }

    public boolean onTouchEvent(MotionEvent event) {
        FtUtil.log_d("UIForceTouchSelfTest", "onTouchEvent", "");
        super.onTouchEvent(event);
        this.mIsTouch = true;
        if (this.mIsEndTest) {
            finish();
        }
        return true;
    }
}
