package com.sec.factory.app.ui;

import android.app.DialogFragment;
import android.app.Presentation;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.graphics.Bitmap;
import android.graphics.Rect;
import android.hardware.display.DisplayManager;
import android.os.Bundle;
import android.os.SystemProperties;
import android.support.v4.hardware.display.DisplayManagerCompat;
import android.view.Display;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestMain;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModuleAudio;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;

public class UIHDMINew extends UIBase {
    private static final String ACTION_HDMI_AUDIO_PLUG = "android.media.action.HDMI_AUDIO_PLUG";
    private static final String ChipSetName;
    private static final int TYPE_HDMI = 2;
    private static final boolean isMSM8930;
    private boolean FLAG_NV_WRITE;
    private final String HDMI_FHD_OFF;
    private final String HDMI_FHD_ON;
    private final String HDMI_MSG;
    private final String LOG_TAG_UTOPIA;
    private boolean isAPQ8064;
    private boolean isAPQ8074;
    private boolean isAPQ8084;
    private boolean isEXYNOS5410;
    private boolean isEXYNOS5433;
    private boolean isMSM8228;
    private boolean isMSM8260A;
    private boolean isMSM8274;
    private boolean isMSM8674;
    private boolean isMSM8928;
    private boolean isMSM8960;
    private boolean isMSM8974;
    private boolean isPegaPrime;
    private boolean isPegasus;
    private boolean isPegasusPrime;
    private Bitmap mBackgroundBitmap;
    private LinearLayout mBackgroundLayout;
    private BroadcastReceiver mBroadcastReceiver;
    private final DisplayManager.DisplayListener mDisplayListener;
    private DisplayManager mDisplayManager;
    private boolean mIsTurnOffAudioPath;
    private Presentation mPresentation;
    private int mTestDisplayId;
    private int mTestID;
    private String testCase;
    private String testView;

    static {
        String string = Support.Feature.getString(Support.Feature.CHIPSET_NAME);
        ChipSetName = string;
        isMSM8930 = "MSM8930".equalsIgnoreCase(string);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Display getDisplay(int displayId) {
        FtUtil.log_i(this.CLASS_NAME, "getDisplay", "Display #" + displayId);
        Display selectedDisplay = null;
        DisplayManager displayManager = this.mDisplayManager;
        if (displayManager != null) {
            Display[] presentationDisplays = displayManager.getDisplays(DisplayManagerCompat.DISPLAY_CATEGORY_PRESENTATION);
            if (presentationDisplays.length > 0) {
                for (Display iterDisplay : presentationDisplays) {
                    if (iterDisplay.getDisplayId() == displayId) {
                        FtUtil.log_i(this.CLASS_NAME, "getDisplay", "Display #" + displayId + " is founded.");
                        selectedDisplay = iterDisplay;
                    }
                }
            }
        }
        return selectedDisplay;
    }

    private Display searchSubDisplay() {
        FtUtil.log_i(this.CLASS_NAME, "searchSubDisplay");
        Display selectedDisplay = null;
        DisplayManager displayManager = this.mDisplayManager;
        if (displayManager != null) {
            Display[] presentationDisplays = displayManager.getDisplays(DisplayManagerCompat.DISPLAY_CATEGORY_PRESENTATION);
            if (presentationDisplays.length > 0) {
                for (Display iterDisplay : presentationDisplays) {
                    if (iterDisplay.getType() == 2) {
                        FtUtil.log_i(this.CLASS_NAME, "searchSubDisplay", "Sub(HDMI or DP) display is founded.");
                        selectedDisplay = iterDisplay;
                    }
                }
            }
        }
        return selectedDisplay;
    }

    private void showFailDialog() {
        FtUtil.log_i(this.CLASS_NAME, "showFailDialog", "Show fail dialog.");
        DisplayDetectDialogFragment.newInstance("Cable Detect FAIL").show(getFragmentManager(), "");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void showPresentation(Display display) {
        FtUtil.log_i(this.CLASS_NAME, "showPresentation", "Show presentation to sub display.");
        if (this.mPresentation == null) {
            this.mTestDisplayId = display.getDisplayId();
            try {
                SubPresentation subPresentation = new SubPresentation(getApplicationContext(), display);
                this.mPresentation = subPresentation;
                subPresentation.show();
            } catch (WindowManager.InvalidDisplayException e) {
                String str = this.CLASS_NAME;
                FtUtil.log_i(str, "showPresentation", "Exception : " + e);
            }
            FtUtil.setRemoveSystemUI(getWindow(), true);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void dismissPresentation() {
        if (this.mPresentation != null) {
            FtUtil.log_i(this.CLASS_NAME, "dismissPresentation", "mPresentation is not null");
            this.mPresentation.dismiss();
            this.mPresentation = null;
            this.mTestDisplayId = -1;
        }
    }

    /* access modifiers changed from: private */
    public final class SubPresentation extends Presentation {
        private final String CLASS_NAME = "SubPresentation";

        public SubPresentation(Context context, Display display) {
            super(context, display);
        }

        /* access modifiers changed from: protected */
        public void onCreate(Bundle savedInstanceState) {
            FtUtil.log_i("SubPresentation", "onCreate", "Create presentation for sub display");
            super.onCreate(savedInstanceState);
            setContentView(R.layout.ui_hdmi_sub);
            FtUtil.log_i("UTOPIA_HDMI", "START", "hdmi wait");
            FtUtil.setRemoveSystemUI(getWindow(), true);
        }
    }

    public static class DisplayDetectDialogFragment extends DialogFragment {
        String message;

        public static DisplayDetectDialogFragment newInstance(String message2) {
            DisplayDetectDialogFragment dialog = new DisplayDetectDialogFragment();
            Bundle args = new Bundle();
            args.putString("message", message2);
            dialog.setArguments(args);
            dialog.setCancelable(false);
            return dialog;
        }

        public void onCreate(Bundle savedInstanceState) {
            super.onCreate(savedInstanceState);
            this.message = getArguments().getString("message");
        }

        public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
            View v = inflater.inflate(R.layout.dp_faildialog, container, false);
            Rect displayRectangle = new Rect();
            getActivity().getWindow().getDecorView().getWindowVisibleDisplayFrame(displayRectangle);
            v.setMinimumWidth((int) (((float) displayRectangle.width()) * 0.7f));
            v.setMinimumHeight((int) (((float) displayRectangle.height()) * 0.5f));
            Button btOk = (Button) v.findViewById(R.id.btOk);
            btOk.setText(R.string.ok);
            getDialog().getWindow().requestFeature(1);
            getDialog().getWindow().setGravity(17);
            ((TextView) v.findViewById(R.id.message)).setText(this.message);
            btOk.setOnClickListener(new View.OnClickListener() {
                /* class com.sec.factory.app.ui.UIHDMINew.DisplayDetectDialogFragment.AnonymousClass1 */

                public void onClick(View v) {
                    DisplayDetectDialogFragment.this.dismiss();
                    DisplayDetectDialogFragment.this.getActivity().finish();
                }
            });
            return v;
        }
    }

    public UIHDMINew() {
        this("UIHDMINew", 23);
    }

    public UIHDMINew(String className, int id) {
        super(className, id);
        this.LOG_TAG_UTOPIA = "UTOPIA_HDMI";
        this.HDMI_MSG = "HDMI Pattern Display On";
        this.HDMI_FHD_ON = EgisFingerprint.MAJOR_VERSION;
        this.HDMI_FHD_OFF = "0";
        this.testCase = null;
        this.FLAG_NV_WRITE = false;
        this.mIsTurnOffAudioPath = false;
        this.mTestID = 0;
        this.mTestDisplayId = -1;
        this.mBackgroundBitmap = null;
        String str = ChipSetName;
        this.isMSM8960 = "MSM8960".equalsIgnoreCase(str);
        this.isMSM8974 = "MSM8974".equalsIgnoreCase(str);
        this.isMSM8928 = "MSM8928".equalsIgnoreCase(str);
        this.isMSM8228 = "MSM8228".equalsIgnoreCase(str);
        this.isMSM8674 = "MSM8674".equalsIgnoreCase(str);
        this.isMSM8274 = "MSM8274".equalsIgnoreCase(str);
        this.isMSM8260A = "MSM8260A".equalsIgnoreCase(str);
        this.isAPQ8064 = "APQ8064".equalsIgnoreCase(str);
        this.isAPQ8074 = "APQ8074".equalsIgnoreCase(str);
        this.isAPQ8084 = "APQ8084".equalsIgnoreCase(str);
        this.isPegasusPrime = "PegasusPrime".equalsIgnoreCase(str);
        this.isPegaPrime = "PegaPrime".equalsIgnoreCase(str);
        this.isPegasus = "Pegasus".equalsIgnoreCase(str);
        this.isEXYNOS5410 = "EXYNOS5410".equalsIgnoreCase(str);
        this.isEXYNOS5433 = "EXYNOS5433".equalsIgnoreCase(str);
        this.mDisplayListener = new DisplayManager.DisplayListener() {
            /* class com.sec.factory.app.ui.UIHDMINew.AnonymousClass1 */

            public void onDisplayAdded(int displayId) {
                String str = UIHDMINew.this.CLASS_NAME;
                FtUtil.log_i(str, "onDisplayAdded", "Display #" + displayId + " added.");
                Display presentationDisplay = UIHDMINew.this.getDisplay(displayId);
                if (presentationDisplay != null && presentationDisplay.getType() == 2) {
                    UIHDMINew.this.showPresentation(presentationDisplay);
                }
            }

            public void onDisplayChanged(int displayId) {
            }

            public void onDisplayRemoved(int displayId) {
                String str = UIHDMINew.this.CLASS_NAME;
                FtUtil.log_i(str, "onDisplayRemoved", "Display #" + displayId + " removed.");
                if (UIHDMINew.this.mTestDisplayId == displayId) {
                    String str2 = UIHDMINew.this.CLASS_NAME;
                    FtUtil.log_i(str2, "onDisplayRemoved", "Dismiss Display #" + displayId);
                    UIHDMINew.this.dismissPresentation();
                }
            }
        };
        this.mBroadcastReceiver = new BroadcastReceiver() {
            /* class com.sec.factory.app.ui.UIHDMINew.AnonymousClass2 */

            public synchronized void onReceive(Context context, Intent intent) {
                String action = intent.getAction();
                try {
                    if (FactoryTestMain.STOP_HDMI_TEST.equals(action)) {
                        FtUtil.log_i(UIHDMINew.this.CLASS_NAME, "onReceive", FactoryTestMain.STOP_HDMI_TEST);
                        UIHDMINew.this.finish();
                    } else if (action.equals(UIHDMINew.ACTION_HDMI_AUDIO_PLUG)) {
                        int state = intent.getIntExtra("state", -1);
                        String str = UIHDMINew.this.CLASS_NAME;
                        FtUtil.log_i(str, "onReceive", "AudioManager.ACTION_HDMI_AUDIO_PLUG - state=" + state);
                        if (UIHDMINew.this.isFinishing()) {
                            FtUtil.log_i(UIHDMINew.this.CLASS_NAME, "onReceive", "Already UIHDMINew finished");
                        }
                        if (state == 1) {
                            FtUtil.log_i("UTOPIA_HDMI", "HDMI", "audio plug");
                            if (UIHDMINew.this.isAPQ8064 || UIHDMINew.this.isAPQ8074 || UIHDMINew.this.isAPQ8084 || UIHDMINew.this.isMSM8960 || UIHDMINew.isMSM8930 || UIHDMINew.this.isMSM8260A || UIHDMINew.this.isMSM8974 || UIHDMINew.this.isMSM8928 || UIHDMINew.this.isMSM8228 || UIHDMINew.this.isMSM8674 || UIHDMINew.this.isMSM8274 || UIHDMINew.this.isPegasus || UIHDMINew.this.isPegasusPrime || UIHDMINew.this.isPegaPrime || UIHDMINew.this.isEXYNOS5410 || UIHDMINew.this.isEXYNOS5433) {
                                try {
                                    FtUtil.log_i(UIHDMINew.this.CLASS_NAME, "delay", " : 1000ms");
                                    Thread.sleep(1000);
                                } catch (InterruptedException e) {
                                    e.printStackTrace();
                                }
                            }
                            ModuleAudio.instance(UIHDMINew.this.getApplicationContext()).setAudioPath(3);
                            ModuleAudio.instance(UIHDMINew.this.getApplicationContext()).playMedia(R.raw.beep, true);
                            if (!UIHDMINew.this.FLAG_NV_WRITE && UIHDMINew.this.getIntent().getBooleanExtra(FactoryTestManager.INTENT_EXTRA_NAME_ENTER15MODE, false)) {
                                FtUtil.log_i("UTOPIA_HDMI", "", "HDMI Pass");
                                UIHDMINew.this.setTestResult((byte) 80);
                                UIHDMINew.this.FLAG_NV_WRITE = true;
                            }
                        } else if (state == 0) {
                            FtUtil.log_i("UTOPIA_HDMI", "HDMI", "audio unplug");
                            UIHDMINew.this.mIsTurnOffAudioPath = false;
                            UIHDMINew.this.turnOffAudioPath();
                            Thread.sleep(300);
                        }
                    } else if ("android.media.AUDIO_BECOMING_NOISY".equals(action)) {
                        FtUtil.log_i(UIHDMINew.this.CLASS_NAME, "onReceive", "AudioManager.ACTION_AUDIO_BECOMING_NOISY");
                        FtUtil.log_i("UTOPIA_HDMI", "HDMI", "audio becoming noisy");
                        UIHDMINew.this.stopMedia();
                    }
                } catch (Exception e2) {
                    String str2 = UIHDMINew.this.CLASS_NAME;
                    FtUtil.log_i(str2, "mBroadcastReceiver.onReceive", "Exception : " + e2);
                }
            }
        };
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.mDisplayManager = (DisplayManager) getApplicationContext().getSystemService("display");
        String platform = SystemProperties.get("ro.board.platform");
        Intent intent = getIntent();
        Bundle extra = intent.getExtras();
        if (extra != null) {
            this.testView = intent.getStringExtra("testView");
            this.mTestID = extra.getInt("testID", 23);
            String str = this.CLASS_NAME;
            FtUtil.log_i(str, "onCreate_extra", "testView / mTestID : " + this.testView + " / " + this.mTestID);
            setTestId(this.mTestID);
        }
        if ("LAND".equals(this.testView)) {
            setRequestedOrientation(0);
        }
        if (platform == null || !platform.equals("capri")) {
            setContentView(R.layout.ui_hdmi);
        } else {
            setContentView(R.layout.ui_hdmi_capri);
        }
        if (this.mTestID == 23) {
            String testCase2 = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML((byte) 23));
            this.testCase = testCase2;
            if (testCase2 != null && testCase2.contains("FHD")) {
                Support.Kernel.write(Support.Kernel.HDMI_FHD_MODE, EgisFingerprint.MAJOR_VERSION);
                String str2 = this.CLASS_NAME;
                FtUtil.log_i(str2, "onCreate", this.testCase + "  " + Support.Kernel.read(Support.Kernel.HDMI_FHD_MODE));
            }
        }
        FtUtil.setRemoveSystemUI(getWindow(), true);
        ModuleAudio.instance(getApplicationContext()).setStreamMusicVolume(0);
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        sendBroadcast(new Intent("com.samsung.android.aircommandmanager.STOP_MONITORING"));
        IntentFilter mIntentFilter = new IntentFilter();
        mIntentFilter.addAction(FactoryTestMain.STOP_HDMI_TEST);
        mIntentFilter.addAction(ACTION_HDMI_AUDIO_PLUG);
        mIntentFilter.addAction("android.media.AUDIO_BECOMING_NOISY");
        registerReceiver(this.mBroadcastReceiver, mIntentFilter);
        this.mDisplayManager.registerDisplayListener(this.mDisplayListener, null);
        if (searchSubDisplay() != null) {
            FtUtil.log_i(this.CLASS_NAME, "onResume()", "Sub display is connected already");
            showFailDialog();
        }
        this.mIsTurnOffAudioPath = false;
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "onResume()", "mIsTurnOffAudioPath = " + this.mIsTurnOffAudioPath);
        ModuleAudio.instance(getApplicationContext()).playMedia(R.raw.beep, true);
        Toast.makeText(getApplicationContext(), "HDMI Pattern Display On", 0).show();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private synchronized void turnOffAudioPath() {
        if (isFinishing()) {
            FtUtil.log_i(this.CLASS_NAME, "turnOffAudioPath", "Already UIHDMINew finished");
            ModuleAudio.instance(getApplicationContext()).setAudioPath(4);
        } else if (!this.mIsTurnOffAudioPath) {
            this.mIsTurnOffAudioPath = true;
            ModuleAudio.instance(getApplicationContext()).setAudioPath(4);
            String str = this.CLASS_NAME;
            FtUtil.log_i(str, "turnOffAudioPath()", "mIsTurnOffAudioPath = " + this.mIsTurnOffAudioPath);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void stopMedia() {
        ModuleAudio.instance(getApplicationContext()).stopMedia();
        turnOffAudioPath();
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        String str;
        super.onPause();
        this.mDisplayManager.unregisterDisplayListener(this.mDisplayListener);
        dismissPresentation();
        unregisterReceiver(this.mBroadcastReceiver);
        if (this.mTestID == 23 && (str = this.testCase) != null && str.contains("FHD")) {
            Support.Kernel.write(Support.Kernel.HDMI_FHD_MODE, "0");
            String str2 = this.CLASS_NAME;
            FtUtil.log_i(str2, "onPause", this.testCase + "  " + Support.Kernel.read(Support.Kernel.HDMI_FHD_MODE));
        }
        stopMedia();
        sendBroadcast(new Intent("com.samsung.android.aircommandmanager.START_MONITORING"));
    }
}
