package com.sec.factory.app.ui;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.hardware.Camera;
import android.os.Bundle;
import android.os.CancellationSignal;
import android.os.Handler;
import android.os.Message;
import android.view.View;
import android.widget.TableRow;
import android.widget.TextView;
import com.samsung.android.camera.iris.SemIrisManager;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModuleCommon;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.modules.ModuleSensor;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;

public class UIIrisProx extends UIBase {
    private static final int LOOP_COUNT = 5;
    private static final int MSG_IRIS_ON = 2;
    private static final int MSG_PROX_ON = 1;
    private static final int MSG_READ_DATA = 3;
    private static final int MSG_TEST_CHECK_PASS = 5;
    private static final int MSG_UPDATE_RESULT = 4;
    private static final String PATH_RESULT_FILE = "/data/log/IrisProxTestResult.log";
    private static final String STRING_FAIL = "FAIL";
    private static final String STRING_NG = "NG";
    private static final String STRING_OK = "OK";
    private static final String STRING_PASS = "PASS";
    private static final int UPDATE_INTERVAL_MS = 25;
    private final String CLASS_NAME = "UIIrisProx";
    private int mAdcSpecMax;
    private int mAdcSpecMin;
    private SemIrisManager.AuthenticationCallback mAuthenticationCallback = new SemIrisManager.AuthenticationCallback() {
        /* class com.sec.factory.app.ui.UIIrisProx.AnonymousClass3 */

        public void onAuthenticationError(int errorCode, CharSequence errString) {
        }

        public void onAuthenticationFailed() {
        }

        public void onAuthenticationHelp(int helpCode, CharSequence helpString) {
        }

        public void onAuthenticationSucceeded(SemIrisManager.AuthenticationResult result) {
        }
    };
    private BroadcastReceiver mBroadcastReceiver = new BroadcastReceiver() {
        /* class com.sec.factory.app.ui.UIIrisProx.AnonymousClass1 */

        public synchronized void onReceive(Context context, Intent intent) {
            try {
                if ("com.android.samsungtest.IRIS_PROX_STOP".equals(intent.getAction())) {
                    FtUtil.log_i("UIIrisProx", "onReceive", "com.android.samsungtest.IRIS_PROX_STOP");
                    UIIrisProx.this.finish();
                }
            } catch (Exception e) {
                FtUtil.log_i("UIIrisProx", "mBroadcastReceiver.onReceive", "Exception : " + e);
            }
        }
    };
    private Camera mCamera;
    private CancellationSignal mCancellationSignal;
    private int mCurrentLoopCnt;
    private Handler mHandler = new Handler() {
        /* class com.sec.factory.app.ui.UIIrisProx.AnonymousClass2 */

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    FtUtil.log_d("UIIrisProx", "mHandler", "MSG_PROX_ON");
                    UIIrisProx.this.turnOnProximitySensor(true);
                    if (UIIrisProx.this.runCalibration()) {
                        UIIrisProx.this.mHandler.sendEmptyMessageDelayed(2, 500);
                        return;
                    } else {
                        UIIrisProx.this.mHandler.sendEmptyMessageDelayed(5, 500);
                        return;
                    }
                case 2:
                    FtUtil.log_d("UIIrisProx", "mHandler", "MSG_IRIS_ON");
                    UIIrisProx.this.turnOnIrisLED(true);
                    UIIrisProx.this.mHandler.sendEmptyMessageDelayed(3, 200);
                    return;
                case 3:
                    FtUtil.log_d("UIIrisProx", "mHandler", "MSG_READ_DATA");
                    UIIrisProx.this.readData();
                    UIIrisProx.this.mHandler.sendEmptyMessageDelayed(4, 0);
                    return;
                case 4:
                    FtUtil.log_d("UIIrisProx", "mHandler", "MSG_UPDATE_RESULT");
                    UIIrisProx.this.updateResult();
                    UIIrisProx.this.mHandler.sendEmptyMessageDelayed(5, 300);
                    return;
                case 5:
                    if (UIIrisProx.this.mIsPassTest) {
                        UIIrisProx.this.setTestResult((byte) 80);
                        UIIrisProx.this.setResult(-1);
                        UIIrisProx.this.finish();
                        return;
                    }
                    return;
                default:
                    return;
            }
        }
    };
    private SemIrisManager mIrisManager;
    private boolean mIsPassTest = false;
    private ArrayList<Integer> mListAdc = new ArrayList<>();
    private ArrayList<Integer> mListOffset = new ArrayList<>();
    private ModuleCommon mModuleCommon = null;
    private ModuleSensor mModuleSensor = null;
    private int mOffsetMax;
    private int mOffsetMin;
    private TableRow mOffsetView;
    private int[] mSensorID;
    private TextView mTextViewAdcMax;
    private TextView mTextViewAdcMin;
    private TextView mTextViewAdcResult;
    private TextView mTextViewAdcSpec;
    private TextView mTextViewOffsetMax;
    private TextView mTextViewOffsetMin;
    private TextView mTextViewOffsetResult;
    private TextView mTextViewOffsetSpec;
    private TextView mTextViewTestResult;

    public UIIrisProx() {
        super("UIIrisProx");
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.TEST_ID = getIntent().getIntExtra("testid", 161);
        FtUtil.log_d("UIIrisProx", "onCreate", "TEST_ID: " + this.TEST_ID);
        setContentView(R.layout.ui_iris_prox);
        this.mSensorID = new int[]{ModuleSensor.ID_MANAGER_PROXIMITY};
        this.mModuleSensor = ModuleSensor.instance(this);
        this.mModuleCommon = ModuleCommon.instance(this);
        this.mCurrentLoopCnt = 0;
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        IntentFilter mIntentFilter = new IntentFilter();
        mIntentFilter.addAction("com.android.samsungtest.IRIS_PROX_STOP");
        registerReceiver(this.mBroadcastReceiver, mIntentFilter);
        initDisplay();
        this.mHandler.sendEmptyMessageDelayed(1, 0);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        super.onPause();
        BroadcastReceiver broadcastReceiver = this.mBroadcastReceiver;
        if (broadcastReceiver != null) {
            unregisterReceiver(broadcastReceiver);
            this.mBroadcastReceiver = null;
        }
        turnOnIrisLED(false);
        turnOnProximitySensor(false);
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        super.onDestroy();
        ModulePower.instance(this).setScreenBrightnessMode(0);
        ModulePower.instance(this).setBrightness(255);
    }

    private void initDisplay() {
        this.mTextViewAdcSpec = (TextView) findViewById(R.id.adc_spec);
        this.mTextViewOffsetSpec = (TextView) findViewById(R.id.offset_spec);
        this.mOffsetView = (TableRow) findViewById(R.id.offset_row);
        this.mAdcSpecMin = Support.Spec.getInt(Support.Spec.IRIS_PROX_ADC_SPEC_MIN);
        this.mAdcSpecMax = Support.Spec.getInt(Support.Spec.IRIS_PROX_ADC_SPEC_MAX);
        this.mOffsetMin = Support.Spec.getInt(Support.Spec.IRIS_PROX_OFFSET_SPEC_MIN);
        this.mOffsetMax = Support.Spec.getInt(Support.Spec.IRIS_PROX_OFFSET_SPEC_MAX);
        TextView textView = this.mTextViewAdcSpec;
        textView.setText(this.mAdcSpecMin + "~" + this.mAdcSpecMax);
        TextView textView2 = this.mTextViewOffsetSpec;
        textView2.setText(this.mOffsetMin + "~" + this.mOffsetMax);
        this.mTextViewAdcMin = (TextView) findViewById(R.id.adc_min);
        this.mTextViewAdcMax = (TextView) findViewById(R.id.adc_max);
        this.mTextViewAdcResult = (TextView) findViewById(R.id.adc_result);
        this.mTextViewOffsetMin = (TextView) findViewById(R.id.offset_min);
        this.mTextViewOffsetMax = (TextView) findViewById(R.id.offset_max);
        this.mTextViewOffsetResult = (TextView) findViewById(R.id.offset_result);
        this.mTextViewTestResult = (TextView) findViewById(R.id.result);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void turnOnProximitySensor(boolean onOffStatus) {
        if (!onOffStatus) {
            this.mModuleSensor.SensorOff(this.mSensorID);
        } else if (!this.mModuleSensor.isSensorOn(ModuleSensor.ID_MANAGER_PROXIMITY)) {
            this.mModuleSensor.SensorOn(this.mSensorID);
        }
    }

    private void turnOnIrisProximitySensor(boolean onOffStatus) {
        if (!onOffStatus) {
            this.mModuleSensor.SensorOff(this.mSensorID);
        } else if (!this.mModuleSensor.isSensorOn(ModuleSensor.ID_MANAGER_IRIS_PROXIMITY)) {
            this.mModuleSensor.SensorOn(this.mSensorID);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean runCalibration() {
        if (Support.Feature.getBoolean(Support.Feature.IS_PROXIMITY_AUTO_CALIBRATION)) {
            FtUtil.log_d("UIIrisProx", "runCalibration", "Support auto calibration, skip factory calibration");
            return true;
        }
        boolean isSuccessOffsetZero = Support.Kernel.write(Support.Kernel.PROXI_SENSOR_OFFSET, "0");
        boolean isSuccessOffsetOne = Support.Kernel.write(Support.Kernel.PROXI_SENSOR_OFFSET, EgisFingerprint.MAJOR_VERSION);
        if (!isSuccessOffsetZero || !isSuccessOffsetOne) {
            return false;
        }
        int result = 1000;
        String data = Support.Kernel.read(Support.Kernel.PROXI_SENSOR_OFFSET_PASS);
        FtUtil.log_d("UIIrisProx", "runCalibration", "PROXI_SENSOR_OFFSET_PASS : " + data);
        try {
            result = Integer.parseInt(data.trim());
        } catch (NumberFormatException ne) {
            FtUtil.log_e(ne);
        }
        if (result != 0) {
            return true;
        }
        return false;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void turnOnIrisLED(boolean onOffStatus) {
        if (onOffStatus) {
            this.mCancellationSignal = new CancellationSignal();
            SemIrisManager semIrisManager = SemIrisManager.getSemIrisManager(this);
            this.mIrisManager = semIrisManager;
            semIrisManager.request(2003, (byte[]) null, (byte[]) null, 0, (SemIrisManager.RequestCallback) null);
            this.mIrisManager.authenticate((SemIrisManager.CryptoObject) null, this.mCancellationSignal, 0, this.mAuthenticationCallback, (Handler) null, (View) null);
            return;
        }
        CancellationSignal cancellationSignal = this.mCancellationSignal;
        if (cancellationSignal != null) {
            cancellationSignal.cancel();
        }
        this.mIrisManager = null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void readData() {
        for (int i = 0; i < 5; i++) {
            String proxADC = this.mModuleCommon.readProxiADC();
            String proxOffset = this.mModuleCommon.readProxiOffset();
            if (proxADC == null || proxOffset == null) {
                FtUtil.log_d("UIIrisProx", "updateResult", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(161), "node value is null"));
                this.mTextViewTestResult.setText("FAIL");
                this.mTextViewTestResult.setTextColor(-65536);
            } else {
                this.mListAdc.add(Integer.valueOf(Integer.parseInt(proxADC)));
                this.mListOffset.add(Integer.valueOf(Integer.parseInt(proxOffset)));
                FtUtil.Sleep.sleep(25);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateResult() {
        boolean z;
        int adcMin = ((Integer) Collections.min(this.mListAdc)).intValue();
        int adcMax = ((Integer) Collections.max(this.mListAdc)).intValue();
        int offsetMin = ((Integer) Collections.min(this.mListOffset)).intValue();
        int offsetMax = ((Integer) Collections.max(this.mListOffset)).intValue();
        TextView textView = this.mTextViewAdcMin;
        textView.setText(adcMin + "");
        TextView textView2 = this.mTextViewAdcMax;
        textView2.setText(adcMax + "");
        TextView textView3 = this.mTextViewOffsetMin;
        textView3.setText(offsetMin + "");
        TextView textView4 = this.mTextViewOffsetMax;
        textView4.setText(offsetMax + "");
        boolean mIsPassAdc = false;
        boolean mIsPassOffset = true;
        int i = 0;
        while (true) {
            z = true;
            if (i >= 5) {
                break;
            }
            int mTempAdc = this.mListAdc.get(i).intValue();
            int mTempOffset = this.mListOffset.get(i).intValue();
            String itemName_RequestCode = FactoryTestManager.getItemName_RequestCode(161);
            FtUtil.log_d("UIIrisProx", "updateResult", FtUtil.setMspSeqMessage(1, itemName_RequestCode, "adc[" + i + "] : " + mTempAdc + "  offset[" + i + "] : " + mTempOffset));
            if (mTempAdc < this.mAdcSpecMin || mTempAdc > this.mAdcSpecMax) {
                String itemName_RequestCode2 = FactoryTestManager.getItemName_RequestCode(161);
                FtUtil.log_d("UIIrisProx", "updateResult", FtUtil.setMspSeqMessage(1, itemName_RequestCode2, "ADC value spec out : " + mTempAdc));
            } else {
                mIsPassAdc = true;
            }
            if (mTempOffset < this.mOffsetMin || mTempOffset > this.mOffsetMax) {
                mIsPassOffset = false;
                String itemName_RequestCode3 = FactoryTestManager.getItemName_RequestCode(161);
                FtUtil.log_d("UIIrisProx", "updateResult", FtUtil.setMspSeqMessage(1, itemName_RequestCode3, "Offset value spec out : " + mTempOffset));
            }
            i++;
        }
        if (mIsPassAdc) {
            this.mTextViewAdcResult.setText("OK");
            this.mTextViewAdcResult.setTextColor(UiHallICTest.FONT_COLOR_PASS);
        } else {
            this.mTextViewAdcResult.setText("NG");
            this.mTextViewAdcResult.setTextColor(-65536);
        }
        if (mIsPassOffset) {
            this.mTextViewOffsetResult.setText("OK");
            this.mTextViewOffsetResult.setTextColor(UiHallICTest.FONT_COLOR_PASS);
        } else {
            this.mTextViewOffsetResult.setText("NG");
            this.mTextViewOffsetResult.setTextColor(-65536);
        }
        if (!mIsPassAdc || !mIsPassOffset) {
            z = false;
        }
        this.mIsPassTest = z;
        if (z) {
            this.mTextViewTestResult.setText("PASS");
            this.mTextViewTestResult.setTextColor(UiHallICTest.FONT_COLOR_PASS);
        } else {
            this.mTextViewTestResult.setText("FAIL");
            this.mTextViewTestResult.setTextColor(-65536);
        }
        saveDataToFile();
    }

    private void saveDataToFile() {
        BufferedWriter bw = null;
        try {
            BufferedWriter bw2 = new BufferedWriter(new FileWriter(PATH_RESULT_FILE));
            if (this.mIsPassTest) {
                bw2.write("OK");
            } else {
                bw2.write("NG");
            }
            bw2.newLine();
            bw2.write(this.mTextViewAdcMin.getText().toString() + "," + this.mTextViewAdcMax.getText().toString() + "," + this.mTextViewOffsetMin.getText().toString() + "," + this.mTextViewOffsetMax.getText().toString());
            bw2.newLine();
            StringBuilder sb = new StringBuilder();
            sb.append("ADC ");
            sb.append(this.mListAdc.toString());
            bw2.write(sb.toString());
            bw2.newLine();
            bw2.write("Offset " + this.mListOffset.toString());
            try {
                bw2.close();
            } catch (IOException e) {
                FtUtil.log_e(e);
            }
        } catch (IOException e2) {
            FtUtil.log_e(e2);
            if (0 != 0) {
                bw.close();
            }
        } catch (Throwable th) {
            if (0 != 0) {
                try {
                    bw.close();
                } catch (IOException e3) {
                    FtUtil.log_e(e3);
                }
            }
            throw th;
        }
    }
}
