package com.sec.factory.app.ui;

import android.content.Intent;
import android.os.Bundle;
import android.view.KeyEvent;
import android.view.View;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.support.FtUtil;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.HashMap;

public class UIKeyBase extends UIBase {
    protected String CLASS_NAME = "UIKeyBase";
    protected Comparator<KeyTestItem> mComparator = new Comparator<KeyTestItem>() {
        /* class com.sec.factory.app.ui.UIKeyBase.AnonymousClass1 */

        public int compare(KeyTestItem item0, KeyTestItem item1) {
            if (item0.mKeyCode > item1.mKeyCode) {
                return 1;
            }
            if (item0.mKeyCode < item1.mKeyCode) {
                return -1;
            }
            return 0;
        }
    };
    protected View.OnClickListener mExitButtonAction = new View.OnClickListener() {
        /* class com.sec.factory.app.ui.UIKeyBase.AnonymousClass2 */

        public void onClick(View view) {
            FtUtil.log_d(UIKeyBase.this.CLASS_NAME, "onClick", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(UIKeyBase.this.TEST_ID), "Cancel - Exit button"));
            UIKeyBase.this.setResult(0);
            UIKeyBase.this.finish();
        }
    };
    private boolean mIsLongPress;
    protected ArrayList<KeyTestItem> mTestList = new ArrayList<>();

    public UIKeyBase(String className) {
        super(className);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    /* access modifiers changed from: protected */
    public void onNewIntent(Intent intent) {
        FtUtil.log_d(this.CLASS_NAME, "onNewIntent", "onNewIntent");
        super.onNewIntent(intent);
        ArrayList<KeyTestItem> arrayList = this.mTestList;
        if (arrayList != null) {
            arrayList.clear();
        } else {
            this.mTestList = new ArrayList<>();
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public boolean onKeyUp(int keyCode, KeyEvent event) {
        setLongPress(true, event);
        switch (keyCode) {
            case 79:
                FtUtil.log_i(this.CLASS_NAME, "onKeyUp", "KEYCODE_HEADSETHOOK");
                return super.onKeyUp(keyCode, event);
            default:
                return true;
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (!isLongPress()) {
            setLongPress(false, event);
        }
        switch (keyCode) {
            case 79:
                FtUtil.log_i(this.CLASS_NAME, "onKeyDown", "KEYCODE_HEADSETHOOK");
                return super.onKeyDown(keyCode, event);
            default:
                return true;
        }
    }

    /* access modifiers changed from: protected */
    public boolean isLongPress() {
        return this.mIsLongPress;
    }

    /* access modifiers changed from: protected */
    public boolean setLongPress(boolean isUp, KeyEvent event) {
        if (isUp) {
            this.mIsLongPress = false;
        } else if (!this.mIsLongPress) {
            this.mIsLongPress = event.isLongPress();
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setLongPress", "mIsLongPress = " + this.mIsLongPress);
        return true;
    }

    /* access modifiers changed from: protected */
    public class KeyTestItem {
        protected boolean mEnabled = false;
        protected HardKeyItem mHardKeyItem = null;
        protected boolean mIsPassed = false;
        protected boolean mIsTouchKey = false;
        protected int mKeyCode;
        protected String mKeyCode_String;
        protected TouchKeyItem mTouchKeyItem = null;

        protected KeyTestItem(int keyCode) {
            this.mKeyCode = keyCode;
        }

        protected KeyTestItem(int keyCode, HardKeyItem hardKeyItem) {
            this.mKeyCode = keyCode;
            this.mHardKeyItem = hardKeyItem;
        }

        protected KeyTestItem(int keyCode, HardKeyItem hardKeyItem, String keyCode_String) {
            this.mKeyCode = keyCode;
            this.mHardKeyItem = hardKeyItem;
            this.mKeyCode_String = keyCode_String;
            if (keyCode_String.equals("DUMMY")) {
                this.mIsPassed = true;
            }
        }

        protected KeyTestItem(int keyCode, HardKeyItem hardKeyItem, TouchKeyItem touchKeyItem, boolean enabled, boolean isTouchKey) {
            this.mKeyCode = keyCode;
            this.mHardKeyItem = hardKeyItem;
            this.mTouchKeyItem = touchKeyItem;
            this.mEnabled = enabled;
            this.mIsTouchKey = isTouchKey;
            if (!enabled) {
                removeHardKeyItem(hardKeyItem);
            } else if (isTouchKey) {
                enableTouchKeyItem(touchKeyItem);
            }
        }

        private void removeHardKeyItem(HardKeyItem item) {
            item.mHardKeyText.setVisibility(8);
        }

        private void enableTouchKeyItem(TouchKeyItem item) {
            if (item != null) {
                item.mTouchKeyText.setVisibility(0);
                item.mTouchKeySensitivityText.setVisibility(0);
                item.mTouchKeyTestResult.setVisibility(0);
            }
        }

        private void disableTouchKeyItem(TouchKeyItem item) {
            if (item != null) {
                item.mTouchKeyText.setVisibility(8);
                item.mTouchKeySensitivityText.setVisibility(8);
                item.mTouchKeyTestResult.setVisibility(8);
            }
        }

        public int getKeyCode() {
            return this.mKeyCode;
        }

        public String getKeyCode_String() {
            return this.mKeyCode_String;
        }

        public TextView getHardKeyTextView() {
            return this.mHardKeyItem.mHardKeyText;
        }

        public void remobeHardKeyItem() {
            removeHardKeyItem(this.mHardKeyItem);
        }

        public void removeTouchKeyItem() {
            disableTouchKeyItem(this.mTouchKeyItem);
        }
    }

    /* access modifiers changed from: protected */
    public class HardKeyItem {
        protected TextView mHardKeyText = null;

        protected HardKeyItem(TextView harKeyText) {
            this.mHardKeyText = harKeyText;
        }

        /* access modifiers changed from: protected */
        public void setAttribute_TextView(int visibility, String text, float textSize, float textViewHeight) {
            TextView textView = this.mHardKeyText;
            if (textView != null) {
                textView.setVisibility(visibility);
                if (text.equals("DUMMY")) {
                    this.mHardKeyText.setText(" ");
                    this.mHardKeyText.setBackgroundColor(UIKeyBase.this.getResources().getColor(R.id.background));
                } else {
                    this.mHardKeyText.setText(text);
                }
                this.mHardKeyText.setTextSize(textSize);
                this.mHardKeyText.setHeight((int) textViewHeight);
            }
        }
    }

    /* access modifiers changed from: protected */
    public class TouchKeyItem {
        protected TextView mTouchKeySensitivityText;
        protected TextView mTouchKeyTestResult;
        protected TextView mTouchKeyText;

        protected TouchKeyItem(TextView text, TextView sensitivity, TextView result) {
            this.mTouchKeyText = text;
            this.mTouchKeySensitivityText = sensitivity;
            this.mTouchKeyTestResult = result;
        }
    }

    protected class TouchKeyItemSet {
        private HashMap<Integer, TouchKeyItem> mTouchKeyMap = new HashMap<>();

        protected TouchKeyItemSet() {
        }

        /* access modifiers changed from: protected */
        public void put(int keyCode, TouchKeyItem tkItem) {
            this.mTouchKeyMap.put(Integer.valueOf(keyCode), tkItem);
        }

        /* access modifiers changed from: protected */
        public TouchKeyItem get(int keyCode) {
            return this.mTouchKeyMap.get(Integer.valueOf(keyCode));
        }
    }
}
