package com.sec.factory.app.ui;

import android.app.Activity;
import android.graphics.BitmapFactory;
import android.graphics.drawable.BitmapDrawable;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.modules.vrr.BuildVersionProvider;
import com.sec.factory.modules.vrr.IBuildVersionProvider;
import com.sec.factory.modules.vrr.RefreshRateChangeUtil;
import com.sec.factory.modules.vrr.VRRcontants;
import com.sec.factory.support.FtUtil;
import java.io.File;
import java.lang.ref.WeakReference;

public class UILCDGradation120Hz extends UIBase implements View.OnClickListener {
    private static final int SHOW_BTN_DELAY = 5000;
    private static final int SHOW_PASS_FAIL_BTN = 10;
    private LinearLayout mBgLayout;
    private Button mBtnFail;
    private Button mBtnPass;
    private final IBuildVersionProvider mBuildVersionProvider = BuildVersionProvider.getInstance();
    private final WeakReferenceTestHandler mNotiHandler = new WeakReferenceTestHandler(this);
    private RefreshRateChangeUtil mRefreshRateChangeUtil;
    private TextView mTxtTitle;

    public UILCDGradation120Hz() {
        super("UILCDGradation120Hz", FactoryTestManager.TEST_LCD_GRADATION_120HZ_TEST);
    }

    private static class WeakReferenceTestHandler extends Handler {
        private final WeakReference<Activity> ref;

        public WeakReferenceTestHandler(Activity act) {
            this.ref = new WeakReference<>(act);
        }

        public void handleMessage(Message msg) {
            UILCDGradation120Hz act = (UILCDGradation120Hz) this.ref.get();
            switch (msg.what) {
                case 10:
                    act.displayTitle();
                    act.btnVisible(true);
                    return;
                default:
                    return;
            }
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        FtUtil.setRemoveSystemUI(getWindow(), true);
        FtUtil.setRemoveStatusBar(getWindow());
        setContentView(R.layout.ui_lcd_gradation_test_120hz);
        this.mRefreshRateChangeUtil = new RefreshRateChangeUtil(this, this.mNotiHandler);
        initializeUI();
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        ModulePower.instance(this).setBrightness(255);
        FtUtil.log_d(this.CLASS_NAME, "onResume", "SHOW_BTN_DELAY: 5000");
        this.mNotiHandler.sendEmptyMessageDelayed(10, 5000);
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        this.mRefreshRateChangeUtil.setRefreshRate(VRRcontants.REFRESH_RATE_MODE_ALWAYS, 120);
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        super.onPause();
        this.mRefreshRateChangeUtil.restoreDefault();
        this.mNotiHandler.removeCallbacksAndMessages(null);
    }

    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.fail_btn:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "FAIL");
                finish();
                return;
            case R.id.pass_btn:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "PASS");
                setTestResult((byte) 80);
                finish();
                return;
            default:
                return;
        }
    }

    private void initializeUI() {
        this.mBtnPass = (Button) findViewById(R.id.pass_btn);
        this.mBtnFail = (Button) findViewById(R.id.fail_btn);
        this.mTxtTitle = (TextView) findViewById(R.id.lcd_test_title);
        this.mBgLayout = (LinearLayout) findViewById(R.id.background);
        setImgBackground(getResourcePath(this.mBuildVersionProvider.currentVersion()));
        this.mBtnPass.setOnClickListener(this);
        this.mBtnFail.setOnClickListener(this);
    }

    private String getResourcePath(int currentVersion) {
        String resourcePath;
        if (currentVersion > 28) {
            resourcePath = "/system/factory/testmedia/";
        } else {
            resourcePath = "/data/testmedia/";
        }
        try {
            String str = this.CLASS_NAME;
            FtUtil.log_d(str, "getResourcePath", "ResourcePath " + resourcePath);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return resourcePath;
    }

    private void setImgBackground(String path) {
        FtUtil.log_d(this.CLASS_NAME, "setImgBackground", "setImgBackground");
        File imgFile = new File(path + "portrait_gradation.png");
        if (imgFile.exists()) {
            this.mBgLayout.setBackgroundDrawable(new BitmapDrawable(BitmapFactory.decodeFile(imgFile.getAbsolutePath())));
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void btnVisible(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "btnVisible", "Visible : " + flag);
        if (flag) {
            this.mBtnPass.setVisibility(0);
            this.mBtnFail.setVisibility(0);
            return;
        }
        this.mBtnPass.setVisibility(4);
        this.mBtnFail.setVisibility(4);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void displayTitle() {
        this.mTxtTitle.setTextColor(-1);
        this.mTxtTitle.setText("LCD Gradation 120Hz Test 5s");
    }
}
