package com.sec.factory.app.ui;

import android.graphics.Point;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.Display;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.Button;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;

public class UILCDTest extends UIBase implements View.OnClickListener, View.OnTouchListener {
    private static final int BLACK_ALL = 5;
    private static final int BRIGHTNESS_DIM = 170;
    private static final int BRIGHTNESS_MAX = 255;
    private static final int GREEN_ALL = 4;
    private static final int GREEN_BOTTOM = 3;
    private static final int GREEN_TOP = 2;
    private static final int MSG_SHOW_BUTTONS = 1;
    private static final int MSG_TEST_START = 2;
    private static final int START_DELAY = 1000;
    private static final int WHITE = 1;
    private final long BACK_KEY_EVENT_TIMELAG;
    private int Sequence = 1;
    private long StartTime;
    private int TestStage = 1;
    private long TouchTime;
    private Button button_fail;
    private Button button_pass;
    private boolean isColorTouchDown = false;
    private boolean isMotorSupport;
    private boolean isWhiteTouchDown = false;
    private int mColorViewHeight;
    private Handler mHandler;
    private ModuleDevice mModuleDevice;
    private long mPrevBackKeyEventTime;
    private int mScreenHeight;
    private String mTestCase;
    private View mView_Color;
    private View mView_White;
    private ViewGroup.LayoutParams params;

    public UILCDTest() {
        super("UILCDTest");
        boolean z = true;
        String testCase = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML((byte) 0));
        this.mTestCase = testCase;
        this.isMotorSupport = (testCase == null || !testCase.contains("MOTOR")) ? false : z;
        this.mPrevBackKeyEventTime = -1;
        this.BACK_KEY_EVENT_TIMELAG = 2000;
        this.mHandler = new Handler() {
            /* class com.sec.factory.app.ui.UILCDTest.AnonymousClass1 */

            public void handleMessage(Message msg) {
                String str = UILCDTest.this.CLASS_NAME;
                FtUtil.log_i(str, "handleMessage", "msg.what = " + msg.what);
                if (msg.what == 1) {
                    UILCDTest.this.button_pass.setVisibility(0);
                    UILCDTest.this.button_fail.setVisibility(0);
                    UILCDTest.this.button_pass.setEnabled(true);
                    UILCDTest.this.button_fail.setEnabled(true);
                    UILCDTest.this.button_pass.bringToFront();
                    UILCDTest.this.button_fail.bringToFront();
                    FtUtil.log_i(UILCDTest.this.CLASS_NAME, "handleMessage", "MSG_SHOW_BUTTONS");
                }
            }
        };
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.TEST_ID = getIntent().getIntExtra("requestCode", 14);
        this.isMotorSupport = getIntent().getBooleanExtra("motorSupport", false);
        setContentView(R.layout.ui_lcd_test);
        FtUtil.setRemoveSystemUI(getWindow(), true);
        initUI();
        getScreenHeight();
        changeColorHeight(this.mColorViewHeight);
        this.mModuleDevice = ModuleDevice.instance(this);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        this.StartTime = System.currentTimeMillis();
        if (this.isMotorSupport && !this.mModuleDevice.isVibrating()) {
            this.mModuleDevice.startVibrate(ModuleDevice.TIMELESS_VIBRATOR);
        }
        ModulePower.instance(this).setBrightness(170);
        ModulePower.instance(this).setTouchLed(true);
        updateFailHist("WHITE");
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        if (this.isMotorSupport) {
            this.mModuleDevice.stopVibrate();
        }
        ModulePower.instance(this).setBrightness(255);
        ModulePower.instance(this).setTouchLed(false);
        getWindow().getDecorView().setVisibility(4);
        super.onPause();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        super.onDestroy();
    }

    private void initUI() {
        FtUtil.log_i(this.CLASS_NAME, "initUI");
        this.button_pass = (Button) findViewById(R.id.button_pass);
        this.button_fail = (Button) findViewById(R.id.button_fail);
        this.button_pass.setOnClickListener(this);
        this.button_fail.setOnClickListener(this);
        this.mView_Color = findViewById(R.id.ui_color_scroll_view);
        this.mView_White = findViewById(R.id.ui_color_scroll_view2);
        this.mView_Color.setOnTouchListener(this);
        this.mView_Color.setClickable(true);
        this.mView_White.setOnTouchListener(this);
        this.mView_White.setClickable(true);
    }

    private void getScreenHeight() {
        Display mDisplay = ((WindowManager) getBaseContext().getSystemService("window")).getDefaultDisplay();
        Point outpoint = new Point();
        mDisplay.getRealSize(outpoint);
        int i = outpoint.y;
        this.mScreenHeight = i;
        this.mColorViewHeight = i / 2;
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getScreenHeight", "ScreenHeight : " + this.mScreenHeight + ", Color Height :" + this.mColorViewHeight);
    }

    public boolean onTouch(View view, MotionEvent event) {
        long currentTimeMillis = System.currentTimeMillis();
        this.TouchTime = currentTimeMillis;
        if (currentTimeMillis - this.StartTime < 1000) {
            FtUtil.log_i(this.CLASS_NAME, "onTouch", "need to delay");
            return false;
        }
        switch (event.getAction()) {
            case 0:
                if (view != this.mView_Color) {
                    if (view == this.mView_White && !this.isWhiteTouchDown) {
                        FtUtil.log_i(this.CLASS_NAME, "onTouch", "Touch down in white view");
                        this.isWhiteTouchDown = true;
                        break;
                    }
                } else if (!this.isColorTouchDown) {
                    FtUtil.log_i(this.CLASS_NAME, "onTouch", "Touch down in color view");
                    this.isColorTouchDown = true;
                    break;
                }
                break;
            case 1:
                if (view != this.mView_Color) {
                    if (view == this.mView_White && this.isWhiteTouchDown && this.Sequence == 1) {
                        changeColorView();
                        this.isWhiteTouchDown = false;
                        break;
                    }
                } else if (this.isColorTouchDown) {
                    changeColorView();
                    this.isColorTouchDown = false;
                    break;
                }
                break;
        }
        return false;
    }

    public void onClick(View view) {
        switch (view.getId()) {
            case R.id.button_fail:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "Fail");
                finish();
                return;
            case R.id.button_pass:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "Pass");
                setResult(-1);
                finish();
                return;
            default:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "Default");
                return;
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        switch (keyCode) {
            case 25:
                String str = this.CLASS_NAME;
                FtUtil.log_d(str, "onKeyDown", "KEYCODE_VOLUME_DOWN => Prev : " + this.mPrevBackKeyEventTime + ", Curr : " + event.getEventTime() + " => Time Lag : " + (event.getEventTime() - this.mPrevBackKeyEventTime) + " [" + 2000L + "]");
                if (this.mPrevBackKeyEventTime == -1) {
                    this.mPrevBackKeyEventTime = event.getEventTime();
                } else if (event.getEventTime() - this.mPrevBackKeyEventTime < 2000) {
                    finish();
                } else {
                    this.mPrevBackKeyEventTime = event.getEventTime();
                }
                FtUtil.log_d("UILCDTest", "onKeyDown", "KEYCODE_BACK = return true");
                return true;
            default:
                this.mPrevBackKeyEventTime = -1;
                FtUtil.log_d("UILCDTest", "onKeyDown", "return true");
                return super.onKeyDown(keyCode, event);
        }
    }

    private void changeColorView() {
        this.TestStage++;
        FtUtil.log_i(this.CLASS_NAME, "changeColorView", "Test Stage : " + this.TestStage);
        switch (this.TestStage) {
            case 2:
                this.Sequence = 2;
                updateFailHist("GREEN_TOP");
                this.mView_Color.setBackgroundColor(-16711936);
                this.mView_Color.setVisibility(0);
                this.StartTime = System.currentTimeMillis();
                ModulePower.instance(this).setTouchLed(false);
                return;
            case 3:
                this.Sequence = 3;
                updateFailHist("GREEN_BOTTOM");
                changeColorHeight(this.mScreenHeight - this.mColorViewHeight);
                this.mView_Color.setY((float) this.mColorViewHeight);
                this.StartTime = System.currentTimeMillis();
                ModulePower.instance(this).setTouchLed(false);
                return;
            case 4:
                this.Sequence = 4;
                updateFailHist("GREEN_ALL");
                changeColorHeight(this.mScreenHeight);
                this.mView_Color.setY(0.0f);
                ModulePower.instance(this).setTouchLed(false);
                return;
            case 5:
                this.Sequence = 5;
                updateFailHist("BLACK_ALL");
                this.mView_Color.setBackgroundColor(-16777216);
                this.mHandler.sendEmptyMessageDelayed(1, 1000);
                ModulePower.instance(this).setTouchLed(true);
                return;
            default:
                return;
        }
    }

    private void updateFailHist(String name) {
        if (this.isMotorSupport) {
            updateSimpleTestStates("LCD_TEST " + name + "/" + "MOTOR");
            return;
        }
        updateSimpleTestStates("LCD_TEST " + name);
    }

    private void changeColorHeight(int height) {
        ViewGroup.LayoutParams layoutParams = this.mView_Color.getLayoutParams();
        this.params = layoutParams;
        layoutParams.height = height;
        this.mView_Color.setLayoutParams(this.params);
    }
}
