package com.sec.factory.app.ui;

import android.app.Activity;
import android.graphics.Color;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.modules.vrr.RefreshRateChangeUtil;
import com.sec.factory.modules.vrr.VRRcontants;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Timer;
import java.util.TimerTask;

public class UILcd120Hz11HzFreqTest extends UIBase implements View.OnTouchListener, View.OnClickListener {
    private static final int IGNORE_TOUCH_DELAY = 5000;
    private static final int IGNORE_TOUCH_END = 11;
    private static final int LFD_CHANGE_DELAY = 1000;
    private static final int STOP_TEST = 10;
    private LinearLayout bgLayout;
    private Button btnFail;
    private Button btnPass;
    private int mCurrentTestIndex = 0;
    private boolean mIsShowBtnEnabled = false;
    private boolean mIsTesting = false;
    private Timer mLfdTimer = null;
    private final WeakReferenceTestHandler mNotiHandler = new WeakReferenceTestHandler(this);
    private RefreshRateChangeUtil mRefreshRateChangeUtil;
    private ArrayList<Integer> mTestBrightness;
    private ArrayList<Integer> mTestRGB;
    private TextView txtTitle;

    public UILcd120Hz11HzFreqTest() {
        super("UILcd120Hz11HzFreqTest", FactoryTestManager.TEST_LCD_120HZ11HZ_FREQ_TEST);
    }

    /* access modifiers changed from: private */
    public static class WeakReferenceTestHandler extends Handler {
        private final WeakReference<Activity> ref;

        public WeakReferenceTestHandler(Activity act) {
            this.ref = new WeakReference<>(act);
        }

        public void handleMessage(Message msg) {
            UILcd120Hz11HzFreqTest act = (UILcd120Hz11HzFreqTest) this.ref.get();
            if (act != null) {
                switch (msg.what) {
                    case 1:
                        FtUtil.log_d(act.CLASS_NAME, "handleMessage", "REFRESH_RATE_CHANGED");
                        act.startTest(act.mCurrentTestIndex);
                        return;
                    case 10:
                        FtUtil.log_d(act.CLASS_NAME, "handleMessage", "STOP_TEST");
                        act.stopTest(act.mCurrentTestIndex);
                        return;
                    case 11:
                        FtUtil.log_d(act.CLASS_NAME, "handleMessage", "IGNORE_TOUCH_END");
                        act.mIsShowBtnEnabled = true;
                        return;
                    default:
                        return;
                }
            }
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        FtUtil.log_d(this.CLASS_NAME, "onCreate", "onCreate");
        setContentView(R.layout.ui_lcd_120hz11hz_freq_test);
        FtUtil.setSystemKeyBlock(getComponentName(), 26);
        FtUtil.setRemoveSystemUI(getWindow(), true);
        FtUtil.setRemoveStatusBar(getWindow());
        this.mRefreshRateChangeUtil = new RefreshRateChangeUtil(this, this.mNotiHandler);
        this.btnPass = (Button) findViewById(R.id.pass_btn);
        this.btnFail = (Button) findViewById(R.id.fail_btn);
        this.txtTitle = (TextView) findViewById(R.id.lcd_test_title);
        this.bgLayout = (LinearLayout) findViewById(R.id.background);
        initTest();
        this.bgLayout.setOnTouchListener(this);
        this.btnPass.setOnClickListener(this);
        this.btnFail.setOnClickListener(this);
    }

    public void onAttachedToWindow() {
        FtUtil.log_d(this.CLASS_NAME, "onAttachedToWindow", "start setting");
        this.mRefreshRateChangeUtil.setRefreshRate(VRRcontants.REFRESH_RATE_MODE_ALWAYS, 120);
    }

    private void initTest() {
        FtUtil.log_d(this.CLASS_NAME, "initTest", "init test setting");
        this.mCurrentTestIndex = 0;
        this.mTestBrightness = new ArrayList<>();
        this.mTestRGB = new ArrayList<>();
        String testCase = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML(this.TEST_ID));
        try {
            String brightnessStr = testCase.split("\\)")[0];
            String rgbStr = testCase.split("\\)")[1];
            String brightnessStr2 = brightnessStr.substring(brightnessStr.lastIndexOf("BRIGHTNESS") + 11);
            String rgbStr2 = rgbStr.substring(rgbStr.lastIndexOf("GRAYRGB") + 8);
            FtUtil.log_d(this.CLASS_NAME, "initTest", "BRIGHTNESS : " + brightnessStr2 + " GRAYRGB : " + rgbStr2);
            String[] testBrightness = brightnessStr2.split(",");
            String[] grayRGB = rgbStr2.split(",");
            int length = testBrightness.length;
            for (int i = 0; i < length; i++) {
                this.mTestBrightness.add(Integer.valueOf(Integer.parseInt(testBrightness[i])));
            }
            for (String rgb : grayRGB) {
                this.mTestRGB.add(Integer.valueOf(Integer.parseInt(rgb)));
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startTest(int index) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "startTest", "index = " + index);
        String str2 = this.CLASS_NAME;
        FtUtil.log_d(str2, "startTest", "Brightness = " + this.mTestBrightness.get(index));
        String str3 = this.CLASS_NAME;
        FtUtil.log_d(str3, "startTest", "RGB = " + this.mTestRGB.get(index));
        this.mIsShowBtnEnabled = false;
        this.mIsTesting = true;
        resultScreenVisible(false);
        ModulePower.instance(this).setBrightness(this.mTestBrightness.get(index).intValue());
        this.bgLayout.setBackgroundColor(Color.rgb(this.mTestRGB.get(index).intValue(), this.mTestRGB.get(index).intValue(), this.mTestRGB.get(index).intValue()));
        stopLfdTest();
        startLfdTest();
        this.mNotiHandler.sendEmptyMessageDelayed(11, 5000);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void stopTest(int index) {
        FtUtil.log_d(this.CLASS_NAME, "stopTest", "index = " + index);
        this.mIsTesting = false;
        stopLfdTest();
        resultScreenVisible(true);
        this.mCurrentTestIndex++;
    }

    private void startLfdTest() {
        FtUtil.log_d(this.CLASS_NAME, "startLfdTest", "startLfdTest");
        Timer timer = new Timer();
        this.mLfdTimer = timer;
        timer.schedule(new TimerTask() {
            /* class com.sec.factory.app.ui.UILcd120Hz11HzFreqTest.AnonymousClass1 */
            boolean bSwitch = false;

            public void run() {
                if (this.bSwitch) {
                    UILcd120Hz11HzFreqTest.this.setLfdMode(LfdCommand.FIX_FREQ_MAX);
                } else {
                    UILcd120Hz11HzFreqTest.this.setLfdMode(LfdCommand.FIX_FREQ_MIN);
                }
                this.bSwitch = !this.bSwitch;
            }
        }, 1000, 1000);
    }

    private void stopLfdTest() {
        FtUtil.log_d(this.CLASS_NAME, "stopLfdTest", "stopLfdTest");
        Timer timer = this.mLfdTimer;
        if (timer != null) {
            timer.cancel();
            this.mLfdTimer = null;
        }
        setLfdMode(LfdCommand.FIX_FREQ_MAX);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setLfdMode(LfdCommand command) {
        FtUtil.log_d(this.CLASS_NAME, "setLfdMode", "start");
        Support.Kernel.write(Support.Kernel.LCD_VARIABLE_RATE_LFD, command.getCommand());
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        super.onPause();
        ModulePower.instance(this).setBrightness(255);
        this.mRefreshRateChangeUtil.restoreDefault();
        this.mNotiHandler.removeCallbacksAndMessages(null);
    }

    private void resultScreenVisible(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "resultScreenVisible", "Visible : " + flag);
        btnVisible(flag);
        displayTitle(flag);
    }

    private void btnVisible(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "btnVisible", "Visible : " + flag);
        if (flag) {
            this.btnPass.setVisibility(0);
            this.btnFail.setVisibility(0);
            return;
        }
        this.btnPass.setVisibility(4);
        this.btnFail.setVisibility(4);
    }

    private void displayTitle(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "displayTitle", "Visible : " + flag);
        if (flag) {
            this.txtTitle.setVisibility(0);
        } else {
            this.txtTitle.setVisibility(4);
        }
        this.txtTitle.setTextColor(-1);
        this.txtTitle.setText("LCD 120Hz 11Hz Frequency Test");
    }

    public boolean onTouch(View view, MotionEvent event) {
        switch (event.getAction()) {
            case 0:
                FtUtil.log_i(this.CLASS_NAME, "onTouch", "Touch down");
                if (!this.mIsShowBtnEnabled || !this.mIsTesting) {
                    return true;
                }
                this.mNotiHandler.sendEmptyMessage(10);
                return true;
            default:
                return true;
        }
    }

    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.fail_btn:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "FAIL");
                finish();
                return;
            case R.id.pass_btn:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "PASS");
                if (this.mCurrentTestIndex == this.mTestBrightness.size()) {
                    setTestResult((byte) 80);
                    finish();
                    return;
                }
                startTest(this.mCurrentTestIndex);
                return;
            default:
                return;
        }
    }

    public enum LfdCommand {
        DEFAULT("0", "client=fac scope=normal fix=0"),
        FIX_FREQ_MAX(EgisFingerprint.MAJOR_VERSION, "client=fac scope=normal fix=1"),
        FIX_FREQ_MIN("2", "client=fac scope=normal fix=2");
        
        public String mCommand;
        public String mCommandID;

        private LfdCommand(String id, String command) {
            this.mCommandID = id;
            this.mCommand = command;
        }

        public String getId() {
            return this.mCommandID;
        }

        public String getCommand() {
            return this.mCommand;
        }
    }
}
