package com.sec.factory.app.ui;

import android.app.Activity;
import android.graphics.BitmapFactory;
import android.graphics.drawable.BitmapDrawable;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.modules.vrr.BuildVersionProvider;
import com.sec.factory.modules.vrr.IBuildVersionProvider;
import com.sec.factory.modules.vrr.RefreshRateChangeUtil;
import com.sec.factory.modules.vrr.VRRcontants;
import com.sec.factory.support.FtUtil;
import java.io.File;
import java.lang.ref.WeakReference;
import java.util.Timer;
import java.util.TimerTask;

public class UILcd120Hz60HzFreqTest extends UIBase implements View.OnTouchListener, View.OnClickListener {
    private static final int FREQUENCY_CHANGE_HS120 = 13;
    private static final int FREQUENCY_CHANGE_HS60 = 12;
    private static final int FREQ_CHANGE_DELAY = 1000;
    private static final int IGNORE_TOUCH_DELAY = 5000;
    private static final int IGNORE_TOUCH_END = 11;
    private static final int STOP_TEST = 10;
    private LinearLayout mBgLayout;
    private Button mBtnFail;
    private Button mBtnPass;
    private final IBuildVersionProvider mBuildVersionProvider = BuildVersionProvider.getInstance();
    private Timer mFreqChangeTimer = null;
    private boolean mIsShowBtnEnabled = false;
    private boolean mIsTesting = false;
    private final WeakReferenceTestHandler mNotiHandler = new WeakReferenceTestHandler(this);
    private RefreshRateChangeUtil mRefreshRateChangeUtil;
    private TextView mTxtTitle;

    public UILcd120Hz60HzFreqTest() {
        super("UILcd120Hz60HzFreqTest", 351);
    }

    /* access modifiers changed from: private */
    public static class WeakReferenceTestHandler extends Handler {
        private final WeakReference<Activity> ref;

        public WeakReferenceTestHandler(Activity act) {
            this.ref = new WeakReference<>(act);
        }

        public void handleMessage(Message msg) {
            UILcd120Hz60HzFreqTest act = (UILcd120Hz60HzFreqTest) this.ref.get();
            switch (msg.what) {
                case 1:
                    FtUtil.log_d(act.CLASS_NAME, "handleMessage", "REFRESH_RATE_CHANGED");
                    if (!act.mIsTesting && ((Integer) msg.obj).intValue() == 120) {
                        act.startTest();
                        return;
                    }
                    return;
                case 10:
                    FtUtil.log_d(act.CLASS_NAME, "handleMessage", "STOP_TEST");
                    act.stopTest();
                    return;
                case 11:
                    FtUtil.log_d(act.CLASS_NAME, "handleMessage", "IGNORE_TOUCH_END");
                    act.setShowBtnEnabledFlag(true);
                    return;
                case 12:
                    FtUtil.log_d(act.CLASS_NAME, "handleMessage", "FREQUENCY_CHANGE_HS60");
                    act.mRefreshRateChangeUtil.setRefreshRate(VRRcontants.REFRESH_RATE_MODE_ALWAYS, 60);
                    return;
                case 13:
                    FtUtil.log_d(act.CLASS_NAME, "handleMessage", "FREQUENCY_CHANGE_HS120");
                    act.mRefreshRateChangeUtil.setRefreshRate(VRRcontants.REFRESH_RATE_MODE_ALWAYS, 120);
                    return;
                default:
                    return;
            }
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        FtUtil.log_d(this.CLASS_NAME, "onCreate", "onCreate");
        FtUtil.setRemoveSystemUI(getWindow(), true);
        FtUtil.setRemoveStatusBar(getWindow());
        this.mRefreshRateChangeUtil = new RefreshRateChangeUtil(this, this.mNotiHandler);
        setContentView(R.layout.ui_lcd_120hz60hz_freq_test);
        initializeUI();
    }

    public void onAttachedToWindow() {
        FtUtil.log_d(this.CLASS_NAME, "onAttachedToWindow", "start setting");
        this.mRefreshRateChangeUtil.setRefreshRate(VRRcontants.REFRESH_RATE_MODE_ALWAYS, 120);
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        super.onPause();
        this.mRefreshRateChangeUtil.restoreDefault();
        this.mNotiHandler.removeCallbacksAndMessages(null);
    }

    public boolean onTouch(View view, MotionEvent event) {
        switch (event.getAction()) {
            case 0:
                FtUtil.log_i(this.CLASS_NAME, "onTouch", "Touch down");
                if (!getShowBtnEnabledFlag() || !getIsTestingFlag()) {
                    return true;
                }
                this.mNotiHandler.sendEmptyMessage(10);
                return true;
            default:
                return true;
        }
    }

    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.fail_btn:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "FAIL");
                finish();
                return;
            case R.id.pass_btn:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "PASS");
                setTestResult((byte) 80);
                finish();
                return;
            default:
                return;
        }
    }

    private void initializeUI() {
        this.mBtnPass = (Button) findViewById(R.id.pass_btn);
        this.mBtnFail = (Button) findViewById(R.id.fail_btn);
        this.mTxtTitle = (TextView) findViewById(R.id.lcd_test_title);
        this.mBgLayout = (LinearLayout) findViewById(R.id.background);
        setImgBackground(getResourcePath(this.mBuildVersionProvider.currentVersion()));
        this.mBgLayout.setOnTouchListener(this);
        this.mBtnPass.setOnClickListener(this);
        this.mBtnFail.setOnClickListener(this);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setShowBtnEnabledFlag(boolean value) {
        this.mIsShowBtnEnabled = value;
    }

    private boolean getShowBtnEnabledFlag() {
        return this.mIsShowBtnEnabled;
    }

    private void setIsTestingFlag(boolean value) {
        this.mIsTesting = value;
    }

    private boolean getIsTestingFlag() {
        return this.mIsTesting;
    }

    private String getResourcePath(int currentVersion) {
        String resourcePath;
        if (currentVersion > 28) {
            resourcePath = "/system/factory/testmedia/";
        } else {
            resourcePath = "/data/testmedia/";
        }
        try {
            String str = this.CLASS_NAME;
            FtUtil.log_d(str, "getResourcePath", "ResourcePath " + resourcePath);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return resourcePath;
    }

    private void setImgBackground(String path) {
        FtUtil.log_d(this.CLASS_NAME, "setImgBackground", "setImgBackground");
        File imgFile = new File(path + "1752x2800_W72_W160_W255.png");
        if (imgFile.exists()) {
            this.mBgLayout.setBackgroundDrawable(new BitmapDrawable(BitmapFactory.decodeFile(imgFile.getAbsolutePath())));
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startTest() {
        FtUtil.log_d(this.CLASS_NAME, "startTest", "Test start");
        setShowBtnEnabledFlag(false);
        setIsTestingFlag(true);
        resultScreenVisible(false);
        ModulePower.instance(this).setBrightness(255);
        startFreqChange();
        this.mNotiHandler.sendEmptyMessageDelayed(11, 5000);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void stopTest() {
        FtUtil.log_d(this.CLASS_NAME, "stopTest", "Test stop");
        setIsTestingFlag(false);
        stopFreqChange();
        resultScreenVisible(true);
    }

    private void startFreqChange() {
        FtUtil.log_d(this.CLASS_NAME, "startFreqChange", "startFreqChange");
        Timer timer = new Timer();
        this.mFreqChangeTimer = timer;
        timer.schedule(new TimerTask() {
            /* class com.sec.factory.app.ui.UILcd120Hz60HzFreqTest.AnonymousClass1 */
            boolean bSwitch = false;

            public void run() {
                if (this.bSwitch) {
                    UILcd120Hz60HzFreqTest.this.mNotiHandler.sendEmptyMessage(13);
                } else {
                    UILcd120Hz60HzFreqTest.this.mNotiHandler.sendEmptyMessage(12);
                }
                this.bSwitch = !this.bSwitch;
            }
        }, 1000, 1000);
    }

    private void stopFreqChange() {
        FtUtil.log_d(this.CLASS_NAME, "stopFreqChange", "stopFreqChange");
        Timer timer = this.mFreqChangeTimer;
        if (timer != null) {
            timer.cancel();
            FtUtil.log_d(this.CLASS_NAME, "stopFreqChange", "mFreqChangeTimer cancel");
            this.mFreqChangeTimer = null;
        }
    }

    private void resultScreenVisible(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "resultScreenVisible", "Visible : " + flag);
        btnVisible(flag);
        displayTitle(flag);
    }

    private void btnVisible(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "btnVisible", "Visible : " + flag);
        if (flag) {
            this.mBtnPass.setVisibility(0);
            this.mBtnFail.setVisibility(0);
            return;
        }
        this.mBtnPass.setVisibility(4);
        this.mBtnFail.setVisibility(4);
    }

    private void displayTitle(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "displayTitle", "Visible : " + flag);
        if (flag) {
            this.mTxtTitle.setVisibility(0);
        } else {
            this.mTxtTitle.setVisibility(4);
        }
        this.mTxtTitle.setTextColor(-1);
        this.mTxtTitle.setText("LCD HS120Hz HS60Hz Frequency Test");
    }
}
