package com.sec.factory.app.ui;

import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.lang.ref.WeakReference;

public class UILcdBrightDottest extends UIBase implements View.OnTouchListener, View.OnClickListener {
    private static final int IGNORE_TOUCH_DELAY = 5000;
    private static final int IGNORE_TOUCH_END = 0;
    private static final int STOP_TEST = 1;
    private LinearLayout bgLayout;
    private Button btnFail;
    private Button btnPass;
    private final TestHandler mHandler = new TestHandler(this);
    private boolean mIsShowBtnEnabled = false;
    private boolean mIsTesting = false;
    private TextView txtTitle;

    public UILcdBrightDottest() {
        super("UILcdBrightDottest", FactoryTestManager.TEST_LCD_BRIGHT_DOT_TEST);
    }

    /* access modifiers changed from: private */
    public static class TestHandler extends Handler {
        private final WeakReference<UILcdBrightDottest> ref;

        public TestHandler(UILcdBrightDottest act) {
            this.ref = new WeakReference<>(act);
        }

        public void handleMessage(Message msg) {
            UILcdBrightDottest act = this.ref.get();
            if (act != null) {
                switch (msg.what) {
                    case 0:
                        FtUtil.log_d(act.CLASS_NAME, "handleMessage", "IGNORE_TOUCH_END");
                        act.mIsShowBtnEnabled = true;
                        return;
                    case 1:
                        FtUtil.log_d(act.CLASS_NAME, "handleMessage", "STOP_TEST");
                        act.stopTest();
                        return;
                    default:
                        return;
                }
            }
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        FtUtil.log_d(this.CLASS_NAME, "onCreate", "onCreate");
        setContentView(R.layout.ui_lcd_bright_dot_test);
        FtUtil.setSystemKeyBlock(getComponentName(), 26);
        FtUtil.setRemoveSystemUI(getWindow(), true);
        this.btnPass = (Button) findViewById(R.id.pass_btn);
        this.btnFail = (Button) findViewById(R.id.fail_btn);
        this.txtTitle = (TextView) findViewById(R.id.lcd_test_title);
        this.bgLayout = (LinearLayout) findViewById(R.id.background);
        initTest();
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
    }

    public void onWindowFocusChanged(boolean hasFocus) {
        FtUtil.log_d(this.CLASS_NAME, "onWindowFocusChanged", "onWindowFocusChanged");
        super.onWindowFocusChanged(hasFocus);
        if (hasFocus) {
            startTest();
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        super.onPause();
        Support.Kernel.write(Support.Kernel.LCD_ALPM, "0");
        if (Support.Feature.getBoolean(Support.Feature.SUPPORT_LCD_FAST_DISCHARGE)) {
            Support.Kernel.write(Support.Kernel.LCD_FAST_DISCHARGE, EgisFingerprint.MAJOR_VERSION);
        }
        this.mHandler.removeCallbacksAndMessages(null);
    }

    private void initTest() {
        FtUtil.log_d(this.CLASS_NAME, "initTest", "init test setting");
        if (Support.Feature.getBoolean(Support.Feature.SUPPORT_LCD_FAST_DISCHARGE)) {
            Support.Kernel.write(Support.Kernel.LCD_FAST_DISCHARGE, "0");
        }
        this.mIsShowBtnEnabled = false;
        this.bgLayout.setOnTouchListener(this);
        this.btnPass.setOnClickListener(this);
        this.btnFail.setOnClickListener(this);
    }

    private void startTest() {
        FtUtil.log_d(this.CLASS_NAME, "startTest", "Test start");
        this.mIsShowBtnEnabled = false;
        this.mIsTesting = true;
        resultScreenVisible(false);
        Support.Kernel.write(Support.Kernel.LCD_ALPM, "2");
        this.mHandler.sendEmptyMessageDelayed(0, 5000);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void stopTest() {
        FtUtil.log_d(this.CLASS_NAME, "stopTest", "Test stop");
        Support.Kernel.write(Support.Kernel.LCD_ALPM, "0");
        this.mIsTesting = false;
        resultScreenVisible(true);
    }

    private void resultScreenVisible(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "resultScreenVisible", "Visible : " + flag);
        btnVisible(flag);
        displayTitle(flag);
    }

    private void btnVisible(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "btnVisible", "Visible : " + flag);
        if (flag) {
            this.btnPass.setVisibility(0);
            this.btnFail.setVisibility(0);
            return;
        }
        this.btnPass.setVisibility(4);
        this.btnFail.setVisibility(4);
    }

    private void displayTitle(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "displayTitle", "Visible : " + flag);
        if (flag) {
            this.txtTitle.setVisibility(0);
        } else {
            this.txtTitle.setVisibility(4);
        }
        this.txtTitle.setTextColor(-1);
        this.txtTitle.setText("LCD Bright Dot Test");
    }

    public boolean onTouch(View view, MotionEvent event) {
        switch (event.getAction()) {
            case 0:
                FtUtil.log_i(this.CLASS_NAME, "onTouch", "Touch down");
                if (this.mIsShowBtnEnabled && this.mIsTesting) {
                    this.mHandler.sendEmptyMessage(1);
                    break;
                }
        }
        return true;
    }

    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.fail_btn:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "FAIL");
                finish();
                return;
            case R.id.pass_btn:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "PASS");
                setTestResult((byte) 80);
                finish();
                return;
            default:
                return;
        }
    }
}
