package com.sec.factory.app.ui;

import android.os.Bundle;
import android.view.KeyEvent;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;

public class UILedTest extends UIBase {
    private static TextView textColor;
    private final int BLACK_BLUE = 3;
    private final int BLACK_GREEN = 2;
    private final int BLACK_RED = 1;
    private final int BLACK_START = 0;
    private final int FINISH = 4;
    private boolean isLedSupport;
    private boolean isMotorSupport;
    private boolean mIsLongPress = false;
    private ModuleDevice mModuleDevice;
    private String mTestCase;
    private int test_state = 0;

    public UILedTest() {
        super("UILedTest");
        boolean z = false;
        String testCase = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML((byte) 0));
        this.mTestCase = testCase;
        if (testCase != null && testCase.contains("MOTOR")) {
            z = true;
        }
        this.isMotorSupport = z;
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ui_ledtest);
        textColor = (TextView) findViewById(R.id.colorstate);
        ModuleDevice instance = ModuleDevice.instance(this);
        this.mModuleDevice = instance;
        instance.setLEDlamp(5);
        FtUtil.setRemoveSystemUI(getWindow(), true);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        if (this.isMotorSupport && !this.mModuleDevice.isVibrating()) {
            this.mModuleDevice.startVibrate(ModuleDevice.TIMELESS_VIBRATOR);
        }
        try {
            this.isLedSupport = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML((byte) 0)).contains("LED");
        } catch (Exception e) {
            this.isLedSupport = false;
        }
        changeTestLevel(this.test_state);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        super.onPause();
        if (this.isMotorSupport) {
            this.mModuleDevice.stopVibrate();
        }
        if (this.test_state != 4 && this.isLedSupport) {
            this.mModuleDevice.setLEDlamp(0);
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (!this.mIsLongPress) {
            this.mIsLongPress = event.isLongPress();
        }
        if (!this.mIsLongPress) {
            switch (keyCode) {
                case 24:
                    changeTestLevel(this.test_state);
                    break;
            }
        }
        return super.onKeyDown(keyCode, event);
    }

    @Override // com.sec.factory.app.ui.UIBase
    public boolean onKeyUp(int keyCode, KeyEvent event) {
        this.mIsLongPress = false;
        return super.onKeyUp(keyCode, event);
    }

    private void changeTestLevel(int state) {
        switch (state) {
            case 0:
                if (this.isLedSupport) {
                    this.mModuleDevice.setLEDlamp(2);
                }
                this.test_state = 1;
                textColor.setText("RED");
                textColor.setTextColor(-65536);
                if (this.isMotorSupport) {
                    updateSimpleTestStates("RED SCREEN/MOTOR");
                } else {
                    updateSimpleTestStates("RED SCREEN");
                }
                FtUtil.log_i(this.CLASS_NAME, "changeTestLevel", "START -> RED");
                return;
            case 1:
                if (this.isLedSupport) {
                    this.mModuleDevice.setLEDlamp(3);
                }
                this.test_state = 2;
                textColor.setText("GREEN");
                textColor.setTextColor(-16711936);
                if (this.isMotorSupport) {
                    updateSimpleTestStates("GREEN SCREEN/MOTOR");
                } else {
                    updateSimpleTestStates("GREEN SCREEN");
                }
                FtUtil.log_i(this.CLASS_NAME, "changeTestLevel", "RED -> GREEN");
                return;
            case 2:
                if (this.isLedSupport) {
                    this.mModuleDevice.setLEDlamp(4);
                }
                this.test_state = 3;
                textColor.setText("BLUE");
                textColor.setTextColor(UiHallICTest.FONT_COLOR_PASS);
                if (this.isMotorSupport) {
                    updateSimpleTestStates("BLUE SCREEN/MOTOR");
                } else {
                    updateSimpleTestStates("BLUE SCREEN");
                }
                FtUtil.log_i(this.CLASS_NAME, "changeTestLevel", "GREEN -> BLUE");
                return;
            case 3:
                if (this.isLedSupport) {
                    this.mModuleDevice.setLEDlamp(0);
                }
                this.test_state = 4;
                setResult(-1);
                finish();
                FtUtil.log_i(this.CLASS_NAME, "changeTestLevel", "BLUE -> FINISH");
                return;
            default:
                String str = this.CLASS_NAME;
                FtUtil.log_i(str, "changeTestLevel", "default, test_state: " + this.test_state);
                return;
        }
    }
}
