package com.sec.factory.app.ui;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.nfc.Tag;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModuleNfc;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.io.File;
import java.lang.ref.WeakReference;
import java.util.Objects;

public class UINFC2 extends UIBase {
    private static final String ACTION_NFC_TEST_RESPONSE = "com.samsung.android.nfc.test.action.RESPONSE";
    private static final int CHECK_CARD_MODE_STATE = 7;
    private static final String CLASS_NAME = "UINFC2";
    private static final String EXTRA_ID = "com.samsung.android.nfc.test.extra.ID";
    private static final String EXTRA_RESULT = "com.samsung.android.nfc.test.extra.RESULT";
    private static final String LOG_TAG = "[UTOPIA_NFC2]";
    private static final byte MSG_DISABLE_DISCOVERY = 3;
    private static final byte MSG_ENABLE_CARDMODE = 5;
    private static final byte MSG_ENABLE_DISCOVERY = 2;
    private static final byte MSG_FINISH_TEST = 4;
    private static final byte MSG_READ_STATUS_TIMEOUT = 1;
    private static final String NFC_DETECTING_FILE_PATH = "data/log/NfcDetecting_ui.log";
    private static final String RES_SEC_NFC_CARD_MODE = "com.sec.android.app.nfctest.CHECK_SEC_NFC_CARDMODE_RESP";
    private static TextView mReaderModeResult;
    private final int NFC_DISABLE_DELAY = 400;
    private final int NFC_FINISH_DELAY = 0;
    private final int NFC_READ_STATUS_TIMEOUT_DELAY = 10000;
    private int mDetectingCount = 0;
    private boolean mIsPassedCardMode = true;
    private boolean mIsPassed_reader = false;
    private File mNfcDetectFile;
    private NfcProcessHandler mNfcHandler = new NfcProcessHandler(this);
    private BroadcastReceiver mReceiver;
    private boolean mSupportCardMode = false;

    /* access modifiers changed from: private */
    public static final class NfcProcessHandler extends Handler {
        private final WeakReference<UINFC2> mReference;

        public NfcProcessHandler(UINFC2 activity) {
            this.mReference = new WeakReference<>(activity);
        }

        public void handleMessage(Message msg) {
            final UINFC2 uiNfc2Activity = null;
            WeakReference<UINFC2> weakReference = this.mReference;
            if (weakReference != null) {
                uiNfc2Activity = weakReference.get();
            }
            if (uiNfc2Activity == null) {
                FtUtil.log_d(UINFC2.CLASS_NAME, "NfcProcessHandler.handleMessage", "Activity is null. So handleMessage is not called.");
                return;
            }
            switch (msg.what) {
                case 1:
                    FtUtil.log_d(UINFC2.CLASS_NAME, "NfcProcessHandler.handleMessage", "[UTOPIA_NFC2][MSP_SEQ] Read Test Fail because of timeout");
                    uiNfc2Activity.unregisterReceiver();
                    uiNfc2Activity.mIsPassed_reader = false;
                    uiNfc2Activity.mIsPassedCardMode = false;
                    FtUtil.log_d(UINFC2.CLASS_NAME, "handleMessage", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(uiNfc2Activity.TEST_ID), "FAIL - Time Out (NFC_FT)"));
                    uiNfc2Activity.updateDisplay(R.id.reader_mode_result, "FAIL", -65536);
                    return;
                case 2:
                    FtUtil.log_d(UINFC2.CLASS_NAME, "handleMessage", "send Intent ENABLE_SEC_NFC_DISCOVERY");
                    uiNfc2Activity.sendBroadcast(ModuleNfc.NfcFunctions.NFC_ENABLE_DISCOVERY.getNfcIntent());
                    return;
                case 3:
                    FtUtil.log_d(UINFC2.CLASS_NAME, "handleMessage", "send Intent DISABLE_SEC_NFC_DISCOVERY");
                    uiNfc2Activity.sendBroadcast(ModuleNfc.NfcFunctions.NFC_DISABLE_DISCOVERY.getNfcIntent());
                    return;
                case 4:
                    FtUtil.log_d(UINFC2.CLASS_NAME, "handleMessage", "MSG_FINISH_TEST");
                    uiNfc2Activity.unregisterReceiver();
                    if (!uiNfc2Activity.mIsPassed_reader || !uiNfc2Activity.mIsPassedCardMode) {
                        FtUtil.log_d(UINFC2.CLASS_NAME, "NfcProcessHandler.handleMessage", UINFC2.LOG_TAG + FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(uiNfc2Activity.TEST_ID), "FAIL (NFC_FT)"));
                        return;
                    }
                    Objects.requireNonNull(uiNfc2Activity);
                    uiNfc2Activity.setTestResult((byte) 80);
                    if (uiNfc2Activity.mNfcDetectFile != null) {
                        Support.Kernel.writeToPathNsync(uiNfc2Activity.mNfcDetectFile.getPath(), Integer.toString(uiNfc2Activity.mDetectingCount));
                    }
                    postDelayed(new Runnable() {
                        /* class com.sec.factory.app.ui.UINFC2.NfcProcessHandler.AnonymousClass1 */

                        public void run() {
                            if (!uiNfc2Activity.isFinishing()) {
                                uiNfc2Activity.finish();
                            }
                        }
                    }, 0);
                    FtUtil.log_d(UINFC2.CLASS_NAME, "NfcProcessHandler.handleMessage", UINFC2.LOG_TAG + FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(uiNfc2Activity.TEST_ID), "PASS (NFC_FT)"));
                    return;
                case 5:
                    FtUtil.log_d(UINFC2.CLASS_NAME, "handleMessage", "send Intent ENABLE_SEC_NFC_CARD_MODE");
                    uiNfc2Activity.sendBroadcast(ModuleNfc.NfcFunctions.NFC_ENABLE_CARD_MODE.getNfcIntent());
                    return;
                default:
                    return;
            }
        }
    }

    public UINFC2() {
        super(CLASS_NAME, 61);
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ui_nfc2);
        initUI();
        initFileStatus();
        registerReceiver();
    }

    private void initFileStatus() {
        File file = new File(NFC_DETECTING_FILE_PATH);
        this.mNfcDetectFile = file;
        Support.Kernel.writeToPathNsync(file.getPath(), "0");
    }

    private void initUI() {
        int id = getIntent().getByteExtra("ID", (byte) 61);
        String testCase = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML((byte) 61));
        if (testCase != null && testCase.contains("CARD_MODE")) {
            this.mSupportCardMode = true;
            this.mIsPassedCardMode = false;
            ((TextView) findViewById(R.id.sub_title)).setText("Reader or Card Mode");
            ((TextView) findViewById(R.id.main_text)).setText("[Detecting NFC TAG\n or NFC CardReader]");
        }
        if (id == 9) {
            setTestId(id);
            ((TextView) findViewById(R.id.title)).setText("NFC Test");
        }
        mReaderModeResult = (TextView) findViewById(R.id.reader_mode_result);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        FtUtil.log_d(CLASS_NAME, "onResume", "onResume");
        super.onResume();
        sendBroadcast(ModuleNfc.NfcFunctions.NFC_START_SEC_NFC_TEST.getNfcIntent());
        runNfcTest();
    }

    private void runNfcTest() {
        FtUtil.log_d(CLASS_NAME, "runNfcTest", "[UTOPIA_NFC2]*** Start nfctest ***");
        this.mNfcHandler.sendEmptyMessageDelayed(1, 10000);
        this.mNfcHandler.sendEmptyMessageDelayed(3, 0);
        long totalDelayTime = 0 + 400;
        this.mNfcHandler.sendEmptyMessageDelayed(2, totalDelayTime);
        if (this.mSupportCardMode) {
            this.mNfcHandler.sendEmptyMessageDelayed(5, totalDelayTime);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        FtUtil.log_d(CLASS_NAME, "onPause", "onPause");
        this.mNfcHandler.removeCallbacksAndMessages(null);
        super.onPause();
        sendBroadcast(ModuleNfc.NfcFunctions.NFC_END_SEC_NFC_TEST.getNfcIntent());
        FtUtil.Sleep.sleep(100);
        sendBroadcast(ModuleNfc.NfcFunctions.NFC_DISABLE_DISCOVERY.getNfcIntent());
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        unregisterReceiver();
        FtUtil.log_d(CLASS_NAME, "onDestroy", LOG_TAG);
        super.onDestroy();
    }

    private synchronized void registerReceiver() {
        FtUtil.log_d(CLASS_NAME, "registerReceiver", null);
        if (this.mReceiver == null) {
            this.mReceiver = new BroadcastReceiver() {
                /* class com.sec.factory.app.ui.UINFC2.AnonymousClass1 */

                public void onReceive(Context context, Intent intent) {
                    String action = intent.getAction();
                    FtUtil.log_d(UINFC2.CLASS_NAME, "onReceive", "Received action = " + action);
                    if ("android.nfc.action.TAG_DISCOVERED".equals(action)) {
                        UINFC2.this.processForDetectingNfcTag(intent);
                    } else if (!UINFC2.this.mSupportCardMode || !UINFC2.RES_SEC_NFC_CARD_MODE.equals(action)) {
                        if (!UINFC2.this.mSupportCardMode || !"com.samsung.android.nfc.test.action.RESPONSE".equals(action)) {
                            FtUtil.log_d(UINFC2.CLASS_NAME, "onReceive", "Unknown action");
                            return;
                        } else if (!UINFC2.this.processForCardModeResponse(intent)) {
                            return;
                        }
                    } else if (!UINFC2.this.processForCardMode(intent)) {
                        return;
                    }
                    UINFC2.this.mIsPassedCardMode = true;
                    UINFC2.this.mNfcHandler.removeMessages(1);
                    if (UINFC2.this.mIsPassed_reader) {
                        UINFC2.this.updateDisplay(R.id.reader_mode_result, "PASS", UiHallICTest.FONT_COLOR_PASS);
                    } else {
                        UINFC2.this.updateDisplay(R.id.reader_mode_result, "FAIL", -65536);
                    }
                    UINFC2.this.mNfcHandler.sendEmptyMessageDelayed(4, 2000);
                }
            };
        }
        registerReceiver(this.mReceiver, setFilteringIntent());
    }

    private IntentFilter setFilteringIntent() {
        IntentFilter filter = new IntentFilter();
        filter.addAction("android.nfc.action.TAG_DISCOVERED");
        if (this.mSupportCardMode) {
            filter.addAction(RES_SEC_NFC_CARD_MODE);
            filter.addAction("com.samsung.android.nfc.test.action.RESPONSE");
        }
        return filter;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean processForCardModeResponse(Intent intent) {
        if (intent.getIntExtra("com.samsung.android.nfc.test.extra.ID", -1) == 7) {
            int state = intent.getIntExtra(EXTRA_RESULT, 0);
            FtUtil.log_d(CLASS_NAME, "onReceive", "[UTOPIA_NFC2]CARDMODE_ACTIVATED = " + state);
            if (state > 0) {
                return true;
            }
            this.mNfcHandler.sendEmptyMessageDelayed(5, 500);
            return false;
        }
        FtUtil.log_e(CLASS_NAME, "Unknown ID: " + intent.getIntExtra("com.samsung.android.nfc.test.extra.ID", -1));
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean processForCardMode(Intent intent) {
        int state = intent.getIntExtra("CARDMODE_ACTIVATED", 0);
        FtUtil.log_d(CLASS_NAME, "processForCardMode", "[UTOPIA_NFC2]CARDMODE_ACTIVATED = " + state);
        if (state > 0) {
            return true;
        }
        this.mNfcHandler.sendEmptyMessageDelayed(5, 500);
        return false;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void processForDetectingNfcTag(Intent intent) {
        if (0 == 1) {
            FtUtil.log_d(CLASS_NAME, "processForDetectingNfcTag", "NFC Type is a SEN82AB Type.");
            this.mIsPassed_reader = true;
        } else {
            String[] techList = ((Tag) intent.getParcelableExtra("android.nfc.extra.TAG")).getTechList();
            if (techList == null) {
                FtUtil.log_d(CLASS_NAME, "processForDetectingNfcTag", "tech list is null");
            } else {
                boolean isJapan = getPackageManager().hasSystemFeature(ModuleNfc.NFC_GLOBAL_FELICA_FEATURE);
                FtUtil.log_d(CLASS_NAME, "processForDetectingNfcTag", "FELICA : isJapan - " + isJapan);
                for (String tech : techList) {
                    if (!isJapan && ModuleNfc.NFC_TECH_TYPE_A.equals(tech)) {
                        FtUtil.log_d(CLASS_NAME, "processForDetectingNfcTag", "tech type : A is pass");
                        this.mIsPassed_reader = true;
                    } else if (isJapan && ModuleNfc.NFC_TECH_TYPE_F.equals(tech)) {
                        FtUtil.log_d(CLASS_NAME, "processForDetectingNfcTag", "tech type : F is pass");
                        this.mIsPassed_reader = true;
                    }
                }
            }
        }
        this.mDetectingCount++;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private synchronized void unregisterReceiver() {
        FtUtil.log_d(CLASS_NAME, "unregisterReceiver", null);
        BroadcastReceiver broadcastReceiver = this.mReceiver;
        if (broadcastReceiver != null) {
            unregisterReceiver(broadcastReceiver);
        }
        this.mReceiver = null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateDisplay(int id, String result, int textColor) {
        if (id == R.id.reader_mode_result) {
            mReaderModeResult.setText(result);
            mReaderModeResult.setTextColor(textColor);
        }
    }
}
