package com.sec.factory.app.ui;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModuleNfc;
import com.sec.factory.support.FtUtil;
import java.lang.ref.WeakReference;
import java.util.Objects;

public class UINfcCardMode extends UIBase {
    private static final String ACTION_NFC_TEST_RESPONSE = "com.samsung.android.nfc.test.action.RESPONSE";
    private static final int CHECK_CARD_MODE_STATE = 7;
    private static final String EXTRA_ID = "com.samsung.android.nfc.test.extra.ID";
    private static final String EXTRA_RESULT = "com.samsung.android.nfc.test.extra.RESULT";
    private static final String LOG_TAG = "[UTOPIA_NFC_CARDMODE]";
    private static final int MSG_ENABLE_CARDMODE = 5;
    private static final int MSG_FINISH_TEST = 4;
    private static final int MSG_READ_STATUS_TIMEOUT = 1;
    private static final int NFC_READ_STATUS_TIMEOUT_DELAY = 10000;
    private static final String RES_SEC_NFC_CARD_MODE = "com.sec.android.app.nfctest.CHECK_SEC_NFC_CARDMODE_RESP";
    private NfcCardModeHandler mNfcHandler = new NfcCardModeHandler(this);
    private TextView mReaderModeResult;
    private BroadcastReceiver mReceiver;

    /* access modifiers changed from: private */
    public static class NfcCardModeHandler extends Handler {
        private static final String CLASS_NAME = "NfcCardModeHandler";
        private final WeakReference<UINfcCardMode> mReference;

        public NfcCardModeHandler(UINfcCardMode activity) {
            this.mReference = new WeakReference<>(activity);
        }

        public void handleMessage(Message msg) {
            UINfcCardMode uiNfcCardModeActivity = null;
            WeakReference<UINfcCardMode> weakReference = this.mReference;
            if (weakReference != null) {
                uiNfcCardModeActivity = weakReference.get();
            }
            if (uiNfcCardModeActivity == null) {
                FtUtil.log_d(CLASS_NAME, "NfcCardModeHandler.handleMessage", "Activity is null. So handleMessage is not called.");
                return;
            }
            switch (msg.what) {
                case 1:
                    FtUtil.log_d(CLASS_NAME, "NfcCardModeHandler.handleMessage", UINfcCardMode.LOG_TAG + FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(72), "FAIL - Timeout (NFC_FT)"));
                    uiNfcCardModeActivity.unregisterReceiver();
                    uiNfcCardModeActivity.updateDisplay(R.id.reader_mode_result, "FAIL", -65536);
                    return;
                case 2:
                case 3:
                default:
                    return;
                case 4:
                    FtUtil.log_i(CLASS_NAME, "MSG_FINISH_TEST");
                    uiNfcCardModeActivity.unregisterReceiver();
                    int i = msg.arg1;
                    Objects.requireNonNull(uiNfcCardModeActivity);
                    if (i == 80) {
                        FtUtil.log_d(CLASS_NAME, "NfcCardModeHandler.handleMessage", UINfcCardMode.LOG_TAG + FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(72), "PASS (NFC_FT)"));
                        Objects.requireNonNull(uiNfcCardModeActivity);
                        uiNfcCardModeActivity.setTestResult((byte) 80);
                        FtUtil.Sleep.sleep(1000);
                        uiNfcCardModeActivity.finish();
                        return;
                    }
                    FtUtil.log_d(CLASS_NAME, "NfcCardModeHandler.handleMessage", UINfcCardMode.LOG_TAG + FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(72), "FAIL (NFC_FT)"));
                    return;
                case 5:
                    FtUtil.log_d(CLASS_NAME, "send Intent ENABLE_SEC_NFC_CARD_MODE");
                    uiNfcCardModeActivity.sendBroadcast(ModuleNfc.NfcFunctions.NFC_ENABLE_CARD_MODE.getNfcIntent());
                    return;
            }
        }
    }

    public UINfcCardMode() {
        super("UINfcCardMode", 72);
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ui_nfc_card_mode);
        initUI();
    }

    private void initUI() {
        this.mReaderModeResult = (TextView) findViewById(R.id.result);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        FtUtil.log_i(this.CLASS_NAME, "onResume");
        runNfcTest();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        FtUtil.log_i(this.CLASS_NAME, "onPause");
        terminateNfcTest();
        super.onPause();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        super.onDestroy();
    }

    private synchronized void registerReceiver() {
        FtUtil.log_i(this.CLASS_NAME, "registerReceiver start");
        if (this.mReceiver == null) {
            this.mReceiver = new BroadcastReceiver() {
                /* class com.sec.factory.app.ui.UINfcCardMode.AnonymousClass1 */

                public void onReceive(Context context, Intent intent) {
                    String action = intent.getAction();
                    String str = UINfcCardMode.this.CLASS_NAME;
                    FtUtil.log_i(str, "onReceive", "Received action = " + action);
                    if (UINfcCardMode.RES_SEC_NFC_CARD_MODE.equals(action)) {
                        int state = intent.getIntExtra("CARDMODE_ACTIVATED", 0);
                        String str2 = UINfcCardMode.this.CLASS_NAME;
                        FtUtil.log_d(str2, "onReceive", "CARDMODE_ACTIVATED = " + state);
                        if (state <= 0) {
                            UINfcCardMode.this.mNfcHandler.sendEmptyMessageDelayed(5, 500);
                            return;
                        }
                    } else if (!"com.samsung.android.nfc.test.action.RESPONSE".equals(action)) {
                        FtUtil.log_d(UINfcCardMode.this.CLASS_NAME, "onReceive", "Not registered action received");
                        return;
                    } else if (intent.getIntExtra("com.samsung.android.nfc.test.extra.ID", -1) == 7) {
                        int state2 = intent.getIntExtra(UINfcCardMode.EXTRA_RESULT, 0);
                        String str3 = UINfcCardMode.this.CLASS_NAME;
                        FtUtil.log_d(str3, "onReceive", "CARDMODE_ACTIVATED = " + state2);
                        if (state2 <= 0) {
                            UINfcCardMode.this.mNfcHandler.sendEmptyMessageDelayed(5, 500);
                            return;
                        }
                    } else {
                        String str4 = UINfcCardMode.this.CLASS_NAME;
                        FtUtil.log_d(str4, "onReceive", "Unknown ID: " + intent.getIntExtra("com.samsung.android.nfc.test.extra.ID", -1));
                    }
                    UINfcCardMode.this.mNfcHandler.removeMessages(1);
                    UINfcCardMode.this.updateDisplay(R.id.reader_mode_result, "PASS", UiHallICTest.FONT_COLOR_PASS);
                    UINfcCardMode.this.mNfcHandler.sendMessage(UINfcCardMode.this.mNfcHandler.obtainMessage(4, 80, -1));
                }
            };
        }
        registerReceiver(this.mReceiver, getIntentFilter());
        FtUtil.log_i(this.CLASS_NAME, "registerReceiver", "registerReceiver done");
    }

    private IntentFilter getIntentFilter() {
        IntentFilter filter = new IntentFilter();
        filter.addAction(RES_SEC_NFC_CARD_MODE);
        filter.addAction("com.samsung.android.nfc.test.action.RESPONSE");
        return filter;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private synchronized void unregisterReceiver() {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "unregisterReceiver", "unregisterReceiver, mReceiver=" + this.mReceiver);
        BroadcastReceiver broadcastReceiver = this.mReceiver;
        if (broadcastReceiver != null) {
            unregisterReceiver(broadcastReceiver);
        }
        this.mReceiver = null;
    }

    private void runNfcTest() {
        FtUtil.log_d(this.CLASS_NAME, "runNfcTest", "[UTOPIA_NFC_CARDMODE][MSP_SEQ] *** runNfcTest ***");
        registerReceiver();
        sendBroadcast(ModuleNfc.NfcFunctions.NFC_START_SEC_NFC_TEST.getNfcIntent());
        this.mNfcHandler.sendEmptyMessageDelayed(5, 100);
        this.mNfcHandler.sendEmptyMessageDelayed(1, 10000);
    }

    private void terminateNfcTest() {
        FtUtil.log_d(this.CLASS_NAME, "terminateNfcTest", "[UTOPIA_NFC_CARDMODE][MSP_SEQ] *** terminateNfcTest ***");
        NfcCardModeHandler nfcCardModeHandler = this.mNfcHandler;
        if (nfcCardModeHandler != null) {
            nfcCardModeHandler.removeCallbacksAndMessages(null);
        }
        sendBroadcast(ModuleNfc.NfcFunctions.NFC_END_SEC_NFC_TEST.getNfcIntent());
        unregisterReceiver();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateDisplay(int id, String result, int textColor) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "updateDisplay", "[UTOPIA_NFC_CARDMODE][MSP_SEQ] Display text : " + result);
        if (id == R.id.reader_mode_result) {
            this.mReaderModeResult.setText(result);
            this.mReaderModeResult.setTextColor(textColor);
        }
    }
}
