package com.sec.factory.app.ui;

import android.app.AlertDialog;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.KeyEvent;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.modules.ModuleNfc;
import com.sec.factory.sensors.SensorListener;
import com.sec.factory.sensors.SensorProximity;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.io.File;
import java.lang.ref.WeakReference;

public class UINfcFelicaSelfCal extends UIBase implements SensorListener, View.OnClickListener {
    private static final int MSG_CHECK_CAL_DATA = 2;
    private static final int MSG_CHECK_JIG_STATE = 0;
    private static final int MSG_TEST_FINISH = 3;
    private static final int MSG_TIME_OUT = 1;
    private static final String NFC_FELICA_CAL_FILE_PATH = "data/log/FelicaCal.log";
    private static final int NFC_TEST_TIME_OUT = 5000;
    private static final String PROXIMITY_DETECT = "0.0";
    private static final int TEST_FINISH_DELAY = 1000;
    private final String LOG_TAG = "[UTOPIA_NFC_FELICA_CAL]";
    private boolean isPass = false;
    private Button mBtnExit;
    private int mCalData = -1;
    private int mCalMaxSpec = -1;
    private int mCalMinSpec = -1;
    private FelicaSelfCalHandler mFelicaHandler = new FelicaSelfCalHandler(this);
    private int mHallIcNumber = 1;
    private boolean mIsEnabledHall_IC = false;
    private boolean mIsEnabledProximity = false;
    private AlertDialog mJigCheckDialog;
    private JigType mJigCheckType = null;
    private String mProximitySensorMgrValue = "5.0";
    public BroadcastReceiver mReceiver = new BroadcastReceiver() {
        /* class com.sec.factory.app.ui.UINfcFelicaSelfCal.AnonymousClass1 */

        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            String calData = "";
            if (ModuleNfc.ACTION_NFC_RESPONSE_V3.equals(action)) {
                FtUtil.log_d(UINfcFelicaSelfCal.this.CLASS_NAME, "onReceive", "Receive ACTION_NFC_RESPONSE(V3)");
                calData = intent.getStringExtra("S_DATA");
            } else if ("com.samsung.android.nfc.test.action.RESPONSE".equals(action)) {
                int id = intent.getIntExtra("com.samsung.android.nfc.test.extra.ID", -1);
                if (id == 23) {
                    FtUtil.log_d(UINfcFelicaSelfCal.this.CLASS_NAME, "onReceive", "Receive ACTION_NFC_RESPONSE(V3)");
                    calData = intent.getStringExtra(ModuleNfc.EXTRA_DATA_STRING);
                } else {
                    String str = UINfcFelicaSelfCal.this.CLASS_NAME;
                    FtUtil.log_d(str, "onReceive", "Unknown ID: " + id);
                }
            }
            if (!"".equals(calData)) {
                String str2 = UINfcFelicaSelfCal.this.CLASS_NAME;
                FtUtil.log_d(str2, "onReceive", "calData : " + calData);
                Message msg = new Message();
                msg.what = 2;
                msg.obj = calData;
                UINfcFelicaSelfCal.this.mFelicaHandler.removeMessages(1);
                UINfcFelicaSelfCal.this.mFelicaHandler.sendMessage(msg);
            }
        }
    };
    private SensorProximity mSensorProximity;
    private TestSequence mTestSequence = TestSequence.TEST_INIT;
    private TextView mTxtViewData;
    private TextView mTxtViewResult;
    private TextView mTxtViewSpec;

    public enum JigType {
        HALL,
        PROX,
        VOLUME_UP
    }

    public enum TestResult {
        PASS,
        FAIL,
        TIME_OUT
    }

    public enum TestSequence {
        TEST_INIT,
        TEST_START,
        TEST_STOP
    }

    public UINfcFelicaSelfCal() {
        super("UINfcFelicaSelfCal", FactoryTestManager.TEST_NFC_FELICA_SELF_CAL);
    }

    /* access modifiers changed from: private */
    public static class FelicaSelfCalHandler extends Handler {
        private static final String CLASS_NAME = "FelicaSelfCalHandler";
        private final WeakReference<UINfcFelicaSelfCal> mReference;

        public FelicaSelfCalHandler(UINfcFelicaSelfCal activity) {
            this.mReference = new WeakReference<>(activity);
        }

        public void handleMessage(Message msg) {
            UINfcFelicaSelfCal uiNfcFelicaActivity = null;
            WeakReference<UINfcFelicaSelfCal> weakReference = this.mReference;
            if (weakReference != null) {
                uiNfcFelicaActivity = weakReference.get();
            }
            if (uiNfcFelicaActivity == null) {
                FtUtil.log_d(CLASS_NAME, "handleMessage", "Activity is null. So handleMessage is not called.");
                return;
            }
            switch (msg.what) {
                case 0:
                    FtUtil.log_i(CLASS_NAME, "handleMessage", "CHECK_JIG_STATE");
                    if (!uiNfcFelicaActivity.checkJigType()) {
                        sendEmptyMessageDelayed(0, 500);
                        return;
                    } else if (uiNfcFelicaActivity.mJigCheckDialog != null) {
                        uiNfcFelicaActivity.mJigCheckDialog.dismiss();
                        return;
                    } else {
                        return;
                    }
                case 1:
                    FtUtil.log_i(CLASS_NAME, "handleMessage", "MSG_TIME_OUT");
                    uiNfcFelicaActivity.displayTestResult(TestResult.TIME_OUT);
                    return;
                case 2:
                    uiNfcFelicaActivity.compareCalSpecAndCalData((String) msg.obj);
                    return;
                case 3:
                    uiNfcFelicaActivity.setTestResult((byte) 80);
                    uiNfcFelicaActivity.finish();
                    return;
                default:
                    return;
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void displayTestResult(TestResult result) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "displayTestResult", "Result : " + result);
        if (result == TestResult.PASS) {
            this.mTxtViewResult.setText("PASS");
            this.mTxtViewResult.setTextColor(UiHallICTest.FONT_COLOR_PASS);
            return;
        }
        this.mTxtViewResult.setTextColor(-65536);
        if (result == TestResult.FAIL) {
            this.mTxtViewResult.setText("FAIL");
            setTestResultFailCase(this.TEST_ID, "NFC Cal Spec Fail or Nfc Turn Off Fail");
        } else if (result == TestResult.TIME_OUT) {
            this.mTxtViewResult.setText("Time Out");
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ui_nfc_felica_self_cal);
        setAtCmd(getIntent().getBooleanExtra("mIsAtCmd", false));
        initUI();
        initFeature();
        showJigCheckPopup();
    }

    private void initFeature() {
        getCalSpec();
        getJigCheckType();
        IntentFilter mFilter = new IntentFilter();
        mFilter.addAction(ModuleNfc.ACTION_NFC_RESPONSE_V3);
        mFilter.addAction("com.samsung.android.nfc.test.action.RESPONSE");
        registerReceiver(this.mReceiver, mFilter);
    }

    private void getCalSpec() {
        String[] testSpecArray = Support.FactoryTestMenu.getSpec(FactoryTestManager.convertorID_XML(this.TEST_ID)).split(",");
        if (testSpecArray.length >= 2) {
            this.mCalMinSpec = Integer.parseInt(testSpecArray[0]);
            this.mCalMaxSpec = Integer.parseInt(testSpecArray[1]);
        }
        displayCalSpec(this.mCalMinSpec, this.mCalMaxSpec);
    }

    private void getJigCheckType() {
        String testCase = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML(this.TEST_ID));
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "initFeature", "testCase : " + testCase);
        if (testCase.contains("HALL")) {
            this.mHallIcNumber = Integer.parseInt(testCase.substring(testCase.indexOf("HALL(") + "HALL:".length(), testCase.indexOf(")")).trim());
            this.mJigCheckType = JigType.HALL;
        } else if (testCase.contains("PROX")) {
            this.mSensorProximity = new SensorProximity(this);
            this.mJigCheckType = JigType.PROX;
        } else if (testCase.contains("VOLUME_UP")) {
            this.mJigCheckType = JigType.VOLUME_UP;
        } else {
            this.mIsEnabledHall_IC = Support.TestCase.getEnabled(Support.TestCase.HALL_IC_TEST);
            boolean contains = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML((byte) 17)).contains("PROX");
            this.mIsEnabledProximity = contains;
            if (this.mIsEnabledHall_IC) {
                this.mJigCheckType = JigType.HALL;
            } else if (contains) {
                this.mSensorProximity = new SensorProximity(this);
                this.mJigCheckType = JigType.PROX;
            } else {
                this.mJigCheckType = JigType.VOLUME_UP;
            }
        }
    }

    private void displayCalSpec(int mCalMinSpec2, int mCalMaxSpec2) {
        String dataFormat = String.format("%s : %d ~ %d", "Spec", Integer.valueOf(mCalMinSpec2), Integer.valueOf(mCalMaxSpec2));
        this.mTxtViewSpec.setText(dataFormat);
        FtUtil.log_d(this.CLASS_NAME, "displayCalSpec", dataFormat);
    }

    private void initUI() {
        this.mTxtViewSpec = (TextView) findViewById(R.id.felica_txt_spec);
        this.mTxtViewData = (TextView) findViewById(R.id.felica_txt_data);
        this.mTxtViewResult = (TextView) findViewById(R.id.felica_txt_result);
        Button button = (Button) findViewById(R.id.felica_btn_exit);
        this.mBtnExit = button;
        button.setOnClickListener(this);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        File felicaCalFile = new File(NFC_FELICA_CAL_FILE_PATH);
        if (felicaCalFile.exists()) {
            FtUtil.log_d(this.CLASS_NAME, "onResume", "Delete felicaCalFile");
            felicaCalFile.delete();
        }
        if (this.mJigCheckType == JigType.PROX) {
            int[] ProximitySensors = {1};
            SensorProximity sensorProximity = this.mSensorProximity;
            if (sensorProximity != null) {
                sensorProximity.SensorOn(this, ProximitySensors, 100);
            }
        }
        if (this.mJigCheckType != JigType.VOLUME_UP) {
            this.mFelicaHandler.sendEmptyMessageDelayed(0, 500);
        }
        showJigCheckPopup();
    }

    private void showJigCheckPopup() {
        if (this.mTestSequence == TestSequence.TEST_INIT) {
            this.mTestSequence = TestSequence.TEST_START;
            AlertDialog.Builder builder = new AlertDialog.Builder(this);
            builder.setTitle("Check Jig Cover");
            if (this.mJigCheckType == JigType.VOLUME_UP) {
                builder.setMessage("Please Close Jig Cover and Press Vol Up Key");
            } else {
                builder.setMessage("Please Close Jig Cover");
            }
            builder.setCancelable(false);
            builder.setNegativeButton("Exit", new DialogInterface.OnClickListener() {
                /* class com.sec.factory.app.ui.UINfcFelicaSelfCal.AnonymousClass2 */

                public void onClick(DialogInterface dialog, int id) {
                    UINfcFelicaSelfCal.this.finish();
                    dialog.cancel();
                }
            });
            AlertDialog create = builder.create();
            this.mJigCheckDialog = create;
            create.getWindow().setGravity(17);
            this.mJigCheckDialog.show();
            this.mJigCheckDialog.setOnKeyListener(new DialogInterface.OnKeyListener() {
                /* class com.sec.factory.app.ui.UINfcFelicaSelfCal.AnonymousClass3 */

                public boolean onKey(DialogInterface dialog, int keyCode, KeyEvent event) {
                    if (keyCode != 24 || event.getAction() != 0 || UINfcFelicaSelfCal.this.mJigCheckType != JigType.VOLUME_UP) {
                        return true;
                    }
                    FtUtil.log_d(UINfcFelicaSelfCal.this.CLASS_NAME, "onKeyDown", "VL_UP action press");
                    if (UINfcFelicaSelfCal.this.mJigCheckDialog == null || !UINfcFelicaSelfCal.this.mJigCheckDialog.isShowing()) {
                        return true;
                    }
                    UINfcFelicaSelfCal.this.mJigCheckDialog.dismiss();
                    return true;
                }
            });
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        SensorProximity sensorProximity;
        super.onPause();
        if (this.mJigCheckType == JigType.PROX && (sensorProximity = this.mSensorProximity) != null) {
            sensorProximity.SensorOff();
        }
        this.mTestSequence = TestSequence.TEST_STOP;
        if (this.mJigCheckType != JigType.VOLUME_UP) {
            this.mFelicaHandler.removeCallbacksAndMessages(null);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        AlertDialog alertDialog = this.mJigCheckDialog;
        if (alertDialog != null && alertDialog.isShowing()) {
            this.mJigCheckDialog.dismiss();
        }
        ModuleNfc.pollingUntilNfcIsOn(this);
        sendBroadcast(ModuleNfc.NfcFunctions.NFC_DISABLE_DISCOVERY.getNfcIntent());
        unregisterReceiver(this.mReceiver);
        super.onDestroy();
    }

    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.felica_btn_exit:
                String str = this.CLASS_NAME;
                FtUtil.log_d(str, "onClick", "[UTOPIA_NFC_FELICA_CAL]" + FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(FactoryTestManager.TEST_NFC_FELICA_SELF_CAL), "exit button (onClick method)"));
                finish();
                return;
            default:
                return;
        }
    }

    public void onWindowFocusChanged(boolean hasFocus) {
        super.onWindowFocusChanged(hasFocus);
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "onWindowFocusChanged", "focused : " + hasFocus);
        if (hasFocus) {
            testStart();
        }
    }

    private void testStart() {
        FtUtil.log_d(this.CLASS_NAME, "testStart", "");
        FtUtil.Sleep.sleep(1000);
        if (ModuleNfc.pollingUntilNfcIsOff(this)) {
            sendIntentForFelicaCal();
            this.mFelicaHandler.sendEmptyMessageDelayed(1, 5000);
            return;
        }
        displayTestResult(TestResult.FAIL);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void compareCalSpecAndCalData(String calData) {
        TestResult result;
        String[] calDataArray = calData.split(",");
        if (calDataArray.length < 2) {
            FtUtil.log_d(this.CLASS_NAME, "compareCalSpecAndCalData", "calData is wrong. so test result is fail.");
        } else if ("OK".equalsIgnoreCase(calDataArray[0])) {
            this.mCalData = Integer.parseInt(calDataArray[1]);
            displayCalData(calDataArray[1]);
            int i = this.mCalData;
            if (i < this.mCalMinSpec || i > this.mCalMaxSpec) {
                String str = this.CLASS_NAME;
                FtUtil.log_d(str, "compareCalSpecAndCalData", "[UTOPIA_NFC_FELICA_CAL]" + FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(FactoryTestManager.TEST_NFC_FELICA_SELF_CAL), "TEST FAIL - Spec Out"));
                result = TestResult.FAIL;
                displayTestResult(TestResult.FAIL);
            } else {
                String str2 = this.CLASS_NAME;
                FtUtil.log_d(str2, "compareCalSpecAndCalData", "[UTOPIA_NFC_FELICA_CAL]" + FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(FactoryTestManager.TEST_NFC_FELICA_SELF_CAL), "TEST PASS"));
                result = TestResult.PASS;
                displayTestResult(TestResult.PASS);
                this.mFelicaHandler.sendEmptyMessageDelayed(3, 1000);
            }
            saveCalDataOnFile(result, this.mCalData);
        } else {
            String str3 = this.CLASS_NAME;
            FtUtil.log_d(str3, "compareCalSpecAndCalData", "[UTOPIA_NFC_FELICA_CAL]" + FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(FactoryTestManager.TEST_NFC_FELICA_SELF_CAL), "TEST FAIL - Cal Fail"));
            FtUtil.log_d(this.CLASS_NAME, "compareCalSpecAndCalData", "calResult is fail");
        }
    }

    private void saveCalDataOnFile(TestResult result, int calData) {
        Support.Kernel.writeToPathNsync(NFC_FELICA_CAL_FILE_PATH, String.format("%s,%d", result == TestResult.PASS ? "OK" : "NG", Integer.valueOf(calData)));
    }

    private void displayCalData(String calData) {
        String dataFormat = String.format("%s : %s", "Data", calData);
        TextView textView = this.mTxtViewData;
        if (textView != null) {
            textView.setText(dataFormat);
        }
        FtUtil.log_d(this.CLASS_NAME, "displayCalData", dataFormat);
    }

    private void sendIntentForFelicaCal() {
        FtUtil.log_d(this.CLASS_NAME, "sendIntentForFelicaCal", "");
        sendBroadcast(ModuleNfc.getNfcTestCommandV3(3, 3, "0"));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean checkJigType() {
        if (this.mJigCheckType == JigType.HALL) {
            return checkHallWorking();
        }
        if (this.mJigCheckType == JigType.PROX) {
            return checkProxWorking();
        }
        return false;
    }

    private boolean checkHallWorking() {
        FtUtil.log_d(this.CLASS_NAME, "checkHallWorking", "");
        ModuleDevice.HallIC checkFolderState = null;
        int i = this.mHallIcNumber;
        if (i == 1) {
            checkFolderState = ModuleDevice.HallIC.getHallICState();
        } else if (i == 2) {
            checkFolderState = ModuleDevice.HallIC.getHallICState2();
        }
        if (checkFolderState != ModuleDevice.HallIC.FOLDER_STATE_CLOSE) {
            return false;
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "checkHallWorking", "checkResult = " + true);
        return true;
    }

    private boolean checkProxWorking() {
        FtUtil.log_d(this.CLASS_NAME, "checkProxWorking", "");
        if (!PROXIMITY_DETECT.equals(this.mProximitySensorMgrValue)) {
            return false;
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "checkProxWorking", "checkResult = " + true);
        return true;
    }

    @Override // com.sec.factory.sensors.SensorListener
    public void onSensorValueReceived(int mSensor, String value) {
        FtUtil.log_d(this.CLASS_NAME, "onSensorValueReceived", value);
        switch (mSensor) {
            case 1:
                String str = this.CLASS_NAME;
                FtUtil.log_d(str, "onSensorValueReceived", "ID_MANAGER_PROXIMITY : " + value);
                this.mProximitySensorMgrValue = value;
                return;
            default:
                return;
        }
    }
}
