package com.sec.factory.app.ui;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.os.Bundle;
import android.os.Handler;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;

public class UIOisGyro extends UIBase {
    private static final String TAG = "OIS GYRO";
    private boolean isPass = false;
    private AlertDialog mAlertDialog;
    private Handler mHandler = new Handler();
    private String[] mIntialTestResults;
    private String[] mSelfTestResults;
    private Runnable mShowResult;
    private String mTestName = FactoryTestManager.getItemName_RequestCode(98);
    private TextView txt_diff_x;
    private TextView txt_diff_y;
    private TextView txt_dps_x;
    private TextView txt_dps_y;
    private TextView txt_intial_x;
    private TextView txt_intial_y;
    private TextView txt_self_result;
    private TextView txtresult;

    public UIOisGyro() {
        super("UIOisGyro", 98);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.TEST_ID = getIntent().getIntExtra("testID", 98);
        setContentView(R.layout.ui_ois);
        init();
    }

    private void init() {
        this.txtresult = (TextView) findViewById(R.id.ois_result);
        this.txt_dps_x = (TextView) findViewById(R.id.dps_X);
        this.txt_dps_y = (TextView) findViewById(R.id.dps_Y);
        this.txt_intial_x = (TextView) findViewById(R.id.intial_X);
        this.txt_intial_y = (TextView) findViewById(R.id.intial_Y);
        this.txt_diff_x = (TextView) findViewById(R.id.diff_X);
        this.txt_diff_y = (TextView) findViewById(R.id.diff_Y);
        this.txt_self_result = (TextView) findViewById(R.id.self_check_result);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        Support.Kernel.write(Support.Kernel.GYRO_OIS_POWER, EgisFingerprint.MAJOR_VERSION);
        String intialData = Support.Kernel.read(Support.Kernel.GYRO_OIS_RAWDATA);
        String selfTestResult = Support.Kernel.read(Support.Kernel.GYRO_OIS_SELFTEST);
        this.txtresult.setVisibility(8);
        this.txtresult.setText("");
        if (selfTestResult == null || intialData == null) {
            String str = this.CLASS_NAME;
            FtUtil.log_d(str, "onResume", "selfTestResult : " + selfTestResult + ", intialData : " + intialData);
            return;
        }
        this.mSelfTestResults = selfTestResult.split(",");
        String[] split = intialData.split(",");
        this.mIntialTestResults = split;
        showTestResults(this.mSelfTestResults, split);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        super.onPause();
        Support.Kernel.write(Support.Kernel.GYRO_OIS_POWER, "0");
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        AlertDialog alertDialog = this.mAlertDialog;
        if (alertDialog != null) {
            alertDialog.dismiss();
            this.mAlertDialog = null;
        }
        super.onDestroy();
    }

    private synchronized void showTestResults(String[] results, String[] intial_results) {
        FtUtil.log_d(this.CLASS_NAME, "showTestResults", null);
        String dps_x = results[1].trim();
        String dps_y = results[2].trim();
        String intial_x = intial_results[0].trim();
        String intial_y = intial_results[1].trim();
        this.txt_dps_x.setText(dps_x);
        this.txt_dps_y.setText(dps_y);
        this.txt_intial_x.setText(intial_x);
        this.txt_intial_y.setText(intial_y);
        Double diff_x_value = Double.valueOf(Double.parseDouble(intial_x) - Double.parseDouble(dps_x));
        Double diff_y_value = Double.valueOf(Double.parseDouble(intial_y) - Double.parseDouble(dps_y));
        this.txt_diff_x.setText(String.format("%.3f", diff_x_value));
        this.txt_diff_y.setText(String.format("%.3f", diff_y_value));
        if (results[0].equals("0")) {
            this.txt_self_result.setText("PASS");
            this.txt_self_result.setTextColor(UiHallICTest.FONT_COLOR_PASS);
            this.isPass = true;
        } else {
            FtUtil.log_d(TAG, "showTestResults", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(this.TEST_ID), "Fail / Reason : selftest value from sysfs is not 0"));
            this.txt_self_result.setText("FAIL");
            this.txt_self_result.setTextColor(-65536);
        }
        this.txt_self_result.setVisibility(0);
        if (!this.isPass || !CheckSpecin(intial_results)) {
            FtUtil.log_d(TAG, "showTestResults", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(this.TEST_ID), "Fail / Reason : initial data from sysfs is spec out"));
            this.txtresult.setText("FAIL");
            this.txtresult.setTextColor(-65536);
            GyroTestFail();
        } else {
            this.txtresult.setText("PASS");
            this.txtresult.setTextColor(UiHallICTest.FONT_COLOR_PASS);
            this.mHandler.postDelayed(new Runnable() {
                /* class com.sec.factory.app.ui.UIOisGyro.AnonymousClass1 */

                public void run() {
                    UIOisGyro.this.setTestResult((byte) 80);
                    UIOisGyro.this.setResult(-1);
                    UIOisGyro.this.finish();
                }
            }, 1000);
        }
        this.txtresult.setVisibility(0);
    }

    private boolean CheckSpecin(String[] data) {
        Double mSpec_Max = Double.valueOf(Support.Spec.getDouble(Support.Spec.OIS_INITIAL_SPEC_MAX));
        Double mSpec_Min = Double.valueOf(Support.Spec.getDouble(Support.Spec.OIS_INITIAL_SPEC_MIN));
        Double[] measure = new Double[data.length];
        boolean isSpecin = true;
        if (data == null) {
            return false;
        }
        for (int i = 0; i < data.length; i++) {
            measure[i] = Double.valueOf(Double.parseDouble(data[i]));
        }
        for (int i2 = 0; i2 < measure.length; i2++) {
            if (measure[i2].doubleValue() < mSpec_Min.doubleValue() || measure[i2].doubleValue() > mSpec_Max.doubleValue()) {
                isSpecin = false;
            }
        }
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "CheckSpecin", "result : " + isSpecin);
        return isSpecin;
    }

    private void GyroTestFail() {
        FtUtil.log_w(this.CLASS_NAME, "GyroTestFail");
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        builder.setTitle("Gyro Test Fail");
        builder.setMessage("Do not move & Re –test");
        DialogInterface.OnDismissListener pl = new EmptyListener();
        AlertDialog create = builder.create();
        this.mAlertDialog = create;
        create.setOnDismissListener(pl);
        this.mAlertDialog.show();
    }

    public class EmptyListener implements DialogInterface.OnDismissListener {
        public EmptyListener() {
        }

        public void onDismiss(DialogInterface dialog) {
            if (!UIOisGyro.this.isFinishing()) {
                UIOisGyro.this.finish();
            }
        }
    }
}
