package com.sec.factory.app.ui;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.nfc.NfcAdapter;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.os.UEventObserver;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.io.File;
import java.util.ArrayList;
import java.util.Collections;

public class UIPDTest extends UIBase {
    private static final String ChipSetName = Support.Feature.getString(Support.Feature.CHIPSET_NAME);
    public static final int LAST_IDX_OF_TEST = 4;
    public static final int LOAD_CHARGE_TEST = 1;
    public static final int PD_CHARGE_TEST = 0;
    public static final int VCONN_CHARGE_TEST = 2;
    public static final int WATER_DETECT_TEST = 3;
    private final String CLASS_NAME = "UIPDTest";
    private final String LOG_TAG = "UTOPIA_PD";
    private boolean isSM6150;
    private boolean isSM7150;
    private PDTest[] mPDTest;
    private TestResultListener mTestResultListener;

    public interface TestResultListener {
        void onTestEnd(int i, boolean z);
    }

    public UIPDTest() {
        super("UIPDTest", 138);
        String str = ChipSetName;
        this.isSM6150 = "SM6150".equalsIgnoreCase(str);
        this.isSM7150 = "SM7150".equalsIgnoreCase(str);
        this.mTestResultListener = new TestResultListener() {
            /* class com.sec.factory.app.ui.UIPDTest.AnonymousClass1 */

            private int getNextTest() {
                for (int i = 0; i < UIPDTest.this.mPDTest.length; i++) {
                    if (UIPDTest.this.mPDTest[i].isEnable() && !UIPDTest.this.mPDTest[i].isPass()) {
                        FtUtil.log_i("UIPDTest", "getNextTest", "next test : " + i);
                        return i;
                    }
                }
                return -1;
            }

            @Override // com.sec.factory.app.ui.UIPDTest.TestResultListener
            public synchronized void onTestEnd(int TEST, boolean _bRes) {
                FtUtil.log_d("UIPDTest", "onTestEnd", TEST + " is " + _bRes);
                if (UIPDTest.this.isAllPass()) {
                    UIPDTest.this.setTestResult();
                    return;
                }
                UIPDTest.this.mPDTest[TEST].endTest();
                if (_bRes) {
                    UIPDTest.this.mPDTest[getNextTest()].startTest();
                }
            }
        };
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ui_pdtest);
        init();
    }

    public void init() {
        boolean waterEnable;
        FtUtil.log_i("UIPDTest", "init", "");
        setAtCmd(getIntent().getBooleanExtra("mIsAtCmd", false));
        PDTest[] pDTestArr = new PDTest[4];
        this.mPDTest = pDTestArr;
        pDTestArr[0] = new PDChargeTest(this, this.mTestResultListener);
        this.mPDTest[1] = new LoadChargeTest(this, this.mTestResultListener);
        this.mPDTest[2] = new VconnChargeTest(this, this.mTestResultListener);
        this.mPDTest[3] = new WaterDetectTest(this, this.mTestResultListener);
        String strTestcase = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML(138));
        FtUtil.log_i("UIPDTest", "init", "testcase : " + strTestcase);
        this.mPDTest[0].init(strTestcase.contains(Support.TestCase.PD_CHARGE));
        this.mPDTest[1].init(strTestcase.contains(Support.TestCase.LOAD_CHARGE));
        this.mPDTest[2].init(strTestcase.contains(Support.TestCase.VCONN_CHARGE));
        if ("unsupport".equals(Support.Kernel.read(Support.Kernel.WATER_TEST_TYPE))) {
            waterEnable = false;
        } else {
            waterEnable = strTestcase.contains(Support.TestCase.WATER_DETECT);
        }
        this.mPDTest[3].init(waterEnable);
        int nIdxNextTest = -1;
        int i = 0;
        while (true) {
            PDTest[] pDTestArr2 = this.mPDTest;
            if (i >= pDTestArr2.length) {
                break;
            } else if (pDTestArr2[i].isEnable()) {
                FtUtil.log_i("UIPDTest", "init", "next test : " + i);
                nIdxNextTest = i;
                break;
            } else {
                i++;
            }
        }
        if (nIdxNextTest != -1) {
            this.mPDTest[nIdxNextTest].startTest();
        } else {
            FtUtil.log_i("UIPDTest", "init", "nothing to test");
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        super.onDestroy();
        Support.Kernel.write(Support.Kernel.CCIC_CONTROL_OPTION, "2");
        Support.Kernel.write(Support.Kernel.CCIC_CONTROL_OPTION, "4");
        PDTest[] pDTestArr = this.mPDTest;
        if (pDTestArr[0] != null) {
            pDTestArr[0].removeHandleMessage();
        }
        NfcAdapter nfc = NfcAdapter.getDefaultAdapter(getApplicationContext());
        if (nfc != null && nfc.isEnabled()) {
            Intent intent = new Intent("com.samsung.android.nfc.test.action.REQUEST");
            intent.putExtra("com.samsung.android.nfc.test.extra.ID", 3);
            sendBroadcast(intent);
            FtUtil.log_d("UIPDTest", "when screen off / on. NFC RF discovery was enabled. so must be disabled before exit here");
        }
        FtUtil.log_d("UTOPIA_PD", "END", "");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setTestResult() {
        FtUtil.log_e("UIPDTest", "setTestResult", "pass!");
        setTestResult((byte) 80);
        if (FactoryTestManager.getEnable(70) && FactoryTestManager.getItemResult(FactoryTestManager.getItemPosition_ID(70)) == 80) {
            setTestResultWithoutNV(78, (byte) 80);
        }
        new Handler().postDelayed(new Runnable() {
            /* class com.sec.factory.app.ui.UIPDTest.AnonymousClass2 */

            public void run() {
                FtUtil.log_d("UIPDTest", "run", "finish");
                UIPDTest.this.finish();
            }
        }, 3000);
    }

    public boolean isAllPass() {
        int i = 0;
        while (true) {
            PDTest[] pDTestArr = this.mPDTest;
            if (i >= pDTestArr.length) {
                return true;
            }
            if (!pDTestArr[i].isEnable() || this.mPDTest[i].isPass()) {
                i++;
            } else {
                FtUtil.log_i("UIPDTest", "isAllPass", i + "th test is not pass");
                return false;
            }
        }
    }

    /* access modifiers changed from: private */
    public abstract class PDTest {
        private final String CLASS_NAME = "PDTest";
        protected Activity mActivity;
        protected Context mContext;
        protected boolean mIsEnable;
        protected TestResultListener mTestResultListener;
        protected boolean mbTestResult;

        public abstract void endTest();

        public abstract void init(boolean z);

        public abstract void startTest();

        public PDTest(Activity _activity, TestResultListener _testResultListener) {
            FtUtil.log_i("PDTest", "PDTest", "");
            this.mActivity = _activity;
            this.mIsEnable = false;
            this.mbTestResult = false;
            this.mTestResultListener = _testResultListener;
        }

        /* access modifiers changed from: protected */
        public boolean isPass() {
            return this.mbTestResult;
        }

        /* access modifiers changed from: protected */
        public boolean isEnable() {
            return this.mIsEnable;
        }

        public void removeHandleMessage() {
        }

        public void setOnTestResultListener(TestResultListener testResultListener) {
            this.mTestResultListener = testResultListener;
        }
    }

    /* access modifiers changed from: private */
    public class PDChargeTest extends PDTest {
        private static final String ACTION_RECEIVE_LOAD_CURRENT = "com.sec.samsung.ACTION_RECEIVE_LOAD_CURRENT";
        private static final int MSG_PDCHARGE_CHECK_LCD_ON = 4;
        private static final int MSG_PDCHARGE_SELFTEST_START = 2;
        private static final int MSG_PDCHARGE_TEST_START = 1;
        private final int AVER_PD_CNT = 5;
        private final String CLASS_NAME = "PDChargeTest";
        private final String NG = "NG";
        private final String OK = "OK";
        private boolean isPDTested = false;
        private int mAvgPDCurrent = 0;
        private BroadcastReceiver mBroadcastReceiver;
        private int mCntLCDOn;
        private int mCurrentCount;
        private Handler mHandler;
        private final boolean mIsChargeModeDual;
        private ModuleDevice mModuleDevice;
        private ModulePower mModulePower;
        private ArrayList<Integer> mPDCurrentList = new ArrayList<>();
        private int mPDCurrentSpecMax;
        private int mPDCurrentSpecMin;
        private int mPDSelftestDelay;
        String[] mStrPDVoltSpecs = null;
        private String mTestCase;
        private int mTestCount;
        private TextView tvPDCheckResult;
        private TextView tvPDCurrent;
        private TextView tvPDMode;
        private TextView tvPDResult;
        private TextView tvPDSpecMax;
        private TextView tvPDSpecMin;
        private TextView tvPDVoltage;
        private TextView tvPDVoltageSpec;

        public PDChargeTest(Activity _activity, TestResultListener _testResultListener) {
            super(_activity, _testResultListener);
            String testCase = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML(138));
            this.mTestCase = testCase;
            this.mIsChargeModeDual = testCase.contains("dual");
            this.mBroadcastReceiver = new BroadcastReceiver() {
                /* class com.sec.factory.app.ui.UIPDTest.PDChargeTest.AnonymousClass1 */

                public void onReceive(Context context, Intent intent) {
                    String action = intent.getAction();
                    FtUtil.log_d("PDChargeTest", "mBroadcastReceiver.onReceive", "action=" + action);
                    if (action.equalsIgnoreCase("android.intent.action.BATTERY_CHANGED")) {
                        int plugged = intent.getIntExtra("plugged", 0);
                        FtUtil.log_d("PDChargeTest", "mBroadcastReceiver.onReceive", "plugged : " + plugged + ", isPDTested : " + PDChargeTest.this.isPDTested);
                        if (!PDChargeTest.this.isPDTested && plugged == 1) {
                            FtUtil.log_d("PDChargeTest", "Battery State: " + plugged);
                            PDChargeTest.this.isPDTested = true;
                            FtUtil.log_d("PDChargeTest", "onReceive", "delay for 3000ms to read VBUS for PD Charge");
                            PDChargeTest.this.mHandler.sendEmptyMessageDelayed(1, 3000);
                        }
                    }
                }
            };
            this.mHandler = new Handler() {
                /* class com.sec.factory.app.ui.UIPDTest.PDChargeTest.AnonymousClass2 */

                public void handleMessage(Message msg) {
                    switch (msg.what) {
                        case 1:
                            FtUtil.log_d("PDChargeTest", "PD_Handler", "MSG_PDCHARGE_TEST_START");
                            PDChargeTest.this.readPDChargeData();
                            return;
                        case 2:
                            FtUtil.log_d("PDChargeTest", "PD_Handler", "MSG_PDCHARGE_SELFTEST_START");
                            PDChargeTest.this.readPDCurrent();
                            return;
                        case 3:
                        default:
                            return;
                        case 4:
                            FtUtil.log_d("PDChargeTest", "PD_Handler", "MSG_PDCHARGE_CHECK_LCD_ON");
                            PDChargeTest.this.checkPDLCDOn();
                            return;
                    }
                }
            };
            this.mCntLCDOn = 0;
            this.mTestCount = 0;
            this.mCurrentCount = 0;
            FtUtil.log_d("PDChargeTest", "PDChargeTest", "");
        }

        public void checkPDLCDOn() {
            int i = this.mCntLCDOn;
            this.mCntLCDOn = i + 1;
            if (i == 5) {
                FtUtil.log_d("PDChargeTest", "handleMessage : LCD is not on state during 1 second.");
                this.mCntLCDOn = 0;
                this.mHandler.sendEmptyMessageDelayed(2, 400);
            } else if (this.mModulePower.isScreenOn()) {
                turnLcdOffForCurrentCheck();
                this.mHandler.sendEmptyMessageDelayed(2, (long) this.mPDSelftestDelay);
                this.mCntLCDOn = 0;
            } else {
                this.mHandler.sendEmptyMessageDelayed(4, 200);
            }
        }

        private void turnLcdOffForCurrentCheck() {
            FtUtil.log_i("PDChargeTest", "turnLcdOffForCurrentCheck", "Turn LCD Off");
            this.mModulePower.doPartialWakeLock(true);
            this.mModulePower.doWakeLock(false);
            if (Support.Feature.getBoolean(Support.Feature.NEED_LPA_MODE_SET, true)) {
                this.mModuleDevice.setLPAmode(ModuleDevice.LPA_MODE_DISABLE);
            }
            this.mModulePower.gotosleep();
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void readPDChargeData() {
            String strMultiChargeMode = Support.Kernel.read(Support.Kernel.SEC_MULTI_CHARGER_MODE);
            this.tvPDMode.setText(strMultiChargeMode);
            String strPDVoltage = Support.Kernel.read(Support.Kernel.SEC_CHARGING_VOLTAGE);
            this.tvPDVoltage.setText(strPDVoltage);
            String strPSReady = Support.Kernel.read(Support.Kernel.PD_CHECK_PS_READY);
            FtUtil.log_i("PDChargeTest", "readPDChargeData", "MultiChargeMode : " + strMultiChargeMode + " PDVoltage : " + strPDVoltage + " PS Ready : " + strPSReady);
            boolean isVoltageSpecIn = false;
            if (Support.Feature.getBoolean(Support.Feature.SUPPORT_VOLTAGE_CHECK_IN_PD_CHARGING_TEST)) {
                int i = 0;
                while (true) {
                    String[] strArr = this.mStrPDVoltSpecs;
                    if (i >= strArr.length) {
                        break;
                    }
                    if (strArr[i].equalsIgnoreCase(strPDVoltage)) {
                        isVoltageSpecIn = true;
                    }
                    i++;
                }
            } else {
                FtUtil.log_i("PDChargeTest", "readPDChargeData", "Skip Check Voltage Spec");
                isVoltageSpecIn = true;
            }
            boolean isPDCheckPSReady = EgisFingerprint.MAJOR_VERSION.equalsIgnoreCase(strPSReady);
            boolean isChargeMode = true;
            if (this.mIsChargeModeDual) {
                isChargeMode = "dual".equalsIgnoreCase(strMultiChargeMode);
            }
            int i2 = this.mTestCount + 1;
            this.mTestCount = i2;
            if (i2 > 20) {
                this.tvPDCheckResult.setTextColor(-65536);
                this.tvPDCheckResult.setText("NG");
                this.tvPDResult.setTextColor(-65536);
                this.tvPDResult.setText("F");
                this.mTestResultListener.onTestEnd(0, false);
                String itemName_RequestCode = FactoryTestManager.getItemName_RequestCode(138);
                FtUtil.log_d("PDChargeTest", "readPDChargeData", FtUtil.setMspSeqMessage(1, itemName_RequestCode, "FAIL - isVoltageSpecIn : " + isVoltageSpecIn + " isPDCheckPSReady : " + isPDCheckPSReady + " isChargeMode : " + isChargeMode));
                UIPDTest.this.setTestResultFailCase(138);
            } else if (!isPDCheckPSReady || !isChargeMode || !isVoltageSpecIn) {
                FtUtil.log_i("PDChargeTest", "readPDChargeData", "/ delay 0.5 sec - TestCount : " + this.mTestCount);
                this.mHandler.sendEmptyMessageDelayed(1, 500);
            } else {
                this.tvPDCheckResult.setText("OK");
                this.tvPDCheckResult.setTextColor(UiHallICTest.FONT_COLOR_PASS);
                FtUtil.log_i("PDChargeTest", "readPDChargeData", "pass");
                FtUtil.log_d("UTOPIA_PD", "PD Charge", "readData PASS / Current Wait");
                this.mHandler.sendEmptyMessageDelayed(4, 2000);
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void readPDCurrent() {
            int i = this.mCurrentCount + 1;
            this.mCurrentCount = i;
            if (i <= 5) {
                this.mPDCurrentList.add(Integer.valueOf(Integer.parseInt(Support.Kernel.read(Support.Kernel.HV_CHARGE_CURRENT)) / 1000));
                StringBuilder sb = new StringBuilder();
                sb.append("Charge Current : ");
                ArrayList<Integer> arrayList = this.mPDCurrentList;
                sb.append(arrayList.get(arrayList.size() - 1));
                sb.append(" / mCurrentCount : ");
                sb.append(this.mCurrentCount);
                FtUtil.log_i("PDChargeTest", "readcurrent", sb.toString());
                StringBuilder sb2 = new StringBuilder();
                sb2.append("CurrentCount(");
                sb2.append(this.mCurrentCount);
                sb2.append(") : ");
                ArrayList<Integer> arrayList2 = this.mPDCurrentList;
                sb2.append(arrayList2.get(arrayList2.size() - 1));
                FtUtil.log_d("UTOPIA_PD", "PD Charge", sb2.toString());
                this.mHandler.sendEmptyMessageDelayed(2, 400);
                return;
            }
            this.mCurrentCount = 0;
            averagePDCurrent();
        }

        private void averagePDCurrent() {
            FtUtil.log_d("PDChargeTest", "averagePDCurrent", "");
            Collections.sort(this.mPDCurrentList);
            ArrayList<Integer> arrayList = this.mPDCurrentList;
            arrayList.remove(arrayList.size() - 1);
            this.mPDCurrentList.remove(0);
            Integer sum = 0;
            for (int i = 0; i < this.mPDCurrentList.size(); i++) {
                sum = Integer.valueOf(sum.intValue() + this.mPDCurrentList.get(i).intValue());
            }
            this.mAvgPDCurrent = (int) (((float) sum.intValue()) / 3.0f);
            this.mPDCurrentList.clear();
            TextView textView = this.tvPDCurrent;
            textView.setText("" + this.mAvgPDCurrent);
            String itemName_RequestCode = FactoryTestManager.getItemName_RequestCode(138);
            FtUtil.log_d("PDChargeTest", "averagePDCurrent", FtUtil.setMspSeqMessage(1, itemName_RequestCode, "PDCurrentSpecMin : " + this.mPDCurrentSpecMin));
            String itemName_RequestCode2 = FactoryTestManager.getItemName_RequestCode(138);
            FtUtil.log_d("PDChargeTest", "averagePDCurrent", FtUtil.setMspSeqMessage(1, itemName_RequestCode2, "PDCurrentSpecMax : " + this.mPDCurrentSpecMax));
            String itemName_RequestCode3 = FactoryTestManager.getItemName_RequestCode(138);
            FtUtil.log_d("PDChargeTest", "averagePDCurrent", FtUtil.setMspSeqMessage(1, itemName_RequestCode3, "Averege Current : " + this.mAvgPDCurrent));
            checkCurrent();
        }

        private void checkCurrent() {
            this.mModulePower.doWakeLock(true);
            File dataAvgFile = new File("data/log/PDChargeData.log");
            Support.Kernel.writeToPathNsync(dataAvgFile.getPath(), Integer.toString(this.mAvgPDCurrent));
            FtUtil.log_i("PDChargeTest", "readFromPath", "PDChargeData.log : " + Support.Kernel.readFromPath(dataAvgFile.getPath(), true));
            FtUtil.log_d("UTOPIA_PD", "PD Charge", "Current : " + this.mAvgPDCurrent + "(spec:" + this.mPDCurrentSpecMin + "~" + this.mPDCurrentSpecMax + ") / PDCheckResult:" + this.tvPDCheckResult.getText().toString());
            int i = this.mAvgPDCurrent;
            if (i < this.mPDCurrentSpecMin || i > this.mPDCurrentSpecMax || !"OK".equals(this.tvPDCheckResult.getText().toString())) {
                FtUtil.log_d("PDChargeTest", "checkCurrent", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(138), "UTOPIA_PD] FAIL - PD Charge current Spec out"));
                this.tvPDResult.setTextColor(-65536);
                this.tvPDResult.setText("F");
                this.mTestResultListener.onTestEnd(0, false);
                UIPDTest.this.setTestResultFailCase(138);
                return;
            }
            FtUtil.log_d("PDChargeTest", "checkCurrent", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(138), "PASS - PD Charge current Spec in"));
            FtUtil.log_d("UTOPIA_PD", "PD Charge", "PASS");
            this.tvPDResult.setTextColor(UiHallICTest.FONT_COLOR_PASS);
            this.tvPDResult.setText("P");
            this.mbTestResult = true;
            this.mHandler.postDelayed(new Runnable() {
                /* class com.sec.factory.app.ui.UIPDTest.PDChargeTest.AnonymousClass3 */

                public void run() {
                    PDChargeTest.this.mTestResultListener.onTestEnd(0, true);
                }
            }, 1000);
        }

        @Override // com.sec.factory.app.ui.UIPDTest.PDTest
        public void init(boolean enable) {
            this.mIsEnable = enable;
            FtUtil.log_d("PDChargeTest", "init", "" + enable);
            if (enable) {
                this.mModuleDevice = ModuleDevice.instance(this.mActivity);
                this.mModulePower = ModulePower.instance(this.mActivity);
                this.tvPDVoltageSpec = (TextView) this.mActivity.findViewById(R.id.tv_pdchargetest_voltage_spec);
                this.tvPDMode = (TextView) this.mActivity.findViewById(R.id.tv_pdchargetest_mode);
                this.tvPDVoltage = (TextView) this.mActivity.findViewById(R.id.tv_pdchargetest_voltage);
                this.tvPDCheckResult = (TextView) this.mActivity.findViewById(R.id.tv_pdchargetest_check_result);
                this.tvPDSpecMin = (TextView) this.mActivity.findViewById(R.id.tv_pdchargetest_spec_min);
                this.mPDCurrentSpecMin = Support.Spec.getInt(Support.Spec.PD_CHARGE_SPEC_MIN);
                TextView textView = this.tvPDSpecMin;
                textView.setText("" + this.mPDCurrentSpecMin);
                this.tvPDSpecMax = (TextView) this.mActivity.findViewById(R.id.tv_pdchargetest_spec_max);
                this.mPDCurrentSpecMax = Support.Spec.getInt(Support.Spec.PD_CHARGE_SPEC_MAX);
                TextView textView2 = this.tvPDSpecMax;
                textView2.setText("" + this.mPDCurrentSpecMax);
                this.tvPDCurrent = (TextView) this.mActivity.findViewById(R.id.tv_pdchargetest_current);
                this.tvPDResult = (TextView) this.mActivity.findViewById(R.id.tv_pdchargetest_result);
                this.mPDSelftestDelay = Support.Spec.getInt(Support.Spec.PD_CHARGE_SELFTEST_DELAY);
                String strPDVoltageSpec = Support.Spec.getString(Support.Spec.PD_VOLTAGE);
                TextView textView3 = this.tvPDVoltageSpec;
                textView3.setText("(" + strPDVoltageSpec + ")");
                this.mStrPDVoltSpecs = strPDVoltageSpec.split(",");
                for (int i = 0; i < this.mStrPDVoltSpecs.length; i++) {
                    FtUtil.log_i("PDChargeTest", "init", "support voltage : " + this.mStrPDVoltSpecs[i]);
                }
                return;
            }
            FtUtil.log_e("PDChargeTest", "init", "nothing to do");
            this.mActivity.findViewById(R.id.v_pdchargetest_line).setVisibility(8);
            ((LinearLayout) this.mActivity.findViewById(R.id.ll_pd_pdcharge)).setVisibility(8);
        }

        @Override // com.sec.factory.app.ui.UIPDTest.PDTest
        public void startTest() {
            FtUtil.log_i("PDChargeTest", "startTest", "");
            IntentFilter intentFilter = new IntentFilter();
            intentFilter.addAction("android.intent.action.BATTERY_CHANGED");
            this.mActivity.registerReceiver(this.mBroadcastReceiver, intentFilter);
            FtUtil.log_d("UTOPIA_PD", "PD Charge", "START / action Wait");
            if (Support.Kernel.isExistFilePath(Support.Kernel.getFilePath(Support.Kernel.USB_CTRL))) {
                Support.Kernel.writeToPath(Support.Kernel.getFilePath(Support.Kernel.USB_CTRL), "0");
            }
            if (Support.Feature.getBoolean(Support.Feature.SUPPORT_FACTORY_CHARGING_TEST)) {
                Support.Kernel.write(Support.Kernel.FACTORY_CHARGING_TEST, EgisFingerprint.MAJOR_VERSION);
            }
        }

        @Override // com.sec.factory.app.ui.UIPDTest.PDTest
        public void endTest() {
            FtUtil.log_e("PDChargeTest", "endTest", "");
            this.mActivity.unregisterReceiver(this.mBroadcastReceiver);
            this.mCurrentCount = 0;
            this.mModulePower.doPartialWakeLock(false);
            this.mModulePower.doWakeLock(false);
            this.mHandler.removeMessages(1);
            this.mHandler.removeMessages(2);
            this.mHandler.removeMessages(4);
            if (Support.Feature.getBoolean(Support.Feature.SUPPORT_FACTORY_CHARGING_TEST)) {
                Support.Kernel.write(Support.Kernel.FACTORY_CHARGING_TEST, "0");
            }
        }

        @Override // com.sec.factory.app.ui.UIPDTest.PDTest
        public void removeHandleMessage() {
            this.mHandler.removeMessages(1);
            this.mHandler.removeMessages(2);
            this.mHandler.removeMessages(4);
        }
    }

    /* access modifiers changed from: private */
    public class LoadChargeTest extends PDTest {
        private static final String ACTION_RECEIVE_LOAD_CURRENT = "com.sec.samsung.ACTION_RECEIVE_LOAD_CURRENT";
        private final String CLASS_NAME = "LoadChargeTest";
        private BroadcastReceiver mBroadcastReceiver = new BroadcastReceiver() {
            /* class com.sec.factory.app.ui.UIPDTest.LoadChargeTest.AnonymousClass1 */

            public void onReceive(Context context, Intent intent) {
                String action = intent.getAction();
                FtUtil.log_d("LoadChargeTest", "mBroadcastReceiver.onReceive", "action=" + action);
                if (action.equalsIgnoreCase(LoadChargeTest.ACTION_RECEIVE_LOAD_CURRENT)) {
                    String strLoadCurrent = intent.getStringExtra("LOAD_CURRENT");
                    FtUtil.log_i("LoadChargeTest", "onReceive", "ACTION_RECEIVE_LOAD_CURRENT, " + strLoadCurrent);
                    LoadChargeTest.this.checkLoadCurrent(strLoadCurrent);
                }
            }
        };
        private int mLoadCurrentSpecMax;
        private int mLoadCurrentSpecMin;
        private TextView tvLoadCurrent;
        private TextView tvLoadResult;
        private TextView tvLoadSpecMax;
        private TextView tvLoadSpecMin;
        private View vLoadchargetestLine;

        public LoadChargeTest(Activity _activity, TestResultListener _testResultListener) {
            super(_activity, _testResultListener);
            FtUtil.log_d("LoadChargeTest", "LoadChargeTest", "");
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void checkLoadCurrent(String _strLoadCurrent) {
            FtUtil.log_e("LoadChargeTest", "checkLoadCurrent", " Load Current : " + _strLoadCurrent);
            this.tvLoadCurrent.setText(_strLoadCurrent);
            FtUtil.log_d("UTOPIA_PD", "LoadCharge", "Current : " + _strLoadCurrent + "(spec:" + this.mLoadCurrentSpecMin + "~" + this.mLoadCurrentSpecMax + ")");
            int nLoadCurrent = Integer.parseInt(_strLoadCurrent);
            if (nLoadCurrent < this.mLoadCurrentSpecMin || nLoadCurrent > this.mLoadCurrentSpecMax) {
                FtUtil.log_d("UTOPIA_PD", "LoadCharge", "FAIL");
                this.tvLoadResult.setText("F");
                this.tvLoadResult.setTextColor(-65536);
                this.mbTestResult = false;
                this.mTestResultListener.onTestEnd(1, false);
                return;
            }
            FtUtil.log_d("UTOPIA_PD", "LoadCharge", "PASS");
            this.tvLoadResult.setText("P");
            this.tvLoadResult.setTextColor(UiHallICTest.FONT_COLOR_PASS);
            this.mbTestResult = true;
            this.mTestResultListener.onTestEnd(1, true);
        }

        @Override // com.sec.factory.app.ui.UIPDTest.PDTest
        public void init(boolean enable) {
            this.mIsEnable = enable;
            FtUtil.log_d("LoadChargeTest", "init", "" + enable);
            if (enable) {
                this.tvLoadSpecMin = (TextView) this.mActivity.findViewById(R.id.tv_loadchargetest_spec_min);
                this.mLoadCurrentSpecMin = Support.Spec.getInt(Support.Spec.LOAD_CHARGE_SPEC_MIN);
                TextView textView = this.tvLoadSpecMin;
                textView.setText("" + this.mLoadCurrentSpecMin);
                this.tvLoadSpecMax = (TextView) this.mActivity.findViewById(R.id.tv_loadchargetest_spec_max);
                this.mLoadCurrentSpecMax = Support.Spec.getInt(Support.Spec.LOAD_CHARGE_SPEC_MAX);
                TextView textView2 = this.tvLoadSpecMax;
                textView2.setText("" + this.mLoadCurrentSpecMax);
                this.tvLoadCurrent = (TextView) this.mActivity.findViewById(R.id.tv_loadchargetest_current);
                this.tvLoadResult = (TextView) this.mActivity.findViewById(R.id.tv_loadchargetest_result);
                return;
            }
            this.mActivity.findViewById(R.id.v_loadchargetest_line).setVisibility(8);
            ((LinearLayout) this.mActivity.findViewById(R.id.ll_pd_loadcharge)).setVisibility(8);
        }

        @Override // com.sec.factory.app.ui.UIPDTest.PDTest
        public void startTest() {
            FtUtil.log_d("LoadChargeTest", "startTest", "");
            IntentFilter intentFilter = new IntentFilter();
            intentFilter.addAction(ACTION_RECEIVE_LOAD_CURRENT);
            this.mActivity.registerReceiver(this.mBroadcastReceiver, intentFilter);
            FtUtil.log_d("UTOPIA_PD", "LoadCharge", "START / action Wait");
        }

        @Override // com.sec.factory.app.ui.UIPDTest.PDTest
        public void endTest() {
            FtUtil.log_d("LoadChargeTest", "endTest", "");
            this.mActivity.unregisterReceiver(this.mBroadcastReceiver);
        }
    }

    /* access modifiers changed from: private */
    public class VconnChargeTest extends PDTest {
        private static final String ACTION_RECEIVE_VCONN_CURRENT = "com.sec.samsung.ACTION_RECEIVE_VCONN_CURRENT";
        private final String CLASS_NAME = "VconnChargeTest";
        private BroadcastReceiver mBroadcastReceiver = new BroadcastReceiver() {
            /* class com.sec.factory.app.ui.UIPDTest.VconnChargeTest.AnonymousClass1 */

            public void onReceive(Context context, Intent intent) {
                String action = intent.getAction();
                FtUtil.log_d("VconnChargeTest", "mBroadcastReceiver.onReceive", "action=" + action);
                if (action.equalsIgnoreCase(VconnChargeTest.ACTION_RECEIVE_VCONN_CURRENT)) {
                    FtUtil.log_i("VconnChargeTest", "onReceive", "ACTION_RECEIVE_VCONN_CURRENT");
                    VconnChargeTest.this.checkVCONNCurrent(intent.getStringExtra("VCONN_CURRENT"));
                }
            }
        };
        private int mVCONNCurrentSpecMax;
        private int mVCONNCurrentSpecMin;
        private TextView tvVCONNCurrent;
        private TextView tvVCONNResult;
        private TextView tvVCONNSpecMax;
        private TextView tvVCONNSpecMin;

        public VconnChargeTest(Activity _activity, TestResultListener _testResultListener) {
            super(_activity, _testResultListener);
            FtUtil.log_d("VconnChargeTest", "VconnChargeTest", "");
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void checkVCONNCurrent(String _strVCONNCurrent) {
            FtUtil.log_e("VconnChargeTest", "checkVCONNCurrent", " Vconn Current : " + _strVCONNCurrent);
            FtUtil.log_e("VconnChargeTest", "checkVCONNCurrent", "min : " + this.mVCONNCurrentSpecMin + " max : " + this.mVCONNCurrentSpecMax);
            this.tvVCONNCurrent.setText(_strVCONNCurrent);
            FtUtil.log_d("UTOPIA_PD", "VconnCharge", "Current : " + _strVCONNCurrent + "(spec:" + this.mVCONNCurrentSpecMin + "~" + this.mVCONNCurrentSpecMax + ")");
            int nVCONNCurrent = Integer.parseInt(_strVCONNCurrent);
            if (nVCONNCurrent < this.mVCONNCurrentSpecMin || nVCONNCurrent > this.mVCONNCurrentSpecMax) {
                FtUtil.log_d("VconnChargeTest", "checkVCONNCurrent", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(138), "UTOPIA_PD] FAIL - VCONN Test Current Spec out"));
                FtUtil.log_d("UTOPIA_PD", "VconnCharge", "FAIL");
                this.tvVCONNResult.setText("F");
                this.tvVCONNResult.setTextColor(-65536);
                this.mbTestResult = false;
                this.mTestResultListener.onTestEnd(2, false);
                UIPDTest.this.setTestResultFailCase(138);
                return;
            }
            FtUtil.log_d("VconnChargeTest", "checkVCONNCurrent", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(138), "PASS - VCONN Test Current Spec in"));
            FtUtil.log_d("UTOPIA_PD", "VconnCharge", "PASS");
            this.tvVCONNResult.setText("P");
            this.tvVCONNResult.setTextColor(UiHallICTest.FONT_COLOR_PASS);
            this.mbTestResult = true;
            this.mTestResultListener.onTestEnd(2, true);
        }

        @Override // com.sec.factory.app.ui.UIPDTest.PDTest
        public void init(boolean enable) {
            this.mIsEnable = enable;
            FtUtil.log_d("VconnChargeTest", "init", "" + enable);
            if (enable) {
                this.tvVCONNSpecMin = (TextView) this.mActivity.findViewById(R.id.tv_vconntest_spec_min);
                this.mVCONNCurrentSpecMin = Support.Spec.getInt(Support.Spec.VCONN_SPEC_MIN);
                TextView textView = this.tvVCONNSpecMin;
                textView.setText("" + this.mVCONNCurrentSpecMin);
                this.tvVCONNSpecMax = (TextView) this.mActivity.findViewById(R.id.tv_vconntest_spec_max);
                this.mVCONNCurrentSpecMax = Support.Spec.getInt(Support.Spec.VCONN_SPEC_MAX);
                TextView textView2 = this.tvVCONNSpecMax;
                textView2.setText("" + this.mVCONNCurrentSpecMax);
                this.tvVCONNCurrent = (TextView) this.mActivity.findViewById(R.id.tv_vconntest_current);
                this.tvVCONNResult = (TextView) this.mActivity.findViewById(R.id.tv_vconntest_result);
                return;
            }
            this.mActivity.findViewById(R.id.v_vconnchargetest_line).setVisibility(8);
            ((LinearLayout) this.mActivity.findViewById(R.id.ll_pd_vconncharge)).setVisibility(8);
        }

        @Override // com.sec.factory.app.ui.UIPDTest.PDTest
        public void startTest() {
            FtUtil.log_d("VconnChargeTest", "startTest", "");
            Support.Kernel.write(Support.Kernel.CCIC_CONTROL_OPTION, EgisFingerprint.MAJOR_VERSION);
            IntentFilter intentFilter = new IntentFilter();
            intentFilter.addAction(ACTION_RECEIVE_VCONN_CURRENT);
            this.mActivity.registerReceiver(this.mBroadcastReceiver, intentFilter);
            FtUtil.log_d("UTOPIA_PD", "VconnCharge", "START / action Wait");
        }

        @Override // com.sec.factory.app.ui.UIPDTest.PDTest
        public void endTest() {
            FtUtil.log_d("VconnChargeTest", "endTest", "");
            Support.Kernel.write(Support.Kernel.CCIC_CONTROL_OPTION, "2");
            this.mActivity.unregisterReceiver(this.mBroadcastReceiver);
        }
    }

    /* access modifiers changed from: private */
    public class WaterDetectTest extends PDTest {
        private static final int MSG_WATERDETECT_ADC_CHECK = 1;
        private static final int MSG_WATERDETECT_TEST_DONE = 2;
        private static final String UEVENT_CCIC_WATER = "CCIC=WATER";
        private final String CLASS_NAME = "WaterDetectTest";
        private Handler mHandler = new Handler() {
            /* class com.sec.factory.app.ui.UIPDTest.WaterDetectTest.AnonymousClass1 */
            private int readCount = 0;

            public void handleMessage(Message msg) {
                switch (msg.what) {
                    case 1:
                        FtUtil.log_d("WaterDetectTest", "Water_Handler", "MSG_WATERDETECT_ADC_CHECK");
                        String adc = Support.Kernel.read(Support.Kernel.WATER_INT_DETECT);
                        FtUtil.log_d("UTOPIA_PD", "WaterDetect", "ADC : " + adc);
                        if ("0".equals(adc)) {
                            WaterDetectTest.this.checkResultWaterDetectTest(true);
                            return;
                        }
                        int i = this.readCount;
                        if (i < 5) {
                            this.readCount = i + 1;
                            WaterDetectTest.this.mHandler.sendEmptyMessageDelayed(1, 1000);
                            return;
                        }
                        WaterDetectTest.this.checkResultWaterDetectTest(false);
                        return;
                    case 2:
                        FtUtil.log_d("WaterDetectTest", "Water_Handler", "MSG_WATERDETECT_TEST_DONE");
                        WaterDetectTest.this.mTestResultListener.onTestEnd(3, WaterDetectTest.this.mbTestResult);
                        return;
                    default:
                        return;
                }
            }
        };
        private String mSupportSysfs = null;
        private final UEventObserver mWaterDetectUEventObserver = new UEventObserver() {
            /* class com.sec.factory.app.ui.UIPDTest.WaterDetectTest.AnonymousClass2 */

            public void onUEvent(UEventObserver.UEvent event) {
                String value = event.get(WaterDetectTest.UEVENT_CCIC_WATER);
                FtUtil.log_i("WaterDetectTest", "get UEvent : " + value);
                WaterDetectTest.this.checkResultWaterDetectTest(true);
            }
        };
        private TextView tvWaterDetectResult;
        private TextView tvWaterDetectType;

        public WaterDetectTest(Activity _activity, TestResultListener _testResultListener) {
            super(_activity, _testResultListener);
            FtUtil.log_d("WaterDetectTest", "WaterDetectTest", "");
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void checkResultWaterDetectTest(boolean result) {
            if (result) {
                FtUtil.log_d("UTOPIA_PD", "WaterDetect", "PASS");
                this.tvWaterDetectResult.setText("P");
                this.tvWaterDetectResult.setTextColor(UiHallICTest.FONT_COLOR_PASS);
                this.mbTestResult = true;
            } else {
                FtUtil.log_d("WaterDetectTest", "checkResultWaterDetectTest", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(138), "UTOPIA_PD] FAIL - Time(5s) out"));
                FtUtil.log_d("UTOPIA_PD", "WaterDetect", "FAIL");
                this.tvWaterDetectResult.setText("F");
                this.tvWaterDetectResult.setTextColor(-65536);
                this.mbTestResult = false;
                UIPDTest.this.setTestResultFailCase(138);
            }
            this.mHandler.sendEmptyMessageDelayed(2, 100);
        }

        @Override // com.sec.factory.app.ui.UIPDTest.PDTest
        public void init(boolean enable) {
            this.mIsEnable = enable;
            FtUtil.log_d("WaterDetectTest", "init", "" + enable);
            if (enable) {
                this.tvWaterDetectType = (TextView) this.mActivity.findViewById(R.id.tv_waterdetecttest_type);
                this.tvWaterDetectResult = (TextView) this.mActivity.findViewById(R.id.tv_waterdetecttest_result);
                String read = Support.Kernel.read(Support.Kernel.WATER_TEST_TYPE);
                this.mSupportSysfs = read;
                if (read == null) {
                    if (!Support.Feature.getBoolean(Support.Feature.SUPPORT_WATER_INT_SYSFS)) {
                        this.mSupportSysfs = "uevent";
                    } else {
                        this.mSupportSysfs = "sysfs";
                    }
                }
                if ("sysfs".equals(this.mSupportSysfs)) {
                    this.tvWaterDetectType.setText("ADC");
                } else if ("uevent".equals(this.mSupportSysfs)) {
                    this.tvWaterDetectType.setText("uEvent");
                }
            } else {
                this.mActivity.findViewById(R.id.v_waterdetecttest_line).setVisibility(8);
                ((LinearLayout) this.mActivity.findViewById(R.id.ll_pd_waterdetect)).setVisibility(8);
            }
        }

        @Override // com.sec.factory.app.ui.UIPDTest.PDTest
        public void startTest() {
            FtUtil.log_d("WaterDetectTest", "startTest", "");
            Support.Kernel.write(Support.Kernel.CCIC_CONTROL_OPTION, egis.optical.client.api.EgisFingerprint.MAJOR_VERSION);
            FtUtil.log_d("UTOPIA_PD", "WaterDetect", "START");
            if ("sysfs".equals(this.mSupportSysfs)) {
                this.mHandler.sendEmptyMessageDelayed(1, 0);
            } else if ("uevent".equals(this.mSupportSysfs)) {
                this.mWaterDetectUEventObserver.startObserving(UEVENT_CCIC_WATER);
                FtUtil.log_d("UTOPIA_PD", "WaterDetect", "uEvent Wait");
            }
        }

        @Override // com.sec.factory.app.ui.UIPDTest.PDTest
        public void endTest() {
            FtUtil.log_d("WaterDetectTest", "endTest", "");
            Support.Kernel.write(Support.Kernel.CCIC_CONTROL_OPTION, "4");
            if ("uevent".equals(this.mSupportSysfs)) {
                this.mWaterDetectUEventObserver.stopObserving();
            }
        }
    }
}
