package com.sec.factory.app.ui;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;

public class UIPogoCharge extends UIBase {
    public static final int MSG_TEST_POGO_READ = 1;
    public static final int MSG_TEST_START = 0;
    public static final int MSG_TEST_STOP = 2;
    private static final int POGO_FINISH_DELAY = 500;
    private final String CLASS_NAME = "UIPogoCharge";
    private boolean isCharged = false;
    private boolean isDocked = false;
    private BroadcastReceiver mBroadcastReceiver = null;
    private TextView mChargeCheck;
    private TextView mChargeNotice;
    private TextView mDockCheck;
    private TextView mDockNotice;
    private final Handler mHandler = new Handler() {
        /* class com.sec.factory.app.ui.UIPogoCharge.AnonymousClass1 */

        public void handleMessage(Message msg) {
            if (msg.what == 0) {
                UIPogoCharge.this.registerReceiver();
                UIPogoCharge.this.mHandler.sendEmptyMessage(1);
            } else if (msg.what == 1) {
                if (UIPogoCharge.this.isDocked) {
                    return;
                }
                if (!UIPogoCharge.this.chekcDockStatus()) {
                    UIPogoCharge.this.mHandler.sendEmptyMessageDelayed(1, 500);
                } else if (UIPogoCharge.this.isCharged) {
                    UIPogoCharge.this.mHandler.sendEmptyMessage(2);
                }
            } else if (msg.what == 2) {
                UIPogoCharge.this.mHandler.removeMessages(0);
                UIPogoCharge.this.mHandler.removeMessages(1);
                UIPogoCharge.this.mHandler.removeMessages(2);
                UIPogoCharge.this.unregisterReceiver();
                UIPogoCharge.this.updateDock();
                UIPogoCharge.this.updateCharge();
                postDelayed(new Runnable() {
                    /* class com.sec.factory.app.ui.UIPogoCharge.AnonymousClass1.AnonymousClass1 */

                    public void run() {
                        if (!UIPogoCharge.this.isFinishing()) {
                            UIPogoCharge.this.setTestResult();
                        }
                    }
                }, 500);
            }
        }
    };
    private boolean mIsTestPass = false;
    private String mTestCase;

    public UIPogoCharge() {
        super("UIPogoCharge");
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ui_pogo_charge);
        this.mDockNotice = (TextView) findViewById(R.id.docknotice);
        this.mDockCheck = (TextView) findViewById(R.id.dockcheck);
        this.mDockNotice.setVisibility(0);
        this.mDockNotice.setText("Connect Charger");
        this.mChargeNotice = (TextView) findViewById(R.id.pogonotice);
        this.mChargeCheck = (TextView) findViewById(R.id.pogocheck);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        this.mHandler.sendEmptyMessageDelayed(0, 100);
        this.mHandler.sendEmptyMessageDelayed(2, 5000);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        super.onPause();
        this.mHandler.sendEmptyMessage(2);
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        super.onDestroy();
    }

    public void registerReceiver() {
        if (this.mBroadcastReceiver == null) {
            IntentFilter intentFilter = new IntentFilter();
            intentFilter.addAction("android.intent.action.BATTERY_CHANGED");
            PogoChargeReceiver pogoChargeReceiver = new PogoChargeReceiver(intentFilter);
            this.mBroadcastReceiver = pogoChargeReceiver;
            registerReceiver(pogoChargeReceiver, intentFilter);
            FtUtil.log_d("UIPogoCharge", "registerReceiver", "");
        }
    }

    public void unregisterReceiver() {
        BroadcastReceiver broadcastReceiver = this.mBroadcastReceiver;
        if (broadcastReceiver != null) {
            unregisterReceiver(broadcastReceiver);
            this.mBroadcastReceiver = null;
            FtUtil.log_i("UIPogoCharge", "unregisterReceiver", null);
        }
    }

    /* access modifiers changed from: private */
    public class PogoChargeReceiver extends BroadcastReceiver {
        public PogoChargeReceiver(IntentFilter filter) {
            FtUtil.log_i("UIPogoCharge", "PogoChargeReceiver", null);
        }

        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            FtUtil.log_d("UIPogoCharge", "mBroadcastReceiver.onReceive", "action=" + action);
            if ("android.intent.action.BATTERY_CHANGED".equals(action) && intent.getIntExtra("plugged", 0) == 1) {
                FtUtil.log_d("UIPogoCharge", "Charged");
                UIPogoCharge.this.isCharged = true;
                UIPogoCharge.this.updateCharge();
            }
            if (UIPogoCharge.this.isDocked && UIPogoCharge.this.isCharged) {
                UIPogoCharge.this.mHandler.sendEmptyMessage(2);
            }
        }
    }

    public boolean chekcDockStatus() {
        String jigCheck = Support.Kernel.read(Support.Kernel.JIG_CONNECTION_CHECK, true);
        if (jigCheck == null || !jigCheck.contains("POGO Dock")) {
            return false;
        }
        this.isDocked = true;
        updateDock();
        return true;
    }

    public void updateDock() {
        this.mDockNotice.setText("Detect : ");
        this.mDockCheck.setVisibility(0);
        if (this.isDocked) {
            this.mDockCheck.setText("PASS");
            this.mDockCheck.setTextColor(UiHallICTest.FONT_COLOR_PASS);
            return;
        }
        this.mDockCheck.setText("FAIL");
        this.mDockCheck.setTextColor(-65536);
    }

    public void updateCharge() {
        this.mChargeNotice.setVisibility(0);
        this.mChargeNotice.setText("Charging : ");
        this.mChargeCheck.setVisibility(0);
        if (this.isCharged) {
            this.mChargeCheck.setText("PASS");
            this.mChargeCheck.setTextColor(UiHallICTest.FONT_COLOR_PASS);
            return;
        }
        this.mChargeCheck.setText("FAIL");
        this.mChargeCheck.setTextColor(-65536);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setTestResult() {
        FtUtil.log_i("UIPogoCharge", "setTestResult", null);
        if (this.isDocked && this.isCharged) {
            setResult(-1);
            finish();
            FtUtil.log_i("UIPogoCharge", "setTestResult", "PASS");
        }
    }
}
