package com.sec.factory.app.ui;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.os.Handler;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.support.FtUtil;

public class UISpenDetectionTest extends UIBase {
    private static final String TAG = "UISpenDetectionTest";
    BroadcastReceiver SpenDetectionReceiver;
    private ModuleDevice mModuleDevice;
    private State mState = this.stateStart;
    private TextView mTextViewPreWorking;
    private TextView mTextViewRelease;
    private TextView mTextViewReleaseFail;
    private TextView mTextViewReleasePass;
    private TextView mTextViewWorking;
    private TextView mTextViewWorkingFail;
    private TextView mTextViewWorkingPass;
    private State statePreWorking = new PreWorkingStatus();
    private State stateRelease = new ReleaseStatus();
    private State stateStart = new StartState();
    private State stateWorking = new WorkingStatus();

    /* access modifiers changed from: package-private */
    public interface State {
        void detected();

        void released();
    }

    public UISpenDetectionTest() {
        super(TAG, 41);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.ui_spendetectiontest);
        this.mTextViewPreWorking = (TextView) findViewById(R.id.TextViewPreRelease);
        this.mTextViewRelease = (TextView) findViewById(R.id.TextViewWorking);
        this.mTextViewReleasePass = (TextView) findViewById(R.id.TextViewWorkingPass);
        this.mTextViewReleaseFail = (TextView) findViewById(R.id.TextViewWorkingFail);
        this.mTextViewWorking = (TextView) findViewById(R.id.TextViewRelease);
        this.mTextViewWorkingPass = (TextView) findViewById(R.id.TextViewReleasePass);
        this.mTextViewWorkingFail = (TextView) findViewById(R.id.TextViewReleaseFail);
        this.mModuleDevice = ModuleDevice.instance(this);
        this.mState = this.stateStart;
        this.SpenDetectionReceiver = new BroadcastReceiver() {
            /* class com.sec.factory.app.ui.UISpenDetectionTest.AnonymousClass1 */

            public void onReceive(Context context, Intent intent) {
                boolean isPenInsert = intent.getBooleanExtra("penInsert", false);
                String str = UISpenDetectionTest.this.CLASS_NAME;
                FtUtil.log_d(str, "onReceive", "isPenInsert: " + isPenInsert);
                if (UISpenDetectionTest.this.mState != null) {
                    if (isPenInsert) {
                        UISpenDetectionTest.this.mState.detected();
                    } else {
                        UISpenDetectionTest.this.mState.released();
                    }
                }
            }
        };
        registerReceiver(this.SpenDetectionReceiver, new IntentFilter("com.samsung.pen.INSERT"));
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        if (this.mModuleDevice.isVibrating()) {
            this.mModuleDevice.stopVibrate();
        }
        super.onPause();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        unregisterReceiver(this.SpenDetectionReceiver);
        super.onDestroy();
    }

    public void onFinish() {
        setResult(-1);
        finish();
    }

    class StartState implements State {
        StartState() {
        }

        @Override // com.sec.factory.app.ui.UISpenDetectionTest.State
        public void detected() {
            FtUtil.log_i(UISpenDetectionTest.this.CLASS_NAME, "StartState detected", "");
            UISpenDetectionTest.this.mTextViewPreWorking.setVisibility(0);
            UISpenDetectionTest uISpenDetectionTest = UISpenDetectionTest.this;
            uISpenDetectionTest.mState = uISpenDetectionTest.statePreWorking;
        }

        @Override // com.sec.factory.app.ui.UISpenDetectionTest.State
        public void released() {
            FtUtil.log_i(UISpenDetectionTest.this.CLASS_NAME, "StartState released", "");
        }
    }

    class PreWorkingStatus implements State {
        PreWorkingStatus() {
        }

        @Override // com.sec.factory.app.ui.UISpenDetectionTest.State
        public void detected() {
            FtUtil.log_i(UISpenDetectionTest.this.CLASS_NAME, "PreWorkingStatus released", "");
        }

        @Override // com.sec.factory.app.ui.UISpenDetectionTest.State
        public void released() {
            FtUtil.log_i(UISpenDetectionTest.this.CLASS_NAME, "PreWorkingStatus released", "");
            UISpenDetectionTest.this.mTextViewRelease.setVisibility(0);
            UISpenDetectionTest.this.mTextViewReleasePass.setVisibility(0);
            UISpenDetectionTest.this.mModuleDevice.stopVibrate();
            UISpenDetectionTest.this.mModuleDevice.startVibrate(1000);
            UISpenDetectionTest uISpenDetectionTest = UISpenDetectionTest.this;
            uISpenDetectionTest.mState = uISpenDetectionTest.stateRelease;
        }
    }

    class ReleaseStatus implements State {
        ReleaseStatus() {
        }

        @Override // com.sec.factory.app.ui.UISpenDetectionTest.State
        public void detected() {
            FtUtil.log_i(UISpenDetectionTest.this.CLASS_NAME, "ReleaseStatus detected", "");
            UISpenDetectionTest.this.mTextViewWorking.setVisibility(0);
            UISpenDetectionTest.this.mTextViewWorkingPass.setVisibility(0);
            UISpenDetectionTest.this.mModuleDevice.stopVibrate();
            UISpenDetectionTest.this.mModuleDevice.startVibrate(1000);
            UISpenDetectionTest uISpenDetectionTest = UISpenDetectionTest.this;
            uISpenDetectionTest.mState = uISpenDetectionTest.stateWorking;
            new Handler().postDelayed(new Runnable() {
                /* class com.sec.factory.app.ui.UISpenDetectionTest.ReleaseStatus.AnonymousClass1 */

                public void run() {
                    UISpenDetectionTest.this.mModuleDevice.stopVibrate();
                    UISpenDetectionTest.this.onFinish();
                }
            }, 1200);
        }

        @Override // com.sec.factory.app.ui.UISpenDetectionTest.State
        public void released() {
            FtUtil.log_i(UISpenDetectionTest.this.CLASS_NAME, "ReleaseStatus released", "");
        }
    }

    class WorkingStatus implements State {
        WorkingStatus() {
        }

        @Override // com.sec.factory.app.ui.UISpenDetectionTest.State
        public void detected() {
            FtUtil.log_i(UISpenDetectionTest.this.CLASS_NAME, "WorkingStatus detected", "");
        }

        @Override // com.sec.factory.app.ui.UISpenDetectionTest.State
        public void released() {
            FtUtil.log_i(UISpenDetectionTest.this.CLASS_NAME, "WorkingStatus released", "");
        }
    }
}
