package com.sec.factory.app.ui;

import android.app.Activity;
import android.graphics.Color;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.modules.vrr.RefreshRateChangeUtil;
import com.sec.factory.modules.vrr.VRRcontants;
import com.sec.factory.support.FtUtil;
import java.lang.ref.WeakReference;

public class UISubLcd32Gray120HzBright0Test extends UIBase implements View.OnTouchListener, View.OnClickListener {
    private static final int IGNORE_TOUCH_DELAY = 5000;
    private static final int IGNORE_TOUCH_END = 11;
    private static final int SHOW_PASS_FAIL_BTN = 10;
    private final int ColorB = 32;
    private final int ColorG = 32;
    private final int ColorR = 32;
    private final int MAX_BRIGHTNESS = 255;
    private final int MIN_BRIGHTNESS = 0;
    private LinearLayout mBgLayout;
    private Button mBtnFail;
    private Button mBtnPass;
    private boolean mIsShowBtnEnabled = false;
    private ModulePower mModulePower;
    private final WeakReferenceTestHandler mNotiHandler = new WeakReferenceTestHandler(this);
    private RefreshRateChangeUtil mRefreshRateChangeUtil;
    private TextView mTxtTitle;
    private int prevBrightness = -1;

    public UISubLcd32Gray120HzBright0Test() {
        super("UISubLcd32Gray120HzBright0Test", FactoryTestManager.TEST_SUB_LCD_32GRAY_120HZ_BRIGHT0_TEST);
    }

    private static class WeakReferenceTestHandler extends Handler {
        private final WeakReference<Activity> ref;

        public WeakReferenceTestHandler(Activity act) {
            this.ref = new WeakReference<>(act);
        }

        public void handleMessage(Message msg) {
            UISubLcd32Gray120HzBright0Test act = (UISubLcd32Gray120HzBright0Test) this.ref.get();
            switch (msg.what) {
                case 10:
                    act.mModulePower.setBrightness(act.prevBrightness);
                    act.displayTitle();
                    act.btnVisible(true);
                    return;
                case 11:
                    FtUtil.log_d(act.CLASS_NAME, "handleMessage", "IGNORE_TOUCH_END");
                    act.setShowBtnEnabledFlag(true);
                    return;
                default:
                    return;
            }
        }
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        FtUtil.log_d(this.CLASS_NAME, "onCreate", "onCreate");
        FtUtil.setRemoveSystemUI(getWindow(), true);
        FtUtil.setRemoveStatusBar(getWindow());
        setContentView(R.layout.ui_sub_lcd_32gray_120hz_bright0_test);
        initializeUI();
        setShowBtnEnabledFlag(false);
        this.mModulePower = ModulePower.instance(this);
        this.mRefreshRateChangeUtil = new RefreshRateChangeUtil(this, this.mNotiHandler);
    }

    private void initializeUI() {
        this.mBtnPass = (Button) findViewById(R.id.pass_btn);
        this.mBtnFail = (Button) findViewById(R.id.fail_btn);
        this.mTxtTitle = (TextView) findViewById(R.id.lcd_test_title);
        LinearLayout linearLayout = (LinearLayout) findViewById(R.id.background);
        this.mBgLayout = linearLayout;
        linearLayout.setBackgroundColor(Color.rgb(32, 32, 32));
        this.mBgLayout.setOnTouchListener(this);
        this.mBtnPass.setOnClickListener(this);
        this.mBtnFail.setOnClickListener(this);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setShowBtnEnabledFlag(boolean value) {
        this.mIsShowBtnEnabled = value;
    }

    private boolean getShowBtnEnabledFlag() {
        return this.mIsShowBtnEnabled;
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        super.onResume();
        this.prevBrightness = this.mModulePower.getBrightness();
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "onResume", "prevBrightness: " + this.prevBrightness);
        this.mModulePower.setBrightness(0);
        FtUtil.log_d(this.CLASS_NAME, "onResume", "IGNORE_TOUCH_DELAY: 5000");
        this.mNotiHandler.sendEmptyMessageDelayed(11, 5000);
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        this.mRefreshRateChangeUtil.setRefreshRate(VRRcontants.REFRESH_RATE_MODE_ALWAYS, 120);
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        super.onPause();
        int i = this.prevBrightness;
        if (i != -1) {
            this.mModulePower.setBrightness(i);
        }
        this.mRefreshRateChangeUtil.restoreDefault();
        this.mNotiHandler.removeCallbacksAndMessages(null);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void btnVisible(boolean flag) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "btnVisible", "Visible : " + flag);
        if (flag) {
            this.mBtnPass.setVisibility(0);
            this.mBtnFail.setVisibility(0);
            return;
        }
        this.mBtnPass.setVisibility(4);
        this.mBtnFail.setVisibility(4);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void displayTitle() {
        this.mTxtTitle.setTextColor(-1);
        this.mTxtTitle.setText("Sub LCD 32Gray 120Hz Bright 0 Test");
    }

    public boolean onTouch(View view, MotionEvent event) {
        switch (event.getAction()) {
            case 0:
                FtUtil.log_i(this.CLASS_NAME, "onTouch", "Touch down");
                if (!getShowBtnEnabledFlag()) {
                    return true;
                }
                this.mNotiHandler.sendEmptyMessage(10);
                return true;
            default:
                return true;
        }
    }

    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.fail_btn:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "FAIL");
                finish();
                return;
            case R.id.pass_btn:
                FtUtil.log_i(this.CLASS_NAME, "onClick", "PASS");
                setTestResult((byte) 80);
                finish();
                return;
            default:
                return;
        }
    }
}
