package com.sec.factory.app.ui;

import android.content.Context;
import android.content.Intent;
import android.graphics.AvoidXfermode;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.DashPathEffect;
import android.graphics.Paint;
import android.graphics.Point;
import android.graphics.Rect;
import android.graphics.RectF;
import android.os.Bundle;
import android.os.Handler;
import android.support.v4.os.EnvironmentCompat;
import android.util.TypedValue;
import android.view.Display;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.WindowManager;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.modules.ModuleTouchScreen;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.util.Iterator;
import java.util.concurrent.ConcurrentLinkedQueue;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class UITSPDrawingSegmentation extends UIBase {
    private static int mTestID = 118;
    private ConcurrentLinkedQueue<RectNode> mCrossRectTopLeftList = null;
    private ConcurrentLinkedQueue<RectNode> mCrossRectTopRightList = null;
    private ExecutorService mExecutorService = null;
    private Handler mHandler = new Handler();
    private boolean mIsPassOuterRect = false;
    private Options mOptions = null;
    private ConcurrentLinkedQueue<RectNode> mOuterRectList = null;
    private boolean misPassRectTopLeft = false;
    private boolean misPassRectTopRight = false;

    public UITSPDrawingSegmentation() {
        super("UITSPDrawingSegmentation", 10);
    }

    public static class Options {
        public static final int BOTTOM = 3;
        private static final String CLASS_NAME = "UITSPDrawingSegmentation.Options";
        public static final int DEFAULT_CROSS_RECT_HEIGHT = 2;
        public static final int DEFAULT_CROSS_RECT_WIDTH = 5;
        public static final int DEFAULT_DEAD_ZONE = 0;
        public static final int DEFAULT_OUTER_RECT_HEIGHT = 4;
        public static final int DEFAULT_OUTER_RECT_WIDTH = 4;
        public static final int HEIGHT = 1;
        public static final int LEFT = 0;
        public static final int RIGHT = 1;
        public static final String TAG_CROSS_RECT = "crossRect";
        public static final String TAG_MATRIX_DEAD_ZONE = "matrixMargin";
        public static final String TAG_OUTER_RECT = "outerRect";
        public static final String TAG_PASS_HALF_CROSS = "PASS_HALF_CROSS";
        public static final String TAG_SUPPORT_DEVICE = "supportDevice";
        public static final String TAG_SUPPORT_MATRIX = "supportMatrix";
        public static final int TOP = 2;
        public static final int WIDTH = 0;
        protected float[] mCrossRect = {5.0f, 2.0f};
        protected int[] mCrossRectChannel = {0, 0};
        protected int[] mDeadZone = {0, 0, 0, 0};
        protected int mMatrix = DRAW_MODE.UNKNOWN.getID();
        protected float mNPixelForOneMM = -1.0f;
        protected float[] mOuterRect = {4.0f, 4.0f};
        protected int[] mOuterRectChannel = {0, 0};
        protected int mScreenHeight = -1;
        protected int mScreenWidth = -1;
        protected int mSupportInput = INPUT_MODE.UNKNOWN.getID();
        protected boolean supportPassWithHalfCross = false;

        public enum INPUT_MODE {
            UNKNOWN(0, EnvironmentCompat.MEDIA_UNKNOWN),
            TSP(1, "tsp"),
            TSP_HOVERING(2, "tsp_hovering"),
            SPEN(4, "spen"),
            SPEN_HOVERING(8, "spen_hovering");
            
            public int mID;
            public String mTag;

            private INPUT_MODE(int id, String tag) {
                this.mID = id;
                this.mTag = tag;
            }

            public String toString() {
                return this.mTag;
            }

            public int getID() {
                return this.mID;
            }
        }

        /* access modifiers changed from: protected */
        public boolean isSupportDevice(int devices) {
            if ((this.mSupportInput & devices) == devices) {
                return true;
            }
            return false;
        }

        public enum DRAW_MODE {
            UNKNOWN(0, EnvironmentCompat.MEDIA_UNKNOWN),
            LEFT(1, "left"),
            RIGHT(2, "right"),
            TOP(4, "top"),
            BOTTOM(8, "bottom"),
            CROSS_TOP_LEFT(16, "cross_top_left"),
            CROSS_TOP_RIGHT(32, "cross_top_right");
            
            public int mID;
            public String mTag;

            private DRAW_MODE(int id, String tag) {
                this.mID = id;
                this.mTag = tag;
            }

            public String toString() {
                return this.mTag;
            }

            public int getID() {
                return this.mID;
            }
        }

        Options(Context context) {
            this.mNPixelForOneMM = TypedValue.applyDimension(5, 1.0f, context.getResources().getDisplayMetrics());
            FtUtil.log_d(CLASS_NAME, "mNPixelForOneMM = " + this.mNPixelForOneMM);
            Display mDisplay = ((WindowManager) context.getSystemService("window")).getDefaultDisplay();
            Point outpoint = new Point();
            mDisplay.getRealSize(outpoint);
            this.mScreenWidth = outpoint.x;
            this.mScreenHeight = outpoint.y;
            FtUtil.log_d(CLASS_NAME, "mScreenWidth = " + this.mScreenWidth + ", mScreenHeight = " + this.mScreenHeight);
        }

        /* JADX WARNING: Removed duplicated region for block: B:28:0x00c9  */
        /* JADX WARNING: Removed duplicated region for block: B:42:0x0129  */
        /* JADX WARNING: Removed duplicated region for block: B:46:0x0155  */
        /* JADX WARNING: Removed duplicated region for block: B:62:0x022e  */
        /* JADX WARNING: Removed duplicated region for block: B:74:0x0294  */
        /* JADX WARNING: Removed duplicated region for block: B:78:0x0320  */
        public void setOptions(Options op, Intent intent) {
            String _input;
            String _deadZone;
            String _outerRect;
            char c;
            String _crossRect;
            String _input2;
            String testCase;
            if (op == null || intent == null) {
                FtUtil.log_e(CLASS_NAME, "setOptions", "Wrong param, op = " + op + ", intent = " + intent);
                return;
            }
            String testCase2 = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
            if (testCase2 != null && testCase2.contains(TAG_PASS_HALF_CROSS)) {
                this.supportPassWithHalfCross = true;
            }
            String _matrix = Support.FactoryTestMenu.getSupportMatrix(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
            if (_matrix != null) {
                if (!_matrix.isEmpty()) {
                    String[] array = _matrix.replaceAll(" ", "").split(",");
                    int length = array.length;
                    int i = 0;
                    while (i < length) {
                        String feature = array[i];
                        FtUtil.log_d(CLASS_NAME, "setOptions", "mMatrix += " + feature);
                        DRAW_MODE[] values = DRAW_MODE.values();
                        int length2 = values.length;
                        int i2 = 0;
                        while (true) {
                            if (i2 >= length2) {
                                testCase = testCase2;
                                break;
                            }
                            DRAW_MODE mode = values[i2];
                            testCase = testCase2;
                            if (feature.equalsIgnoreCase(mode.toString())) {
                                op.mMatrix += mode.getID();
                                break;
                            } else {
                                i2++;
                                testCase2 = testCase;
                            }
                        }
                        i++;
                        array = array;
                        testCase2 = testCase;
                    }
                    FtUtil.log_d(CLASS_NAME, "setOptions", "mMatrix = " + op.mMatrix);
                    _input = Support.FactoryTestMenu.getSupportDevice(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
                    if (_input == null) {
                        if (!_input.isEmpty()) {
                            String[] array2 = _input.replaceAll(" ", "").split(",");
                            int length3 = array2.length;
                            int i3 = 0;
                            while (i3 < length3) {
                                String feature2 = array2[i3];
                                FtUtil.log_d(CLASS_NAME, "setOptions", "mSupportInput += " + feature2);
                                INPUT_MODE[] values2 = INPUT_MODE.values();
                                int length4 = values2.length;
                                int i4 = 0;
                                while (true) {
                                    if (i4 >= length4) {
                                        _input2 = _input;
                                        break;
                                    }
                                    INPUT_MODE mode2 = values2[i4];
                                    _input2 = _input;
                                    if (feature2.equalsIgnoreCase(mode2.toString())) {
                                        op.mSupportInput += mode2.getID();
                                        break;
                                    } else {
                                        i4++;
                                        _input = _input2;
                                    }
                                }
                                i3++;
                                array2 = array2;
                                _input = _input2;
                            }
                            FtUtil.log_d(CLASS_NAME, "setOptions", "mSupportInput = " + op.mSupportInput);
                            _deadZone = Support.FactoryTestMenu.getMargin(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
                            if (_deadZone != null || _deadZone.isEmpty()) {
                                FtUtil.log_d(CLASS_NAME, "setOptions", "No Margin options");
                                int[] iArr = this.mDeadZone;
                                int i5 = Support.Spec.getInt(Support.Spec.TSP_DEADZONE_WIDTH);
                                iArr[0] = i5;
                                iArr[1] = i5;
                                int[] iArr2 = this.mDeadZone;
                                int i6 = Support.Spec.getInt(Support.Spec.TSP_DEADZONE_HEIGHT);
                                iArr2[2] = i6;
                                iArr2[3] = i6;
                                FtUtil.log_d(CLASS_NAME, "setOptions", "TSP_DEAZONE_WIDTH, TSP_DEADZONE_HEIGHT mDeadZone[L/R] = " + this.mDeadZone[1] + ", mDeadZone[T/B] = " + this.mDeadZone[3]);
                            } else {
                                String[] array3 = _deadZone.replaceAll(" ", "").split(",");
                                int i7 = 0;
                                while (i7 < this.mDeadZone.length && i7 < array3.length) {
                                    FtUtil.log_d(CLASS_NAME, "setOptions", "mDeadZone += " + array3[i7]);
                                    try {
                                        this.mDeadZone[i7] = Integer.parseInt(array3[i7]);
                                    } catch (NumberFormatException ne) {
                                        FtUtil.log_e(ne);
                                    }
                                    i7++;
                                }
                            }
                            float[] fArr = this.mOuterRect;
                            float f = fArr[0];
                            float f2 = this.mNPixelForOneMM;
                            fArr[0] = f * f2;
                            fArr[1] = fArr[1] * f2;
                            FtUtil.log_d(CLASS_NAME, "setOptions", "mOuterRect.pixel.w += " + this.mOuterRect[0]);
                            FtUtil.log_d(CLASS_NAME, "setOptions", "mOuterRect.pixel.h += " + this.mOuterRect[1]);
                            _outerRect = Support.FactoryTestMenu.getOuterRect(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
                            if (_outerRect != null) {
                                if (!_outerRect.isEmpty()) {
                                    String[] array4 = _outerRect.replaceAll(" ", "").split(",");
                                    if (array4.length == 2) {
                                        FtUtil.log_d(CLASS_NAME, "setOptions", "mOuterRect.channel.w += " + array4[0]);
                                        FtUtil.log_d(CLASS_NAME, "setOptions", "mOuterRect.channel.h += " + array4[1]);
                                        try {
                                            this.mOuterRectChannel[0] = Integer.parseInt(array4[0]);
                                            this.mOuterRectChannel[1] = Integer.parseInt(array4[1]);
                                            c = 0;
                                        } catch (NumberFormatException ne2) {
                                            FtUtil.log_e(ne2);
                                            c = 0;
                                        }
                                    } else {
                                        c = 0;
                                    }
                                    float[] fArr2 = this.mCrossRect;
                                    float f3 = fArr2[c];
                                    float f4 = this.mNPixelForOneMM;
                                    fArr2[c] = f3 * f4;
                                    fArr2[1] = fArr2[1] * f4;
                                    FtUtil.log_d(CLASS_NAME, "setOptions", "mCrossRectChannel.pixel.w = " + this.mCrossRect[c]);
                                    FtUtil.log_d(CLASS_NAME, "setOptions", "mCrossRectChannel.pixel.h = " + this.mCrossRect[1]);
                                    _crossRect = Support.FactoryTestMenu.getCrossRect(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
                                    if (_crossRect != null || _crossRect.isEmpty()) {
                                        FtUtil.log_d(CLASS_NAME, "setOptions", "No CrossRect channel options");
                                        this.mCrossRectChannel[0] = Support.Spec.getInt(Support.Spec.TSP_NODE_COUNT_WIDTH);
                                        this.mCrossRectChannel[1] = Support.Spec.getInt(Support.Spec.TSP_NODE_COUNT_HEIGHT) * 2;
                                        FtUtil.log_d(CLASS_NAME, "setOptions", "TSP_NODE_COUNT_WIDTH, TSP_NODE_COUNT_HEIGHT WIDTH = " + this.mCrossRectChannel[0] + ", HEIGHT = " + this.mCrossRectChannel[1]);
                                    }
                                    String[] array5 = _crossRect.replaceAll(" ", "").split(",");
                                    if (array5.length == 2) {
                                        FtUtil.log_d(CLASS_NAME, "setOptions", "mCrossRect.channel.w = " + array5[0]);
                                        FtUtil.log_d(CLASS_NAME, "setOptions", "mCrossRect.channel.h = " + array5[1]);
                                        try {
                                            this.mCrossRectChannel[0] = Integer.parseInt(array5[0]);
                                            this.mCrossRectChannel[1] = Integer.parseInt(array5[1]);
                                            return;
                                        } catch (NumberFormatException ne3) {
                                            FtUtil.log_e(ne3);
                                            return;
                                        }
                                    } else {
                                        return;
                                    }
                                }
                            }
                            FtUtil.log_d(CLASS_NAME, "setOptions", "No OutRect channel options");
                            c = 0;
                            this.mOuterRectChannel[0] = Support.Spec.getInt(Support.Spec.TSP_X_AXIS_CHANNEL);
                            this.mOuterRectChannel[1] = Support.Spec.getInt(Support.Spec.TSP_Y_AXIS_CHANNEL);
                            FtUtil.log_d(CLASS_NAME, "setOptions", "TSP_NODE_COUNT_WIDTH, TSP_NODE_COUNT_HEIGHT WIDTH = " + this.mOuterRectChannel[0] + ", HEIGHT = " + this.mOuterRectChannel[1]);
                            float[] fArr22 = this.mCrossRect;
                            float f32 = fArr22[c];
                            float f42 = this.mNPixelForOneMM;
                            fArr22[c] = f32 * f42;
                            fArr22[1] = fArr22[1] * f42;
                            FtUtil.log_d(CLASS_NAME, "setOptions", "mCrossRectChannel.pixel.w = " + this.mCrossRect[c]);
                            FtUtil.log_d(CLASS_NAME, "setOptions", "mCrossRectChannel.pixel.h = " + this.mCrossRect[1]);
                            _crossRect = Support.FactoryTestMenu.getCrossRect(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
                            if (_crossRect != null) {
                            }
                            FtUtil.log_d(CLASS_NAME, "setOptions", "No CrossRect channel options");
                            this.mCrossRectChannel[0] = Support.Spec.getInt(Support.Spec.TSP_NODE_COUNT_WIDTH);
                            this.mCrossRectChannel[1] = Support.Spec.getInt(Support.Spec.TSP_NODE_COUNT_HEIGHT) * 2;
                            FtUtil.log_d(CLASS_NAME, "setOptions", "TSP_NODE_COUNT_WIDTH, TSP_NODE_COUNT_HEIGHT WIDTH = " + this.mCrossRectChannel[0] + ", HEIGHT = " + this.mCrossRectChannel[1]);
                        }
                    }
                    FtUtil.log_d(CLASS_NAME, "setOptions", "No Input devices options");
                    FtUtil.log_d(CLASS_NAME, "setOptions", "mSupportInput = " + op.mSupportInput);
                    _deadZone = Support.FactoryTestMenu.getMargin(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
                    if (_deadZone != null) {
                    }
                    FtUtil.log_d(CLASS_NAME, "setOptions", "No Margin options");
                    int[] iArr3 = this.mDeadZone;
                    int i52 = Support.Spec.getInt(Support.Spec.TSP_DEADZONE_WIDTH);
                    iArr3[0] = i52;
                    iArr3[1] = i52;
                    int[] iArr22 = this.mDeadZone;
                    int i62 = Support.Spec.getInt(Support.Spec.TSP_DEADZONE_HEIGHT);
                    iArr22[2] = i62;
                    iArr22[3] = i62;
                    FtUtil.log_d(CLASS_NAME, "setOptions", "TSP_DEAZONE_WIDTH, TSP_DEADZONE_HEIGHT mDeadZone[L/R] = " + this.mDeadZone[1] + ", mDeadZone[T/B] = " + this.mDeadZone[3]);
                    float[] fArr3 = this.mOuterRect;
                    float f5 = fArr3[0];
                    float f22 = this.mNPixelForOneMM;
                    fArr3[0] = f5 * f22;
                    fArr3[1] = fArr3[1] * f22;
                    FtUtil.log_d(CLASS_NAME, "setOptions", "mOuterRect.pixel.w += " + this.mOuterRect[0]);
                    FtUtil.log_d(CLASS_NAME, "setOptions", "mOuterRect.pixel.h += " + this.mOuterRect[1]);
                    _outerRect = Support.FactoryTestMenu.getOuterRect(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
                    if (_outerRect != null) {
                    }
                    FtUtil.log_d(CLASS_NAME, "setOptions", "No OutRect channel options");
                    c = 0;
                    this.mOuterRectChannel[0] = Support.Spec.getInt(Support.Spec.TSP_X_AXIS_CHANNEL);
                    this.mOuterRectChannel[1] = Support.Spec.getInt(Support.Spec.TSP_Y_AXIS_CHANNEL);
                    FtUtil.log_d(CLASS_NAME, "setOptions", "TSP_NODE_COUNT_WIDTH, TSP_NODE_COUNT_HEIGHT WIDTH = " + this.mOuterRectChannel[0] + ", HEIGHT = " + this.mOuterRectChannel[1]);
                    float[] fArr222 = this.mCrossRect;
                    float f322 = fArr222[c];
                    float f422 = this.mNPixelForOneMM;
                    fArr222[c] = f322 * f422;
                    fArr222[1] = fArr222[1] * f422;
                    FtUtil.log_d(CLASS_NAME, "setOptions", "mCrossRectChannel.pixel.w = " + this.mCrossRect[c]);
                    FtUtil.log_d(CLASS_NAME, "setOptions", "mCrossRectChannel.pixel.h = " + this.mCrossRect[1]);
                    _crossRect = Support.FactoryTestMenu.getCrossRect(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
                    if (_crossRect != null) {
                    }
                    FtUtil.log_d(CLASS_NAME, "setOptions", "No CrossRect channel options");
                    this.mCrossRectChannel[0] = Support.Spec.getInt(Support.Spec.TSP_NODE_COUNT_WIDTH);
                    this.mCrossRectChannel[1] = Support.Spec.getInt(Support.Spec.TSP_NODE_COUNT_HEIGHT) * 2;
                    FtUtil.log_d(CLASS_NAME, "setOptions", "TSP_NODE_COUNT_WIDTH, TSP_NODE_COUNT_HEIGHT WIDTH = " + this.mCrossRectChannel[0] + ", HEIGHT = " + this.mCrossRectChannel[1]);
                }
            }
            FtUtil.log_d(CLASS_NAME, "setOptions", "No Matrix options");
            FtUtil.log_d(CLASS_NAME, "setOptions", "mMatrix = " + op.mMatrix);
            _input = Support.FactoryTestMenu.getSupportDevice(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
            if (_input == null) {
            }
            FtUtil.log_d(CLASS_NAME, "setOptions", "No Input devices options");
            FtUtil.log_d(CLASS_NAME, "setOptions", "mSupportInput = " + op.mSupportInput);
            _deadZone = Support.FactoryTestMenu.getMargin(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
            if (_deadZone != null) {
            }
            FtUtil.log_d(CLASS_NAME, "setOptions", "No Margin options");
            int[] iArr32 = this.mDeadZone;
            int i522 = Support.Spec.getInt(Support.Spec.TSP_DEADZONE_WIDTH);
            iArr32[0] = i522;
            iArr32[1] = i522;
            int[] iArr222 = this.mDeadZone;
            int i622 = Support.Spec.getInt(Support.Spec.TSP_DEADZONE_HEIGHT);
            iArr222[2] = i622;
            iArr222[3] = i622;
            FtUtil.log_d(CLASS_NAME, "setOptions", "TSP_DEAZONE_WIDTH, TSP_DEADZONE_HEIGHT mDeadZone[L/R] = " + this.mDeadZone[1] + ", mDeadZone[T/B] = " + this.mDeadZone[3]);
            float[] fArr32 = this.mOuterRect;
            float f52 = fArr32[0];
            float f222 = this.mNPixelForOneMM;
            fArr32[0] = f52 * f222;
            fArr32[1] = fArr32[1] * f222;
            FtUtil.log_d(CLASS_NAME, "setOptions", "mOuterRect.pixel.w += " + this.mOuterRect[0]);
            FtUtil.log_d(CLASS_NAME, "setOptions", "mOuterRect.pixel.h += " + this.mOuterRect[1]);
            _outerRect = Support.FactoryTestMenu.getOuterRect(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
            if (_outerRect != null) {
            }
            FtUtil.log_d(CLASS_NAME, "setOptions", "No OutRect channel options");
            c = 0;
            this.mOuterRectChannel[0] = Support.Spec.getInt(Support.Spec.TSP_X_AXIS_CHANNEL);
            this.mOuterRectChannel[1] = Support.Spec.getInt(Support.Spec.TSP_Y_AXIS_CHANNEL);
            FtUtil.log_d(CLASS_NAME, "setOptions", "TSP_NODE_COUNT_WIDTH, TSP_NODE_COUNT_HEIGHT WIDTH = " + this.mOuterRectChannel[0] + ", HEIGHT = " + this.mOuterRectChannel[1]);
            float[] fArr2222 = this.mCrossRect;
            float f3222 = fArr2222[c];
            float f4222 = this.mNPixelForOneMM;
            fArr2222[c] = f3222 * f4222;
            fArr2222[1] = fArr2222[1] * f4222;
            FtUtil.log_d(CLASS_NAME, "setOptions", "mCrossRectChannel.pixel.w = " + this.mCrossRect[c]);
            FtUtil.log_d(CLASS_NAME, "setOptions", "mCrossRectChannel.pixel.h = " + this.mCrossRect[1]);
            _crossRect = Support.FactoryTestMenu.getCrossRect(FactoryTestManager.convertorID_XML(UITSPDrawingSegmentation.mTestID));
            if (_crossRect != null) {
            }
            FtUtil.log_d(CLASS_NAME, "setOptions", "No CrossRect channel options");
            this.mCrossRectChannel[0] = Support.Spec.getInt(Support.Spec.TSP_NODE_COUNT_WIDTH);
            this.mCrossRectChannel[1] = Support.Spec.getInt(Support.Spec.TSP_NODE_COUNT_HEIGHT) * 2;
            FtUtil.log_d(CLASS_NAME, "setOptions", "TSP_NODE_COUNT_WIDTH, TSP_NODE_COUNT_HEIGHT WIDTH = " + this.mCrossRectChannel[0] + ", HEIGHT = " + this.mCrossRectChannel[1]);
        }
    }

    public void generateCrossRect() {
        int nRect = this.mOptions.mCrossRectChannel[1];
        if (this.mOptions.mCrossRectChannel.length > 1 && this.mOptions.mCrossRectChannel[1] <= 0) {
            nRect = (int) (((float) ((this.mOptions.mScreenHeight - this.mOptions.mDeadZone[3]) - this.mOptions.mDeadZone[2])) / this.mOptions.mCrossRect[1]);
        }
        float overLapWidth = (((((float) this.mOptions.mScreenWidth) - this.mOptions.mCrossRect[0]) - ((float) this.mOptions.mDeadZone[0])) - ((float) this.mOptions.mDeadZone[1])) / ((float) (nRect - 1));
        float height = (float) (((this.mOptions.mScreenHeight - this.mOptions.mDeadZone[3]) - this.mOptions.mDeadZone[2]) / nRect);
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "generateCrossRect", "nRect = " + nRect + ", overLapWidth = " + overLapWidth + "height = " + height);
        if ((this.mOptions.mMatrix & Options.DRAW_MODE.CROSS_TOP_LEFT.getID()) == Options.DRAW_MODE.CROSS_TOP_LEFT.getID()) {
            this.mCrossRectTopLeftList = new ConcurrentLinkedQueue<>();
            float currentX = ((float) this.mOptions.mDeadZone[0]) + (this.mOptions.mCrossRect[0] / 2.0f);
            float currentY = (float) this.mOptions.mDeadZone[2];
            float currentX2 = currentX;
            for (int i = 0; i < nRect; i++) {
                RectF r = new RectF();
                r.left = currentX2;
                r.top = currentY;
                r.right = this.mOptions.mCrossRect[0] + currentX2;
                r.bottom = currentY + height;
                currentX2 += overLapWidth;
                currentY += height;
                String str2 = this.CLASS_NAME;
                FtUtil.log_d(str2, "generateCrossRect - Draw CROSS_TOP_LEFT", "currentX = " + currentX2 + ", currentY = " + currentY);
                this.mCrossRectTopLeftList.add(new RectNode(r));
            }
        }
        if ((this.mOptions.mMatrix & Options.DRAW_MODE.CROSS_TOP_RIGHT.getID()) == Options.DRAW_MODE.CROSS_TOP_RIGHT.getID()) {
            this.mCrossRectTopRightList = new ConcurrentLinkedQueue<>();
            float currentY2 = (float) this.mOptions.mDeadZone[2];
            float currentX3 = (((float) this.mOptions.mScreenWidth) - this.mOptions.mCrossRect[0]) - (this.mOptions.mCrossRect[0] / 2.0f);
            for (int i2 = 0; i2 < nRect; i2++) {
                RectF r2 = new RectF();
                r2.left = currentX3;
                r2.top = currentY2;
                r2.right = this.mOptions.mCrossRect[0] + currentX3;
                r2.bottom = currentY2 + height;
                currentX3 -= overLapWidth;
                currentY2 += height;
                String str3 = this.CLASS_NAME;
                FtUtil.log_d(str3, "generateCrossRect - Draw CROSS_TOP_LEFT", "currentX = " + currentX3 + ", currentY = " + currentY2);
                this.mCrossRectTopRightList.add(new RectNode(r2));
            }
        }
    }

    public void generateOuterRect() {
        int nHorizontalRect = this.mOptions.mOuterRectChannel[0];
        if (this.mOptions.mOuterRectChannel.length > 0 && this.mOptions.mOuterRectChannel[0] <= 0) {
            nHorizontalRect = (int) (((float) ((this.mOptions.mScreenWidth - this.mOptions.mDeadZone[0]) - this.mOptions.mDeadZone[1])) / this.mOptions.mOuterRect[0]);
        }
        int nVerticalRect = this.mOptions.mOuterRectChannel[1];
        if (this.mOptions.mOuterRectChannel.length > 1 && this.mOptions.mCrossRectChannel[1] <= 0) {
            nVerticalRect = (int) (((float) ((this.mOptions.mScreenHeight - this.mOptions.mDeadZone[2]) - this.mOptions.mDeadZone[3])) / this.mOptions.mOuterRect[1]);
        }
        float width = ((float) ((this.mOptions.mScreenWidth - this.mOptions.mDeadZone[0]) - this.mOptions.mDeadZone[1])) / ((float) nHorizontalRect);
        float height = ((float) ((this.mOptions.mScreenHeight - this.mOptions.mDeadZone[2]) - this.mOptions.mDeadZone[3])) / ((float) nVerticalRect);
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "generateOuterRect", "nHorizontalRect = " + nHorizontalRect + ", nVerticalRect = " + nVerticalRect + ", width = " + width + ", height = " + height);
        if ((this.mOptions.mMatrix & Options.DRAW_MODE.LEFT.getID()) == Options.DRAW_MODE.LEFT.getID()) {
            if (this.mOuterRectList == null) {
                this.mOuterRectList = new ConcurrentLinkedQueue<>();
            }
            float currentX = (float) this.mOptions.mDeadZone[0];
            float currentY = (float) this.mOptions.mDeadZone[2];
            for (int i = 0; i < nVerticalRect; i++) {
                RectF r = new RectF();
                r.left = currentX;
                r.top = currentY;
                r.right = currentX + width;
                r.bottom = currentY + height;
                currentY += height;
                String str2 = this.CLASS_NAME;
                FtUtil.log_d(str2, "generateOuterRect - Draw LEFT", "currentX = " + currentX + ", currentY = " + currentY);
                this.mOuterRectList.add(new RectNode(r));
            }
        }
        if ((this.mOptions.mMatrix & Options.DRAW_MODE.RIGHT.getID()) == Options.DRAW_MODE.RIGHT.getID()) {
            if (this.mOuterRectList == null) {
                this.mOuterRectList = new ConcurrentLinkedQueue<>();
            }
            float currentX2 = ((float) (this.mOptions.mScreenWidth - this.mOptions.mDeadZone[1])) - width;
            float currentY2 = (float) this.mOptions.mDeadZone[2];
            for (int i2 = 0; i2 < nVerticalRect; i2++) {
                RectF r2 = new RectF();
                r2.left = currentX2;
                r2.top = currentY2;
                r2.right = currentX2 + width;
                r2.bottom = currentY2 + height;
                currentY2 += height;
                String str3 = this.CLASS_NAME;
                FtUtil.log_d(str3, "generateOuterRect - Draw RIGHT", "currentX = " + currentX2 + ", currentY = " + currentY2);
                this.mOuterRectList.add(new RectNode(r2));
            }
        }
        if ((this.mOptions.mMatrix & Options.DRAW_MODE.TOP.getID()) == Options.DRAW_MODE.TOP.getID()) {
            if (this.mOuterRectList == null) {
                this.mOuterRectList = new ConcurrentLinkedQueue<>();
            }
            float currentY3 = (float) this.mOptions.mDeadZone[2];
            float currentX3 = ((float) this.mOptions.mDeadZone[0]) + this.mOptions.mOuterRect[0];
            for (int i3 = 0; i3 < nHorizontalRect - 2; i3++) {
                RectF r3 = new RectF();
                r3.left = currentX3;
                r3.top = currentY3;
                r3.right = currentX3 + width;
                r3.bottom = currentY3 + height;
                currentX3 += width;
                String str4 = this.CLASS_NAME;
                FtUtil.log_d(str4, "generateOuterRect - Draw TOP", "currentX = " + currentX3 + ", currentY = " + currentY3);
                this.mOuterRectList.add(new RectNode(r3));
            }
        }
        if ((this.mOptions.mMatrix & Options.DRAW_MODE.BOTTOM.getID()) == Options.DRAW_MODE.BOTTOM.getID()) {
            if (this.mOuterRectList == null) {
                this.mOuterRectList = new ConcurrentLinkedQueue<>();
            }
            float currentX4 = ((float) this.mOptions.mDeadZone[0]) + this.mOptions.mOuterRect[0];
            float currentY4 = ((float) (this.mOptions.mScreenHeight - this.mOptions.mDeadZone[3])) - this.mOptions.mOuterRect[1];
            float currentX5 = currentX4;
            for (int i4 = 0; i4 < nHorizontalRect - 2; i4++) {
                RectF r4 = new RectF();
                r4.left = currentX5;
                r4.top = currentY4;
                r4.right = currentX5 + width;
                r4.bottom = currentY4 + height;
                currentX5 += width;
                String str5 = this.CLASS_NAME;
                FtUtil.log_d(str5, "generateOuterRect - Draw Bottom", "currentX = " + currentX5 + ", currentY = " + currentY4);
                this.mOuterRectList.add(new RectNode(r4));
            }
        }
    }

    public static class RectNode {
        boolean isTouched = false;
        RectF mRect;

        RectNode(RectF rect) {
            this.mRect = rect;
        }

        public RectF getRect() {
            return this.mRect;
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        int intExtra = getIntent().getIntExtra("testID", 118);
        this.TEST_ID = intExtra;
        mTestID = intExtra;
        this.mExecutorService = Executors.newSingleThreadExecutor();
        Options options = new Options(this);
        this.mOptions = options;
        options.setOptions(options, getIntent());
        generateOuterRect();
        generateCrossRect();
        setContentView(new MatrixView(this, this.mOptions.mScreenWidth, this.mOptions.mScreenHeight));
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        if (this.mOptions.isSupportDevice(Options.INPUT_MODE.TSP_HOVERING.getID())) {
            FtUtil.log_d(this.CLASS_NAME, "onPause", "DisableHovering");
            ModuleDevice.instance(this).hoveringOnOFF("0");
            if (Support.TestCase.getEnabled(Support.TestCase.IS_TSP_HOVERING_TEST_SET_EDGE_DEADLOCK)) {
                ModuleTouchScreen.instance(this).TSPHoveringEdge("0");
            }
        }
        super.onPause();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        if (this.mOptions.isSupportDevice(Options.INPUT_MODE.TSP_HOVERING.getID())) {
            FtUtil.log_d(this.CLASS_NAME, "onResume", "EnableHovering");
            ModuleDevice.instance(this).hoveringOnOFF(EgisFingerprint.MAJOR_VERSION);
            if (Support.TestCase.getEnabled(Support.TestCase.IS_TSP_HOVERING_TEST_SET_EDGE_DEADLOCK)) {
                ModuleTouchScreen.instance(this).TSPHoveringEdge(EgisFingerprint.MAJOR_VERSION);
            }
        }
        super.onResume();
    }

    @Override // com.sec.factory.app.ui.UIBase
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (keyCode == 24) {
            if (!isPass()) {
                setResult(0);
            }
            FtUtil.log_d(this.CLASS_NAME, "onKeyDown", FtUtil.setMspSeqMessage(1, FactoryTestManager.getItemName_RequestCode(44), "Cancel - Volume Up"));
            finish();
        }
        return super.onKeyDown(keyCode, event);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void checkPassNfinishTest(Handler h) {
        if (!isFinishing() && isPass()) {
            h.postAtFrontOfQueue(new Runnable() {
                /* class com.sec.factory.app.ui.UITSPDrawingSegmentation.AnonymousClass1 */

                public void run() {
                    UITSPDrawingSegmentation.this.setTestResult(UITSPDrawingSegmentation.mTestID, (byte) 80);
                    UITSPDrawingSegmentation.this.setResult(-1);
                    FtUtil.log_d(UITSPDrawingSegmentation.this.CLASS_NAME, "checkPassNfinishTest", "Pass!");
                    UITSPDrawingSegmentation.this.finish();
                }
            });
        }
    }

    private boolean isPass() {
        if (!this.mIsPassOuterRect) {
            this.mIsPassOuterRect = true;
            ConcurrentLinkedQueue<RectNode> concurrentLinkedQueue = this.mOuterRectList;
            if (concurrentLinkedQueue != null) {
                Iterator<RectNode> it = concurrentLinkedQueue.iterator();
                while (true) {
                    if (it.hasNext()) {
                        if (!it.next().isTouched) {
                            this.mIsPassOuterRect = false;
                            break;
                        }
                    } else {
                        break;
                    }
                }
            } else {
                FtUtil.log_d(this.CLASS_NAME, "isPass", "Not Support Outer lines");
            }
        }
        if (!this.misPassRectTopLeft) {
            this.misPassRectTopLeft = true;
            ConcurrentLinkedQueue<RectNode> concurrentLinkedQueue2 = this.mCrossRectTopLeftList;
            if (concurrentLinkedQueue2 != null) {
                Iterator<RectNode> it2 = concurrentLinkedQueue2.iterator();
                while (true) {
                    if (it2.hasNext()) {
                        if (!it2.next().isTouched) {
                            this.misPassRectTopLeft = false;
                            break;
                        }
                    } else {
                        break;
                    }
                }
            } else {
                FtUtil.log_d(this.CLASS_NAME, "isPass", "Not Support mCrossRectTopLeftList");
            }
        }
        if (!this.misPassRectTopRight) {
            this.misPassRectTopRight = true;
            ConcurrentLinkedQueue<RectNode> concurrentLinkedQueue3 = this.mCrossRectTopRightList;
            if (concurrentLinkedQueue3 != null) {
                Iterator<RectNode> it3 = concurrentLinkedQueue3.iterator();
                while (true) {
                    if (it3.hasNext()) {
                        if (!it3.next().isTouched) {
                            this.misPassRectTopRight = false;
                            break;
                        }
                    } else {
                        break;
                    }
                }
            } else {
                FtUtil.log_d(this.CLASS_NAME, "isPass", "Not Support mCrossRectTopRightList");
            }
        }
        boolean z = this.mIsPassOuterRect;
        if (z && this.misPassRectTopLeft && this.misPassRectTopRight) {
            FtUtil.log_d(this.CLASS_NAME, "isPass", "All state passed");
            return true;
        } else if (!z || !this.mOptions.supportPassWithHalfCross || (!this.misPassRectTopLeft && !this.misPassRectTopRight)) {
            return false;
        } else {
            FtUtil.log_d(this.CLASS_NAME, "isPass", "All state passed");
            return true;
        }
    }

    private class MatrixView extends View {
        private static final int X_MARGINE = 25;
        private static final int Y_MARGINE = 10;
        private String mHoveringText;
        private boolean mIsHovering;
        private Bitmap mMatrixBitmap;
        private Canvas mMatrixCanvas;
        private Paint mPaintFailLine;
        private Paint mPaintHoveringText;
        private Paint mPaintHoveringTextBackground;
        private Paint mPaintRectInner;
        private Paint mPaintRectOutLine;
        private Paint mPaintTSP;
        private float mPreTouchedX = 0.0f;
        private float mPreTouchedY = 0.0f;
        private Rect mRectHoveringText;
        private String mResultText;
        private int mScreenHeight;
        private int mScreenWidth;
        private float mTouchedX = 0.0f;
        private float mTouchedY = 0.0f;

        public MatrixView(Context context, int width, int height) {
            super(context);
            setKeepScreenOn(true);
            this.mScreenWidth = width;
            this.mScreenHeight = height;
            this.mMatrixBitmap = Bitmap.createScaledBitmap(Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_8888), this.mScreenWidth, this.mScreenHeight, false);
            Canvas canvas = new Canvas(this.mMatrixBitmap);
            this.mMatrixCanvas = canvas;
            canvas.drawColor(-1);
            setPaint();
            initRect();
            initTextDrawingPaint();
            this.mIsHovering = false;
        }

        private void setPaint() {
            Paint paint = new Paint();
            this.mPaintRectInner = paint;
            paint.setAntiAlias(false);
            this.mPaintRectInner.setStyle(Paint.Style.FILL);
            this.mPaintRectInner.setColor(-16711936);
            this.mPaintRectInner.setXfermode(new AvoidXfermode(-1, 255, AvoidXfermode.Mode.TARGET));
            Paint paint2 = new Paint();
            this.mPaintRectOutLine = paint2;
            paint2.setColor(-16777216);
            this.mPaintRectOutLine.setStyle(Paint.Style.STROKE);
            this.mPaintRectOutLine.setAntiAlias(true);
            this.mPaintRectOutLine.setStrokeWidth(1.0f);
            Paint paint3 = new Paint();
            this.mPaintTSP = paint3;
            paint3.setAntiAlias(true);
            this.mPaintTSP.setDither(true);
            this.mPaintTSP.setColor(-16777216);
            this.mPaintTSP.setStyle(Paint.Style.STROKE);
            this.mPaintTSP.setStrokeJoin(Paint.Join.ROUND);
            this.mPaintTSP.setStrokeCap(Paint.Cap.SQUARE);
            this.mPaintTSP.setStrokeWidth(5.0f);
            this.mPaintTSP.setPathEffect(new DashPathEffect(new float[]{5.0f, 5.0f}, 1.0f));
            this.mPaintTSP.setColor(-16777216);
            Paint paint4 = new Paint();
            this.mPaintFailLine = paint4;
            paint4.setAntiAlias(true);
            this.mPaintFailLine.setColor(-65536);
            this.mPaintFailLine.setStrokeWidth(5.0f);
        }

        /* access modifiers changed from: protected */
        public void onDraw(Canvas canvas) {
            canvas.drawBitmap(this.mMatrixBitmap, 0.0f, 0.0f, (Paint) null);
        }

        public boolean onTouchEvent(MotionEvent event) {
            switch (event.getAction()) {
                case 0:
                    this.mTouchedX = event.getX();
                    float y = event.getY();
                    this.mTouchedY = y;
                    fillRect(this.mTouchedX, y, this.mPaintRectInner);
                    drawPoint(this.mTouchedX, this.mTouchedY, this.mPaintTSP);
                    break;
                case 1:
                    this.mTouchedX = event.getX();
                    float y2 = event.getY();
                    this.mTouchedY = y2;
                    drawPoint(this.mTouchedX, y2, this.mPaintTSP);
                    return true;
                case 2:
                    for (int i = 0; i < event.getHistorySize(); i++) {
                        this.mPreTouchedX = this.mTouchedX;
                        this.mPreTouchedY = this.mTouchedY;
                        this.mTouchedX = event.getHistoricalX(i);
                        float historicalY = event.getHistoricalY(i);
                        this.mTouchedY = historicalY;
                        fillRect(this.mTouchedX, historicalY, this.mPaintRectInner);
                        drawLine(this.mPreTouchedX, this.mPreTouchedY, this.mTouchedX, this.mTouchedY, this.mPaintTSP);
                    }
                    this.mPreTouchedX = this.mTouchedX;
                    this.mPreTouchedY = this.mTouchedY;
                    this.mTouchedX = event.getX();
                    float y3 = event.getY();
                    this.mTouchedY = y3;
                    fillRect(this.mTouchedX, y3, this.mPaintRectInner);
                    drawLine(this.mPreTouchedX, this.mPreTouchedY, this.mTouchedX, this.mTouchedY, this.mPaintTSP);
                    break;
                default:
                    FtUtil.log_d(UITSPDrawingSegmentation.this.CLASS_NAME, "onTouchEvent", "Not Support type event");
                    return true;
            }
            invalidate();
            UITSPDrawingSegmentation.this.mExecutorService.execute(new Runnable() {
                /* class com.sec.factory.app.ui.UITSPDrawingSegmentation.MatrixView.AnonymousClass1 */

                public void run() {
                    UITSPDrawingSegmentation.this.checkPassNfinishTest(UITSPDrawingSegmentation.this.mHandler);
                }
            });
            return true;
        }

        public boolean onHoverEvent(MotionEvent event) {
            if (!UITSPDrawingSegmentation.this.mOptions.isSupportDevice(Options.INPUT_MODE.TSP_HOVERING.getID())) {
                FtUtil.log_d(UITSPDrawingSegmentation.this.CLASS_NAME, "onHoverEvent", "not support Hover event");
                return false;
            }
            drawByEvent(event);
            invalidate();
            UITSPDrawingSegmentation.this.mExecutorService.execute(new Runnable() {
                /* class com.sec.factory.app.ui.UITSPDrawingSegmentation.MatrixView.AnonymousClass2 */

                public void run() {
                    UITSPDrawingSegmentation.this.checkPassNfinishTest(UITSPDrawingSegmentation.this.mHandler);
                }
            });
            return true;
        }

        private void drawByEvent(MotionEvent event) {
            switch (event.getAction()) {
                case 7:
                    for (int i = 0; i < event.getHistorySize(); i++) {
                        this.mPreTouchedX = this.mTouchedX;
                        this.mPreTouchedY = this.mTouchedY;
                        this.mTouchedX = event.getHistoricalX(i);
                        float historicalY = event.getHistoricalY(i);
                        this.mTouchedY = historicalY;
                        fillRect(this.mTouchedX, historicalY, this.mPaintRectInner);
                        drawLine(this.mPreTouchedX, this.mPreTouchedY, this.mTouchedX, this.mTouchedY, this.mPaintTSP);
                    }
                    this.mPreTouchedX = this.mTouchedX;
                    this.mPreTouchedY = this.mTouchedY;
                    this.mTouchedX = event.getX();
                    float y = event.getY();
                    this.mTouchedY = y;
                    this.mIsHovering = true;
                    fillRect(this.mTouchedX, y, this.mPaintRectInner);
                    drawLine(this.mPreTouchedX, this.mPreTouchedY, this.mTouchedX, this.mTouchedY, this.mPaintTSP);
                    return;
                case 8:
                default:
                    FtUtil.log_d(UITSPDrawingSegmentation.this.CLASS_NAME, "onTouchEvent", "Not Support type event");
                    return;
                case 9:
                    this.mTouchedX = event.getX();
                    float y2 = event.getY();
                    this.mTouchedY = y2;
                    fillRect(this.mTouchedX, y2, this.mPaintRectInner);
                    drawPoint(this.mTouchedX, this.mTouchedY, this.mPaintTSP);
                    drawHoverText(true);
                    this.mIsHovering = true;
                    return;
                case 10:
                    if (this.mIsHovering) {
                        this.mPreTouchedX = this.mTouchedX;
                        this.mPreTouchedY = this.mTouchedY;
                        this.mTouchedX = event.getX();
                        float y3 = event.getY();
                        this.mTouchedY = y3;
                        float f = this.mPreTouchedX;
                        float f2 = this.mTouchedX;
                        if (f == f2 && this.mPreTouchedY == y3) {
                            drawPoint(f2, y3, this.mPaintTSP);
                        }
                        this.mIsHovering = false;
                    }
                    drawHoverText(false);
                    return;
            }
        }

        private void drawLine(float preX, float preY, float x, float y, Paint paint) {
            this.mMatrixCanvas.drawLine(preX, preY, x, y, paint);
        }

        private void drawPoint(float x, float y, Paint paint) {
            this.mMatrixCanvas.drawPoint(x, y, paint);
        }

        private void initRect() {
            if (UITSPDrawingSegmentation.this.mOuterRectList != null) {
                FtUtil.log_d(UITSPDrawingSegmentation.this.CLASS_NAME, "initRect", "mOuterRectList");
                Iterator it = UITSPDrawingSegmentation.this.mOuterRectList.iterator();
                while (it.hasNext()) {
                    this.mMatrixCanvas.drawRect(((RectNode) it.next()).getRect(), this.mPaintRectOutLine);
                }
            }
            if (UITSPDrawingSegmentation.this.mCrossRectTopLeftList != null) {
                FtUtil.log_d(UITSPDrawingSegmentation.this.CLASS_NAME, "initRect", "mCrossRectTopLeftList");
                Iterator it2 = UITSPDrawingSegmentation.this.mCrossRectTopLeftList.iterator();
                while (it2.hasNext()) {
                    this.mMatrixCanvas.drawRect(((RectNode) it2.next()).getRect(), this.mPaintRectOutLine);
                }
            }
            if (UITSPDrawingSegmentation.this.mCrossRectTopRightList != null) {
                FtUtil.log_d(UITSPDrawingSegmentation.this.CLASS_NAME, "initRect", "mCrossRectTopRightList");
                Iterator it3 = UITSPDrawingSegmentation.this.mCrossRectTopRightList.iterator();
                while (it3.hasNext()) {
                    this.mMatrixCanvas.drawRect(((RectNode) it3.next()).getRect(), this.mPaintRectOutLine);
                }
            }
        }

        private void fillRect(float x, float y, Paint paint) {
            if (UITSPDrawingSegmentation.this.mOuterRectList != null) {
                Iterator it = UITSPDrawingSegmentation.this.mOuterRectList.iterator();
                while (true) {
                    if (!it.hasNext()) {
                        break;
                    }
                    RectNode r = (RectNode) it.next();
                    if (!r.isTouched && r.getRect().contains(x, y)) {
                        this.mMatrixCanvas.drawRect(r.getRect(), paint);
                        r.isTouched = true;
                        break;
                    }
                }
            }
            if (UITSPDrawingSegmentation.this.mCrossRectTopRightList != null) {
                Iterator it2 = UITSPDrawingSegmentation.this.mCrossRectTopRightList.iterator();
                while (true) {
                    if (!it2.hasNext()) {
                        break;
                    }
                    RectNode r2 = (RectNode) it2.next();
                    if (!r2.isTouched && r2.getRect().contains(x, y)) {
                        this.mMatrixCanvas.drawRect(r2.getRect(), paint);
                        r2.isTouched = true;
                        break;
                    }
                }
            }
            if (UITSPDrawingSegmentation.this.mCrossRectTopLeftList != null) {
                Iterator it3 = UITSPDrawingSegmentation.this.mCrossRectTopLeftList.iterator();
                while (it3.hasNext()) {
                    RectNode r3 = (RectNode) it3.next();
                    if (!r3.isTouched && r3.getRect().contains(x, y)) {
                        this.mMatrixCanvas.drawRect(r3.getRect(), paint);
                        r3.isTouched = true;
                        return;
                    }
                }
            }
        }

        private void initTextDrawingPaint() {
            int i = this.mScreenWidth;
            this.mRectHoveringText = new Rect(i / 3, 0, ((i / 3) * 2) + 25, (this.mScreenHeight / 16) + 10);
            Paint paint = new Paint();
            this.mPaintHoveringTextBackground = paint;
            paint.setColor(-1);
            this.mPaintHoveringTextBackground.setStyle(Paint.Style.FILL);
            this.mPaintHoveringTextBackground.setTextAlign(Paint.Align.LEFT);
            Paint paint2 = new Paint();
            this.mPaintHoveringText = paint2;
            paint2.setColor(-16777216);
            this.mPaintHoveringText.setAntiAlias(true);
            this.mPaintHoveringText.setStyle(Paint.Style.FILL);
            this.mPaintHoveringText.setTextAlign(Paint.Align.LEFT);
            this.mHoveringText = getResources().getString(R.string.spen_hovertest_result_hovering);
            int breakLength = -1;
            float fontSize = 80.0f;
            this.mPaintHoveringText.setTextSize(80.0f);
            while (this.mHoveringText.length() > breakLength) {
                breakLength = this.mPaintHoveringText.breakText(this.mHoveringText, true, (float) (this.mRectHoveringText.right - this.mRectHoveringText.left), null);
                String str = UITSPDrawingSegmentation.this.CLASS_NAME;
                FtUtil.log_d(str, "initTextDrawingPaint", "breakLength=" + breakLength);
                fontSize -= 1.0f;
                this.mPaintHoveringText.setTextSize(fontSize);
            }
            String str2 = UITSPDrawingSegmentation.this.CLASS_NAME;
            FtUtil.log_d(str2, "initTextDrawingPaint", "fontSize=" + fontSize);
        }

        private void drawHoverText(boolean result) {
            this.mMatrixCanvas.drawRect(this.mRectHoveringText, this.mPaintHoveringTextBackground);
            this.mMatrixCanvas.drawText(this.mHoveringText, (float) this.mRectHoveringText.left, (float) (this.mRectHoveringText.bottom - 10), this.mPaintHoveringText);
        }

        private void drawResultText(boolean result) {
            Paint paint = new Paint();
            if (result) {
                this.mResultText = getResources().getString(R.string.PASS);
                paint.setColor(UiHallICTest.FONT_COLOR_PASS);
            } else {
                this.mResultText = getResources().getString(R.string.FAIL);
                paint.setColor(-65536);
            }
            paint.setTextAlign(Paint.Align.CENTER);
            paint.setAntiAlias(true);
            paint.setTextSize(150.0f);
            this.mMatrixCanvas.drawText(this.mResultText, (float) ((this.mScreenWidth / 8) * 2), (float) ((this.mScreenHeight / 8) * 6), paint);
        }
    }
}
