package com.sec.factory.app.ui;

import android.content.Context;
import android.content.Intent;
import android.content.res.Resources;
import android.graphics.AvoidXfermode;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Point;
import android.graphics.Rect;
import android.graphics.RectF;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.Display;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.WindowManager;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.modules.ModuleTouchScreen;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.util.Iterator;
import java.util.LinkedList;

public class UITSPHoveringDrawTest extends UIBase {
    private static final String TAG = "UITSPHoveringDrawTest";
    private boolean CrossDoubleMode = false;
    private final float MARGINE = 4.0f;
    private final int SPEC_HEIGHT = 5;
    private final int SPEC_WIDTH = 10;
    private boolean isTestFinish = false;
    private boolean isTestStart = false;
    private ModuleDevice mModuleDevice;
    private float mNPixelForOneMM;
    private LinkedList<RectNode> mRectList = new LinkedList<>();

    /* access modifiers changed from: package-private */
    public class RectNode {
        boolean isTouched;
        RectF mRect;

        RectNode() {
        }

        RectNode(RectF rect) {
            this.mRect = rect;
            this.isTouched = false;
        }

        public RectF getRect() {
            return this.mRect;
        }
    }

    public UITSPHoveringDrawTest() {
        super(TAG, 56);
    }

    private void setTSP() {
        Resources r = getResources();
        String testcase = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML(this.TEST_ID));
        if (testcase.contains("MM_TO_PX")) {
            String mmToPx = testcase.substring(testcase.indexOf("MM_TO_PX(") + "MM_TO_PX(".length(), testcase.indexOf(")")).trim();
            String str = this.CLASS_NAME;
            FtUtil.log_d(str, "HoverView", "MM_TO_PX = " + mmToPx);
            this.mNPixelForOneMM = Float.parseFloat(mmToPx);
        } else {
            this.mNPixelForOneMM = TypedValue.applyDimension(5, 1.0f, r.getDisplayMetrics());
        }
        String str2 = this.CLASS_NAME;
        FtUtil.log_d(str2, "HoverView", "mNPixelForOneMM = " + this.mNPixelForOneMM);
    }

    /* access modifiers changed from: protected */
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "onActivityResult", "resultCode = " + requestCode);
        if (requestCode == 56) {
            String str2 = this.CLASS_NAME;
            FtUtil.log_d(str2, "onActivityResult", "resultCode = " + resultCode);
            if (resultCode == 0) {
                setResult(0);
                finish();
            }
        }
        FactoryTestManager.notifyDataSetChanged();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        FtUtil.log_d(this.CLASS_NAME, "onCreate");
        super.onCreate(savedInstanceState);
        this.mModuleDevice = ModuleDevice.instance(this);
        setTSP();
        this.CrossDoubleMode = getIntent().getExtras().getBoolean("CROSS_DOUBLE", false);
        setContentView(new HoverView(this));
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onPause() {
        FtUtil.log_d(this.CLASS_NAME, "onPause", "DisableHovering");
        this.mModuleDevice.hoveringOnOFF("0");
        if (Support.TestCase.getEnabled(Support.TestCase.IS_TSP_HOVERING_TEST_SET_EDGE_DEADLOCK)) {
            ModuleTouchScreen.instance(this).TSPHoveringEdge("0");
        }
        super.onPause();
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        FtUtil.log_d(this.CLASS_NAME, "onResume", "EnableHovering");
        this.mModuleDevice.hoveringOnOFF(EgisFingerprint.MAJOR_VERSION);
        if (Support.TestCase.getEnabled(Support.TestCase.IS_TSP_HOVERING_TEST_SET_EDGE_DEADLOCK)) {
            ModuleTouchScreen.instance(this).TSPHoveringEdge(EgisFingerprint.MAJOR_VERSION);
        }
        super.onResume();
    }

    @Override // com.sec.factory.app.ui.UIBase
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (keyCode == 24 && !isPassCross()) {
            setResult(0);
            finish();
        }
        return super.onKeyDown(keyCode, event);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean isPassCross() {
        int LeftRectEndIdx;
        int LeftRectStartIdx;
        boolean LeftTopCross = true;
        boolean RightTopCross = true;
        int RightRectStartIdx = 0;
        int RightRectEndIdx = 0;
        new RectNode();
        if (this.CrossDoubleMode) {
            LeftRectStartIdx = 0;
            LeftRectEndIdx = this.mRectList.size() / 2;
            RightRectStartIdx = this.mRectList.size() / 2;
            RightRectEndIdx = this.mRectList.size();
        } else {
            LeftRectStartIdx = 0;
            LeftRectEndIdx = this.mRectList.size();
        }
        int i = LeftRectStartIdx;
        while (true) {
            if (i >= LeftRectEndIdx) {
                break;
            } else if (!this.mRectList.get(i).isTouched) {
                LeftTopCross = false;
                break;
            } else {
                i++;
            }
        }
        if (this.CrossDoubleMode) {
            int i2 = RightRectStartIdx;
            while (true) {
                if (i2 >= RightRectEndIdx) {
                    break;
                } else if (!this.mRectList.get(i2).isTouched) {
                    RightTopCross = false;
                    break;
                } else {
                    i2++;
                }
            }
        } else {
            RightTopCross = false;
        }
        if (LeftTopCross || RightTopCross) {
            return true;
        }
        return false;
    }

    public class HoverView extends View {
        private static final int X_MARGINE = 25;
        private static final int Y_MARGINE = 10;
        private long MILLIS_IN_SEC = 100;
        private float col_height = 0.0f;
        private float col_width = 0.0f;
        private boolean isHovering;
        private boolean isTesteShouldAtOnce = true;
        private Paint mClickPaint;
        private float mHeightCross = 0.0f;
        private String mHoveringText;
        private Paint mLineFailPaint;
        private Paint mLinePaint;
        private Bitmap mMatrixBitmap;
        private Canvas mMatrixCanvas;
        private Paint mPaintHoveringText;
        private Paint mPaintHoveringTextBackground;
        private float mPreTouchedX = 0.0f;
        private float mPreTouchedY = 0.0f;
        private Rect mRectHoveringText;
        private String mResultText;
        private int mScreenHeight;
        private int mScreenWidth;
        private float mTouchedX = 0.0f;
        private float mTouchedY = 0.0f;
        private float mWidthBetween = 0.0f;
        private float mWidthCross = 0.0f;

        public HoverView(Context context) {
            super(context);
            setKeepScreenOn(true);
            Display mDisplay = ((WindowManager) context.getSystemService("window")).getDefaultDisplay();
            Point outpoint = new Point();
            mDisplay.getRealSize(outpoint);
            this.mScreenWidth = outpoint.x;
            this.mScreenHeight = outpoint.y;
            String str = UITSPHoveringDrawTest.this.CLASS_NAME;
            FtUtil.log_d(str, "HoverView", "mScreenWidth = " + this.mScreenWidth);
            String str2 = UITSPHoveringDrawTest.this.CLASS_NAME;
            FtUtil.log_d(str2, "HoverView", "mScreenHeight = " + this.mScreenHeight);
            int nRect = (int) ((((float) this.mScreenHeight) - ((UITSPHoveringDrawTest.this.mNPixelForOneMM * 4.0f) * 2.0f)) / (UITSPHoveringDrawTest.this.mNPixelForOneMM * 5.0f));
            float overLapWidth = ((((float) this.mScreenWidth) - (UITSPHoveringDrawTest.this.mNPixelForOneMM * 10.0f)) - ((UITSPHoveringDrawTest.this.mNPixelForOneMM * 4.0f) * 2.0f)) / ((float) (nRect + -1));
            float height = (((float) this.mScreenHeight) - ((UITSPHoveringDrawTest.this.mNPixelForOneMM * 4.0f) * 2.0f)) / ((float) nRect);
            String str3 = UITSPHoveringDrawTest.this.CLASS_NAME;
            FtUtil.log_d(str3, "HoverView", "nRect = " + nRect);
            String str4 = UITSPHoveringDrawTest.this.CLASS_NAME;
            FtUtil.log_d(str4, "HoverView", "overLapWidth = " + overLapWidth);
            String str5 = UITSPHoveringDrawTest.this.CLASS_NAME;
            FtUtil.log_d(str5, "HoverView", "height = " + height);
            this.mMatrixBitmap = Bitmap.createScaledBitmap(Bitmap.createBitmap(this.mScreenWidth, this.mScreenHeight, Bitmap.Config.ARGB_8888), this.mScreenWidth, this.mScreenHeight, false);
            Canvas canvas = new Canvas(this.mMatrixBitmap);
            this.mMatrixCanvas = canvas;
            canvas.drawColor(-1);
            float currentX = UITSPHoveringDrawTest.this.mNPixelForOneMM * 4.0f;
            float currentY = UITSPHoveringDrawTest.this.mNPixelForOneMM * 4.0f;
            int i = 0;
            while (i < nRect) {
                RectF r = new RectF();
                r.left = currentX;
                r.top = currentY;
                r.right = currentX + (UITSPHoveringDrawTest.this.mNPixelForOneMM * 10.0f);
                r.bottom = currentY + height;
                currentX += overLapWidth;
                currentY += height;
                String str6 = UITSPHoveringDrawTest.this.CLASS_NAME;
                FtUtil.log_d(str6, "HoverView", "currentX = " + currentX + ", currentY = " + currentY);
                UITSPHoveringDrawTest.this.mRectList.add(new RectNode(r));
                i++;
                mDisplay = mDisplay;
            }
            float currentX2 = currentX - overLapWidth;
            if (UITSPHoveringDrawTest.this.CrossDoubleMode) {
                float currentY2 = UITSPHoveringDrawTest.this.mNPixelForOneMM * 4.0f;
                for (int i2 = nRect; i2 < nRect * 2; i2++) {
                    RectF r2 = new RectF();
                    r2.left = currentX2;
                    r2.top = currentY2;
                    r2.right = (UITSPHoveringDrawTest.this.mNPixelForOneMM * 10.0f) + currentX2;
                    r2.bottom = currentY2 + height;
                    currentX2 -= overLapWidth;
                    currentY2 += height;
                    String str7 = UITSPHoveringDrawTest.this.CLASS_NAME;
                    FtUtil.log_d(str7, "HoverView", "currentX = " + currentX2 + ", currentY = " + currentY2);
                    UITSPHoveringDrawTest.this.mRectList.add(new RectNode(r2));
                }
            }
            setPaint();
            initRect();
            initTextDrawingPaint();
            this.isHovering = false;
        }

        private void setPaint() {
            Paint paint = new Paint();
            this.mLinePaint = paint;
            paint.setAntiAlias(true);
            this.mLinePaint.setColor(-16777216);
            this.mLinePaint.setStyle(Paint.Style.STROKE);
            this.mLinePaint.setStrokeJoin(Paint.Join.ROUND);
            this.mLinePaint.setStrokeWidth(5.0f);
            Paint paint2 = new Paint();
            this.mLineFailPaint = paint2;
            paint2.setAntiAlias(true);
            this.mLineFailPaint.setColor(-65536);
            this.mLineFailPaint.setStrokeWidth(20.0f);
            Paint paint3 = new Paint();
            this.mClickPaint = paint3;
            paint3.setAntiAlias(false);
            this.mClickPaint.setStyle(Paint.Style.FILL);
            this.mClickPaint.setColor(-16711936);
            this.mClickPaint.setXfermode(new AvoidXfermode(-1, 255, AvoidXfermode.Mode.TARGET));
        }

        /* access modifiers changed from: protected */
        public void onDraw(Canvas canvas) {
            canvas.drawBitmap(this.mMatrixBitmap, 0.0f, 0.0f, (Paint) null);
        }

        public boolean onTouchEvent(MotionEvent event) {
            int action = event.getAction();
            if (event.getToolType(0) == 2) {
                return true;
            }
            switch (action) {
                case 0:
                    this.mTouchedX = event.getX();
                    float y = event.getY();
                    this.mTouchedY = y;
                    drawPoint(this.mTouchedX, y, false);
                    break;
                case 1:
                    this.mTouchedX = event.getX();
                    float y2 = event.getY();
                    this.mTouchedY = y2;
                    drawPoint(this.mTouchedX, y2, false);
                    break;
                case 2:
                    for (int i = 0; i < event.getHistorySize(); i++) {
                        this.mPreTouchedX = this.mTouchedX;
                        this.mPreTouchedY = this.mTouchedY;
                        this.mTouchedX = event.getHistoricalX(i);
                        float historicalY = event.getHistoricalY(i);
                        this.mTouchedY = historicalY;
                        drawLine(this.mPreTouchedX, this.mPreTouchedY, this.mTouchedX, historicalY, false);
                    }
                    this.mPreTouchedX = this.mTouchedX;
                    this.mPreTouchedY = this.mTouchedY;
                    this.mTouchedX = event.getX();
                    float y3 = event.getY();
                    this.mTouchedY = y3;
                    drawLine(this.mPreTouchedX, this.mPreTouchedY, this.mTouchedX, y3, false);
                    break;
            }
            if (!UITSPHoveringDrawTest.this.isTestFinish) {
                Intent i2 = new Intent(UITSPHoveringDrawTest.this, UITspFail.class);
                i2.putExtra("isHovering", true);
                startActivityForResult(i2, 56);
                UITSPHoveringDrawTest.this.isTestFinish = true;
            }
            return true;
        }

        public boolean onHoverEvent(MotionEvent event) {
            event.getAction();
            if (event.getToolType(0) == 2) {
                return true;
            }
            drawByEvent(event);
            return true;
        }

        private void drawByEvent(MotionEvent event) {
            int action = event.getAction();
            if (!UITSPHoveringDrawTest.this.isTestFinish) {
                switch (action) {
                    case 7:
                        for (int i = 0; i < event.getHistorySize(); i++) {
                            this.mPreTouchedX = this.mTouchedX;
                            this.mPreTouchedY = this.mTouchedY;
                            this.mTouchedX = event.getHistoricalX(i);
                            float historicalY = event.getHistoricalY(i);
                            this.mTouchedY = historicalY;
                            drawRect(this.mTouchedX, historicalY, this.mClickPaint);
                            drawLine(this.mPreTouchedX, this.mPreTouchedY, this.mTouchedX, this.mTouchedY, true);
                        }
                        this.mPreTouchedX = this.mTouchedX;
                        this.mPreTouchedY = this.mTouchedY;
                        this.mTouchedX = event.getX();
                        this.mTouchedY = event.getY();
                        if (!UITSPHoveringDrawTest.this.isTestStart) {
                            UITSPHoveringDrawTest.this.isTestStart = true;
                        }
                        this.isHovering = true;
                        drawRect(this.mTouchedX, this.mTouchedY, this.mClickPaint);
                        drawLine(this.mPreTouchedX, this.mPreTouchedY, this.mTouchedX, this.mTouchedY, true);
                        return;
                    case 8:
                    default:
                        return;
                    case 9:
                        this.mTouchedX = event.getX();
                        float y = event.getY();
                        this.mTouchedY = y;
                        drawRect(this.mTouchedX, y, this.mClickPaint);
                        drawPoint(this.mTouchedX, this.mTouchedY, true);
                        drawHoverText(true);
                        if (!UITSPHoveringDrawTest.this.isTestStart) {
                            UITSPHoveringDrawTest.this.isTestStart = true;
                        }
                        this.isHovering = true;
                        return;
                    case 10:
                        if (this.isHovering) {
                            this.mPreTouchedX = this.mTouchedX;
                            this.mPreTouchedY = this.mTouchedY;
                            this.mTouchedX = event.getX();
                            float y2 = event.getY();
                            this.mTouchedY = y2;
                            float f = this.mPreTouchedX;
                            float f2 = this.mTouchedX;
                            if (f == f2 && this.mPreTouchedY == y2) {
                                drawPoint(f2, y2, true);
                            }
                            this.isHovering = false;
                        }
                        drawHoverText(false);
                        return;
                }
            }
        }

        private void drawLine(float preX, float preY, float x, float y, boolean isHover) {
            if (isHover) {
                this.mMatrixCanvas.drawLine(preX, preY, x, y, this.mLinePaint);
            } else {
                this.mMatrixCanvas.drawLine(preX, preY, x, y, this.mLineFailPaint);
            }
            if (preX >= x) {
                int highX = (int) preX;
                int lowX = (int) x;
            } else {
                int highX2 = (int) x;
                int lowX2 = (int) preX;
            }
            if (preY >= y) {
                int highY = (int) preY;
                int lowY = (int) y;
            } else {
                int highY2 = (int) y;
                int lowY2 = (int) preY;
            }
            invalidate();
        }

        private void drawPoint(float x, float y, boolean isHover) {
            if (isHover) {
                this.mMatrixCanvas.drawPoint(x, y, this.mLinePaint);
            } else {
                this.mMatrixCanvas.drawPoint(x, y, this.mLineFailPaint);
            }
            invalidate();
        }

        private void initRect() {
            Paint mRectPaintCross = new Paint();
            mRectPaintCross.setColor(-16777216);
            mRectPaintCross.setStyle(Paint.Style.STROKE);
            mRectPaintCross.setAntiAlias(true);
            mRectPaintCross.setStrokeWidth(3.0f);
            Iterator it = UITSPHoveringDrawTest.this.mRectList.iterator();
            while (it.hasNext()) {
                this.mMatrixCanvas.drawRect(((RectNode) it.next()).getRect(), mRectPaintCross);
            }
        }

        private void drawRect(float x, float y, Paint paint) {
            checkCrossRectRegion(x, y, paint);
            checkPassNfinishSpenTest();
        }

        private void checkPassNfinishSpenTest() {
            if (UITSPHoveringDrawTest.this.isPassCross()) {
                drawResultText(true);
                UITSPHoveringDrawTest.this.setResult(-1);
                FtUtil.log_d(UITSPHoveringDrawTest.this.CLASS_NAME, "checkPassNfinishSpenTest", "Pass!");
                UITSPHoveringDrawTest.this.finish();
            }
        }

        private void checkCrossRectRegion(float x, float y, Paint paint) {
            Iterator it = UITSPHoveringDrawTest.this.mRectList.iterator();
            while (it.hasNext()) {
                RectNode r = (RectNode) it.next();
                if (!r.isTouched && r.getRect().contains(x, y)) {
                    this.mMatrixCanvas.drawRect(r.getRect(), paint);
                    invalidate();
                    r.isTouched = true;
                }
            }
        }

        private void initTextDrawingPaint() {
            if (UITSPHoveringDrawTest.this.CrossDoubleMode) {
                int i = this.mScreenWidth;
                this.mRectHoveringText = new Rect(i / 3, 0, ((i / 3) * 2) + 25, (this.mScreenHeight / 16) + 10);
            } else {
                int i2 = this.mScreenWidth;
                this.mRectHoveringText = new Rect((i2 / 8) * 4, 0, (i2 / 8) * 8, ((this.mScreenHeight / 8) * 1) + 10);
            }
            Paint paint = new Paint();
            this.mPaintHoveringTextBackground = paint;
            paint.setColor(-1);
            this.mPaintHoveringTextBackground.setStyle(Paint.Style.FILL);
            this.mPaintHoveringTextBackground.setTextAlign(Paint.Align.LEFT);
            Paint paint2 = new Paint();
            this.mPaintHoveringText = paint2;
            paint2.setColor(-16777216);
            this.mPaintHoveringText.setAntiAlias(true);
            this.mPaintHoveringText.setStyle(Paint.Style.FILL);
            this.mPaintHoveringText.setTextAlign(Paint.Align.LEFT);
            this.mHoveringText = getResources().getString(R.string.spen_hovertest_result_hovering);
            int breakLength = -1;
            float fontSize = 80.0f;
            this.mPaintHoveringText.setTextSize(80.0f);
            while (this.mHoveringText.length() > breakLength) {
                breakLength = this.mPaintHoveringText.breakText(this.mHoveringText, true, (float) (this.mRectHoveringText.right - this.mRectHoveringText.left), null);
                String str = UITSPHoveringDrawTest.this.CLASS_NAME;
                FtUtil.log_d(str, "initTextDrawingPaint", "breakLength=" + breakLength);
                fontSize -= 1.0f;
                this.mPaintHoveringText.setTextSize(fontSize);
            }
            String str2 = UITSPHoveringDrawTest.this.CLASS_NAME;
            FtUtil.log_d(str2, "initTextDrawingPaint", "fontSize=" + fontSize);
        }

        private void drawHoverText(boolean result) {
            this.mMatrixCanvas.drawRect(this.mRectHoveringText, this.mPaintHoveringTextBackground);
            if (result) {
                if (UITSPHoveringDrawTest.this.CrossDoubleMode) {
                    this.mMatrixCanvas.drawText(this.mHoveringText, (float) this.mRectHoveringText.left, (float) (this.mRectHoveringText.bottom - 10), this.mPaintHoveringText);
                } else {
                    this.mMatrixCanvas.drawText(this.mHoveringText, (float) this.mRectHoveringText.left, (float) (this.mRectHoveringText.bottom - 10), this.mPaintHoveringText);
                }
            }
            invalidate();
        }

        private void drawResultText(boolean result) {
            Paint paint = new Paint();
            if (result) {
                this.mResultText = getResources().getString(R.string.PASS);
                paint.setColor(UiHallICTest.FONT_COLOR_PASS);
            } else {
                this.mResultText = getResources().getString(R.string.FAIL);
                paint.setColor(-65536);
            }
            paint.setTextAlign(Paint.Align.CENTER);
            paint.setAntiAlias(true);
            paint.setTextSize(150.0f);
            this.mMatrixCanvas.drawText(this.mResultText, (float) ((this.mScreenWidth / 8) * 2), (float) ((this.mScreenHeight / 8) * 6), paint);
            invalidate();
        }
    }
}
