package com.sec.factory.app.ui;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.KeyEvent;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;

public class UIUSBGen2 extends UIBase {
    private static final String ACTION_USB_STATE = "android.hardware.usb.action.USB_STATE";
    private static final int MSG_TEST_FINISH = 2;
    private static final int MSG_TEST_READY = 0;
    private static final int MSG_TEST_START = 1;
    private static final String TYPE_UNKNOWN = "UNKNOWN";
    private static final String TYPE_USB10 = "low-speed";
    private static final String TYPE_USB11 = "full-speed";
    private static final String TYPE_USB20 = "high-speed";
    private static final String TYPE_USB31_GEN1 = "super-speed";
    private static final String TYPE_USB31_GEN2 = "super-speed-plus";
    private final String CLASS_NAME = "UIUSBGen2";
    private final int TEST_CONNECT = 2;
    private final int TEST_START = 1;
    private BroadcastReceiver mBroadcastReceiverConnect = new BroadcastReceiver() {
        /* class com.sec.factory.app.ui.UIUSBGen2.AnonymousClass1 */

        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            FtUtil.log_d("UIUSBGen2", "mBroadcastReceiverConnect.onReceive", "action=" + action);
            if (UIUSBGen2.ACTION_USB_STATE.equals(action)) {
                boolean connected = intent.getExtras().getBoolean("connected");
                boolean configured = intent.getExtras().getBoolean("configured");
                FtUtil.log_d("UIUSBGen2", "USB State: " + connected + " Configured : " + configured);
                if (UIUSBGen2.this.mState == 1 && connected && configured) {
                    UIUSBGen2.this.mState = 2;
                    UIUSBGen2.this.mHandler.sendEmptyMessageDelayed(1, 500);
                } else if (UIUSBGen2.this.mState == 2 && !connected && !configured) {
                    UIUSBGen2.this.mHandler.sendEmptyMessageDelayed(2, 100);
                }
            }
        }
    };
    private BroadcastReceiver mBroadcastReceiverStop = new BroadcastReceiver() {
        /* class com.sec.factory.app.ui.UIUSBGen2.AnonymousClass2 */

        public synchronized void onReceive(Context context, Intent intent) {
            try {
                if ("com.android.samsungtest.USB_GEN2_STOP".equals(intent.getAction())) {
                    FtUtil.log_i("UIUSBGen2", "onReceive", "com.android.samsungtest.USB_GEN2_STOP");
                    UIUSBGen2.this.finish();
                }
            } catch (Exception e) {
                FtUtil.log_i("UIUSBGen2", "mBroadcastReceiverStop.onReceive", "Exception : " + e);
            }
        }
    };
    private Handler mHandler = new Handler() {
        /* class com.sec.factory.app.ui.UIUSBGen2.AnonymousClass3 */

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 0:
                    ModuleDevice moduleDevice = UIUSBGen2.this.mModuleDevice;
                    ModuleDevice unused = UIUSBGen2.this.mModuleDevice;
                    ModuleDevice unused2 = UIUSBGen2.this.mModuleDevice;
                    moduleDevice.turnOn4Led(15, ModuleDevice.LED4_YELLOW, 500, 500);
                    return;
                case 1:
                    UIUSBGen2.this.StartTest();
                    return;
                case 2:
                    UIUSBGen2.this.finish();
                    return;
                default:
                    return;
            }
        }
    };
    private ModuleDevice mModuleDevice;
    private int mState = 1;

    public UIUSBGen2() {
        super("UIUSBGen2", 183);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        ModuleDevice instance = ModuleDevice.instance(this);
        this.mModuleDevice = instance;
        instance.sendToPMSLEDControl(true);
        this.mHandler.sendEmptyMessageDelayed(0, 200);
    }

    /* access modifiers changed from: protected */
    @Override // com.sec.factory.app.ui.UIBase
    public void onResume() {
        IntentFilter filterConnect = new IntentFilter();
        filterConnect.addAction(ACTION_USB_STATE);
        registerReceiver(this.mBroadcastReceiverConnect, filterConnect);
        IntentFilter filterStop = new IntentFilter();
        filterStop.addAction("com.android.samsungtest.USB_GEN2_STOP");
        registerReceiver(this.mBroadcastReceiverStop, filterStop);
        this.mState = 1;
        super.onResume();
    }

    @Override // com.sec.factory.app.ui.UIBase
    public void onDestroy() {
        super.onDestroy();
        unregisterReceiver(this.mBroadcastReceiverConnect);
        unregisterReceiver(this.mBroadcastReceiverStop);
        this.mModuleDevice.turnOff4Led(15);
        this.mModuleDevice.sendToPMSLEDControl(false);
    }

    @Override // com.sec.factory.app.ui.UIBase
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        FtUtil.log_d("UIUSBGen2", "onKeyDown", "KeyCode : " + keyCode);
        switch (keyCode) {
            case 26:
                finish();
                return true;
            default:
                return true;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void StartTest() {
        FtUtil.log_d("UIUSBGen2", "StartTest", "");
        if (checkUSBGEN2()) {
            writeNV(183, true);
            this.mModuleDevice.turnOn4Led(15, ModuleDevice.LED4_GREEN, 1, 0);
            return;
        }
        writeNV(183, false);
        this.mModuleDevice.turnOn4Led(15, ModuleDevice.LED4_RED, 1, 0);
    }

    private boolean checkUSBGEN2() {
        if (TYPE_USB31_GEN2.equals(Support.Kernel.read(Support.Kernel.USBGEN2_CONNECTION_CHECK))) {
            FtUtil.log_d("UIUSBGen2", "checkUSBGEN2", "pass");
            return true;
        }
        FtUtil.log_d("UIUSBGen2", "checkUSBGEN2", "fail");
        return false;
    }

    private void writeNV(int id, boolean isPass) {
        if (isPass) {
            FtUtil.log_i("UIUSBGen2", "writeNV", "id : " + id + " PASS");
            setTestResult(id, (byte) 80);
            return;
        }
        FtUtil.log_e("UIUSBGen2", "writeNV", "FAIL");
        setTestResult(id, (byte) 70);
    }
}
