package com.sec.factory.app.ui;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.graphics.BitmapFactory;
import android.graphics.drawable.BitmapDrawable;
import android.os.Bundle;
import android.os.Environment;
import android.os.Handler;
import android.os.Message;
import android.view.KeyEvent;
import android.widget.ImageView;
import android.widget.LinearLayout;
import com.sec.factory.R;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.modules.vrr.RefreshRateChangeUtil;
import com.sec.factory.modules.vrr.VRRcontants;
import com.sec.factory.support.FtUtil;
import java.io.File;
import java.lang.ref.WeakReference;

public class UIVrrDisptestActivity extends Activity {
    private static final int ADAPTIVE_HIGH_SPEED = 1;
    private static final int ALWAYS_HIGH_SPEED = 2;
    private static final int BRIGHTNESS_MAX = 255;
    private static final int NORMAL_SPEED = 0;
    private static final String TAG = "UIVrrDisptestActivity";
    public static final String VRRDISPTEST_END = "android.intent.action.VRRDISPTEST_END";
    private LinearLayout mBgLayout;
    private ImageView mImageView;
    private String mImgFileName = null;
    private final WeakReferenceTestHandler mNotiHandler = new WeakReferenceTestHandler(this);
    private int mOriginalBrightness;
    private RefreshRateChangeUtil mRefreshRateChangeUtil;
    private BroadcastReceiver testEndReceiver = new BroadcastReceiver() {
        /* class com.sec.factory.app.ui.UIVrrDisptestActivity.AnonymousClass1 */

        public void onReceive(Context context, Intent intent) {
            if (intent.getAction().equals(UIVrrDisptestActivity.VRRDISPTEST_END)) {
                UIVrrDisptestActivity.this.finish();
            }
        }
    };

    private static class WeakReferenceTestHandler extends Handler {
        private final WeakReference<Activity> ref;

        public WeakReferenceTestHandler(Activity act) {
            this.ref = new WeakReference<>(act);
        }

        public void handleMessage(Message msg) {
        }
    }

    /* access modifiers changed from: protected */
    public void onCreate(Bundle arg0) {
        FtUtil.log_d(TAG, "onCreate", "onCreate");
        super.onCreate(arg0);
        setContentView(R.layout.ui_vrrdisptestactivity);
        this.mBgLayout = (LinearLayout) findViewById(R.id.background);
        this.mOriginalBrightness = ModulePower.instance(this).getBrightness();
        FtUtil.setRemoveSystemUI(getWindow(), true);
        FtUtil.setRemoveStatusBar(getWindow());
        FtUtil.disableDisplayCutOutMode(getWindow(), true);
        this.mRefreshRateChangeUtil = new RefreshRateChangeUtil(this, this.mNotiHandler);
    }

    public void onAttachedToWindow() {
        FtUtil.log_d(TAG, "onAttachedToWindow", "onAttachedToWindow");
        changeSettingFromIntent(getIntent());
    }

    /* access modifiers changed from: protected */
    public void onResume() {
        FtUtil.log_d(TAG, "onResume", "onResume");
        super.onResume();
        sendBroadcast(new Intent("com.samsung.android.aircommandmanager.STOP_MONITORING"));
        registerReceiver(this.testEndReceiver, new IntentFilter(VRRDISPTEST_END));
    }

    /* access modifiers changed from: protected */
    public void onNewIntent(Intent intent) {
        FtUtil.log_d(TAG, "onNewIntent", "onNewIntent");
        super.onNewIntent(intent);
        changeSettingFromIntent(intent);
    }

    private void changeSettingFromIntent(Intent intent) {
        FtUtil.log_d(TAG, "changeSettingFromIntent", "change setting");
        int rate = intent.getIntExtra("TEST_RATE", -1);
        int speed = intent.getIntExtra("TEST_SPEED", -1);
        String stringExtra = intent.getStringExtra("TEST_FILENAME");
        this.mImgFileName = stringExtra;
        displayBackground(stringExtra);
        FtUtil.log_d(TAG, "changeSettingFromIntent", "rate: " + rate + " speed: " + speed + " filename: " + this.mImgFileName);
        int speedMode = VRRcontants.REFRESH_RATE_MODE_ALWAYS;
        if (speed == 0) {
            speedMode = VRRcontants.REFRESH_RATE_MODE_NORMAL;
        } else if (speed == 1) {
            speedMode = VRRcontants.REFRESH_RATE_MODE_ADAPTIVE;
        } else if (speed == 2) {
            speedMode = VRRcontants.REFRESH_RATE_MODE_ALWAYS;
        }
        this.mRefreshRateChangeUtil.setRefreshRate(speedMode, rate);
        FtUtil.setRemoveStatusBar(getWindow());
        FtUtil.disableDisplayCutOutMode(getWindow(), true);
    }

    /* access modifiers changed from: protected */
    public void onPause() {
        FtUtil.log_d(TAG, "onPause", "onPause");
        super.onPause();
        sendBroadcast(new Intent("com.samsung.android.aircommandmanager.START_MONITORING"));
        unregisterReceiver(this.testEndReceiver);
    }

    /* access modifiers changed from: protected */
    public void onDestroy() {
        FtUtil.log_d(TAG, "onDestroy", "onDestroy");
        super.onDestroy();
        this.mRefreshRateChangeUtil.restoreDefault();
        this.mNotiHandler.removeCallbacksAndMessages(null);
        ModulePower.instance(this).setBrightness(this.mOriginalBrightness);
    }

    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (!event.isLongPress()) {
            return true;
        }
        switch (keyCode) {
            case 24:
                FtUtil.log_d(TAG, "onKeyDown", "VOLUME UP key long press");
                finish();
                return true;
            default:
                return true;
        }
    }

    private void displayBackground(String fileName) {
        FtUtil.log_d(TAG, "displayBackground", "file name: " + fileName);
        if ("WHITE".equals(fileName)) {
            ImageView imageView = (ImageView) findViewById(R.id.disptest_imageview);
            this.mImageView = imageView;
            imageView.setScaleType(ImageView.ScaleType.FIT_XY);
            this.mImageView.setBackgroundColor(-1);
        } else if ("BLACK".equals(fileName)) {
            ImageView imageView2 = (ImageView) findViewById(R.id.disptest_imageview);
            this.mImageView = imageView2;
            imageView2.setScaleType(ImageView.ScaleType.FIT_XY);
            this.mImageView.setBackgroundColor(-16777216);
        } else {
            ModulePower.instance(this).setBrightness(255);
            OpenFileForDisplayTest(fileName);
        }
    }

    private void OpenFileForDisplayTest(String file_name) {
        FtUtil.log_d(TAG, "OpenFileForDisplayTest", "file name: " + file_name);
        String SD_PATH = Environment.getExternalStorageDirectory().getPath() + "/testmedia/";
        String EXT_SD_PATH = ModuleDevice.instance(this).getStoragePath(1) + "/testmedia/";
        String path = null;
        String name = getFullName(EXT_SD_PATH, file_name);
        FtUtil.log_d(TAG, "OpenFileForDisplayTest", "Check Externel SD Card");
        if (!ModuleDevice.instance(this).isExternalMemoryExist() || !ModuleDevice.instance(this).isMountedStorage(1) || name == null) {
            String name2 = getFullName(SD_PATH, file_name);
            FtUtil.log_d(TAG, "OpenFileForDisplayTest", "Check SD Card");
            if (name2 != null) {
                FtUtil.log_d(TAG, "OpenFileForDisplayTest", "Get file from SD Card");
                path = SD_PATH + name2;
            } else {
                String name3 = getFullName("/system/factory/testmedia/", file_name);
                FtUtil.log_d(TAG, "OpenFileForDisplayTest", "Check data path");
                if (name3 != null) {
                    FtUtil.log_d(TAG, "OpenFileForDisplayTest", "Get file from data path");
                    path = "/system/factory/testmedia/" + name3;
                }
            }
        } else {
            FtUtil.log_d(TAG, "OpenFileForDisplayTest", "Get file from Externel SD Card");
            path = EXT_SD_PATH + name;
        }
        FtUtil.log_d(TAG, "OpenFileForDisplayTest", "path: " + path);
        if (path != null) {
            File imgFile = new File(path);
            if (imgFile.exists()) {
                this.mBgLayout.setBackgroundDrawable(new BitmapDrawable(BitmapFactory.decodeFile(imgFile.getAbsolutePath())));
                FtUtil.log_d(TAG, "OpenFileForDisplayTest", "background drawing done");
            }
        }
    }

    private String getFullName(String path, String name) {
        File[] files = new File(path).listFiles();
        if (files == null) {
            return null;
        }
        for (int i = 0; i < files.length; i++) {
            if (files[i].isFile()) {
                String fullName = files[i].getName();
                FtUtil.log_d(TAG, "getFullName", fullName);
                int pos = fullName.lastIndexOf(".");
                if (pos > 0) {
                    String fName = fullName.substring(0, pos);
                    FtUtil.log_d(TAG, "getFullName", fullName);
                    if (fName.equals(name)) {
                        return fullName;
                    }
                } else {
                    continue;
                }
            }
        }
        return null;
    }
}
