package com.sec.factory.app.uicommander;

import android.app.Service;
import android.content.Intent;
import android.net.LocalSocket;
import android.net.LocalSocketAddress;
import android.os.AsyncTask;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.os.Messenger;
import android.os.RemoteException;
import android.text.TextUtils;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.XMLDataStorage;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.nio.charset.Charset;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;

public class UICommanderService extends Service {
    public static final String CLASS_NAME = "UICommanderService";
    public static final int MSG_CONTROL_SCENARIO_THREAD = 7;
    public static final int MSG_FINISHED_SCENARIO_THREAD = 6;
    public static final int MSG_RECEIVE_COMMAND_RESPONSE = 5;
    public static final int MSG_REGISTER_CLIENT_IN_SERVICE = 1;
    public static final int MSG_RUN_SCENARIO_THREAD = 3;
    public static final int MSG_TRANSMIT_COMMAND = 4;
    public static final int MSG_UNREGISTER_CLIENT_IN_SERVICE = 2;
    public static final String SCENARIO_ITEM_COMPONENT_1 = "interval";
    public static final String SCENARIO_ITEM_COMPONENT_2 = "tx_command";
    public static final String SCENARIO_ITEM_COMPONENT_3 = "rx_matching";
    public static final String UI_UPDATE_HASHMAP_KEY_1 = "data";
    public static final String UI_UPDATE_HASHMAP_KEY_2 = "timestamp";
    public static final String UI_UPDATE_HASHMAP_KEY_3 = "type";
    private final ControlObject mControlObject = new ControlObject();
    private LocalSocket mLocalSocket;
    private Messenger mMessengerForClient = null;
    final Messenger mMessengerInService = new Messenger(this.mServiceMainHandler);
    private SocketInStream mRxReader;
    private ScenarioRunnerTask mScenarioRunnerTask = null;
    private Handler mServiceMainHandler = new Handler() {
        /* class com.sec.factory.app.uicommander.UICommanderService.AnonymousClass1 */

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "mServiceMainHandler.handleMessage", "MSG_REGISTER_CLIENT_IN_SERVICE");
                    UICommanderService.this.mMessengerForClient = msg.replyTo;
                    return;
                case 2:
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "mServiceMainHandler.handleMessage", "MSG_UNREGISTER_CLIENT_IN_SERVICE");
                    UICommanderService.this.mMessengerForClient = null;
                    return;
                case 3:
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "mServiceMainHandler.handleMessage", "MSG_RUN_SCENARIO_THREAD");
                    if (msg.obj != null) {
                        ArrayList<ScenarioItem> scenarioItemList = new ArrayList<>();
                        Iterator<HashMap<String, String>> it = ((ArrayList) msg.obj).iterator();
                        while (it.hasNext()) {
                            HashMap<String, String> item = it.next();
                            scenarioItemList.add(new ScenarioItem(item.get(UICommanderService.SCENARIO_ITEM_COMPONENT_1), item.get(UICommanderService.SCENARIO_ITEM_COMPONENT_2), item.get(UICommanderService.SCENARIO_ITEM_COMPONENT_3)));
                        }
                        FtUtil.log_d(UICommanderService.CLASS_NAME, "mServiceMainHandler.handleMessage", "MSG_RUN_SCENARIO_THREAD scenarioItemList.size():" + scenarioItemList.size());
                        ScenarioItem[] scenarioItemListArray = (ScenarioItem[]) scenarioItemList.toArray(new ScenarioItem[scenarioItemList.size()]);
                        if (UICommanderService.this.mScenarioRunnerTask == null) {
                            FtUtil.log_d(UICommanderService.CLASS_NAME, "mServiceMainHandler.handleMessage", "MSG_RUN_SCENARIO_THREAD execute mScenarioRunnerTask");
                            UICommanderService uICommanderService = UICommanderService.this;
                            UICommanderService uICommanderService2 = UICommanderService.this;
                            uICommanderService.mScenarioRunnerTask = new ScenarioRunnerTask(uICommanderService2.mControlObject, UICommanderService.this.mTxWriter);
                            UICommanderService.this.mScenarioRunnerTask.execute(scenarioItemListArray);
                            return;
                        }
                        FtUtil.log_d(UICommanderService.CLASS_NAME, "mServiceMainHandler.handleMessage", "MSG_RUN_SCENARIO_THREAD already executed another mScenarioRunnerTask");
                        return;
                    }
                    return;
                case 4:
                case 5:
                case 6:
                default:
                    super.handleMessage(msg);
                    return;
                case 7:
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "mServiceMainHandler.handleMessage", "MSG_CONTROL_SCENARIO_THREAD msg.obj:" + ((ScenarioStatus) msg.obj));
                    ScenarioStatus controlValue = (ScenarioStatus) msg.obj;
                    switch (AnonymousClass2.$SwitchMap$com$sec$factory$app$uicommander$UICommanderService$ScenarioStatus[controlValue.ordinal()]) {
                        case 1:
                        case 2:
                            UICommanderService.this.mControlObject.setStatus(controlValue);
                            return;
                        case 3:
                            UICommanderService.this.mControlObject.setStatus(ScenarioStatus.RUNNING);
                            return;
                        case 4:
                            UICommanderService.this.mControlObject.setStatus(controlValue);
                            UICommanderService.this.mControlObject.requestResume();
                            return;
                        default:
                            return;
                    }
            }
        }
    };
    private SocketOutStream mTxWriter;
    private Thread receiverThread = null;
    private SocketConnectThread socketConnectThread;

    public enum ScenarioStatus {
        NEW,
        RUNNABLE,
        RUNNING,
        TERMINATED,
        RUN,
        PAUSE,
        RESUME
    }

    public int onStartCommand(Intent intent, int flags, int startId) {
        FtUtil.log_d(CLASS_NAME, "onStartCommand", null);
        if (this.socketConnectThread != null) {
            return 1;
        }
        SocketConnectThread socketConnectThread2 = new SocketConnectThread(this.mControlObject);
        this.socketConnectThread = socketConnectThread2;
        socketConnectThread2.start();
        return 1;
    }

    public void onCreate() {
        FtUtil.log_d(CLASS_NAME, "onCreate", "Create UICommanderService");
        if (!XMLDataStorage.instance().parseXML(getApplicationContext())) {
            FtUtil.log_d(CLASS_NAME, "onCreate", "UICommanderService => XML data parsing was failed.");
        }
        if (this.socketConnectThread == null) {
            FtUtil.log_d(CLASS_NAME, "onCreate", "start socketConnectThread");
            SocketConnectThread socketConnectThread2 = new SocketConnectThread(this.mControlObject);
            this.socketConnectThread = socketConnectThread2;
            socketConnectThread2.start();
        }
    }

    public void onDestroy() {
        super.onDestroy();
        if (this.mScenarioRunnerTask != null) {
            FtUtil.log_d(CLASS_NAME, "onDestroy", "terminate mScenarioRunnerTask");
            this.mScenarioRunnerTask.cancel(true);
        }
        if (this.receiverThread != null) {
            FtUtil.log_d(CLASS_NAME, "onDestroy", "terminate receiverThread ??");
            this.receiverThread.interrupt();
            this.receiverThread = null;
        }
        FtUtil.log_d(CLASS_NAME, "onDestroy", "terminate socketConnectThread");
        this.socketConnectThread.disconnect();
    }

    public IBinder onBind(Intent intent) {
        return this.mMessengerInService.getBinder();
    }

    public boolean onUnbind(Intent intent) {
        return super.onUnbind(intent);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private HashMap<String, String> generateUiHashMap(String type, String data) {
        HashMap<String, String> uiHashMap = new HashMap<>();
        uiHashMap.put(UI_UPDATE_HASHMAP_KEY_3, type);
        uiHashMap.put("data", data);
        uiHashMap.put(UI_UPDATE_HASHMAP_KEY_2, new SimpleDateFormat("yyyy/MM/dd HH:mm:ss.SSS").format(new Date(System.currentTimeMillis())));
        return uiHashMap;
    }

    /* access modifiers changed from: private */
    public class SocketConnectThread extends Thread {
        private static final String SOCKET_NAME = "AirCmdService";
        private int MAX_TIMEOUT = 80;
        private ControlObject controlObject;
        private LocalSocket localSocket;
        private LocalSocketAddress localSocketAddress;

        public SocketConnectThread(ControlObject controlObject2) {
            this.controlObject = controlObject2;
            this.localSocket = new LocalSocket(2);
            this.localSocketAddress = new LocalSocketAddress(SOCKET_NAME);
        }

        public void run() {
            FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.run", "start");
            boolean connected = false;
            while (true) {
                if (connected) {
                    break;
                }
                try {
                    if (!this.localSocket.isConnected()) {
                        this.localSocket.connect(this.localSocketAddress);
                        FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.run", "Connect client socket");
                    }
                } catch (IOException e) {
                    e.printStackTrace();
                    FtUtil.log_e(e);
                }
                if (this.localSocket.isConnected()) {
                    connected = true;
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.run", "Client socket connect success");
                } else {
                    connected = false;
                    int i = this.MAX_TIMEOUT;
                    this.MAX_TIMEOUT = i - 1;
                    if (i < 0) {
                        FtUtil.log_w(UICommanderService.CLASS_NAME, "SocketConnectThread.run", "Connection accept failed");
                        break;
                    }
                    FtUtil.Sleep.sleep(1000);
                }
            }
            if (connected) {
                FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.run", "Connected to AT Core(ATD) through AirCmdService");
                UICommanderService uICommanderService = UICommanderService.this;
                uICommanderService.mRxReader = new SocketInStream(this.localSocket);
                UICommanderService uICommanderService2 = UICommanderService.this;
                uICommanderService2.mTxWriter = new SocketOutStream(this.localSocket);
                UICommanderService.this.mLocalSocket = this.localSocket;
                FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.run", "set instance of mRxReader, mTxWriter, mLocalSocket");
                if (UICommanderService.this.receiverThread == null) {
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.run", "execute receiverThread");
                    UICommanderService uICommanderService3 = UICommanderService.this;
                    UICommanderService uICommanderService4 = UICommanderService.this;
                    uICommanderService3.receiverThread = new Thread(new ReceiverThread(this.controlObject, uICommanderService4.mRxReader));
                    UICommanderService.this.receiverThread.start();
                }
            }
            FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.run", "end");
        }

        public void disconnect() {
            FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.disconnect", "start");
            FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.disconnect", "request socketConnectThread.interrupt ??");
            UICommanderService.this.socketConnectThread.interrupt();
            if (this.localSocket != null) {
                FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.disconnect", "try localSocket.shutdownInput(SocketInStream)");
                try {
                    this.localSocket.shutdownInput();
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.disconnect", "receiverThread maybe end loop?");
                } catch (IOException e) {
                    e.printStackTrace();
                    FtUtil.log_e(e);
                }
                FtUtil.Sleep.sleep(5);
                FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.disconnect", "try localSocket.shutdownOutput(SocketOutStream)");
                try {
                    this.localSocket.shutdownOutput();
                } catch (IOException e2) {
                    e2.printStackTrace();
                    FtUtil.log_e(e2);
                }
                FtUtil.Sleep.sleep(5);
                FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.disconnect", "try localSocket.close");
                try {
                    this.localSocket.close();
                } catch (IOException e3) {
                    e3.printStackTrace();
                    FtUtil.log_e(e3);
                }
                FtUtil.Sleep.sleep(5);
                FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.disconnect", "set mRxReader, mTxWriter, mLocalSocket to null");
                UICommanderService.this.mRxReader = null;
                UICommanderService.this.mTxWriter = null;
                UICommanderService.this.mLocalSocket = null;
            }
            FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.disconnect", "set socketConnectThread to null");
            UICommanderService.this.socketConnectThread = null;
            FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketConnectThread.disconnect", "end");
        }
    }

    /* access modifiers changed from: private */
    public class SocketOutStream {
        private final int STREAM_BUFFER_SIZE = 8192;
        private LocalSocket localSocket;
        private DataOutputStream out;

        public SocketOutStream(LocalSocket socketToSendData) {
            FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketOutStream", "create SocketOutStream");
            this.localSocket = socketToSendData;
            if (socketToSendData.isConnected()) {
                try {
                    this.out = new DataOutputStream(new BufferedOutputStream(socketToSendData.getOutputStream(), 8192));
                } catch (IOException e) {
                    e.printStackTrace();
                    FtUtil.log_e(e);
                }
            } else {
                FtUtil.log_e(UICommanderService.CLASS_NAME, "SocketOutStream", "socket is closed");
            }
        }

        public synchronized boolean write(String msg) {
            boolean result;
            result = false;
            if (msg != null) {
                FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketOutStream.write", "msg:" + msg);
                if (this.localSocket.isConnected()) {
                    result = writeToSocket(msg);
                }
            }
            return result;
        }

        private boolean writeToSocket(String msg) {
            boolean result = false;
            DataOutputStream dataOutputStream = this.out;
            if (dataOutputStream == null || msg == null) {
                FtUtil.log_e(UICommanderService.CLASS_NAME, "SocketOutStream.writeToSocket", "out is null");
                return false;
            }
            try {
                dataOutputStream.writeBytes(msg);
                this.out.flush();
                result = true;
                FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketOutStream.writeToSocket", "out.writeBytes and out.flush success");
                return true;
            } catch (IOException e) {
                e.printStackTrace();
                FtUtil.log_e(e);
                return result;
            }
        }
    }

    /* access modifiers changed from: private */
    public class SocketInStream {
        private final int INPUT_BUFFER_SIZE = 8192;
        private StringBuffer dataBuffer;
        private byte[] empty;
        private byte[] hexData;
        private BufferedInputStream inStream;
        private LocalSocket localSocket;
        private String response = null;

        public SocketInStream(LocalSocket socketToReadData) {
            FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketInStream", "create SocketInStream");
            this.localSocket = socketToReadData;
            if (socketToReadData.isConnected()) {
                try {
                    this.inStream = new BufferedInputStream(this.localSocket.getInputStream());
                } catch (IOException e) {
                    e.printStackTrace();
                    FtUtil.log_e(e);
                }
                this.dataBuffer = new StringBuffer(8192);
                byte[] bArr = new byte[8192];
                this.hexData = bArr;
                byte[] bArr2 = new byte[8192];
                this.empty = bArr2;
                System.arraycopy(bArr2, 0, bArr, 0, bArr.length);
                StringBuffer stringBuffer = this.dataBuffer;
                stringBuffer.delete(0, stringBuffer.length());
                return;
            }
            FtUtil.log_e(UICommanderService.CLASS_NAME, "SocketInStream", "socket is closed");
        }

        public boolean read() {
            FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketInStream.read", "start");
            boolean result = false;
            this.response = null;
            if (this.localSocket.isConnected() && this.inStream != null) {
                try {
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketInStream.read", "inStream.available():" + this.inStream.available());
                } catch (IOException e) {
                    e.printStackTrace();
                    FtUtil.log_e(e);
                }
                try {
                    BufferedInputStream bufferedInputStream = this.inStream;
                    byte[] bArr = this.hexData;
                    int count = bufferedInputStream.read(bArr, 0, bArr.length);
                    if (count != -1) {
                        byte[] tempData = new byte[count];
                        System.arraycopy(this.hexData, 0, tempData, 0, count);
                        if (tempData[tempData.length - 1] == 126) {
                            for (byte byteValue : tempData) {
                                this.dataBuffer.append(String.format("%02X", Byte.valueOf(byteValue)));
                            }
                        } else {
                            this.dataBuffer.append(new String(this.hexData, 0, count, Charset.forName("UTF-8")));
                            this.dataBuffer.trimToSize();
                        }
                        FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketInStream.read", "dataBuffer(length:" + this.dataBuffer.length() + "):<" + this.dataBuffer.toString() + ">");
                        this.response = this.dataBuffer.toString();
                        StringBuffer stringBuffer = this.dataBuffer;
                        stringBuffer.delete(0, stringBuffer.length());
                        byte[] bArr2 = this.empty;
                        byte[] bArr3 = this.hexData;
                        System.arraycopy(bArr2, 0, bArr3, 0, bArr3.length);
                        result = true;
                    } else {
                        FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketInStream.read", "count:" + count);
                        result = false;
                    }
                } catch (IOException e2) {
                    e2.printStackTrace();
                    FtUtil.log_e(e2);
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketInStream.read", "inStream closed");
                    return false;
                }
            }
            FtUtil.log_d(UICommanderService.CLASS_NAME, "SocketInStream.read", "end, result:" + result);
            return result;
        }

        public String getResponse() {
            return this.response;
        }
    }

    private class ReceiverThread implements Runnable {
        private static final String RESPONSE_FORMAT = "OK\r\n";
        private ControlObject controlObject;
        private SocketInStream rxReader;

        public ReceiverThread(ControlObject controlObject2, SocketInStream rxReader2) {
            this.controlObject = controlObject2;
            this.rxReader = rxReader2;
        }

        public void run() {
            FtUtil.log_d(UICommanderService.CLASS_NAME, "ReceiverThread.run", "start");
            StringBuilder responseSB = new StringBuilder();
            if (!this.controlObject.isCompletedResponseEmpty()) {
                this.controlObject.clearCompletedResponse();
            }
            FtUtil.log_d(UICommanderService.CLASS_NAME, "ReceiverThread.run", "enter rxReader.read loop");
            while (this.rxReader.read()) {
                FtUtil.log_d(UICommanderService.CLASS_NAME, "ReceiverThread.run", "rxReader.read success");
                String received = this.rxReader.getResponse();
                if (UICommanderService.this.mMessengerForClient != null) {
                    try {
                        UICommanderService.this.mMessengerForClient.send(Message.obtain(null, 5, UICommanderService.this.generateUiHashMap("RX", received)));
                    } catch (RemoteException e) {
                        e.printStackTrace();
                        FtUtil.log_e(e);
                        return;
                    }
                }
                switch (this.controlObject.getStatus()) {
                    case PAUSE:
                    case RUN:
                    case RESUME:
                    case RUNNING:
                        FtUtil.log_d(UICommanderService.CLASS_NAME, "ReceiverThread.run", "append in responseSB");
                        responseSB.append(received);
                        if (responseSB.length() >= RESPONSE_FORMAT.length() && TextUtils.equals(RESPONSE_FORMAT, responseSB.substring(responseSB.length() - RESPONSE_FORMAT.length(), responseSB.length()))) {
                            FtUtil.log_d(UICommanderService.CLASS_NAME, "ReceiverThread.run", "set completedResponse(flush responseSB)");
                            this.controlObject.setCompletedResponse(responseSB.toString());
                            FtUtil.log_d(UICommanderService.CLASS_NAME, "ReceiverThread.run", "clear responseSB");
                            responseSB.delete(0, responseSB.length());
                            break;
                        }
                }
            }
            FtUtil.log_d(UICommanderService.CLASS_NAME, "ReceiverThread.run", "escaped rxReader.read loop");
            FtUtil.log_d(UICommanderService.CLASS_NAME, "ReceiverThread.run", "end");
        }
    }

    /* access modifiers changed from: private */
    public class ScenarioRunnerTask extends AsyncTask<ScenarioItem, Void, Boolean> {
        private static final String SERVICE_EOL_STRING = "\r\n";
        private ControlObject controlObject;
        private SocketOutStream txWriter;

        public ScenarioRunnerTask(ControlObject controlObject2, SocketOutStream txWriter2) {
            this.controlObject = controlObject2;
            this.txWriter = txWriter2;
        }

        /* access modifiers changed from: protected */
        public void onPreExecute() {
            super.onPreExecute();
        }

        /* access modifiers changed from: protected */
        public Boolean doInBackground(ScenarioItem... scenarioItems) {
            if (TextUtils.isEmpty(scenarioItems[0].getTxCommand())) {
                FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "scenarioItems[0].getTxCommand is null");
                return false;
            }
            FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "start");
            FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "scenarioItems.length:" + scenarioItems.length);
            for (ScenarioItem item : scenarioItems) {
                if (item.getIntervalMsAsInteger() > 0) {
                    FtUtil.Sleep.sleep((long) item.getIntervalMsAsInteger());
                }
                if (isCancelled()) {
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "cancelled during interval");
                    return false;
                }
                if (this.controlObject.getStatus() == ScenarioStatus.PAUSE) {
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "ScenarioStatus PAUSE (interval<->transmit)");
                    try {
                        this.controlObject.requestPause();
                        if (this.controlObject.getStatus() == ScenarioStatus.RESUME) {
                            FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "change status PAUSE->RESUME->RUNNING (interval<->transmit)");
                            this.controlObject.setStatus(ScenarioStatus.RUNNING);
                        }
                    } catch (InterruptedException e) {
                        if (isCancelled()) {
                            FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "cancelled during pause(interval<->transmit)");
                            return false;
                        }
                    }
                }
                String txString = item.getTxCommand() + SERVICE_EOL_STRING;
                if (UICommanderService.this.mMessengerForClient != null) {
                    try {
                        UICommanderService.this.mMessengerForClient.send(Message.obtain(null, 4, UICommanderService.this.generateUiHashMap("TX", txString)));
                    } catch (RemoteException e2) {
                        e2.printStackTrace();
                        FtUtil.log_e(e2);
                    }
                }
                FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "write txString(length:" + txString.length() + "): <" + txString + ">");
                if (!this.txWriter.write(txString)) {
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "txWriter.write fail");
                    return false;
                }
                FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "wait receiving response, default timeout 10000ms");
                String rxString = null;
                try {
                    rxString = this.controlObject.getCompletedResponse(10000);
                } catch (InterruptedException e3) {
                    if (isCancelled()) {
                        FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "cancelled during receiving response");
                        return false;
                    }
                }
                FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "received completed response");
                if (TextUtils.equals(rxString, "TIMEOUT")) {
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "timeout during receiving response");
                    if (UICommanderService.this.mMessengerForClient != null) {
                        try {
                            UICommanderService.this.mMessengerForClient.send(Message.obtain(null, 4, UICommanderService.this.generateUiHashMap("CORE", rxString)));
                        } catch (RemoteException e4) {
                            e4.printStackTrace();
                            FtUtil.log_e(e4);
                        }
                    }
                    return false;
                }
                String rxMatching = item.getRxMatching();
                if (!(TextUtils.isEmpty(rxMatching) || checkSpec(rxString, rxMatching))) {
                    return false;
                }
            }
            FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.doInBackground", "end, return true");
            return true;
        }

        /* access modifiers changed from: protected */
        public void onProgressUpdate(Void... values) {
            super.onProgressUpdate((Object[]) values);
        }

        /* access modifiers changed from: protected */
        public void onPostExecute(Boolean backgroundResult) {
            super.onPostExecute((Object) backgroundResult);
            if (!backgroundResult.booleanValue()) {
                FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.onPostExecute", "scenario runner FAIL");
            } else {
                FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.onPostExecute", "scenario runner SUCCESS");
            }
            if (UICommanderService.this.mMessengerForClient != null) {
                try {
                    UICommanderService.this.mMessengerForClient.send(Message.obtain(null, 6, backgroundResult));
                } catch (RemoteException e) {
                    e.printStackTrace();
                    FtUtil.log_e(e);
                }
            }
            UICommanderService.this.mScenarioRunnerTask = null;
        }

        /* access modifiers changed from: protected */
        public void onCancelled(Boolean backgroundResult) {
            super.onCancelled((Object) backgroundResult);
            FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.onCancelled(Boolean)", "result:" + backgroundResult);
            this.controlObject.setStatus(ScenarioStatus.TERMINATED);
            UICommanderService.this.mScenarioRunnerTask = null;
        }

        /* JADX INFO: Multiple debug info for r1v24 float: [D('ne' java.lang.NumberFormatException), D('upperSpec' float)] */
        /* JADX WARNING: Removed duplicated region for block: B:38:0x00ec  */
        /* JADX WARNING: Removed duplicated region for block: B:87:0x00fa A[SYNTHETIC] */
        private boolean checkSpec(String strRxResult, String strRawRxSpec) {
            HashMap<String, String> indexAndSpecHashMap;
            int i;
            NumberFormatException e;
            float floatValue;
            float lowerSpec;
            float upperSpec;
            HashMap<String, String> indexAndSpecHashMap2 = new HashMap<>();
            for (String strSpec : strRawRxSpec.split(",")) {
                String[] indexAndSpec = strSpec.split("__");
                if (indexAndSpec.length == 2) {
                    indexAndSpecHashMap2.put(indexAndSpec[0], indexAndSpec[1]);
                }
            }
            if (strRxResult != null) {
                String[] arrStrRxLine = strRxResult.split("\n");
                if (arrStrRxLine.length <= 1) {
                    return true;
                }
                String[] arrStrRxParam = arrStrRxLine[1].split(",");
                int i2 = 1;
                while (i2 < arrStrRxParam.length) {
                    String strSpec2 = indexAndSpecHashMap2.get(i2 + "");
                    if (strSpec2 != null) {
                        String strSpec3 = strSpec2.trim();
                        arrStrRxParam[i2] = arrStrRxParam[i2].trim();
                        if (strSpec3.contains("~")) {
                            String[] arrUpperLower = strSpec3.split("~");
                            if (arrUpperLower.length == 2) {
                                try {
                                    int intValue = Integer.parseInt(arrStrRxParam[i2]);
                                    int lowerSpec2 = (int) Float.parseFloat(arrUpperLower[0]);
                                    indexAndSpecHashMap = indexAndSpecHashMap2;
                                    try {
                                        int upperSpec2 = (int) Float.parseFloat(arrUpperLower[1]);
                                        if (lowerSpec2 <= intValue) {
                                            if (upperSpec2 < intValue) {
                                            }
                                        }
                                        FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.checkSpec", "Failed! index[" + i2 + "], spec[" + strSpec3 + "], result[" + intValue + "]");
                                        return false;
                                    } catch (NumberFormatException e2) {
                                        e = e2;
                                        try {
                                            floatValue = Float.parseFloat(arrStrRxParam[i2]);
                                            lowerSpec = Float.parseFloat(arrUpperLower[0]);
                                            float upperSpec3 = Float.parseFloat(arrUpperLower[1]);
                                            if (Float.compare(floatValue, lowerSpec) < 0) {
                                                upperSpec = upperSpec3;
                                                try {
                                                    if (Float.compare(floatValue, upperSpec) <= 0) {
                                                        i2++;
                                                        indexAndSpecHashMap2 = indexAndSpecHashMap;
                                                    }
                                                } catch (NumberFormatException e3) {
                                                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.checkSpec", "Failed, should check spec and result! index[" + i2 + "]");
                                                    i2++;
                                                    indexAndSpecHashMap2 = indexAndSpecHashMap;
                                                }
                                            } else {
                                                upperSpec = upperSpec3;
                                            }
                                            FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.checkSpec", "Failed! index[" + i2 + "], spec[" + strSpec3 + "], result[" + floatValue + "]");
                                            return false;
                                        } catch (NumberFormatException e4) {
                                            FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.checkSpec", "Failed, should check spec and result! index[" + i2 + "]");
                                            i2++;
                                            indexAndSpecHashMap2 = indexAndSpecHashMap;
                                        }
                                    }
                                } catch (NumberFormatException e5) {
                                    e = e5;
                                    indexAndSpecHashMap = indexAndSpecHashMap2;
                                    floatValue = Float.parseFloat(arrStrRxParam[i2]);
                                    lowerSpec = Float.parseFloat(arrUpperLower[0]);
                                    float upperSpec32 = Float.parseFloat(arrUpperLower[1]);
                                    if (Float.compare(floatValue, lowerSpec) < 0) {
                                    }
                                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.checkSpec", "Failed! index[" + i2 + "], spec[" + strSpec3 + "], result[" + floatValue + "]");
                                    return false;
                                }
                            } else {
                                indexAndSpecHashMap = indexAndSpecHashMap2;
                            }
                        } else {
                            indexAndSpecHashMap = indexAndSpecHashMap2;
                            boolean isLogicalOpposite = false;
                            if (strSpec3.charAt(0) == '!') {
                                FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.checkSpec", "add condition logical oppoisite");
                                i = 1;
                                strSpec3 = strSpec3.substring(1);
                                isLogicalOpposite = true;
                            } else {
                                i = 1;
                            }
                            if (strSpec3.charAt(0) == '|') {
                                String strSpec4 = strSpec3.substring(i);
                                boolean isContainSpec = arrStrRxParam[i2].contains(strSpec4);
                                if ((!isContainSpec && !isLogicalOpposite) || (isContainSpec && isLogicalOpposite)) {
                                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.checkSpec", "check contains, fail, index[" + i2 + "], spec[" + strSpec4 + "], result[" + arrStrRxParam[i2] + "]");
                                    return false;
                                }
                            } else {
                                boolean isEquals = strSpec3.equalsIgnoreCase(arrStrRxParam[i2]);
                                if ((!isEquals && !isLogicalOpposite) || (isEquals && isLogicalOpposite)) {
                                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.checkSpec", "check matched, index[" + i2 + "], spec[" + strSpec3 + "], result[" + arrStrRxParam[i2] + "]");
                                    return false;
                                }
                            }
                        }
                    } else {
                        indexAndSpecHashMap = indexAndSpecHashMap2;
                    }
                    i2++;
                    indexAndSpecHashMap2 = indexAndSpecHashMap;
                }
                return true;
            }
            FtUtil.log_d(UICommanderService.CLASS_NAME, "ScenarioRunnerTask.checkSpec", "strRxResult miss! stop scenario runner");
            return false;
        }
    }

    /* access modifiers changed from: private */
    public class ControlObject {
        private String completedResponse;
        private Object lockControlStatus;
        private Object lockResponse;
        private StringBuilder responseBuilder;
        private ScenarioStatus status;

        private ControlObject() {
            this.completedResponse = null;
            this.status = ScenarioStatus.NEW;
            this.responseBuilder = new StringBuilder();
            this.lockResponse = new Object();
            this.lockControlStatus = new Object();
        }

        public void setCompletedResponse(String responseString) {
            synchronized (this.lockResponse) {
                if (this.completedResponse == null) {
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ControlObject.setCompletedResponse", "completedResponse is null");
                    this.completedResponse = responseString;
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ControlObject.setCompletedResponse", "set completedResponse:" + this.completedResponse);
                    this.lockResponse.notifyAll();
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ControlObject.setCompletedResponse", "called notify");
                } else {
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ControlObject.setCompletedResponse", "completedResponse(not null):" + this.completedResponse);
                }
            }
        }

        public String getCompletedResponse() throws InterruptedException {
            return getCompletedResponse(0);
        }

        public String getCompletedResponse(int timeout) throws InterruptedException {
            String returnValue;
            boolean isTimeout = false;
            synchronized (this.lockResponse) {
                while (true) {
                    if (this.completedResponse != null) {
                        break;
                    }
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ControlObject.getCompletedResponse", "completedResponse is null, timeout:" + timeout);
                    long waitStartTime = System.currentTimeMillis();
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ControlObject.getCompletedResponse", "start wait:" + waitStartTime);
                    this.lockResponse.wait((long) timeout);
                    long waitEndTime = System.currentTimeMillis();
                    FtUtil.log_d(UICommanderService.CLASS_NAME, "ControlObject.getCompletedResponse", "end wait:" + waitEndTime);
                    if (waitEndTime - waitStartTime >= ((long) timeout)) {
                        isTimeout = true;
                        break;
                    }
                }
                if (isTimeout) {
                    returnValue = "TIMEOUT";
                } else {
                    returnValue = this.completedResponse;
                }
                clearCompletedResponse();
            }
            FtUtil.log_d(UICommanderService.CLASS_NAME, "ControlObject.getCompletedResponse", "returnValue:" + returnValue);
            return returnValue;
        }

        public void clearCompletedResponse() {
            synchronized (this.lockResponse) {
                this.completedResponse = null;
            }
        }

        public boolean isCompletedResponseEmpty() {
            boolean returnValue;
            synchronized (this.lockResponse) {
                returnValue = this.completedResponse == null;
            }
            return returnValue;
        }

        public void setStatus(ScenarioStatus status2) {
            synchronized (this.lockControlStatus) {
                this.status = status2;
            }
        }

        public ScenarioStatus getStatus() {
            ScenarioStatus returnValue;
            synchronized (this.lockControlStatus) {
                returnValue = this.status;
            }
            return returnValue;
        }

        public void requestPause() throws InterruptedException {
            synchronized (this.lockControlStatus) {
                this.lockControlStatus.wait();
            }
        }

        public void requestResume() {
            synchronized (this.lockControlStatus) {
                this.lockControlStatus.notifyAll();
            }
        }

        public StringBuilder getResponseBuilder() {
            return this.responseBuilder;
        }
    }

    public static class ScenarioItem {
        private String intervalMs;
        private String rxMatching;
        private String txCommand;

        public ScenarioItem(String intervalMs2, String txCommand2, String rxMatching2) {
            this.intervalMs = intervalMs2;
            this.txCommand = txCommand2;
            this.rxMatching = rxMatching2;
        }

        public int getIntervalMsAsInteger() {
            if (TextUtils.isEmpty(getIntervalMs())) {
                setIntervalMs("0");
            }
            return Integer.valueOf(getIntervalMs()).intValue();
        }

        public String getIntervalMs() {
            return this.intervalMs;
        }

        public void setIntervalMs(String intervalMs2) {
            this.intervalMs = intervalMs2;
        }

        public String getTxCommand() {
            return this.txCommand;
        }

        public void setTxCommand(String txCommand2) {
            this.txCommand = txCommand2;
        }

        public String getRxMatching() {
            return this.rxMatching;
        }

        public void setRxMatching(String rxMatching2) {
            this.rxMatching = rxMatching2;
        }
    }
}
