package com.sec.factory.common;

import android.content.Context;
import android.hardware.fingerprint.FingerprintManager;
import android.os.Handler;
import android.os.Message;
import android.os.SystemProperties;
import com.sec.factory.modules.ModuleCommunicationService;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egistec.csa.client.api.Fingerprint;
import egistec.optical.csa.client.api.Fingerprint;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.StringReader;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedHashMap;

public class CommonFingerprintEgis {
    public static final int CALIBRATION_FINISHED = 1004;
    public static final int CAPTURE_FAILED = 310;
    public static final int CAPTURE_FINISHED = 320;
    public static final int CAPTURE_READY = 301;
    public static final int CAPTURE_STARTED = 303;
    public static final int CAPTURE_SUCCESS = 309;
    private static final String CLASS_NAME = "CommonFingerprintEgis";
    public static final int END_TEST = 500;
    public static final int ENROLL_FAILED = 314;
    public static final int ENROLL_SUCCESS = 313;
    public static final int EVT_ERROR = 2020;
    private static final int FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_END_GOOGLE = 10009;
    private static final int FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_START_GOOGLE = 10008;
    public static final String FP_TEST_STATUS = "fp_test_status";
    public static final String FP_TEST_STEP = "fp_test_step";
    public static final int IDENTIFY_FAILED = 318;
    public static final int IDENTIFY_SUCCESS = 317;
    public static final int NEED_CHECK_BRIGHTNESS = 1001;
    public static final String PATH_CHIP_NAME = "/sys/class/fingerprint/fingerprint/name";
    public static final String PATH_LOG_CALIBRATION = "/data/log/FingerSNRData.log";
    public static final String PATH_LOG_NORMAL_SCAN = "/data/log/FingerNormalData.log";
    public static final String PATH_RESULT_CALIBRATION = "/data/egis_sensor_test_SNR.log";
    public static final String PATH_RESULT_NORMAL_SCAN = "/data/egis_sensor_test_NS.log";
    public static final int READY_BKBOX = 202;
    public static final int READY_CHART = 204;
    public static final int READY_SNR = 208;
    public static final int READY_WKBOX = 200;
    public static final String SPEC_NA = "NA";
    public static final int TIME_OUT = 10000;
    private static String mChipName = null;
    private static CommonFingerprintEgis mInstance = null;
    private static int mIntConceptNum = 0;
    private static Object mLock;
    private Handler mCallbackHandler = null;
    private Context mContext;
    private Fingerprint mFingerprintCap;
    private FingerprintManager mFingerprintManager;
    private egistec.optical.csa.client.api.Fingerprint mFingerprintOptical;
    private Handler mHandler;
    private boolean mIsFactoryBin = true;
    private ArrayList<FpTestItem> mListFpTestItemCalibration = new ArrayList<>();

    public enum STATUS {
        WAIT,
        READY,
        RUNNING,
        PASS,
        FAIL,
        NOTEST
    }

    public enum STEP {
        NORMALSCAN,
        SNR,
        WKBOX,
        BKBOX,
        CHART,
        ENROLL,
        VERIFY,
        RESULT,
        NOTEST
    }

    private CommonFingerprintEgis(Context context) {
        this.mContext = context;
        this.mHandler = new Handler(this.mContext.getMainLooper());
        this.mIsFactoryBin = FpUtil.isFactoryBinary();
        mLock = new Object();
        mChipName = FpUtil.read("/sys/class/fingerprint/fingerprint/name");
        if (!this.mIsFactoryBin) {
            this.mFingerprintManager = (FingerprintManager) this.mContext.getSystemService("fingerprint");
        } else if (isOptical()) {
            egistec.optical.csa.client.api.Fingerprint create = egistec.optical.csa.client.api.Fingerprint.create(this.mContext);
            this.mFingerprintOptical = create;
            if (create != null) {
                this.mFingerprintOptical.setEventListener(new FingerPrintEventListenerOptical());
            }
        } else {
            Fingerprint create2 = Fingerprint.create(this.mContext);
            this.mFingerprintCap = create2;
            if (create2 != null) {
                this.mFingerprintCap.setEventListener(new FingerprintEventListenerCap());
            }
        }
        loadConceptVersion();
    }

    public static synchronized CommonFingerprintEgis instance(Context context) {
        CommonFingerprintEgis commonFingerprintEgis;
        synchronized (CommonFingerprintEgis.class) {
            if (mInstance == null) {
                mInstance = new CommonFingerprintEgis(context);
            }
            commonFingerprintEgis = mInstance;
        }
        return commonFingerprintEgis;
    }

    public static boolean isOptical() {
        if (mChipName == null) {
            mChipName = FpUtil.read("/sys/class/fingerprint/fingerprint/name");
        }
        String str = mChipName;
        return str != null && (str.contains("ET71") || mChipName.contains("EL72"));
    }

    private void loadConceptVersion() {
        String fpVersion = getVersion();
        int factoryVersion = -1;
        FpUtil.log_d(CLASS_NAME, "loadConceptVersion", "fp ver : " + fpVersion);
        if (fpVersion != null) {
            String[] arrFpVersion = fpVersion.split("\\.");
            if (arrFpVersion.length >= 3) {
                try {
                    factoryVersion = Integer.parseInt(arrFpVersion[2]);
                    FpUtil.log_d(CLASS_NAME, "loadConceptVersion", "factory fp ver : " + factoryVersion);
                } catch (NumberFormatException ne) {
                    FpUtil.log_e(ne);
                }
            }
        }
        if (isOptical()) {
            String vendorDevice = SystemProperties.get("ro.product.vendor.device", "DEFAULT");
            if (vendorDevice.contains("a52s") || vendorDevice.contains("a33")) {
                mIntConceptNum = 22;
            } else if (vendorDevice.contains("a52") || vendorDevice.contains("a72") || vendorDevice.contains("a32")) {
                mIntConceptNum = 17;
            } else {
                mIntConceptNum = 11;
            }
        } else if ("ET528".equalsIgnoreCase(mChipName) || "ET523".equalsIgnoreCase(mChipName) || "ET603".equalsIgnoreCase(mChipName)) {
            if (factoryVersion >= 202) {
                mIntConceptNum = 14;
            } else {
                mIntConceptNum = 10;
            }
        } else if ("ET510".equalsIgnoreCase(mChipName) || "ET516".equalsIgnoreCase(mChipName) || "ET520".equalsIgnoreCase(mChipName)) {
            if (factoryVersion >= 202) {
                mIntConceptNum = 15;
            } else {
                mIntConceptNum = 3;
            }
        }
        FpUtil.log_d(CLASS_NAME, "loadConceptVersion", "concept ver : " + mIntConceptNum);
    }

    public int getConceptVersion() {
        return mIntConceptNum;
    }

    public void setHandler(Handler handler) {
        FpUtil.log_d(CLASS_NAME, "setHandler", "");
        this.mCallbackHandler = handler;
    }

    public ArrayList<FpTestItem> getSensorInfo() {
        FpUtil.log_d(CLASS_NAME, "getSensorInfo", "");
        String sensorInfoAll = "";
        if (this.mIsFactoryBin) {
            egistec.optical.csa.client.api.Fingerprint fingerprint = this.mFingerprintOptical;
            if (fingerprint != null) {
                sensorInfoAll = fingerprint.getSensorInfo();
            } else {
                Fingerprint fingerprint2 = this.mFingerprintCap;
                if (fingerprint2 != null) {
                    sensorInfoAll = fingerprint2.getSensorInfo();
                }
            }
        } else {
            sensorInfoAll = this.mFingerprintManager.semGetSensorInfo();
        }
        FpUtil.log_d(CLASS_NAME, "getSensorInfo", sensorInfoAll);
        return getSensorInfoFromString(sensorInfoAll);
    }

    public void initCalibration() {
        egistec.optical.csa.client.api.Fingerprint fingerprint;
        FpUtil.log_d(CLASS_NAME, "initCalibration", "");
        if (this.mIsFactoryBin && (fingerprint = this.mFingerprintOptical) != null) {
            fingerprint.verifySensorState(100108, 0, 0, 0, 0);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void unInitCalibration(boolean needToSave) {
        FpUtil.log_d(CLASS_NAME, "unInitCalibration", "needToSave : " + needToSave);
        int opt = 1;
        if (needToSave) {
            opt = 0;
        }
        this.mFingerprintOptical.verifySensorState(egistec.optical.csa.client.api.Fingerprint.SENSOR_TEST_SNR_UNINIT_COMMAND, 0, opt, 0, 0);
    }

    public void setIsCalBrightnessNormal(boolean isNormalBrightness) {
        FpUtil.log_d(CLASS_NAME, "setIsCalBrightnessNormal", "isNormalBrightness : " + isNormalBrightness);
        boolean isPass = true;
        ArrayList<FpTestItem> itemListFromString = getItemListFromString(Support.Kernel.readEnterFromPath(PATH_RESULT_CALIBRATION, true));
        this.mListFpTestItemCalibration = itemListFromString;
        boolean isPassWithoutCheckBrightness = true;
        Iterator<FpTestItem> it = itemListFromString.iterator();
        while (true) {
            if (it.hasNext()) {
                if (!it.next().getIsPass()) {
                    isPassWithoutCheckBrightness = false;
                    break;
                }
            } else {
                break;
            }
        }
        if (!isNormalBrightness || !isPassWithoutCheckBrightness) {
            isPass = false;
        }
        this.mListFpTestItemCalibration.add(new FpTestItem("Calibration Save", "0", "0", isPass ? "0" : ModuleCommunicationService.SMD_NOK));
        unInitCalibration(isPass);
    }

    public void initSnrTest() {
        egistec.optical.csa.client.api.Fingerprint fingerprint;
        FpUtil.log_d(CLASS_NAME, "initSnrTest", "");
        if (this.mIsFactoryBin && (fingerprint = this.mFingerprintOptical) != null) {
            fingerprint.verifySensorState(100108, 0, 1, 0, 0);
        }
    }

    public void initSublineTest() {
        egistec.optical.csa.client.api.Fingerprint fingerprint;
        FpUtil.log_d(CLASS_NAME, "initSublineTest", "");
        if (this.mIsFactoryBin && (fingerprint = this.mFingerprintOptical) != null) {
            fingerprint.verifySensorState(100108, 0, 2, 0, 0);
        }
    }

    public void initSnrCapTest() {
        Fingerprint fingerprint;
        FpUtil.log_d(CLASS_NAME, "initSnrCapTest", "");
        if (this.mIsFactoryBin && (fingerprint = this.mFingerprintCap) != null) {
            fingerprint.verifySensorState(100106, 0, 0, 0, 0);
        }
    }

    public ArrayList<FpTestItem> startNormalScan() {
        FpUtil.log_d(CLASS_NAME, "startNormalScan", "");
        this.mHandler.post(new Runnable() {
            /* class com.sec.factory.common.CommonFingerprintEgis.AnonymousClass1 */

            public void run() {
                if (CommonFingerprintEgis.this.mIsFactoryBin) {
                    if (CommonFingerprintEgis.this.mFingerprintOptical != null) {
                        CommonFingerprintEgis.this.mFingerprintOptical.verifySensorState(100103, 0, 0, 0, 0);
                    } else if (CommonFingerprintEgis.this.mFingerprintCap != null) {
                        CommonFingerprintEgis.this.mFingerprintCap.verifySensorState(100103, 0, 0, 0, 0);
                    }
                } else if (CommonFingerprintEgis.this.mFingerprintManager != null) {
                    CommonFingerprintEgis.this.mFingerprintManager.semRunSensorTest(100103, 0, new RequestCallbackTz());
                }
            }
        });
        synchronized (mLock) {
            try {
                mLock.wait(10000);
            } catch (InterruptedException e) {
            }
        }
        String rawResult = null;
        if (this.mIsFactoryBin) {
            rawResult = Support.Kernel.readEnterFromPath(PATH_RESULT_NORMAL_SCAN, true);
        } else {
            byte[] outbuffer = new byte[30720];
            if (this.mFingerprintManager.semGetSensorTestResult(outbuffer) == -1) {
                FpUtil.log_d(CLASS_NAME, "startNormalScan", "error, semGetSensorTestResult -1");
            } else {
                rawResult = new String(outbuffer);
            }
        }
        ArrayList<FpTestItem> listFpTestItemNormalScan = getItemListFromString(rawResult, STEP.NORMALSCAN);
        makeLogFile(listFpTestItemNormalScan, "/data/log/FingerNormalData.log");
        return listFpTestItemNormalScan;
    }

    public void startWkboxTest() {
        FpUtil.log_d(CLASS_NAME, "startWkboxTest", "");
        this.mListFpTestItemCalibration.clear();
        egistec.optical.csa.client.api.Fingerprint fingerprint = this.mFingerprintOptical;
        if (fingerprint != null) {
            fingerprint.verifySensorState(100109, 0, 0, 0, 0);
        }
    }

    public void startBkboxTest() {
        FpUtil.log_d(CLASS_NAME, "startBkboxTest", "");
        egistec.optical.csa.client.api.Fingerprint fingerprint = this.mFingerprintOptical;
        if (fingerprint != null) {
            fingerprint.verifySensorState(100110, 0, 0, 0, 0);
        }
    }

    public void startChartTest() {
        FpUtil.log_d(CLASS_NAME, "startChartTest", "");
        egistec.optical.csa.client.api.Fingerprint fingerprint = this.mFingerprintOptical;
        if (fingerprint != null) {
            fingerprint.verifySensorState(egistec.optical.csa.client.api.Fingerprint.SENSOR_TEST_SNR_CHART_ON_COMMAND, 0, 0, 0, 0);
        }
    }

    public void startSnrCapTest() {
        FpUtil.log_d(CLASS_NAME, "startChartTest", "");
        Fingerprint fingerprint = this.mFingerprintCap;
        if (fingerprint != null) {
            fingerprint.verifySensorState(100107, 0, 0, 0, 0);
        }
    }

    public ArrayList<FpTestItem> getListSnrResult() {
        FpUtil.log_d(CLASS_NAME, "getListSnrResult", "");
        return getItemListFromString(Support.Kernel.readEnterFromPath(PATH_RESULT_CALIBRATION, true), STEP.SNR);
    }

    public void cancel() {
        FpUtil.log_d(CLASS_NAME, "cancel", "");
        egistec.optical.csa.client.api.Fingerprint fingerprint = this.mFingerprintOptical;
        if (fingerprint != null) {
            fingerprint.cancel();
            return;
        }
        Fingerprint fingerprint2 = this.mFingerprintCap;
        if (fingerprint2 != null) {
            fingerprint2.cancel();
        }
    }

    public String[] getUserIdList() {
        FpUtil.log_d(CLASS_NAME, "hasUserIdList", "");
        FingerprintManager fingerprintManager = this.mFingerprintManager;
        if (fingerprintManager != null) {
            return fingerprintManager.semGetUserIdList();
        }
        return null;
    }

    public String getVersion() {
        FpUtil.log_d(CLASS_NAME, "getVersion", "");
        if (this.mIsFactoryBin) {
            egistec.optical.csa.client.api.Fingerprint fingerprint = this.mFingerprintOptical;
            if (fingerprint != null) {
                return fingerprint.getVersion();
            }
            Fingerprint fingerprint2 = this.mFingerprintCap;
            if (fingerprint2 != null) {
                return fingerprint2.getVersion();
            }
            return null;
        }
        FingerprintManager fingerprintManager = this.mFingerprintManager;
        if (fingerprintManager != null) {
            return fingerprintManager.semGetDaemonVersion();
        }
        return null;
    }

    public void setEnrollSession(boolean flag) {
        FpUtil.log_d(CLASS_NAME, "setEnrollSession", "flag : " + flag);
        Fingerprint fingerprint = this.mFingerprintCap;
        if (fingerprint != null) {
            fingerprint.setEnrollSession(flag);
        }
    }

    public void enroll() {
        FpUtil.log_d(CLASS_NAME, "enroll", "");
        Fingerprint fingerprint = this.mFingerprintCap;
        if (fingerprint != null) {
            fingerprint.enroll("Test", 1);
        }
    }

    public void identify() {
        FpUtil.log_d(CLASS_NAME, "identify", "");
        Fingerprint fingerprint = this.mFingerprintCap;
        if (fingerprint != null) {
            fingerprint.identify("Test");
        }
    }

    public void makeLogFile(ArrayList<FpTestItem> listItem, String path) {
        String packageName = this.mContext.getPackageName();
        if (packageName == null || !packageName.contains("hwmoduletest")) {
            FpUtil.log_d(CLASS_NAME, "makeLogFile", "path :" + path);
            StringBuilder sb = new StringBuilder();
            boolean isPass = true;
            for (int i = 0; i < listItem.size(); i++) {
                sb.append(",");
                sb.append(listItem.get(i).getTestResult());
                if (!listItem.get(i).getIsPass()) {
                    isPass = false;
                }
            }
            sb.insert(0, isPass ? "PASS" : "FAIL");
            FpUtil.write(path, sb.toString());
            return;
        }
        FpUtil.log_d(CLASS_NAME, "makeLogFile", "No file creation");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private ArrayList<FpTestItem> getItemListFromString(String rawString) {
        return getItemListFromString(rawString, STEP.RESULT);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private ArrayList<FpTestItem> getItemListFromString(String rawString, STEP step) {
        LinkedHashMap<String, Integer> itemMap;
        FpUtil.log_d(CLASS_NAME, "getItemListFromString", "");
        ArrayList<FpTestItem> list = new ArrayList<>();
        if (!(rawString == null || rawString.length() == 0)) {
            String str = mChipName;
            if (str == null || (!str.contains("ET510") && !mChipName.contains("ET516") && !mChipName.contains("ET520") && !mChipName.contains("ET523") && !mChipName.contains("ET603") && !mChipName.contains("ET5XX") && !mChipName.contains("ET713") && !mChipName.contains("ET715") && !mChipName.contains("ET7XX"))) {
                BufferedReader br = new BufferedReader(new StringReader(rawString));
                while (true) {
                    try {
                        String strRead = br.readLine();
                        if (strRead != null) {
                            FpUtil.log_d(CLASS_NAME, "getItemListFromString", "strRead : " + strRead);
                            String[] itemData = strRead.split(";");
                            if (itemData.length == 4) {
                                list.add(new FpTestItem(itemData[0].trim(), itemData[1].trim(), itemData[2].trim(), itemData[3].trim()));
                            } else {
                                FpUtil.log_d(CLASS_NAME, "getItemListFromString", "wrong format : " + strRead);
                            }
                        } else {
                            try {
                                break;
                            } catch (IOException e) {
                                FpUtil.log_e(e);
                            }
                        }
                    } catch (IOException e2) {
                        FpUtil.log_e(e2);
                        br.close();
                    } catch (Throwable th) {
                        try {
                            br.close();
                        } catch (IOException e3) {
                            FpUtil.log_e(e3);
                        }
                        throw th;
                    }
                }
                br.close();
            } else if (Character.isDigit(rawString.charAt(0))) {
                String[] arrResult = rawString.split(",");
                new LinkedHashMap();
                if (step == STEP.NORMALSCAN) {
                    itemMap = Spec.getNsNameIndexMap();
                } else if (step == STEP.SNR) {
                    itemMap = Spec.getSnrNameIndexMap();
                } else {
                    itemMap = Spec.getCalNameIndexMap();
                }
                if (itemMap == null) {
                    return list;
                }
                try {
                    for (String itemName : itemMap.keySet()) {
                        list.add(new FpTestItem(itemName, Spec.getSpec(itemName, "MIN"), Spec.getSpec(itemName, "MAX"), arrResult[itemMap.get(itemName).intValue()].trim()));
                    }
                } catch (ArrayIndexOutOfBoundsException e4) {
                    FpUtil.log_e(e4);
                }
            } else if (rawString.contains("Result,")) {
                String rawString2 = rawString.replaceFirst("Result,", "");
                String[] arrResult2 = rawString2.split(",");
                for (int i = 0; i < arrResult2.length; i += 4) {
                    try {
                        list.add(new FpTestItem(arrResult2[i].trim(), arrResult2[i + 1].trim(), arrResult2[i + 2].trim(), arrResult2[i + 3].trim()));
                    } catch (ArrayIndexOutOfBoundsException e5) {
                        FpUtil.log_d(CLASS_NAME, "getItemListFromString", "wrong format : " + rawString2);
                    }
                }
            }
        }
        return list;
    }

    private ArrayList<FpTestItem> getSensorInfoFromString(String rawString) {
        FpUtil.log_d(CLASS_NAME, "getSensorInfoFromString", "");
        ArrayList<FpTestItem> list = new ArrayList<>();
        if (!(rawString == null || rawString.length() == 0)) {
            BufferedReader br = new BufferedReader(new StringReader(rawString));
            while (true) {
                try {
                    String strRead = br.readLine();
                    if (strRead != null) {
                        String[] itemData = strRead.split(":");
                        if (itemData.length == 2) {
                            list.add(new FpTestItem(itemData[0].trim(), "0", "0", itemData[1].trim()));
                        } else {
                            FpUtil.log_d(CLASS_NAME, "getItemListFromString", "wrong format : " + strRead);
                        }
                    } else {
                        try {
                            break;
                        } catch (IOException e) {
                            FpUtil.log_e(e);
                        }
                    }
                } catch (IOException e2) {
                    FpUtil.log_e(e2);
                    br.close();
                } catch (Throwable th) {
                    try {
                        br.close();
                    } catch (IOException e3) {
                        FpUtil.log_e(e3);
                    }
                    throw th;
                }
            }
            br.close();
        }
        return list;
    }

    private class FingerPrintEventListenerOptical implements Fingerprint.FingerprintEventListener {
        boolean isStageCal;

        private FingerPrintEventListenerOptical() {
            this.isStageCal = false;
        }

        @Override // egistec.optical.csa.client.api.Fingerprint.FingerprintEventListener
        public void onFingerprintEvent(int eventId, Object evt) {
            FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : " + eventId);
            switch (eventId) {
                case 2020:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : EVT_ERROR");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(2020);
                    }
                    if (this.isStageCal) {
                        CommonFingerprintEgis commonFingerprintEgis = CommonFingerprintEgis.this;
                        commonFingerprintEgis.mListFpTestItemCalibration = commonFingerprintEgis.getItemListFromString(Support.Kernel.readEnterFromPath(CommonFingerprintEgis.PATH_RESULT_CALIBRATION, true));
                        CommonFingerprintEgis.this.mListFpTestItemCalibration.add(new FpTestItem("Calibration Save", "0", "0", ModuleCommunicationService.SMD_NOK));
                        CommonFingerprintEgis.this.unInitCalibration(false);
                        return;
                    }
                    return;
                case 285212675:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_START");
                    return;
                case 285212676:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_END");
                    synchronized (CommonFingerprintEgis.mLock) {
                        FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "mLock -> notify");
                        CommonFingerprintEgis.mLock.notify();
                    }
                    if (this.isStageCal) {
                        if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                            CommonFingerprintEgis commonFingerprintEgis2 = CommonFingerprintEgis.this;
                            commonFingerprintEgis2.makeLogFile(commonFingerprintEgis2.mListFpTestItemCalibration, "/data/log/FingerSNRData.log");
                            Message message = CommonFingerprintEgis.this.mCallbackHandler.obtainMessage();
                            message.what = 1004;
                            message.obj = CommonFingerprintEgis.this.mListFpTestItemCalibration;
                            CommonFingerprintEgis.this.mCallbackHandler.sendMessage(message);
                        }
                        this.isStageCal = false;
                        return;
                    } else if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(500);
                        return;
                    } else {
                        return;
                    }
                case 285212678:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : FACTORY_TEST_EVT_SNSR_TEST_PUT_WKBOX");
                    this.isStageCal = true;
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(200);
                        return;
                    }
                    return;
                case 285212679:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : FACTORY_TEST_EVT_SNSR_TEST_PUT_BKBOX");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(202);
                        return;
                    }
                    return;
                case 285212680:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : FACTORY_TEST_EVT_SNSR_TEST_PUT_CHART");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(204);
                        return;
                    }
                    return;
                case 285212681:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : FACTORY_TEST_EVT_SNSR_TEST_WAIT_COMMAND");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(1001);
                        return;
                    }
                    return;
                default:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : UNKNOWN_EVT_MESSAGE, event id : " + eventId);
                    return;
            }
        }
    }

    private class FingerprintEventListenerCap implements Fingerprint.FingerprintEventListener {
        boolean isStageSnr;

        private FingerprintEventListenerCap() {
            this.isStageSnr = false;
        }

        @Override // egistec.csa.client.api.Fingerprint.FingerprintEventListener
        public void onFingerprintEvent(int eventId, Object evt) {
            switch (eventId) {
                case 1001:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : ENROLL_SUCCESS");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(313);
                        return;
                    }
                    return;
                case 1002:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : ENROLL_FAILED");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(314);
                        return;
                    }
                    return;
                case 1020:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : IDENTIFY_SUCCESS");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(317);
                        return;
                    }
                    return;
                case 1021:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : IDENTIFY_FAILED");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(318);
                        return;
                    }
                    return;
                case 1040:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : CAPTURE_READY");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(301);
                        return;
                    }
                    return;
                case 1041:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : CAPTURE_STARTED");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(303);
                        return;
                    }
                    return;
                case 1043:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : CAPTURE_FINISHED");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(320);
                        return;
                    }
                    return;
                case 1044:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : CAPTURE_SUCCESS");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        Message message = CommonFingerprintEgis.this.mCallbackHandler.obtainMessage();
                        message.what = 309;
                        message.obj = ((Fingerprint.FingerprintBitmap) evt).bitmap;
                        CommonFingerprintEgis.this.mCallbackHandler.sendMessage(message);
                        return;
                    }
                    return;
                case 1045:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : CAPTURE_FAILED");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(310);
                        return;
                    }
                    return;
                case 285212675:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_START");
                    this.isStageSnr = false;
                    return;
                case 285212676:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_END");
                    synchronized (CommonFingerprintEgis.mLock) {
                        FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "mLock -> notify");
                        CommonFingerprintEgis.mLock.notify();
                    }
                    if (CommonFingerprintEgis.this.mCallbackHandler != null && this.isStageSnr) {
                        ArrayList<FpTestItem> listFpTestItemSnr = CommonFingerprintEgis.this.getItemListFromString(Support.Kernel.readEnterFromPath(CommonFingerprintEgis.PATH_RESULT_CALIBRATION, true), STEP.SNR);
                        CommonFingerprintEgis.this.makeLogFile(listFpTestItemSnr, "/data/log/FingerSNRData.log");
                        Message message2 = CommonFingerprintEgis.this.mCallbackHandler.obtainMessage();
                        message2.what = 500;
                        message2.obj = listFpTestItemSnr;
                        CommonFingerprintEgis.this.mCallbackHandler.sendMessage(message2);
                        this.isStageSnr = false;
                        return;
                    }
                    return;
                case 285212677:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : FACTORY_TEST_EVT_SNSR_TEST_PUT");
                    if (CommonFingerprintEgis.this.mCallbackHandler != null) {
                        CommonFingerprintEgis.this.mCallbackHandler.sendEmptyMessage(208);
                    }
                    this.isStageSnr = true;
                    return;
                default:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "onFingerprintEvent", "Event is : UNKNOWN_EVT_MESSAGE, event id : " + eventId);
                    return;
            }
        }
    }

    private class RequestCallbackTz extends FingerprintManager.SemRequestCallback {
        private RequestCallbackTz() {
        }

        public void onRequested(int msgId) {
            switch (msgId) {
                case 10008:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "RequestCallbackTz,onRequested", "Event is : FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_START_GOOGLE");
                    return;
                case 10009:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "RequestCallbackTz,onRequested", "Event is : FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_END_GOOGLE");
                    synchronized (CommonFingerprintEgis.mLock) {
                        FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "RequestCallbackTz,onRequested", "mLock -> notify");
                        CommonFingerprintEgis.mLock.notify();
                    }
                    return;
                default:
                    FpUtil.log_d(CommonFingerprintEgis.CLASS_NAME, "RequestCallbackTz,onRequested", "Event is : UNKNOWN_EVT_MESSAGE");
                    return;
            }
        }
    }

    public static class FpTestItem {
        private boolean mIsPass = false;
        private String mStringName;
        private String mStringResult;
        private String mStringSpecMax;
        private String mStringSpecMin;
        private DATA_TYPE mTYPE = DATA_TYPE.NOT_DETERMINED;

        /* access modifiers changed from: private */
        public enum DATA_TYPE {
            STRING,
            INT,
            FLOAT,
            NOT_DETERMINED
        }

        public FpTestItem(String testName, String specMin, String specMax, String result) {
            this.mStringName = testName;
            this.mStringSpecMin = specMin;
            this.mStringSpecMax = specMax;
            this.mStringResult = result;
            checkResultType(result);
            checkSpec();
        }

        private void checkResultType(String rawData) {
            try {
                Integer.parseInt(rawData);
                this.mTYPE = DATA_TYPE.INT;
            } catch (NumberFormatException e) {
                try {
                    Float.parseFloat(rawData);
                    this.mTYPE = DATA_TYPE.FLOAT;
                } catch (NumberFormatException e2) {
                    this.mTYPE = DATA_TYPE.STRING;
                }
            }
        }

        private void checkSpec() {
            if ("NA".equalsIgnoreCase(this.mStringSpecMin) || "NA".equalsIgnoreCase(this.mStringSpecMax)) {
                this.mIsPass = true;
                return;
            }
            try {
                if (this.mTYPE == DATA_TYPE.STRING) {
                    String str = this.mStringResult;
                    if (str != null && (str.equalsIgnoreCase(this.mStringSpecMin) || this.mStringResult.equalsIgnoreCase(this.mStringSpecMax))) {
                        this.mIsPass = true;
                        return;
                    }
                } else if (this.mTYPE == DATA_TYPE.INT) {
                    int intSpecMin = (int) Float.parseFloat(this.mStringSpecMin);
                    int intSpecMax = (int) Float.parseFloat(this.mStringSpecMax);
                    int intResult = Integer.parseInt(this.mStringResult);
                    if (intResult >= intSpecMin && intResult <= intSpecMax) {
                        this.mIsPass = true;
                        return;
                    }
                } else if (this.mTYPE == DATA_TYPE.FLOAT) {
                    Float floatSpecMin = Float.valueOf(Float.parseFloat(this.mStringSpecMin));
                    Float floatSpecMax = Float.valueOf(Float.parseFloat(this.mStringSpecMax));
                    Float floatResult = Float.valueOf(Float.parseFloat(this.mStringResult));
                    if (Float.compare(floatResult.floatValue(), floatSpecMin.floatValue()) >= 0 && Float.compare(floatResult.floatValue(), floatSpecMax.floatValue()) <= 0) {
                        this.mIsPass = true;
                        return;
                    }
                } else {
                    this.mIsPass = false;
                    return;
                }
                this.mIsPass = false;
            } catch (NumberFormatException ne) {
                FpUtil.log_e(ne);
                this.mIsPass = false;
            }
        }

        public String getTestName() {
            return this.mStringName;
        }

        public String getTestResult() {
            return this.mStringResult;
        }

        public String getTestSpec() {
            if ("NA".equals(this.mStringSpecMin) || "NA".equals(this.mStringSpecMax)) {
                return "NA";
            }
            return this.mStringSpecMin + "~" + this.mStringSpecMax;
        }

        public boolean getIsPass() {
            return this.mIsPass;
        }

        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append("Item [");
            sb.append(this.mStringName);
            sb.append("]  Spec [");
            sb.append(getTestSpec());
            sb.append("]  Result [");
            sb.append(getTestResult());
            sb.append("]  -> ");
            sb.append(this.mIsPass ? "PASS" : "FAIL");
            return sb.toString();
        }
    }

    public static class Spec {
        private static LinkedHashMap<String, Integer> calNameIndexMap = new LinkedHashMap<>();
        private static boolean isInitNameIndexMap = false;
        private static LinkedHashMap<String, Integer> nsNameIndexMap = new LinkedHashMap<>();
        private static LinkedHashMap<String, Integer> snrNameIndexMap = new LinkedHashMap<>();

        public static String getSpec(String itemName, String MinOrMax) {
            if (itemName == null || MinOrMax == null) {
                return null;
            }
            String modifiedName = itemName.replaceAll("[0-9]", "");
            String modifiedName2 = "FINGERPRINT_" + modifiedName.trim().replace(" ", "_").toUpperCase() + "_" + MinOrMax + "_EGIS";
            String spec = Support.Spec.getStringWithNoExceptionLog(modifiedName2);
            if (spec == null || Support.Properties.PROPERTIES_DEFAULT_STRING.equals(spec)) {
                spec = Support.Spec.getStringWithNoExceptionLog(modifiedName2.replaceAll("_EGIS", ""));
            }
            if (spec == null || Support.Properties.PROPERTIES_DEFAULT_STRING.equals(spec)) {
                return "0";
            }
            return spec;
        }

        private static void init() {
            if (!isInitNameIndexMap) {
                isInitNameIndexMap = true;
                if (CommonFingerprintEgis.isOptical()) {
                    nsNameIndexMap.put("History Check", 0);
                    nsNameIndexMap.put("Register test", 1);
                    nsNameIndexMap.put("OTP test", 2);
                    nsNameIndexMap.put("Flash test", 3);
                    nsNameIndexMap.put("Test Pattern test", 4);
                    nsNameIndexMap.put("Reset test", 5);
                    calNameIndexMap.put("Cet", 0);
                    calNameIndexMap.put("Signal", 1);
                    calNameIndexMap.put("Noise", 2);
                    calNameIndexMap.put("SNR", 3);
                    calNameIndexMap.put("M Factor", 4);
                    calNameIndexMap.put("FEA X1", 5);
                    calNameIndexMap.put("FEA X2", 6);
                    calNameIndexMap.put("FEA Y1", 7);
                    calNameIndexMap.put("FEA Y2", 8);
                    calNameIndexMap.put("Bad Pixel Block", 9);
                    calNameIndexMap.put("Bad Pixel Consecutive", 10);
                    calNameIndexMap.put("Bad Pixel Total", 11);
                    snrNameIndexMap.put("Cet", 0);
                    snrNameIndexMap.put("Signal", 1);
                    snrNameIndexMap.put("Noise", 2);
                    snrNameIndexMap.put("SNR", 3);
                    snrNameIndexMap.put("M Factor", 4);
                    return;
                }
                if (CommonFingerprintEgis.mIntConceptNum == 3 || CommonFingerprintEgis.mIntConceptNum == 15) {
                    nsNameIndexMap.put("Black Total Bad Pixel", 0);
                    nsNameIndexMap.put("White Total Bad Pixel", 2);
                    nsNameIndexMap.put("Bad Total Bad Pixel", 4);
                    nsNameIndexMap.put("Reset Test", 6);
                    nsNameIndexMap.put("MTP test", 7);
                    nsNameIndexMap.put("Cal Result", 8);
                    if (CommonFingerprintEgis.mIntConceptNum == 15) {
                        nsNameIndexMap.put("BK score", 9);
                    }
                } else {
                    nsNameIndexMap.put("Black Total Bad Pixel", 0);
                    nsNameIndexMap.put("White Total Bad Pixel", 2);
                    nsNameIndexMap.put("Defect Total Bad Pixel", 4);
                    nsNameIndexMap.put("Bad Total Bad Pixel", 6);
                    nsNameIndexMap.put("Reset Test", 8);
                    nsNameIndexMap.put("MTP test", 9);
                    nsNameIndexMap.put("Cal Result", 10);
                    if (CommonFingerprintEgis.mIntConceptNum == 14) {
                        nsNameIndexMap.put("BK score", 11);
                    }
                }
                snrNameIndexMap.put("Interrupt Pin Test", 0);
                snrNameIndexMap.put("Placement Test", 21);
                snrNameIndexMap.put("Signal", 1);
                snrNameIndexMap.put("Noise", 2);
                snrNameIndexMap.put("SNR", 3);
            }
        }

        public static LinkedHashMap<String, Integer> getNsNameIndexMap() {
            init();
            return nsNameIndexMap;
        }

        public static LinkedHashMap<String, Integer> getCalNameIndexMap() {
            init();
            return calNameIndexMap;
        }

        public static LinkedHashMap<String, Integer> getSnrNameIndexMap() {
            init();
            return snrNameIndexMap;
        }
    }

    public static class FpUtil {
        public static void log_d(String className, String methodName, String message) {
            FtUtil.log_d(className, methodName, message);
        }

        public static void log_e(Exception e) {
            FtUtil.log_e(e);
        }

        public static boolean write(String path, String value) {
            return Support.Kernel.writeToPathNsync(path, value);
        }

        public static String read(String path) {
            return Support.Kernel.readAllFromPath(path, true);
        }

        public static boolean isFactoryBinary() {
            return FtUtil.isFactoryBinary();
        }
    }
}
