package com.sec.factory.common;

import android.content.Context;
import android.hardware.fingerprint.FingerprintManager;
import android.os.Handler;
import android.os.Message;
import com.goodix.cap.fingerprint.sec.GoodixFpCaptureInfo;
import com.goodix.cap.fingerprint.sec.GoodixFpEnrollStatus;
import com.goodix.cap.fingerprint.sec.GoodixFpIdentifyResult;
import com.goodix.cap.fingerprint.sec.mt.GFTestManager;
import com.goodix.cap.fingerprint.sec.mt.TestResultNotify;
import com.goodix.display.fingerprint.insystem.CalibrationData;
import com.goodix.display.fingerprint.insystem.InSystemTest;
import com.goodix.display.fingerprint.insystem.NormalScanData;
import com.goodix.display.fingerprint.insystem.SensorInfo;
import com.goodix.display.fingerprint.insystem.SnrData;
import com.goodix.display.fingerprint.insystem.SublineData;
import com.sec.factory.common.CommonFingerprintEgis;
import com.sec.factory.modules.ModuleCommunicationService;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.Serializable;
import java.io.StringReader;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Locale;

public class CommonFingerprintGoodix {
    public static final int CALIBRATION_FINISHED = 1004;
    public static final int CAPTURE_FAILED = 310;
    public static final int CAPTURE_SUCCESS = 309;
    public static final int END_TEST = 500;
    public static final int ENROLL_FAILED = 314;
    public static final int ENROLL_SUCCESS = 313;
    private static final int FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_END_GOOGLE = 10009;
    private static final int FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_START_GOOGLE = 10008;
    public static final int FINGER_LEAVED = 402;
    public static final int FINISHED_CHART = 204;
    public static final int FINISHED_DARK = 202;
    public static final int FINISHED_FLESH = 200;
    public static final String FP_TEST_STATUS = "fp_test_status";
    public static final String FP_TEST_STEP = "fp_test_step";
    public static final int IDENTIFY_FAILED = 318;
    public static final int IDENTIFY_SUCCESS = 317;
    public static final int NEED_BRIGHTNESS_HIGH = 502;
    public static final int NEED_BRIGHTNESS_LOW = 500;
    public static final int NEED_BRIGHTNESS_NONE = 504;
    public static final int NEED_CHECK_BRIGHTNESS = 1001;
    public static final int NORMALSCAN_FINISHED = 1002;
    public static final String PATH_CELL_ID = "/sys/class/lcd/panel/cell_id";
    public static final String PATH_CHIP_NAME = "/sys/class/fingerprint/fingerprint/name";
    public static final String PATH_LOG_CALIBRATION = "/data/log/FingerSNRData.log";
    public static final String PATH_LOG_CELL_ID = "/efs/biometrics/meta/cell_id";
    public static final String PATH_LOG_NORMAL_SCAN = "/data/log/FingerNormalData.log";
    public static final int READY_SNR = 208;
    public static final int SENSORINFO_FINISHED = 1006;
    public static final int SNRTEST_FINISHED = 1008;
    public static final String SPEC_NA = "NA";
    public static final int TEST_FAIL = 513;
    public static final int TEST_SUCCESS = 512;
    public static final int TIME_OUT = 10000;
    private static int mConceptNum = 0;
    private static CommonFingerprintGoodix mInstance = null;
    private String CLASS_NAME = "CommonFingerprintGoodix";
    private Handler mCallbackHandler = null;
    private String mChipName = null;
    private Context mContext;
    private FingerprintManager mFingerprintManager;
    private GFTestManager mGFTestManager;
    private Handler mHandler;
    private InSystemTest mInSystemTest;
    private boolean mIsFactoryBin = true;
    private ArrayList<FpTestItem> mListFpTestItemCalibration = new ArrayList<>();
    private ArrayList<FpTestItem> mListFpTestItemNormalScan = new ArrayList<>();
    private ArrayList<FpTestItem> mListFpTestItemSensorInfo = new ArrayList<>();
    private ArrayList<FpTestItem> mListFpTestItemSnrData = new ArrayList<>();
    private final Object mLock;
    private TestResultCallback mTestResultCallback;
    private TestResultNotify mTestResultNotify;

    public enum STATUS {
        WAIT,
        READY,
        RUNNING,
        PASS,
        FAIL,
        NOTEST
    }

    public enum STEP {
        NORMALSCAN,
        SNR,
        FLESH,
        DARK,
        CHART,
        ENROLL,
        VERIFY,
        RESULT,
        NOTEST
    }

    private CommonFingerprintGoodix(Context context) {
        this.mContext = context;
        this.mHandler = new Handler(this.mContext.getMainLooper());
        this.mIsFactoryBin = FpUtil.isFactoryBinary();
        this.mLock = new Object();
        if (!this.mIsFactoryBin) {
            this.mFingerprintManager = (FingerprintManager) this.mContext.getSystemService("fingerprint");
        } else if (isOptical()) {
            this.mInSystemTest = new InSystemTest(context);
            TestResultCallback testResultCallback = new TestResultCallback();
            this.mTestResultCallback = testResultCallback;
            this.mInSystemTest.setTestResultCallback(testResultCallback);
        } else {
            this.mGFTestManager = new GFTestManager(context);
            TestResultNotifyCallback testResultNotifyCallback = new TestResultNotifyCallback();
            this.mTestResultNotify = testResultNotifyCallback;
            this.mGFTestManager.registerResultNotify(testResultNotifyCallback);
        }
        loadConceptVersion();
    }

    public static synchronized CommonFingerprintGoodix instance(Context context) {
        CommonFingerprintGoodix commonFingerprintGoodix;
        synchronized (CommonFingerprintGoodix.class) {
            if (mInstance == null) {
                mInstance = new CommonFingerprintGoodix(context);
            }
            commonFingerprintGoodix = mInstance;
        }
        return commonFingerprintGoodix;
    }

    public boolean isOptical() {
        if (this.mChipName == null) {
            this.mChipName = FpUtil.read("/sys/class/fingerprint/fingerprint/name");
        }
        String str = this.mChipName;
        if (str == null || !str.contains("GW95")) {
            return false;
        }
        return true;
    }

    private void loadConceptVersion() {
        if (isOptical()) {
            String testNum = String.format(Locale.ENGLISH, "%s", getTestNum()).trim();
            String str = this.CLASS_NAME;
            FpUtil.log_d(str, "loadConceptVersion", "testNum  : " + testNum);
            if (testNum.contains("1.2.06,20")) {
                mConceptNum = 18;
            } else if (testNum.contains("1.2.11,22")) {
                mConceptNum = 19;
            } else if (testNum.contains("1.1.22,25") || testNum.contains("1.2.28,25") || testNum.contains("1.2.51")) {
                mConceptNum = 20;
            } else {
                mConceptNum = 12;
            }
        } else {
            mConceptNum = 8;
        }
        String str2 = this.CLASS_NAME;
        FpUtil.log_d(str2, "loadConceptVersion", "concept ver : " + mConceptNum);
    }

    public int getConceptVersion() {
        return mConceptNum;
    }

    private String getTestNum() {
        try {
            return this.mInSystemTest.getTestNum();
        } catch (NoSuchMethodError | NullPointerException | UnsatisfiedLinkError e) {
            e.printStackTrace();
            return "";
        }
    }

    public void setHandler(Handler handler) {
        FpUtil.log_d(this.CLASS_NAME, "setHandler", "");
        this.mCallbackHandler = handler;
    }

    public ArrayList<FpTestItem> getSensorInfo() {
        this.mListFpTestItemSensorInfo.clear();
        FpUtil.log_d(this.CLASS_NAME, "getSensorInfo", "");
        if (this.mIsFactoryBin) {
            this.mHandler.post(new Runnable() {
                /* class com.sec.factory.common.CommonFingerprintGoodix.AnonymousClass1 */

                public void run() {
                    if (CommonFingerprintGoodix.this.mInSystemTest != null) {
                        CommonFingerprintGoodix.this.mInSystemTest.getSensorInfo();
                    } else if (CommonFingerprintGoodix.this.mGFTestManager != null) {
                        CommonFingerprintGoodix.this.mGFTestManager.startGetSensorInfo();
                    }
                }
            });
            synchronized (this.mLock) {
                try {
                    this.mLock.wait(10000);
                } catch (InterruptedException e) {
                }
            }
        } else {
            String sensorInfoAll = this.mFingerprintManager.semGetSensorInfo();
            FpUtil.log_d(this.CLASS_NAME, "getSensorInfo", sensorInfoAll);
            this.mListFpTestItemSensorInfo = getSensorInfoFromString(sensorInfoAll);
        }
        return this.mListFpTestItemSensorInfo;
    }

    public ArrayList<FpTestItem> startNormalScan() {
        FpUtil.log_d(this.CLASS_NAME, "startNormalScan", "");
        this.mListFpTestItemNormalScan.clear();
        this.mHandler.post(new Runnable() {
            /* class com.sec.factory.common.CommonFingerprintGoodix.AnonymousClass2 */

            public void run() {
                if (CommonFingerprintGoodix.this.mIsFactoryBin) {
                    if (CommonFingerprintGoodix.this.mInSystemTest != null) {
                        CommonFingerprintGoodix.this.mInSystemTest.startNormalScan();
                    } else if (CommonFingerprintGoodix.this.mGFTestManager != null) {
                        CommonFingerprintGoodix.this.mGFTestManager.startUnTouchTest();
                    }
                } else if (CommonFingerprintGoodix.this.mFingerprintManager != null) {
                    CommonFingerprintGoodix.this.mFingerprintManager.semRunSensorTest(100103, 0, new TestResultCallbackTz());
                }
            }
        });
        synchronized (this.mLock) {
            try {
                this.mLock.wait(10000);
            } catch (InterruptedException e) {
            }
        }
        if (!this.mIsFactoryBin) {
            byte[] outbuffer = new byte[30720];
            if (this.mFingerprintManager.semGetSensorTestResult(outbuffer) == -1) {
                FpUtil.log_d(this.CLASS_NAME, "startNormalScan", "error, semGetSensorTestResult -1");
            } else {
                String normalScanResult = new String(outbuffer);
                String str = this.CLASS_NAME;
                FpUtil.log_d(str, "startNormalScan", "normalScanResult : " + normalScanResult);
                this.mListFpTestItemNormalScan = getItemListFromString(normalScanResult);
            }
        }
        return this.mListFpTestItemNormalScan;
    }

    public void startFleshRubberTest() {
        FpUtil.log_d(this.CLASS_NAME, "startFleshRubberTest", "");
        this.mListFpTestItemCalibration.clear();
        InSystemTest inSystemTest = this.mInSystemTest;
        if (inSystemTest != null) {
            inSystemTest.startFleshRubberTest();
        }
    }

    public void startBlackRubberTest() {
        FpUtil.log_d(this.CLASS_NAME, "startBlackRubberTest", "");
        InSystemTest inSystemTest = this.mInSystemTest;
        if (inSystemTest != null) {
            inSystemTest.startBlackRubberTest();
        }
    }

    public void start3DRubberTest() {
        FpUtil.log_d(this.CLASS_NAME, "start3DRubberTest", "");
        InSystemTest inSystemTest = this.mInSystemTest;
        if (inSystemTest != null) {
            inSystemTest.start3DRubberTest();
        }
    }

    public void startSNRTest() {
        FpUtil.log_d(this.CLASS_NAME, "startSNRTest", "");
        this.mListFpTestItemSnrData.clear();
        InSystemTest inSystemTest = this.mInSystemTest;
        if (inSystemTest != null) {
            inSystemTest.startSNRTest();
        }
    }

    public void startTouchIntRstTest() {
        FpUtil.log_d(this.CLASS_NAME, "startTouchIntRstTest", "");
        GFTestManager gFTestManager = this.mGFTestManager;
        if (gFTestManager != null) {
            gFTestManager.startTouchIntRstTest();
        }
    }

    public void startTouchTest() {
        FpUtil.log_d(this.CLASS_NAME, "startTouchTest", "");
        GFTestManager gFTestManager = this.mGFTestManager;
        if (gFTestManager != null) {
            gFTestManager.startTouchTest();
        }
    }

    public void startSublineTest() {
        FpUtil.log_d(this.CLASS_NAME, "startSublineTest", "");
        InSystemTest inSystemTest = this.mInSystemTest;
        if (inSystemTest != null) {
            inSystemTest.startSublineTest();
        }
    }

    public void setBrightnessReady() {
        FpUtil.log_d(this.CLASS_NAME, "setBrightnessReady", "");
        InSystemTest inSystemTest = this.mInSystemTest;
        if (inSystemTest != null) {
            inSystemTest.setBrightnessReady();
        }
    }

    private void startGetInSystemSpec() {
        InSystemTest inSystemTest;
        FpUtil.log_d(this.CLASS_NAME, "startGetInSystemSpec", "");
        if (this.mIsFactoryBin && (inSystemTest = this.mInSystemTest) != null) {
            inSystemTest.startGetInSystemSpec();
        }
    }

    public void cancelTest() {
        FpUtil.log_d(this.CLASS_NAME, "cancelTest", "");
        InSystemTest inSystemTest = this.mInSystemTest;
        if (inSystemTest != null) {
            inSystemTest.cancelTest();
            return;
        }
        GFTestManager gFTestManager = this.mGFTestManager;
        if (gFTestManager != null) {
            gFTestManager.cancelTest();
            this.mGFTestManager.registerResultNotify(this.mTestResultNotify);
        }
    }

    public int getHighBrightness() {
        FpUtil.log_d(this.CLASS_NAME, "getHighBrighness", "");
        InSystemTest inSystemTest = this.mInSystemTest;
        if (inSystemTest != null) {
            return inSystemTest.getHighBrightness();
        }
        return -1;
    }

    public int getMiddleBrightness() {
        FpUtil.log_d(this.CLASS_NAME, "getMiddleBrightness", "");
        InSystemTest inSystemTest = this.mInSystemTest;
        if (inSystemTest != null) {
            return inSystemTest.getMiddleBrightness();
        }
        return -1;
    }

    public int getLowBrightness() {
        FpUtil.log_d(this.CLASS_NAME, "getLowBrightness", "");
        InSystemTest inSystemTest = this.mInSystemTest;
        if (inSystemTest != null) {
            return inSystemTest.getLowBrightness();
        }
        return -1;
    }

    public String getVersion() {
        FpUtil.log_d(this.CLASS_NAME, "getVersion", "");
        if (this.mIsFactoryBin) {
            InSystemTest inSystemTest = this.mInSystemTest;
            if (inSystemTest != null) {
                return inSystemTest.getVersion();
            }
            GFTestManager gFTestManager = this.mGFTestManager;
            if (gFTestManager != null) {
                return gFTestManager.getVersion();
            }
            return null;
        }
        FingerprintManager fingerprintManager = this.mFingerprintManager;
        if (fingerprintManager != null) {
            return fingerprintManager.semGetDaemonVersion();
        }
        return null;
    }

    public String[] getUserIdList() {
        FpUtil.log_d(this.CLASS_NAME, "hasUserIdList", "");
        FingerprintManager fingerprintManager = this.mFingerprintManager;
        if (fingerprintManager != null) {
            return fingerprintManager.semGetUserIdList();
        }
        return null;
    }

    public void enroll() {
        FpUtil.log_d(this.CLASS_NAME, "enroll", "");
        GFTestManager gFTestManager = this.mGFTestManager;
        if (gFTestManager != null) {
            gFTestManager.enroll();
        }
    }

    public void identify() {
        FpUtil.log_d(this.CLASS_NAME, "identify", "");
        GFTestManager gFTestManager = this.mGFTestManager;
        if (gFTestManager != null) {
            gFTestManager.identify();
        }
    }

    public void makeLogFile(ArrayList<FpTestItem> listItem, String path) {
        String packageName = this.mContext.getPackageName();
        if (packageName == null || !packageName.contains("hwmoduletest")) {
            String str = this.CLASS_NAME;
            FpUtil.log_d(str, "makeLogFile", "path :" + path);
            StringBuilder sb = new StringBuilder();
            boolean isPass = true;
            for (int i = 0; i < listItem.size(); i++) {
                sb.append(",");
                sb.append(listItem.get(i).getTestResult());
                if (!listItem.get(i).getIsPass()) {
                    isPass = false;
                }
            }
            sb.insert(0, isPass ? "PASS" : "FAIL");
            FpUtil.write(path, sb.toString());
            return;
        }
        FpUtil.log_d(this.CLASS_NAME, "makeLogFile", "No file creation");
    }

    public void setIsCalBrightnessNormal(boolean isNormalBrightness) {
        String str = this.CLASS_NAME;
        CommonFingerprintEgis.FpUtil.log_d(str, "setIsCalBrightnessNormal", "isNormalBrightness : " + isNormalBrightness);
        boolean isPassWithoutCheckBrightness = true;
        Iterator<FpTestItem> it = this.mListFpTestItemCalibration.iterator();
        while (true) {
            if (it.hasNext()) {
                if (!it.next().getIsPass()) {
                    isPassWithoutCheckBrightness = false;
                    break;
                }
            } else {
                break;
            }
        }
        if (!isPassWithoutCheckBrightness || !isNormalBrightness) {
            this.mListFpTestItemCalibration.add(new FpTestItem("Calibration Save", "0", "0", ModuleCommunicationService.SMD_NOK));
            sendCalResult();
            return;
        }
        this.mInSystemTest.saveCalibrationData(0);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sendCalResult() {
        if (this.mCallbackHandler != null) {
            makeLogFile(this.mListFpTestItemCalibration, "/data/log/FingerSNRData.log");
            Message message = this.mCallbackHandler.obtainMessage();
            message.what = 1004;
            message.obj = this.mListFpTestItemCalibration;
            this.mCallbackHandler.sendMessage(message);
        }
    }

    public void saveCellId() {
        String packageName = this.mContext.getPackageName();
        if (packageName == null || !packageName.contains("com.sec.hwmoduletest")) {
            FpUtil.log_d(this.CLASS_NAME, "saveCellId", "");
            String cell_id = FpUtil.read(PATH_CELL_ID);
            if (cell_id != null) {
                cell_id = cell_id.replace(" ", "");
                if (cell_id.length() > 29) {
                    FpUtil.log_d(this.CLASS_NAME, "saveCellId", "cell_id is too long, cut under 30 letter");
                    cell_id.substring(0, 29);
                }
                FpUtil.write(PATH_LOG_CELL_ID, cell_id);
            }
            String str = this.CLASS_NAME;
            FpUtil.log_d(str, "saveCellId", "cell_id :" + cell_id);
            return;
        }
        FpUtil.log_d(this.CLASS_NAME, "saveCellId", "No file creation");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private ArrayList<FpTestItem> getItemListFromString(String rawString) {
        ArrayList<FpTestItem> list = new ArrayList<>();
        if (rawString != null) {
            BufferedReader br = new BufferedReader(new StringReader(rawString));
            while (true) {
                try {
                    String strRead = br.readLine();
                    if (strRead != null) {
                        String str = this.CLASS_NAME;
                        FpUtil.log_d(str, "getItemListFromString", "strRead : " + strRead);
                        String[] itemData = strRead.split(";");
                        if (itemData.length == 4) {
                            list.add(new FpTestItem(itemData[0].trim(), itemData[1].trim(), itemData[2].trim(), itemData[3].trim()));
                        } else {
                            String str2 = this.CLASS_NAME;
                            FpUtil.log_d(str2, "getItemListFromString", "skip add data : " + Arrays.toString(itemData));
                        }
                    } else {
                        try {
                            break;
                        } catch (IOException e) {
                            FpUtil.log_e(e);
                        }
                    }
                } catch (IOException e2) {
                    FpUtil.log_e(e2);
                    br.close();
                } catch (Throwable th) {
                    try {
                        br.close();
                    } catch (IOException e3) {
                        FpUtil.log_e(e3);
                    }
                    throw th;
                }
            }
            br.close();
        }
        return list;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private ArrayList<FpTestItem> getSensorInfoFromString(String rawString) {
        ArrayList<FpTestItem> list = new ArrayList<>();
        if (rawString != null) {
            BufferedReader br = new BufferedReader(new StringReader(rawString));
            while (true) {
                try {
                    String strRead = br.readLine();
                    if (strRead != null) {
                        String str = this.CLASS_NAME;
                        FpUtil.log_d(str, "getSensorInfoFromString", "strRead : " + strRead);
                        String[] itemData = strRead.split(":");
                        if (itemData.length == 2) {
                            list.add(new FpTestItem(itemData[0].trim(), "0", "0", itemData[1].trim()));
                        } else {
                            String str2 = this.CLASS_NAME;
                            FpUtil.log_d(str2, "getSensorInfoFromString", "skip add data : " + Arrays.toString(itemData));
                        }
                    } else {
                        try {
                            break;
                        } catch (IOException e) {
                            FpUtil.log_e(e);
                        }
                    }
                } catch (IOException e2) {
                    FpUtil.log_e(e2);
                    br.close();
                } catch (Throwable th) {
                    try {
                        br.close();
                    } catch (IOException e3) {
                        FpUtil.log_e(e3);
                    }
                    throw th;
                }
            }
            br.close();
        }
        return list;
    }

    private class TestResultCallback implements InSystemTest.ITestResultCallback {
        public TestResultCallback() {
        }

        @Override // com.goodix.display.fingerprint.insystem.InSystemTest.ITestResultCallback
        public void onResult(int param1Int1, int param1Int2) {
            String str = CommonFingerprintGoodix.this.CLASS_NAME;
            FpUtil.log_d(str, "TestResultCallback,onResult", "param1Int1 : " + param1Int1 + ", param1Int2 : " + param1Int2);
            int msgWhat = -1;
            switch (param1Int1) {
                case 7:
                    msgWhat = 502;
                    break;
                case 8:
                    msgWhat = 500;
                    break;
                case 9:
                    msgWhat = 200;
                    break;
                case 10:
                    msgWhat = 500;
                    break;
                case 11:
                    msgWhat = 504;
                    break;
                case 12:
                    msgWhat = 202;
                    break;
                case 13:
                    msgWhat = 502;
                    break;
                case 17:
                    CommonFingerprintGoodix.this.saveCellId();
                    CommonFingerprintGoodix.this.mListFpTestItemCalibration.add(new FpTestItem("Calibration Save", "0", "0", param1Int2 == 512 ? "0" : ModuleCommunicationService.SMD_NOK));
                    CommonFingerprintGoodix.this.sendCalResult();
                    break;
            }
            if (msgWhat != -1 && CommonFingerprintGoodix.this.mCallbackHandler != null) {
                CommonFingerprintGoodix.this.mCallbackHandler.sendEmptyMessage(msgWhat);
            }
        }

        @Override // com.goodix.display.fingerprint.insystem.InSystemTest.ITestResultCallback
        public void onSensorInfo(SensorInfo param1SensorInfo) {
            FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallback,onSensorInfo", "");
        }

        @Override // com.goodix.display.fingerprint.insystem.InSystemTest.ITestResultCallback
        public void onSensorInfoHelp(String param1String) {
            FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallback,onSensorInfoHelp", param1String);
            CommonFingerprintGoodix.this.mListFpTestItemSensorInfo.clear();
            CommonFingerprintGoodix commonFingerprintGoodix = CommonFingerprintGoodix.this;
            commonFingerprintGoodix.mListFpTestItemSensorInfo = commonFingerprintGoodix.getSensorInfoFromString(param1String);
            synchronized (CommonFingerprintGoodix.this.mLock) {
                FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallback,onSensorInfoHelp", "mLock -> notify");
                CommonFingerprintGoodix.this.mLock.notify();
            }
        }

        @Override // com.goodix.display.fingerprint.insystem.InSystemTest.ITestResultCallback
        public void onNormalScanData(NormalScanData param1NormalScanData) {
            FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallback,onNormalScanData", "");
        }

        @Override // com.goodix.display.fingerprint.insystem.InSystemTest.ITestResultCallback
        public void onNormalScanDataHelp(String param1String) {
            FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallback,onNormalScanDataHelp", param1String);
            CommonFingerprintGoodix.this.mListFpTestItemNormalScan.clear();
            CommonFingerprintGoodix commonFingerprintGoodix = CommonFingerprintGoodix.this;
            commonFingerprintGoodix.mListFpTestItemNormalScan = commonFingerprintGoodix.getItemListFromString(param1String);
            synchronized (CommonFingerprintGoodix.this.mLock) {
                FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallback,onNormalScanData", "mLock -> notify");
                CommonFingerprintGoodix.this.mLock.notify();
            }
            CommonFingerprintGoodix commonFingerprintGoodix2 = CommonFingerprintGoodix.this;
            commonFingerprintGoodix2.makeLogFile(commonFingerprintGoodix2.mListFpTestItemNormalScan, "/data/log/FingerNormalData.log");
        }

        @Override // com.goodix.display.fingerprint.insystem.InSystemTest.ITestResultCallback
        public void onCalibrationData(CalibrationData param1CalibrationData) {
            FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallback,onCalibrationData", "");
        }

        @Override // com.goodix.display.fingerprint.insystem.InSystemTest.ITestResultCallback
        public void onCalibrationDataHelp(String param1String) {
            FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallback,onCalibrationDataHelp", param1String);
            CommonFingerprintGoodix.this.mListFpTestItemCalibration.clear();
            CommonFingerprintGoodix commonFingerprintGoodix = CommonFingerprintGoodix.this;
            commonFingerprintGoodix.mListFpTestItemCalibration = commonFingerprintGoodix.getItemListFromString(param1String);
            if (CommonFingerprintGoodix.this.mCallbackHandler != null) {
                CommonFingerprintGoodix.this.mCallbackHandler.sendEmptyMessage(1001);
            }
        }

        @Override // com.goodix.display.fingerprint.insystem.InSystemTest.ITestResultCallback
        public void onSublineData(SublineData param1SublineData) {
            FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallback,onSublineData", "");
        }

        @Override // com.goodix.display.fingerprint.insystem.InSystemTest.ITestResultCallback
        public void onSublineDataHelp(String param1String) {
            FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallback,onSublineDataHelp", param1String);
            CommonFingerprintGoodix.this.mListFpTestItemCalibration.clear();
            CommonFingerprintGoodix commonFingerprintGoodix = CommonFingerprintGoodix.this;
            commonFingerprintGoodix.mListFpTestItemCalibration = commonFingerprintGoodix.getItemListFromString(param1String);
            if (CommonFingerprintGoodix.this.mCallbackHandler != null) {
                Message message = CommonFingerprintGoodix.this.mCallbackHandler.obtainMessage();
                message.what = 1004;
                message.obj = CommonFingerprintGoodix.this.mListFpTestItemCalibration;
                CommonFingerprintGoodix.this.mCallbackHandler.sendMessage(message);
            }
        }

        @Override // com.goodix.display.fingerprint.insystem.InSystemTest.ITestResultCallback
        public void onSNRData(SnrData param1SnrData) {
            FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallback,onSNRData", "");
        }

        @Override // com.goodix.display.fingerprint.insystem.InSystemTest.ITestResultCallback
        public void onSNRDataHelp(String param1String) {
            FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallback,onSNRDataHelp", param1String);
            CommonFingerprintGoodix commonFingerprintGoodix = CommonFingerprintGoodix.this;
            commonFingerprintGoodix.mListFpTestItemSnrData = commonFingerprintGoodix.getItemListFromString(param1String);
            if (CommonFingerprintGoodix.this.mCallbackHandler != null) {
                Message message = CommonFingerprintGoodix.this.mCallbackHandler.obtainMessage();
                message.what = 1008;
                message.obj = CommonFingerprintGoodix.this.mListFpTestItemSnrData;
                CommonFingerprintGoodix.this.mCallbackHandler.sendMessage(message);
            }
        }

        @Override // com.goodix.display.fingerprint.insystem.InSystemTest.ITestResultCallback
        public void onInSystemSpec(String param1String) {
            FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallback,onInSystemSpec", param1String);
        }
    }

    private class TestResultCallbackTz extends FingerprintManager.SemRequestCallback {
        private TestResultCallbackTz() {
        }

        public void onRequested(int msgId) {
            switch (msgId) {
                case 10008:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallbackTz,onRequested", "Event is : FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_START_GOOGLE");
                    return;
                case 10009:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallbackTz,onRequested", "Event is : FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_END_GOOGLE");
                    synchronized (CommonFingerprintGoodix.this.mLock) {
                        FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallbackTz,onRequested", "mLock -> notify");
                        CommonFingerprintGoodix.this.mLock.notify();
                    }
                    return;
                default:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultCallbackTz,onRequested", "Event is : UNKNOWN_EVT_MESSAGE");
                    return;
            }
        }
    }

    private class TestResultNotifyCallback implements TestResultNotify {
        private TestResultNotifyCallback() {
        }

        @Override // com.goodix.cap.fingerprint.sec.mt.TestResultNotify
        public void onUnTouchResultNotify(int paramInt, Object paramObject) {
            switch (paramInt) {
                case 898:
                    return;
                case 917:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onUnTouchResultNotify", "CMD_UNTOUCH_TEST_START");
                    return;
                case 918:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultNotifyCallback,onUnTouchResultNotify", "CMD_UNTOUCH_TEST_END");
                    String str = CommonFingerprintGoodix.this.CLASS_NAME;
                    FpUtil.log_d(str, "TestResultNotifyCallback,onUnTouchResultNotify", "paramObject : " + paramObject.toString());
                    CommonFingerprintGoodix.this.mListFpTestItemNormalScan.clear();
                    CommonFingerprintGoodix commonFingerprintGoodix = CommonFingerprintGoodix.this;
                    commonFingerprintGoodix.mListFpTestItemNormalScan = commonFingerprintGoodix.getItemListFromString(paramObject.toString());
                    CommonFingerprintGoodix commonFingerprintGoodix2 = CommonFingerprintGoodix.this;
                    commonFingerprintGoodix2.makeLogFile(commonFingerprintGoodix2.mListFpTestItemNormalScan, "/data/log/FingerNormalData.log");
                    synchronized (CommonFingerprintGoodix.this.mLock) {
                        FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultNotifyCallback,onUnTouchResultNotify", "mLock -> notify");
                        CommonFingerprintGoodix.this.mLock.notify();
                    }
                    return;
                case 933:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onUnTouchResultNotify", " CMD_SENSOR_AVAILABLE_STATUS");
                    if (EgisFingerprint.MAJOR_VERSION.equals(paramObject.toString())) {
                        FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onUnTouchResultNotify", " CMD_SENSOR_AVAILABLE_STATUS - fail");
                        return;
                    } else {
                        FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onUnTouchResultNotify", " CMD_SENSOR_AVAILABLE_STATUS - pass");
                        return;
                    }
                default:
                    String str2 = CommonFingerprintGoodix.this.CLASS_NAME;
                    FpUtil.log_d(str2, "onUnTouchResultNotify", "Unknown, TestCmdId : " + paramInt + ", paramObject : " + paramObject.toString());
                    return;
            }
        }

        @Override // com.goodix.cap.fingerprint.sec.mt.TestResultNotify
        public void onTouchResultNotify(int paramInt, Object paramObject) {
            switch (paramInt) {
                case 899:
                    return;
                case 902:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onTouchResultNotify", "CMD_TOUCH_WAITING");
                    if (CommonFingerprintGoodix.this.mCallbackHandler != null) {
                        CommonFingerprintGoodix.this.mCallbackHandler.sendEmptyMessage(208);
                        return;
                    }
                    return;
                case 919:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onTouchResultNotify", "CMD_TOUCH_TEST_START");
                    CommonFingerprintGoodix.this.mListFpTestItemCalibration.clear();
                    return;
                case 920:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "TestResultNotifyCallback,onTouchResultNotify", "CMD_TOUCH_TEST_END");
                    if (CommonFingerprintGoodix.this.mCallbackHandler != null) {
                        String str = CommonFingerprintGoodix.this.CLASS_NAME;
                        FpUtil.log_d(str, "TestResultNotifyCallback,onTouchResultNotify", "paramObject : " + paramObject.toString());
                        CommonFingerprintGoodix.this.mListFpTestItemCalibration.clear();
                        CommonFingerprintGoodix commonFingerprintGoodix = CommonFingerprintGoodix.this;
                        commonFingerprintGoodix.mListFpTestItemCalibration = commonFingerprintGoodix.getItemListFromString(paramObject.toString());
                        CommonFingerprintGoodix commonFingerprintGoodix2 = CommonFingerprintGoodix.this;
                        commonFingerprintGoodix2.makeLogFile(commonFingerprintGoodix2.mListFpTestItemCalibration, "/data/log/FingerSNRData.log");
                        Message message = CommonFingerprintGoodix.this.mCallbackHandler.obtainMessage();
                        message.what = 500;
                        message.obj = CommonFingerprintGoodix.this.mListFpTestItemCalibration;
                        CommonFingerprintGoodix.this.mCallbackHandler.sendMessage(message);
                        return;
                    }
                    return;
                case 933:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onTouchResultNotify", " CMD_SENSOR_AVAILABLE_STATUS");
                    if (EgisFingerprint.MAJOR_VERSION.equals(paramObject.toString())) {
                        FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onTouchResultNotify", " CMD_SENSOR_AVAILABLE_STATUS - fail");
                        return;
                    } else {
                        FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onTouchResultNotify", " CMD_SENSOR_AVAILABLE_STATUS - pass");
                        return;
                    }
                default:
                    String str2 = CommonFingerprintGoodix.this.CLASS_NAME;
                    FpUtil.log_d(str2, "onTouchResultNotify", "Unknown, TestCmdId : " + paramInt + ", paramObject : " + paramObject.toString());
                    return;
            }
        }

        @Override // com.goodix.cap.fingerprint.sec.mt.TestResultNotify
        public void onCaptureNotify(int paramInt, Object paramObject) {
            int msgWhat = -1;
            switch (paramInt) {
                case 4004:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onCaptureNotify", "CAPTURE_SUCCESS");
                    msgWhat = 309;
                    break;
                case 4005:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onCaptureNotify", "CAPTURE_FAILED");
                    msgWhat = 310;
                    break;
                default:
                    String str = CommonFingerprintGoodix.this.CLASS_NAME;
                    FpUtil.log_d(str, "onCaptureNotify", "Unknown, TestCmdId : " + paramInt + ", paramObject : " + paramObject.toString());
                    break;
            }
            if (CommonFingerprintGoodix.this.mCallbackHandler != null) {
                GoodixFpCaptureInfo goodixFpCaptureInfo = (GoodixFpCaptureInfo) paramObject;
                Message message = CommonFingerprintGoodix.this.mCallbackHandler.obtainMessage();
                message.what = msgWhat;
                message.arg1 = goodixFpCaptureInfo.quality;
                message.obj = goodixFpCaptureInfo.bitmap;
                CommonFingerprintGoodix.this.mCallbackHandler.sendMessage(message);
            }
        }

        @Override // com.goodix.cap.fingerprint.sec.mt.TestResultNotify
        public void onCaptureFingerLeaved(int paramInt, Object paramObject) {
            FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onCaptureFingerLeaved", "");
            if (CommonFingerprintGoodix.this.mCallbackHandler != null) {
                CommonFingerprintGoodix.this.mCallbackHandler.sendEmptyMessage(402);
            }
        }

        @Override // com.goodix.cap.fingerprint.sec.mt.TestResultNotify
        public void onEnrollStatus(int paramInt, Object paramObject) {
            switch (paramInt) {
                case 5001:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onEnrollStatus", "ENROLL_STATUS");
                    return;
                case 5002:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onEnrollStatus", "ENROLL_SUCCESS");
                    if (CommonFingerprintGoodix.this.mCallbackHandler != null) {
                        Message message = CommonFingerprintGoodix.this.mCallbackHandler.obtainMessage();
                        message.what = 313;
                        message.obj = ((GoodixFpEnrollStatus) paramObject).coverageBitmap;
                        CommonFingerprintGoodix.this.mCallbackHandler.sendMessage(message);
                        return;
                    }
                    return;
                default:
                    String str = CommonFingerprintGoodix.this.CLASS_NAME;
                    FpUtil.log_d(str, "onEnrollStatus", "Unknown, TestCmdId : " + paramInt + ", paramObject : " + paramObject.toString());
                    return;
            }
        }

        @Override // com.goodix.cap.fingerprint.sec.mt.TestResultNotify
        public void onIdentifyStatus(int paramInt, Object paramObject) {
            GoodixFpIdentifyResult goodixFpIdentifyResult = (GoodixFpIdentifyResult) paramObject;
            String str = CommonFingerprintGoodix.this.CLASS_NAME;
            FpUtil.log_d(str, "onIdentifyStatus", "userId = " + goodixFpIdentifyResult.userId);
            String str2 = CommonFingerprintGoodix.this.CLASS_NAME;
            FpUtil.log_d(str2, "onIdentifyStatus", "result = " + goodixFpIdentifyResult.result);
            Message message = CommonFingerprintGoodix.this.mCallbackHandler.obtainMessage();
            switch (paramInt) {
                case 6001:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onIdentifyStatus", "IDENTIFY_SUCCESS");
                    message.what = 317;
                    CommonFingerprintGoodix.this.mCallbackHandler.sendMessage(message);
                    return;
                case 6002:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onIdentifyStatus", "IDENTIFY_FAILED");
                    message.what = 318;
                    CommonFingerprintGoodix.this.mCallbackHandler.sendMessage(message);
                    return;
                default:
                    String str3 = CommonFingerprintGoodix.this.CLASS_NAME;
                    FpUtil.log_d(str3, "onIdentifyStatus", "Unknown, TestCmdId : " + paramInt + ", paramObject : " + paramObject.toString());
                    return;
            }
        }

        @Override // com.goodix.cap.fingerprint.sec.mt.TestResultNotify
        public void onOTPCheckNotify(int paramInt, Object paramObject) {
        }

        @Override // com.goodix.cap.fingerprint.sec.mt.TestResultNotify
        public void onGetSensorInfoNotify(int paramInt, Object paramObject) {
            switch (paramInt) {
                case 914:
                case 927:
                case 928:
                case 929:
                    String str = CommonFingerprintGoodix.this.CLASS_NAME;
                    FpUtil.log_d(str, "onGetSensorInfoNotify", "TestCmdId : " + paramInt);
                    String itemName = Spec.getNameById(paramInt);
                    String str2 = CommonFingerprintGoodix.this.CLASS_NAME;
                    FpUtil.log_d(str2, "onGetSensorInfoNotify", "item name : " + itemName);
                    CommonFingerprintGoodix.this.mListFpTestItemSensorInfo.add(new FpTestItem(itemName, "NA", "NA", paramObject.toString()));
                    return;
                case 923:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onGetSensorInfoNotify", "CMD_GET_SENSOR_INFO_START");
                    return;
                case 924:
                    FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onGetSensorInfoNotify", "CMD_GET_SENSOR_INFO_END");
                    synchronized (CommonFingerprintGoodix.this.mLock) {
                        FpUtil.log_d(CommonFingerprintGoodix.this.CLASS_NAME, "onGetSensorInfoNotify", "mLock -> notify");
                        CommonFingerprintGoodix.this.mLock.notify();
                    }
                    return;
                case 933:
                    String str3 = CommonFingerprintGoodix.this.CLASS_NAME;
                    FpUtil.log_d(str3, "onGetSensorInfoNotify", "CMD_SENSOR_AVAILABLE_STATUS, " + paramObject.toString());
                    return;
                default:
                    String str4 = CommonFingerprintGoodix.this.CLASS_NAME;
                    FpUtil.log_d(str4, "onGetSensorInfoNotify", "Unknown, TestCmdId : " + paramInt + ", paramObject : " + paramObject.toString());
                    return;
            }
        }
    }

    public static class FpTestItem {
        private boolean mIsPass = false;
        private String mStringName;
        private String mStringResult;
        private String mStringSpecMax;
        private String mStringSpecMin;
        private DATA_TYPE mTYPE = DATA_TYPE.NOT_DETERMINED;

        /* access modifiers changed from: private */
        public enum DATA_TYPE {
            STRING,
            INT,
            FLOAT,
            NOT_DETERMINED
        }

        public FpTestItem(String testName, String specMin, String specMax, String result) {
            this.mStringName = testName;
            this.mStringSpecMin = specMin;
            this.mStringSpecMax = specMax;
            this.mStringResult = result;
            checkResultType();
            checkSpec();
        }

        private void checkResultType() {
            String str = this.mStringResult;
            if (str == null || !str.contains("e")) {
                try {
                    Integer.parseInt(this.mStringResult);
                    this.mTYPE = DATA_TYPE.INT;
                } catch (NumberFormatException e) {
                    try {
                        Float.parseFloat(this.mStringResult);
                        this.mTYPE = DATA_TYPE.FLOAT;
                        this.mStringResult = String.format(Locale.ENGLISH, "%.2f", Float.valueOf(Float.parseFloat(this.mStringResult)));
                    } catch (NumberFormatException e2) {
                        this.mTYPE = DATA_TYPE.STRING;
                    }
                }
            } else {
                this.mTYPE = DATA_TYPE.STRING;
            }
        }

        private void checkSpec() {
            if ("NA".equalsIgnoreCase(this.mStringSpecMin) || "NA".equalsIgnoreCase(this.mStringSpecMax)) {
                this.mIsPass = true;
                return;
            }
            try {
                if (this.mTYPE == DATA_TYPE.STRING) {
                    String str = this.mStringResult;
                    if (str != null && (str.equalsIgnoreCase(this.mStringSpecMin) || this.mStringResult.equalsIgnoreCase(this.mStringSpecMax))) {
                        this.mIsPass = true;
                        return;
                    }
                } else if (this.mTYPE == DATA_TYPE.INT) {
                    int intSpecMin = (int) Float.parseFloat(this.mStringSpecMin);
                    int intSpecMax = (int) Float.parseFloat(this.mStringSpecMax);
                    int intResult = Integer.parseInt(this.mStringResult);
                    if (intResult >= intSpecMin && intResult <= intSpecMax) {
                        this.mIsPass = true;
                        return;
                    }
                } else if (this.mTYPE == DATA_TYPE.FLOAT) {
                    float floatSpecMin = Float.parseFloat(this.mStringSpecMin);
                    float floatSpecMax = Float.parseFloat(this.mStringSpecMax);
                    float floatResult = Float.parseFloat(this.mStringResult);
                    if (Float.compare(floatResult, floatSpecMin) >= 0 && Float.compare(floatResult, floatSpecMax) <= 0) {
                        this.mIsPass = true;
                        return;
                    }
                } else {
                    this.mIsPass = false;
                    return;
                }
                this.mIsPass = false;
            } catch (NumberFormatException ne) {
                FpUtil.log_e(ne);
                this.mIsPass = false;
            }
        }

        public String getTestName() {
            return this.mStringName;
        }

        public String getTestResult() {
            return this.mStringResult;
        }

        public String getTestSpec() {
            return this.mStringSpecMin + "~" + this.mStringSpecMax;
        }

        public boolean getIsPass() {
            return this.mIsPass;
        }

        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append("Item [");
            sb.append(this.mStringName);
            sb.append("]  Spec [");
            sb.append(getTestSpec());
            sb.append("]  Result [");
            sb.append(getTestResult());
            sb.append("]  -> ");
            sb.append(this.mIsPass ? "PASS" : "FAIL");
            return sb.toString();
        }
    }

    public static class Spec {
        private static boolean isInitSpecMap = false;
        private static HashMap<String, Integer> orderMap = new HashMap<>();
        private static LinkedHashMap<Integer, String> testCmdIdMap = new LinkedHashMap<>();

        private static void init() {
            if (!isInitSpecMap) {
                isInitSpecMap = true;
                testCmdIdMap.put(927, "UI Product ID");
                testCmdIdMap.put(914, "Module Test");
                testCmdIdMap.put(929, "Calibration");
                testCmdIdMap.put(928, "UID");
                int tmpIndex = 0;
                for (Integer key : testCmdIdMap.keySet()) {
                    orderMap.put(testCmdIdMap.get(key), Integer.valueOf(tmpIndex));
                    tmpIndex++;
                }
            }
        }

        public static String getNameById(int cmdId) {
            init();
            return testCmdIdMap.get(Integer.valueOf(cmdId));
        }

        public static int getOrderForCompare(String itemName) {
            Integer order = orderMap.get(itemName);
            if (order != null) {
                return order.intValue();
            }
            return 9999;
        }

        public static class ComparatorFpTestItem implements Comparator<FpTestItem>, Serializable {
            public int compare(FpTestItem item1, FpTestItem item2) {
                return Integer.compare(Spec.getOrderForCompare(item1.getTestName()), Spec.getOrderForCompare(item2.getTestName()));
            }
        }
    }

    public static class FpUtil {
        public static void log_d(String className, String methodName, String message) {
            FtUtil.log_d(className, methodName, message);
        }

        public static void log_e(Exception e) {
            FtUtil.log_e(e);
        }

        public static boolean write(String path, String value) {
            return Support.Kernel.writeToPathNsync(path, value);
        }

        public static String read(String path) {
            return Support.Kernel.readAllFromPath(path, true);
        }

        public static boolean isFactoryBinary() {
            return FtUtil.isFactoryBinary();
        }
    }
}
