package com.sec.factory.common;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.hardware.fingerprint.FingerprintManager;
import com.qualcomm.qti.biometrics.fingerprint.QFSEventListener;
import com.qualcomm.qti.biometrics.fingerprint.QFSManager;
import com.qualcomm.qti.biometrics.fingerprint.QFSScanListener;
import com.sec.factory.support.FtUtil;
import com.sec.factory.support.Status;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.io.BufferedReader;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.List;
import java.util.Locale;

public class CommonFingerprintQcom {
    public static int ATCMD = 0;
    public static int MANUAL = 1;
    public static final int PRIORITY_FP_CAL = 15;
    public static final int PRIORITY_FP_CONTROLLER = 20;
    public static final int PRIORITY_FP_SCAN = 10;
    private static QFSManager mFingerprint = null;
    private String CLASS_NAME = "CommonFingerprintQcom";
    public final int FINGERPRINT_ACQUIRED_FACTORY_TEST_SNSR_TEST_SCRIPT_END = 10009;
    public final int FINGERPRINT_ACQUIRED_FACTORY_TEST_SNSR_TEST_SCRIPT_START = 10008;
    public final String MSG_CAL_FINISH_FAIL = "com.sec.factory.common.CommonFingerprintQcom.MSG_CAL_FINISH_FAIL";
    public final String MSG_CAL_FINISH_PASS = "com.sec.factory.common.CommonFingerprintQcom.MSG_CAL_FINISH_PASS";
    public final String MSG_CAPTURE_FAIL = "com.sec.factory.common.CommonFingerprintQcom.MSG_CAPTURE_FAIL";
    public final String MSG_CAPTURE_READY = "com.sec.factory.common.CommonFingerprintQcom.MSG_CAPTURE_READY";
    public final String MSG_CAPTURE_SUCCESS = "com.sec.factory.common.CommonFingerprintQcom.MSG_CAPTURE_SUCCESS";
    public final String MSG_CONTAMINATION_INVALID_TEMP_FAIL = "com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_INVALID_TEMP_FAIL";
    public final String MSG_CONTAMINATION_M0_DEFECT_FAIL = "com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_M0_DEFECT_FAIL";
    public final String MSG_CONTAMINATION_MEMORY_DEFECT_FAIL = "com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_MEMORY_DEFECT_FAIL";
    public final String MSG_CONTAMINATION_NOT_DEFINED_FAIL = "com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_NOT_DEFINED_FAIL";
    public final String MSG_CONTAMINATION_PASS = "com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_PASS";
    public final String MSG_CONTAMINATION_SANITY_ERROR_20_FAIL = "com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_SANITY_ERROR_20_FAIL";
    public final String MSG_CONTAMINATION_STRONG_FAIL = "com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_STRONG_FAIL";
    public final String MSG_CONTAMINATION_UNKNOWN_FAIL = "com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_UNKNOWN_FAIL";
    public final String MSG_CONTAMINATION_WEAK_FAIL = "com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_WEAK_FAIL";
    public final String MSG_INT1_FAIL = "com.sec.factory.common.CommonFingerprintQcom.MSG_INT1_FAIL";
    public final String MSG_INT1_SUCCESS = "com.sec.factory.common.CommonFingerprintQcom.MSG_INT1_SUCCESS";
    public final String MSG_NORMAL_SCAN_FAIL = "com.sec.factory.common.CommonFingerprintQcom.MSG_NORMAL_SCAN_FAIL";
    public final String MSG_NORMAL_SCAN_FINISH_TZ = "com.sec.factory.common.CommonFingerprintQcom.MSG_NORMAL_SCAN_FINISH_TZ";
    public final String MSG_NORMAL_SCAN_START_TZ = "com.sec.factory.common.CommonFingerprintQcom.MSG_NORMAL_SCAN_START_TZ";
    public final String MSG_NORMAL_SCAN_SUCCESS = "com.sec.factory.common.CommonFingerprintQcom.MSG_NORMAL_SCAN_SUCCESS";
    public final String MSG_SNR_SCAN_FAIL = "com.sec.factory.common.CommonFingerprintQcom.MSG_SNR_SCAN_FAIL";
    public final String MSG_SNR_SCAN_READY = "com.sec.factory.common.CommonFingerprintQcom.MSG_SNR_SCAN_READY";
    public final String MSG_SNR_SCAN_SUCCESS = "com.sec.factory.common.CommonFingerprintQcom.MSG_SNRc_SCAN_SUCCESS";
    public final String MSG_SNR_SCAN_TIMEOUT = "com.sec.factory.common.CommonFingerprintQcom.MSG_SNR_SCAN_TIMEOUT";
    public final String MSG_TIME_OUT = "com.sec.factory.common.CommonFingerprintQcom.MSG_TIME_OUT";
    private String UTOPIA_TAG = "[UTOPIA_FINGERPRINT]";
    private Thread checkTimeOutThread;
    private boolean isEnabledListeners = false;
    private String mChipName;
    private Context mContext;
    private FingerPrintEventListener mFingerPrintEventListener = null;
    private FingerPrintScanListener mFingerPrintScanListener = null;
    private FingerprintManager mFingerprintManager;
    private NormalScanEventListener_TZ mNormalScanEventListener_TZ;
    private boolean mTzEnabled;
    private TestType testType = TestType.NOTEST;

    public enum TestType {
        NORMALSCAN,
        SNRSCAN,
        BGECAL,
        INT1,
        INT2,
        CONTAMINATION,
        NOTEST
    }

    public CommonFingerprintQcom(Context context, String callerName) {
        this.CLASS_NAME = callerName + "(" + this.CLASS_NAME + ")";
        this.mContext = context;
        this.mTzEnabled = FtUtil.isFactoryBinary() ^ true;
        this.mChipName = getChipName();
        enableListeners();
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "CommonFingerprintQcom", " mTzEnabled:" + this.mTzEnabled);
        if (this.mTzEnabled) {
            FingerprintManager fingerprintManager = (FingerprintManager) this.mContext.getSystemService("fingerprint");
            this.mFingerprintManager = fingerprintManager;
            if (fingerprintManager == null) {
                FtUtil.log_e(this.CLASS_NAME, "CommonFingerprintQcom", "FAIL to get FingerprintManager instance");
                return;
            }
            return;
        }
        QFSManager qFSManagerInstance = getQFSManagerInstance();
        mFingerprint = qFSManagerInstance;
        if (qFSManagerInstance == null) {
            FtUtil.log_e(this.CLASS_NAME, "CommonFingerprintQcom", "FAIL to get getQFSManagerInstance instance");
        }
        this.mFingerPrintEventListener = new FingerPrintEventListener();
    }

    private QFSManager getQFSManagerInstance() {
        if (mFingerprint == null) {
            synchronized (QFSManager.class) {
                if (mFingerprint == null) {
                    mFingerprint = new QFSManager();
                    FtUtil.log_d(this.CLASS_NAME, "getQFSManagerInstance", "get new object");
                }
            }
        } else {
            FtUtil.log_d(this.CLASS_NAME, "getQFSManagerInstance", "get existent instance");
        }
        return mFingerprint;
    }

    private class NormalScanEventListener_TZ extends FingerprintManager.SemRequestCallback {
        private final String TAG;

        private NormalScanEventListener_TZ() {
            this.TAG = "NormalScanEventListener_TZ-";
        }

        public void onRequested(int msgId) {
            String str = CommonFingerprintQcom.this.CLASS_NAME;
            FtUtil.log_d(str, "NormalScanEventListener_TZ-onRequested", "msgId : " + msgId);
            if (!CommonFingerprintQcom.this.isEnabledListeners) {
                FtUtil.log_d(CommonFingerprintQcom.this.CLASS_NAME, "NormalScanEventListener_TZ-onRequested", "Disabled Listener - msg Ignored");
                return;
            }
            Intent i = new Intent();
            if (CommonFingerprintQcom.this.getTestType() == TestType.NORMALSCAN) {
                switch (msgId) {
                    case 10008:
                        i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_NORMAL_SCAN_START_TZ");
                        break;
                    case 10009:
                        i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_NORMAL_SCAN_FINISH_TZ");
                        break;
                }
                if (i.getAction() != null) {
                    String str2 = CommonFingerprintQcom.this.CLASS_NAME;
                    FtUtil.log_d(str2, "NormalScanEventListener_TZ-onRequested", "Send Broadcast: " + i.getAction());
                    CommonFingerprintQcom.this.mContext.sendBroadcast(i);
                }
            }
        }
    }

    private byte[] getNormalScanResult_TZ() {
        byte[] outBuffer = new byte[30720];
        Arrays.fill(outBuffer, (byte) 0);
        if (this.mFingerprintManager.semGetSensorTestResult(outBuffer) >= 0) {
            return outBuffer;
        }
        FtUtil.log_e(this.CLASS_NAME, "getNormalScanResult_TZ", "FAIL - FingerprintManager.semGetSensorTestResult()");
        return null;
    }

    private class FingerPrintEventListener implements QFSEventListener {
        private final String TAG;

        private FingerPrintEventListener() {
            this.TAG = "FingerPrintEventListener-";
        }

        @Override // com.qualcomm.qti.biometrics.fingerprint.QFSEventListener
        public void onFingerprintEvent(int eventId, Object eventData) {
            String str;
            String str2 = CommonFingerprintQcom.this.CLASS_NAME;
            StringBuilder sb = new StringBuilder();
            sb.append("eventId : ");
            sb.append(eventId);
            sb.append(", eventData : ");
            sb.append(eventData);
            if (eventData == null) {
                str = "";
            } else {
                str = " (Class: " + eventData.getClass().getName() + ")";
            }
            sb.append(str);
            FtUtil.log_d(str2, "FingerPrintEventListener-onFingerprintEvent", sb.toString());
            if (!CommonFingerprintQcom.this.isEnabledListeners) {
                FtUtil.log_d(CommonFingerprintQcom.this.CLASS_NAME, "FingerPrintEventListener-onFingerprintEvent", "Disabled Listener - Events Ignored");
                return;
            }
            Intent i = new Intent();
            TestType testType = CommonFingerprintQcom.this.getTestType();
            if (testType != TestType.CONTAMINATION) {
                if (testType != TestType.BGECAL) {
                    if (testType != TestType.NORMALSCAN && testType != TestType.SNRSCAN) {
                        if (testType != TestType.INT1) {
                            if (testType == TestType.INT2) {
                                switch (eventId) {
                                    case 4001:
                                        i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CAPTURE_READY");
                                        break;
                                    case 4004:
                                        i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CAPTURE_SUCCESS");
                                        break;
                                    case 4005:
                                        i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CAPTURE_FAIL");
                                        break;
                                }
                            }
                        } else if (eventId == 9999 && (eventData instanceof Integer)) {
                            if (Integer.parseInt(eventData.toString()) == 0) {
                                i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_INT1_SUCCESS");
                            } else {
                                i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_INT1_FAIL");
                            }
                        }
                    } else if (eventId == 9999 && (eventData instanceof Integer) && Integer.parseInt(eventData.toString()) == 1) {
                        FtUtil.log_d(CommonFingerprintQcom.this.CLASS_NAME, "FingerPrintEventListener-onFingerprintEvent", "One of QFS tests FAIL");
                    }
                } else if (eventId == 9999 && (eventData instanceof Integer)) {
                    int result = Integer.parseInt(eventData.toString());
                    if (result == 0) {
                        i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CAL_FINISH_PASS");
                    } else if (result == 1) {
                        i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CAL_FINISH_FAIL");
                    } else {
                        FtUtil.log_e(CommonFingerprintQcom.this.CLASS_NAME, "FingerPrintEventListener-onFingerprintEvent", "Unknown BGE Cal Result");
                    }
                }
            } else if (eventId == 9999 && (eventData instanceof Integer)) {
                int result2 = Integer.parseInt(eventData.toString());
                if (result2 == 0) {
                    i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_PASS");
                } else if (result2 == 1) {
                    i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_UNKNOWN_FAIL");
                } else if (result2 == 2) {
                    i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_WEAK_FAIL");
                } else if (result2 == 3) {
                    i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_STRONG_FAIL");
                } else if (result2 == 4) {
                    i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_MEMORY_DEFECT_FAIL");
                } else if (result2 == 5) {
                    i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_M0_DEFECT_FAIL");
                } else if (result2 == 7) {
                    i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_SANITY_ERROR_20_FAIL");
                } else if (result2 == 8) {
                    i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_INVALID_TEMP_FAIL");
                } else {
                    i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_CONTAMINATION_NOT_DEFINED_FAIL");
                    FtUtil.log_e(CommonFingerprintQcom.this.CLASS_NAME, "FingerPrintEventListener-onFingerprintEvent", "Not Defined Contamination Error Code");
                }
            }
            if (i.getAction() != null) {
                FtUtil.log_d(CommonFingerprintQcom.this.CLASS_NAME, "FingerPrintEventListener-onFingerprintEvent", "Send Broadcast: " + i.getAction());
                CommonFingerprintQcom.this.mContext.sendBroadcast(i);
            }
        }
    }

    /* access modifiers changed from: private */
    public class FingerPrintScanListener implements QFSScanListener {
        private final String TAG;

        private FingerPrintScanListener() {
            this.TAG = "FingerPrintScanListener-";
        }

        @Override // com.qualcomm.qti.biometrics.fingerprint.QFSScanListener
        public void onFingerprintEvent(int eventId, Object eventData) {
            String str;
            String str2 = CommonFingerprintQcom.this.CLASS_NAME;
            StringBuilder sb = new StringBuilder();
            sb.append("eventId : ");
            sb.append(eventId);
            sb.append(", eventData : ");
            sb.append(eventData);
            if (eventData == null) {
                str = "";
            } else {
                str = " (Class: " + eventData.getClass().getName() + ")";
            }
            sb.append(str);
            FtUtil.log_d(str2, "FingerPrintScanListener-onFingerprintEvent", sb.toString());
            if (!CommonFingerprintQcom.this.isEnabledListeners) {
                FtUtil.log_d(CommonFingerprintQcom.this.CLASS_NAME, "FingerPrintScanListener-onFingerprintEvent", "Disabled Listener - Events Ignored");
                return;
            }
            Intent i = new Intent();
            TestType testType = CommonFingerprintQcom.this.getTestType();
            if (testType == TestType.NORMALSCAN) {
                if (eventId == 8888 && (eventData instanceof Integer)) {
                    int result = Integer.parseInt(eventData.toString());
                    if (result == 0) {
                        i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_NORMAL_SCAN_SUCCESS");
                    } else if (result == 1) {
                        i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_NORMAL_SCAN_FAIL");
                    }
                }
            } else if (testType == TestType.SNRSCAN && eventId == 8888 && (eventData instanceof Integer)) {
                int result2 = Integer.parseInt(eventData.toString());
                if (result2 == 0) {
                    i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_SNRc_SCAN_SUCCESS");
                } else if (result2 == 1) {
                    i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_SNR_SCAN_FAIL");
                } else if (result2 == 2) {
                    i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_SNR_SCAN_READY");
                } else if (result2 == 3) {
                    i.setAction("com.sec.factory.common.CommonFingerprintQcom.MSG_SNR_SCAN_TIMEOUT");
                }
            }
            if (i.getAction() != null) {
                FtUtil.log_d(CommonFingerprintQcom.this.CLASS_NAME, "FingerPrintScanListener-onFingerprintEvent", "Send Broadcast: " + i.getAction());
                CommonFingerprintQcom.this.mContext.sendBroadcast(i);
            }
        }
    }

    private FingerPrintScanListener getScanListener() {
        FtUtil.log_d(this.CLASS_NAME, "getScanListener", "getScanListener");
        if (this.mFingerPrintScanListener == null) {
            this.mFingerPrintScanListener = new FingerPrintScanListener();
        }
        return this.mFingerPrintScanListener;
    }

    public void enableListeners() {
        FtUtil.log_d(this.CLASS_NAME, "enableListeners", "enableListeners");
        this.isEnabledListeners = true;
    }

    public void disableListeners() {
        FtUtil.log_d(this.CLASS_NAME, "disableListeners", "disableListeners");
        this.isEnabledListeners = false;
    }

    private void setTestType(TestType testType2) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setTestType", " Before:" + this.testType.name() + " After:" + testType2);
        this.testType = testType2;
    }

    public TestType getTestType() {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "getTestType", " Current:" + this.testType);
        return this.testType;
    }

    public long startCheckTimeOut(final long timeout) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "startCheckTimeOut", " timeout:" + timeout);
        Thread thread = new Thread(new Runnable() {
            /* class com.sec.factory.common.CommonFingerprintQcom.AnonymousClass1 */

            public void run() {
                String str = CommonFingerprintQcom.this.CLASS_NAME;
                FtUtil.log_d(str, "startCheckTimeOut-" + "thread_run", "checkTimeOut thread start");
                try {
                    Thread.sleep(timeout);
                    Intent i = new Intent("com.sec.factory.common.CommonFingerprintQcom.MSG_TIME_OUT");
                    Long threadId = Long.valueOf(Thread.currentThread().getId());
                    i.putExtra("THREAD_ID", threadId);
                    String str2 = CommonFingerprintQcom.this.CLASS_NAME;
                    FtUtil.log_d(str2, "startCheckTimeOut", "Send Broadcast: " + i.getAction() + " threadId:" + threadId);
                    CommonFingerprintQcom.this.mContext.sendBroadcast(i);
                } catch (InterruptedException e) {
                    String str3 = CommonFingerprintQcom.this.CLASS_NAME;
                    FtUtil.log_d(str3, "startCheckTimeOut-" + "thread_run", "checkTimeOut thread Interrupted");
                }
            }
        });
        this.checkTimeOutThread = thread;
        thread.start();
        return this.checkTimeOutThread.getId();
    }

    public void endCheckTimeOut() {
        Thread thread = this.checkTimeOutThread;
        if (thread != null) {
            thread.interrupt();
            FtUtil.log_d(this.CLASS_NAME, "endCheckTimeOut", "endCheckTimeOut");
        }
    }

    public void killRunningService(String packageName, String fullClassName) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "killRunningService", " packageName:" + packageName + " ,fullClassName:" + fullClassName);
        ComponentName mComponentName = new ComponentName(packageName, fullClassName);
        Intent i = new Intent();
        i.setComponent(mComponentName);
        Boolean result = Boolean.valueOf(this.mContext.stopService(i));
        String str2 = this.CLASS_NAME;
        FtUtil.log_d(str2, "killRunningService", " kill result:" + result);
    }

    public void checkContamination() {
        FtUtil.log_d(this.CLASS_NAME, "checkContamination", "checkContamination");
        setTestType(TestType.CONTAMINATION);
        enableListeners();
        mFingerprint.setEventListener(this.mFingerPrintEventListener);
        mFingerprint.runQFSTest(1030);
    }

    public void runBGEcal() {
        String bgeData_path = Support.Kernel.getFilePath(Support.Kernel.ULTRASONIC_BGE_CAL_RESULT_PATH);
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "runBGEcal", " path:" + bgeData_path);
        setTestType(TestType.BGECAL);
        enableListeners();
        mFingerprint.setEventListener(this.mFingerPrintEventListener);
        mFingerprint.runBGECalibration(bgeData_path);
    }

    public boolean checkBGE() {
        boolean result = mFingerprint.checkBGE();
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "checkBGE", " result" + String.valueOf(result));
        return result;
    }

    public boolean delBGE() {
        boolean isExistFile = false;
        if ("QBT2000".equals(this.mChipName)) {
            if (Support.Kernel.isExistFile(Support.Kernel.ULTRASONIC_BGE_CAL_RESULT_FILE_1) || Support.Kernel.isExistFile(Support.Kernel.ULTRASONIC_BGE_CAL_RESULT_FILE_2) || Support.Kernel.isExistFile(Support.Kernel.ULTRASONIC_BGE_CAL_RESULT_FILE_3)) {
                isExistFile = true;
            }
        } else if (Support.Kernel.isExistFile(Support.Kernel.ULTRASONIC_BGE_CAL_RESULT_FILE_1)) {
            isExistFile = true;
        }
        if (isExistFile) {
            String bgeData_path = Support.Kernel.getFilePath(Support.Kernel.ULTRASONIC_BGE_CAL_RESULT_PATH);
            boolean result = mFingerprint.delBGE(bgeData_path);
            String str = this.CLASS_NAME;
            FtUtil.log_d(str, "delBGE", " path:" + bgeData_path + " delete result:" + result);
            return result;
        }
        FtUtil.log_d(this.CLASS_NAME, "delBGE", " bge data not exist");
        return true;
    }

    public boolean saveSensorID() {
        boolean result = false;
        String sensorID = getSensorInfoValue(getRawSensorInfo(), "Sensor ID");
        if (!sensorID.equals("N/A")) {
            result = Support.Kernel.writeNsync(Support.Kernel.ULTRASONIC_SENSOR_ID_SAVE_PATH, sensorID);
        }
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "saveSensorIDinEFS", " result:" + result);
        return result;
    }

    public String readSavedSensorID() {
        String savedSensorID = Support.Kernel.read(Support.Kernel.ULTRASONIC_SENSOR_ID_SAVE_PATH);
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "readSavedSensorID", " savedSensorID:" + savedSensorID);
        if (savedSensorID == null) {
            return "NONE";
        }
        return savedSensorID;
    }

    public boolean deleteSavedSensorID() {
        if (new File(Support.Kernel.getFilePath(Support.Kernel.ULTRASONIC_SENSOR_ID_SAVE_PATH)).exists()) {
            boolean result = Support.Kernel.deleteFile(Support.Kernel.ULTRASONIC_SENSOR_ID_SAVE_PATH);
            String str = this.CLASS_NAME;
            FtUtil.log_d(str, "deleteSavedSensorID", " result:" + result);
            return result;
        }
        FtUtil.log_d(this.CLASS_NAME, "deleteSavedSensorID", " sensorID File not exist");
        return true;
    }

    private boolean copyFile(String src, String dst) {
        boolean res = false;
        FileInputStream in = null;
        FileOutputStream out = null;
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "copyFile", " sourcePath:" + src + " targetPath:" + dst);
        if (src == null || dst == null) {
            FtUtil.log_e(this.CLASS_NAME, "copyFile", " copy fil path wrong");
        } else {
            File dstDirectoryPath = new File(dst).getParentFile();
            if (dstDirectoryPath == null) {
                FtUtil.log_e(this.CLASS_NAME, "copyFile", " dst directory path is null, return false");
                return false;
            }
            if (!dstDirectoryPath.exists()) {
                dstDirectoryPath.mkdirs();
                FtUtil.log_d(this.CLASS_NAME, "copyFile", " dst directory not exist -> exist");
            }
            try {
                FileInputStream in2 = new FileInputStream(src);
                FileOutputStream out2 = new FileOutputStream(dst);
                byte[] buf = new byte[8192];
                while (true) {
                    int data = in2.read(buf);
                    if (data <= 0) {
                        break;
                    }
                    out2.write(buf, 0, data);
                }
                FtUtil.log_d(this.CLASS_NAME, "copyFile", " copy file success");
                res = true;
                try {
                    in2.close();
                    out2.flush();
                    out2.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            } catch (IOException e2) {
                e2.printStackTrace();
                FtUtil.log_e(this.CLASS_NAME, "copyFile", " copy file fail");
                if (0 != 0) {
                    in.close();
                }
                if (0 != 0) {
                    out.flush();
                    out.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        in.close();
                    } catch (IOException e3) {
                        e3.printStackTrace();
                        throw th;
                    }
                }
                if (0 != 0) {
                    out.flush();
                    out.close();
                }
                throw th;
            }
        }
        return res;
    }

    public void setCalResultIntoSharedPreferences(String result) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setCalResultIntoSharedPreferences", "result:" + result);
        SharedPreferences.Editor sharedPreferencesEditor = this.mContext.getSharedPreferences("BGE_CALIBRATION_RESULT", 0).edit();
        sharedPreferencesEditor.putString("TestResult", result);
        sharedPreferencesEditor.apply();
    }

    public String getCalResultIntoSharedPreferences() {
        String result = this.mContext.getSharedPreferences("BGE_CALIBRATION_RESULT", 0).getString("TestResult", Status.NOTEST.name());
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setCalResultIntoSharedPreferences", "result:" + result);
        return result;
    }

    public void setWacomChargingMode(boolean isOn) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setWacomChargingMode", "isOn: " + isOn);
        if (isOn) {
            Support.Kernel.write(Support.Kernel.EPEN_BLE_CHARGING_MODE, EgisFingerprint.MAJOR_VERSION);
            return;
        }
        Support.Kernel.write(Support.Kernel.EPEN_BLE_CHARGING_MODE, "0");
        FtUtil.Sleep.sleep(100);
    }

    public String getScanResultFilePath(TestType testType2) {
        String path = null;
        switch (AnonymousClass2.$SwitchMap$com$sec$factory$common$CommonFingerprintQcom$TestType[testType2.ordinal()]) {
            case 1:
                path = Support.Kernel.getFilePath(Support.Kernel.ULTRASONIC_FP_BGECAL_RESULT);
                break;
            case 2:
                path = Support.Kernel.getFilePath(Support.Kernel.ULTRASONIC_FP_NRSC_RESULT);
                break;
            case 3:
                path = Support.Kernel.getFilePath(Support.Kernel.ULTRASONIC_FP_SNR_RESULT);
                break;
        }
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "getScanResultFilePath", " path:" + path);
        return path;
    }

    public String getValueAllfromScanData(List<ScanData> scanDataList) {
        FtUtil.log_d(this.CLASS_NAME, "getValueAllfromScanData", "Test Item Total Cnt:" + scanDataList.size());
        String data = "";
        for (ScanData scanData : scanDataList) {
            data = scanData != null ? data + scanData.getValue() + "," : data + "NA,";
        }
        if (data.length() > 0) {
            data = data.substring(0, data.length() - 1);
        }
        FtUtil.log_d(this.CLASS_NAME, "getValueAllfromScanData", "data:" + data);
        return data;
    }

    public boolean getFinalResultfromScanData(List<ScanData> scanDataList) {
        boolean result;
        if (scanDataList == null) {
            FtUtil.log_d(this.CLASS_NAME, "getFinalResultfromScanData", "scanDataList is null");
            return false;
        }
        int passCnt = 0;
        int failCnt = 0;
        FtUtil.log_d(this.CLASS_NAME, "getFinalResultfromScanData", "Test Item Total Cnt:" + scanDataList.size());
        for (ScanData scanData : scanDataList) {
            if (scanData == null) {
                failCnt++;
                FtUtil.log_e(this.CLASS_NAME, "getFinalResultfromScanData", "FAIL, scandata is null");
            } else if (scanData.getResult() == Status.PASS || scanData.getResult() == null || scanData.getResult() == Status.NOTEST) {
                passCnt++;
            } else {
                failCnt++;
                String specStr = scanData.getSpecMin() + " ~ " + scanData.getSpecMax();
                if (specStr.contains(Support.Properties.PROPERTIES_DEFAULT_STRING)) {
                    specStr = "-";
                }
                FtUtil.log_e(this.CLASS_NAME, "getFinalResultfromScanData", this.UTOPIA_TAG + "FAIL - ItemName: " + scanData.getName() + " ,Value: " + scanData.getValue() + " ,Spec: " + specStr);
            }
        }
        if (passCnt == scanDataList.size() || failCnt == 0) {
            result = true;
        } else {
            result = false;
        }
        FtUtil.log_d(this.CLASS_NAME, "getFinalResultfromScanData", "Result:" + result + " ,Total Item Cnt:" + scanDataList.size() + " ,Pass Cnt:" + passCnt + " ,Fail Cnt:" + failCnt);
        return result;
    }

    public void startNormalScan() {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "startNormalScan", " mTzEnabled:" + this.mTzEnabled);
        setTestType(TestType.NORMALSCAN);
        if (this.mTzEnabled) {
            FingerprintManager.SemRequestCallback normalScanEventListener_TZ = new NormalScanEventListener_TZ();
            this.mNormalScanEventListener_TZ = normalScanEventListener_TZ;
            this.mFingerprintManager.semRunSensorTest(0, 0, normalScanEventListener_TZ);
            return;
        }
        enableListeners();
        mFingerprint.startNormalScan(getScanListener());
    }

    public void startSNRPrepare() {
        FtUtil.log_d(this.CLASS_NAME, "startSNRPrepare", "startSNRPrepare");
        setTestType(TestType.SNRSCAN);
        enableListeners();
        mFingerprint.startSNRPrepare(getScanListener());
    }

    public void startSNR() {
        FtUtil.log_d(this.CLASS_NAME, "startSNR", "startSNR");
        mFingerprint.startSNR();
    }

    public boolean copySnrImg() {
        File snrImgFile = new File(Support.Kernel.getFilePath(Support.Kernel.ULTRASONIC_FP_SNR_IMAGE));
        File snrImgFile_copy = new File(Support.Kernel.getFilePath(Support.Kernel.ULTRASONIC_FP_SNR_IMAGE_COPY_PATH));
        String time = getTimeToString();
        if (!snrImgFile.exists()) {
            return false;
        }
        String path = snrImgFile.getPath();
        if (copyFile(path, snrImgFile_copy.getPath() + "/SNR_Fail_Image_" + time + ".png")) {
            return true;
        }
        return false;
    }

    private String getTimeToString() {
        Calendar cal = Calendar.getInstance();
        DecimalFormat df = new DecimalFormat("00", DecimalFormatSymbols.getInstance(Locale.US));
        String rtnData = cal.get(1) + df.format((long) (cal.get(2) + 1)) + df.format((long) cal.get(5)) + df.format((long) cal.get(11)) + df.format((long) cal.get(12));
        FtUtil.log_d(this.CLASS_NAME, "getTimeToString", " rtnData:" + rtnData);
        return rtnData;
    }

    public void endFpManger() {
        if (!this.mTzEnabled && mFingerprint != null) {
            FtUtil.log_d(this.CLASS_NAME, "endFpManger", "cancelTest() called");
            mFingerprint.cancelTest();
        }
    }

    private BufferedReader getBufferedReader(TestType testType2) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "getBufferedReader", " testType:" + testType2.name() + " mTzEnabled:" + this.mTzEnabled);
        if (this.mTzEnabled) {
            byte[] result = getNormalScanResult_TZ();
            if (result != null) {
                return new BufferedReader(new InputStreamReader(new ByteArrayInputStream(result)));
            }
            return null;
        }
        String path = getScanResultFilePath(testType2);
        try {
            return new BufferedReader(new InputStreamReader(new FileInputStream(path)));
        } catch (FileNotFoundException e) {
            String str2 = this.CLASS_NAME;
            FtUtil.log_e(str2, "getBufferedReader", " path:" + path + " FAIL - Scan Result File Not Exist");
            return null;
        }
    }

    public List<ScanData> getScanDataList(TestType testType2) {
        if ("QBT2000".equals(this.mChipName)) {
            return getScanDataList_qbt(testType2);
        }
        return getScanDataList_qfs(testType2);
    }

    public List<ScanData> getScanDataList_qbt(TestType testType2) {
        FtUtil.log_d(this.CLASS_NAME, "getScanDataList_qbt", "Read start");
        List<ScanData> scanDataList = new ArrayList<>();
        if (testType2 == TestType.NORMALSCAN) {
            FtUtil.log_d(this.CLASS_NAME, "getScanDataList_qbt", "set COMP_TEMP_REAL data manually");
            ScanData scanData = new ScanData();
            scanData.setName("COMP_TEMP");
            String value = Support.Kernel.read(Support.Kernel.ULTRASONIC_COMP_TEMP_REAL);
            if (value != null) {
                scanData.setValue(value.trim());
            }
            scanData.setSpecMin(Support.Properties.PROPERTIES_DEFAULT_STRING);
            scanData.setSpecMax(Support.Properties.PROPERTIES_DEFAULT_STRING);
            scanData.decideResult();
            scanDataList.add(scanData);
        }
        BufferedReader bufferedReader = getBufferedReader(testType2);
        if (bufferedReader != null) {
            while (true) {
                try {
                    String readStr = bufferedReader.readLine();
                    if (readStr != null) {
                        String str = this.CLASS_NAME;
                        FtUtil.log_d(str, "getScanDataList_qbt", "File line read: " + readStr);
                        if (readStr.matches("[a-zA-Z0-9](.*)")) {
                            if (!readStr.contains("Date:")) {
                                ScanData scanData2 = new ScanData();
                                String[] splitStr = readStr.split(";");
                                scanData2.setName(splitStr[0].trim());
                                scanData2.setSpecMin(splitStr[1].trim());
                                scanData2.setSpecMax(splitStr[2].trim());
                                scanData2.setValue(splitStr[3].trim());
                                scanData2.decideResult();
                                scanDataList.add(scanData2);
                            }
                        }
                        FtUtil.log_d(this.CLASS_NAME, "getScanDataList_qbt", "dummy data skip");
                    } else {
                        try {
                            break;
                        } catch (IOException e) {
                            e.printStackTrace();
                        }
                    }
                } catch (IOException e2) {
                    FtUtil.log_e(this.CLASS_NAME, "getScanDataList_qbt", " FAIL - bufferedReader.readLine()");
                    e2.printStackTrace();
                    bufferedReader.close();
                } catch (Throwable th) {
                    try {
                        bufferedReader.close();
                    } catch (IOException e3) {
                        e3.printStackTrace();
                    }
                    throw th;
                }
            }
            bufferedReader.close();
            String str2 = this.CLASS_NAME;
            FtUtil.log_d(str2, "getScanDataList_qbt", "scanDataList Size: " + scanDataList.size());
            return scanDataList;
        }
        FtUtil.log_e(this.CLASS_NAME, "getScanDataList_qbt", "bufferedReader is null");
        return null;
    }

    public List<ScanData> getScanDataList_qfs(TestType testType2) {
        FtUtil.log_d(this.CLASS_NAME, "getScanDataList_qfs", "Read start");
        List<ScanData> scanDataList = new ArrayList<>();
        if (testType2 == TestType.NORMALSCAN) {
            FtUtil.log_d(this.CLASS_NAME, "getScanDataList_qfs", "set COMP_TEMP_REAL data manually");
            ScanData scanData = new ScanData();
            scanData.setName("COMP_TEMP");
            String value = Support.Kernel.read(Support.Kernel.ULTRASONIC_COMP_TEMP_REAL);
            if (value != null) {
                scanData.setValue(value.trim());
            }
            scanData.setSpecMin(Support.Properties.PROPERTIES_DEFAULT_STRING);
            scanData.setSpecMax(Support.Properties.PROPERTIES_DEFAULT_STRING);
            scanData.decideResult();
            scanDataList.add(scanData);
        }
        BufferedReader bufferedReader = getBufferedReader(testType2);
        if (bufferedReader != null) {
            while (true) {
                try {
                    String readStr = bufferedReader.readLine();
                    if (readStr != null) {
                        String str = this.CLASS_NAME;
                        FtUtil.log_d(str, "getScanDataList_qfs", "File line read: " + readStr);
                        if (readStr.matches("[a-zA-Z0-9](.*)")) {
                            if (!readStr.contains("Date:")) {
                                ScanData scanData2 = new ScanData();
                                String[] splitStr = readStr.split(";");
                                scanData2.setName(splitStr[0].trim());
                                scanData2.setSpecMin(splitStr[1].trim());
                                scanData2.setSpecMax(splitStr[2].trim());
                                scanData2.setValue(splitStr[3].trim());
                                scanData2.decideResult();
                                scanDataList.add(scanData2);
                            }
                        }
                        FtUtil.log_d(this.CLASS_NAME, "getScanDataList_qfs", "dummy data skip");
                    } else {
                        try {
                            break;
                        } catch (IOException e) {
                            e.printStackTrace();
                        }
                    }
                } catch (IOException e2) {
                    FtUtil.log_e(this.CLASS_NAME, "getScanDataList_qfs", " FAIL - bufferedReader.readLine()");
                    e2.printStackTrace();
                    bufferedReader.close();
                } catch (Throwable th) {
                    try {
                        bufferedReader.close();
                    } catch (IOException e3) {
                        e3.printStackTrace();
                    }
                    throw th;
                }
            }
            bufferedReader.close();
            String str2 = this.CLASS_NAME;
            FtUtil.log_d(str2, "getScanDataList_qfs", "scanDataList Size: " + scanDataList.size());
            return scanDataList;
        }
        FtUtil.log_e(this.CLASS_NAME, "getScanDataList_qfs", "bufferedReader is null");
        return null;
    }

    public class ScanData {
        private String mCategory;
        private String mName;
        private Status mResult = Status.FAIL;
        private String mSpecMax;
        private String mSpecMin;
        private String mValue;

        public ScanData() {
        }

        public void decideResult() {
            if (this.mSpecMin.equalsIgnoreCase("NA") || (this.mSpecMin.equalsIgnoreCase(Support.Properties.PROPERTIES_DEFAULT_STRING) && this.mSpecMax.equalsIgnoreCase(Support.Properties.PROPERTIES_DEFAULT_STRING))) {
                setResult(Status.PASS);
                return;
            }
            try {
                float value = Float.parseFloat(this.mValue);
                float min = Float.parseFloat(this.mSpecMin);
                float max = Float.parseFloat(this.mSpecMax);
                if (value < min || value > max) {
                    setResult(Status.FAIL);
                } else {
                    setResult(Status.PASS);
                }
            } catch (NumberFormatException e) {
                String str = CommonFingerprintQcom.this.CLASS_NAME;
                FtUtil.log_e(str, "decideResult", " parsing fail - mName:" + this.mName + " mValue:" + this.mValue + " mSpecMin:" + this.mSpecMin + " mSpecMax:" + this.mSpecMax);
                setResult(Status.ERROR);
            }
        }

        public void setCategory(String mCategory2) {
            this.mCategory = mCategory2;
        }

        public void setName(String mName2) {
            this.mName = mName2;
        }

        public void setSpecMin(String mSpecMin2) {
            this.mSpecMin = mSpecMin2;
        }

        public void setSpecMax(String mSpecMax2) {
            this.mSpecMax = mSpecMax2;
        }

        public void setValue(String mValue2) {
            this.mValue = mValue2;
        }

        public void setResult(Status mResult2) {
            this.mResult = mResult2;
        }

        public String getCategory() {
            return this.mCategory;
        }

        public String getName() {
            return this.mName;
        }

        public String getSpecMin() {
            return this.mSpecMin;
        }

        public String getSpecMax() {
            return this.mSpecMax;
        }

        public String getValue() {
            return this.mValue;
        }

        public Status getResult() {
            return this.mResult;
        }
    }

    public void startInt1() {
        FtUtil.log_d(this.CLASS_NAME, "startInt1", "startInt1");
        setTestType(TestType.INT1);
        enableListeners();
        mFingerprint.setEventListener(this.mFingerPrintEventListener);
        mFingerprint.runQFSTest(1010);
    }

    private int setActiveStorage(String testID) {
        String path = Support.Kernel.getFilePath(Support.Kernel.ULTRASONIC_INT_CHECK_PATH);
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setActiveStorage", " ID:" + testID + " path:" + path);
        int result = mFingerprint.setActiveStorage(testID, path);
        if (result == 0) {
            FtUtil.log_d(this.CLASS_NAME, "setActiveStorage", " setActiveStorage result: OK");
        } else {
            FtUtil.log_d(this.CLASS_NAME, "setActiveStorage", " setActiveStorage result: FAIL");
        }
        return result;
    }

    public boolean startInt2() {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "startInt2", " ID:" + "test");
        setTestType(TestType.INT2);
        enableListeners();
        mFingerprint.setEventListener(this.mFingerPrintEventListener);
        if (setActiveStorage("test") == 0 && mFingerprint.authenticate("test") == 0) {
            FtUtil.log_d(this.CLASS_NAME, "startInt2", " result: OK");
            return true;
        }
        FtUtil.log_d(this.CLASS_NAME, "startInt2", " result: FAIL");
        return false;
    }

    public boolean setWuhbMode() {
        boolean result = Support.Kernel.write(Support.Kernel.ULTRASONIC_WUHB_INT_CMD, "wuhb");
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "setWuhbMode", " result:" + result);
        return result;
    }

    public boolean getWuhbResult() {
        String result = Support.Kernel.read(Support.Kernel.ULTRASONIC_WUHB_INT_RESULT);
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "getWuhbResult", " result:" + result);
        if (EgisFingerprint.MAJOR_VERSION.equals(result)) {
            return true;
        }
        return false;
    }

    public boolean controlTspInt(boolean isOn) {
        String cmd;
        if (isOn) {
            cmd = "fp_int_control,1";
        } else {
            cmd = "fp_int_control,0";
        }
        FtUtil.Sleep.sleep(100);
        Support.Kernel.write(Support.Kernel.TSP_COMMAND_CMD, cmd);
        String result = Support.Kernel.read(Support.Kernel.TSP_COMMAND_RESULT);
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "controlTspInt", " cmd:" + cmd + " result:" + result);
        if (result == null) {
            FtUtil.log_d(this.CLASS_NAME, "controlTspInt", "tsp cmd result value is null");
            return false;
        } else if (result.contains("OK")) {
            return true;
        } else {
            return false;
        }
    }

    public void cancelIntCheckOpeation() {
        QFSManager qFSManager = mFingerprint;
        if (qFSManager == null) {
            return;
        }
        if (qFSManager.cancel() == 0) {
            FtUtil.log_d(this.CLASS_NAME, "cancelIntCheckOpeation", " result: OK");
        } else {
            FtUtil.log_e(this.CLASS_NAME, "cancelIntCheckOpeation", " result: FAIL");
        }
    }

    public String getVendorName() {
        String vendorName = Support.Kernel.read(Support.Kernel.FINGERPRINT_VENDOR);
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "getVendorName", " vendorName:" + vendorName);
        return vendorName;
    }

    public String getChipName() {
        String chipName = Support.Kernel.read(Support.Kernel.FINGERPRINT_CHIP_NAME);
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "getChipName", " chipName:" + chipName);
        return chipName;
    }

    public int getChipTypeIndex() {
        String chipName = Support.Kernel.read(Support.Kernel.FINGERPRINT_CHIP_NAME);
        char c = 65535;
        if (chipName == null) {
            return -1;
        }
        int chipIndex = -1;
        switch (chipName.hashCode()) {
            case 841991073:
                if (chipName.equals("QBT2000")) {
                    c = 0;
                    break;
                }
                break;
            case 841996847:
                if (chipName.equals("QBT2608")) {
                    c = 1;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                chipIndex = 9;
                break;
            case 1:
                chipIndex = 21;
                break;
        }
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "getChipTypeIndex", "chipIndex:" + chipIndex);
        return chipIndex;
    }

    public String getVersion() {
        String versionStr = mFingerprint.getVersion();
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "getVersion", " version:" + versionStr);
        if (versionStr == null) {
            return "";
        }
        return versionStr;
    }

    public String getFpVersion() {
        String fpVersionStr = mFingerprint.getFpVersion();
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "getFpVersion", " fpVersionStr:" + fpVersionStr);
        if (fpVersionStr == null) {
            return "";
        }
        return fpVersionStr;
    }

    public String getRawSensorInfo() {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "getRawSensorInfo", " mTzEnabled: " + this.mTzEnabled);
        String sensorInfoAll = null;
        if (this.mTzEnabled) {
            sensorInfoAll = this.mFingerprintManager.semGetSensorInfo();
        } else if (mFingerprint.getSensorStatus() == 3001) {
            sensorInfoAll = mFingerprint.getSensorInfo();
        } else {
            FtUtil.log_e(this.CLASS_NAME, "getRawSensorInfo", " Fail - SensorStatus is Not SENSOR_OK");
        }
        String str2 = this.CLASS_NAME;
        FtUtil.log_d(str2, "getRawSensorInfo", " sensorInfoAll: " + sensorInfoAll);
        return sensorInfoAll;
    }

    public String getSensorInfoValue(String rawSensorInfo, String sensorName) {
        FtUtil.log_d(this.CLASS_NAME, "getSensorInfoValue", " objectSensorName:" + sensorName);
        if (rawSensorInfo == null) {
            FtUtil.log_d(this.CLASS_NAME, "getSensorInfoValue", " Fail - rawSensorInfo: N/A");
            return "N/A";
        }
        String[] infoArray = rawSensorInfo.split("\n");
        for (String info : infoArray) {
            if (info.contains(sensorName)) {
                String[] infoArray2 = info.split(":");
                if (infoArray2.length >= 2) {
                    return infoArray2[1].trim();
                }
            }
        }
        FtUtil.log_d(this.CLASS_NAME, "getSensorInfoValue", " Fail - name:" + sensorName + " value: N/A");
        return "N/A";
    }

    public boolean hasUserIdList() {
        String[] userIdArr = this.mFingerprintManager.semGetUserIdList();
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "hasUserIdList", " userIdArr:" + Arrays.toString(userIdArr));
        if (userIdArr == null || userIdArr.length == 0) {
            return false;
        }
        return true;
    }

    public class ScanItemList {
        private final String[] fingerprint_qcom_normal_scan_item_list_read = {"History Check", "BGE Cal Check", "Offset OTP", "Offset CNT", "Calibrated Temp", "Comp Temp", "Tuned Dbias Voltage", "Mean Gray Scale Level", "Max Gray Scale Level", "Min Gray Scale Level", "Tuned Dbias OTP", "dm_dp_bg_total", "dm_max_bg_defS", "dm_dp_cir", "dm_dp_bg_density", "dm_dp_bg_hlo", "dm_dp_bg_vlo", "L_pct_d", "M_gmag_max"};
        private final String[] fingerprint_qcom_normal_scan_item_list_read_user_bin = {"History Check", "BGE Cal Check", "Offset OTP", "Offset CNT", "Calibrated Temp", "Comp Temp", "Tuned Dbias Voltage", "Mean Gray Scale Level", "Max Gray Scale Level", "Min Gray Scale Level", "Tuned Dbias OTP"};
        private final String[] fingerprint_qcom_normal_scan_item_list_shown = {"HISTORY_CHECK", "BGE_CAL_CHECK", "OFFSET_OTP", "OFFSET_CNT", "CALIBRATED_TEMP", "COMP_TEMP", "TUNED_DBIAS_VOLTAGE", "MEAN_GRAY_SCALE_LEVEL", "MAX_GRAY_SCALE_LEVEL", "MIN_GRAY_SCALE_LEVEL", "TUNED_DBIAS_OTP", "BG_DEFECTPIXEL_TOTAL", "BG_MAX_DEFECT_SIZE", "BG_DEFECT_CIR", "BG_DEFECT_DENSITY", "BG_DEFECT_HLO", "BG_DEFECT_VLO", "UNIFORMITY", "M_MAX_GRADIENT"};
        private final String[] fingerprint_qcom_normal_scan_item_list_shown_user_bin = {"HISTORY_CHECK", "BGE_CAL_CHECK", "OFFSET_OTP", "OFFSET_CNT", "CALIBRATED_TEMP", "COMP_TEMP", "TUNED_DBIAS_VOLTAGE", "MEAN_GRAY_SCALE_LEVEL", "MAX_GRAY_SCALE_LEVEL", "MIN_GRAY_SCALE_LEVEL", "TUNED_DBIAS_OTP"};
        private final String[] fingerprint_qcom_snr_scan_item_list_read = {"Signal", "Noise", "SNR", "Target Coverage", "RT", "OTP Freq", "OTP RGD", "Bare Sensor SNR", "Cover Glass SNR", "Sensor ID", "QTest version", "Sequence File version", "dm_dp_tgt_total", "dm_max_tgt_defS", "dm_dp_tgt_hlo", "dm_dp_tgt_vlo"};
        private final String[] fingerprint_qcom_snr_scan_item_list_shown = {"SIGNAL", "NOISE", "SNR", "TARGET_COVERAGE", "RT", "OTP_FREQ", "OTP_RGD", "BARE_SENSOR_SNR", "UD_SNR", "SENSOR_ID", "QTEST_VERSION", "SEQUENCE_FILE_VERSION", "TARGET_DEFECT_TOTAL", "TARGET_MAX_DEFECT_SIZE", "TARGET_DEFECT_HLO", "TARGET_DEFECT_VLO"};

        public ScanItemList() {
        }

        public List<String> getScanItemList(TestType testType, boolean isForRead) {
            List<String> scanItemList = null;
            switch (testType) {
                case NORMALSCAN:
                    if (!CommonFingerprintQcom.this.mTzEnabled) {
                        if (!isForRead) {
                            scanItemList = new ArrayList<>(Arrays.asList(this.fingerprint_qcom_normal_scan_item_list_shown));
                            break;
                        } else {
                            scanItemList = new ArrayList<>(Arrays.asList(this.fingerprint_qcom_normal_scan_item_list_read));
                            break;
                        }
                    } else if (!isForRead) {
                        scanItemList = new ArrayList<>(Arrays.asList(this.fingerprint_qcom_normal_scan_item_list_shown_user_bin));
                        break;
                    } else {
                        scanItemList = new ArrayList<>(Arrays.asList(this.fingerprint_qcom_normal_scan_item_list_read_user_bin));
                        break;
                    }
                case SNRSCAN:
                    if (!isForRead) {
                        scanItemList = new ArrayList<>(Arrays.asList(this.fingerprint_qcom_snr_scan_item_list_shown));
                        break;
                    } else {
                        scanItemList = new ArrayList<>(Arrays.asList(this.fingerprint_qcom_snr_scan_item_list_read));
                        break;
                    }
            }
            String str = CommonFingerprintQcom.this.CLASS_NAME;
            FtUtil.log_d(str, "getScanItemList", " mTzEnabled:" + CommonFingerprintQcom.this.mTzEnabled + " testType:" + testType.name() + "isForRead:" + isForRead);
            return scanItemList;
        }
    }
}
