package com.sec.factory.entry;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.SystemProperties;
import android.os.UEventObserver;
import android.widget.Toast;
import com.sec.factory.app.service.AbcPopup;
import com.sec.factory.app.service.CablePopup;
import com.sec.factory.modules.ModuleCommon;
import com.sec.factory.modules.ModuleCommunicationService;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.modules.ModuleNfc;
import com.sec.factory.modules.ModuleTouchScreen;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.NVAccessor;
import com.sec.xmldata.support.Support;
import com.sec.xmldata.support.XMLDataStorage;
import egis.client.api.EgisFingerprint;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.channels.FileChannel;

public class FactoryBinaryReceiver extends BroadcastReceiver {
    private static final String ACTION_NFC_AUTH_READY = "com.sec.android.nfc.AUTH_READY";
    private static final String ACTION_SET_COLOR_BALANCE_NV = "com.sec.android.app.factorykeystring.action.ACTION_SET_COLOR_BALANCE_NV";
    private static final String ACTION_SHOW_ABC_POPUP = "com.sec.factory.SHOW_ABC_POPUP";
    private static final String CLASS_NAME = "FactoryBinaryReceiver";
    private static boolean mCheckESIMstate = false;
    private Context mContext;
    private UEventObserver mUEventObserver = new UEventObserver() {
        /* class com.sec.factory.entry.FactoryBinaryReceiver.AnonymousClass1 */

        public void onUEvent(UEventObserver.UEvent event) {
            if (event.toString().indexOf("CONNECTOR_NAME") != -1) {
                String name = event.get("CONNECTOR_NAME");
                FtUtil.log_d(FactoryBinaryReceiver.CLASS_NAME, "onUEvent", "event name : " + name);
                String type = event.get("CONNECTOR_TYPE");
                if (type != null) {
                    FtUtil.log_d(FactoryBinaryReceiver.CLASS_NAME, "onUEvent", "event type : " + type);
                    if (type.equals("HIGH_LEVEL")) {
                        FactoryBinaryReceiver.this.openPopup(name);
                    } else if (!type.equals("LOW_LEVEL")) {
                        if (type.equals("EDGE_BOTH")) {
                            FactoryBinaryReceiver.this.openPopup(name);
                        } else if (type.equals("RISING_EDGE")) {
                            FactoryBinaryReceiver.this.openPopup(name);
                        }
                    }
                } else {
                    FtUtil.log_d(FactoryBinaryReceiver.CLASS_NAME, "onUEvent", "event type : null");
                }
            }
        }
    };

    public void onReceive(Context context, Intent intent) {
        String action = intent.getAction();
        FtUtil.log_d(CLASS_NAME, "onReceive", "onReceive action = " + action);
        this.mContext = context;
        if (!XMLDataStorage.instance().wasCompletedParsing() && !XMLDataStorage.instance().parseXML(context)) {
            FtUtil.log_i(CLASS_NAME, "onReceive", "XML data parsing was failed.");
        }
        if ("android.intent.action.BOOT_COMPLETED".equals(action)) {
            ModuleCommon.instance(context).startForegroundService();
            if (Support.Feature.getBoolean(Support.Feature.SUPPORT_CABLE_CONNECT_DETECT)) {
                initUEventObserver();
            }
            if (Support.Feature.getBoolean(Support.Feature.SUPPORT_SPEN_BLE_TEST, false)) {
                copytoSpenFW();
            }
            startSRSService(context);
            ModuleNfc.enableNfc(context);
            if (Support.Feature.getBoolean(Support.Feature.SUPPORT_HRM_CONCEPT_ONCE, false)) {
                checkHrmXtalkDataExists();
            }
            if ("fail".equalsIgnoreCase(Support.Properties.get(Support.Properties.ABC_RESULT))) {
                context.startService(new Intent(this.mContext, AbcPopup.class));
            }
        } else if (ACTION_NFC_AUTH_READY.equalsIgnoreCase(action)) {
            ModuleCommunicationService.isEnabledNFCService = true;
        } else if (ACTION_SET_COLOR_BALANCE_NV.equalsIgnoreCase(action)) {
            NVAccessor.setNV(236, (byte) 80);
        } else if ("android.intent.action.SIM_STATE_CHANGED".equals(action)) {
            int slot = intent.getIntExtra(ModuleTouchScreen.TSP_DEVICE_TYPE__PHONE, 0);
            int simSwitchSlot = ModuleDevice.instance(context).getSupportSimSwitch();
            String switchStat = SystemProperties.get("ril.simslottype" + simSwitchSlot, "0");
            FtUtil.log_d(CLASS_NAME, "onReceive", "sim slot - " + slot + " , ril.simslottype" + simSwitchSlot + " - " + switchStat + " , checkESIMstate - " + mCheckESIMstate);
            if (!mCheckESIMstate && slot == simSwitchSlot - 1) {
                if (EgisFingerprint.MAJOR_VERSION.equals(switchStat)) {
                    ModuleDevice.instance(context).setSimSwitchRSIM(simSwitchSlot);
                    Toast.makeText(context, "eSIM -> rSIM switching", 0).show();
                }
                mCheckESIMstate = true;
                FtUtil.log_d(CLASS_NAME, "onReceive", "finish switching eSIM check");
            }
        } else if ("com.sec.factory.rdm_model_info".equals(action)) {
            checkRdmModelInfoFile();
        } else if (ACTION_SHOW_ABC_POPUP.equalsIgnoreCase(action)) {
            context.startService(new Intent(this.mContext, AbcPopup.class));
        }
    }

    private void checkRdmModelInfoFile() {
        FtUtil.log_i(CLASS_NAME, "checkRdmModelInfoFile", "Start checkRdmModelInfoFile");
        boolean result = true;
        String[] modelinfo = {"MODEL : " + Support.Properties.get(Support.Properties.PRODUCT_NAME), "AP_VER : " + Support.Properties.get(Support.Properties.PDA_VERSION), "CP_VER : " + Support.Properties.get(Support.Properties.SW_VERSION), "UN : " + Support.Kernel.getUniqueNumber(), "PATH : log"};
        if (Support.Kernel.isExistFile(Support.Kernel.RDM_MODEL_INFO_PATH)) {
            String[] data = Support.Kernel.readNsyncContinuous(Support.Kernel.RDM_MODEL_INFO_PATH, true).split("\n");
            if (data.length == 5) {
                int i = 0;
                while (true) {
                    if (data.length <= i) {
                        break;
                    } else if (!modelinfo[i].equals(data[i])) {
                        result = false;
                        break;
                    } else {
                        i++;
                    }
                }
            } else {
                result = false;
            }
        } else {
            result = false;
        }
        if (!result) {
            createRdmModelInfoFile(modelinfo);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void openPopup(String module) {
        if ("UB_CONNECT".equals(module)) {
            int countOCTA = Integer.parseInt(Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_OCTA)) + 1;
            FtUtil.log_d(CLASS_NAME, "openPopup", "OCTA: " + countOCTA);
            Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_OCTA, String.valueOf(countOCTA));
        } else if ("CAM_CONNECT".equals(module)) {
            int countCAMERA = Integer.parseInt(Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_CAMERA)) + 1;
            FtUtil.log_d(CLASS_NAME, "openPopup", "Camera: " + countCAMERA);
            Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_CAMERA, String.valueOf(countCAMERA));
        } else if ("SUB_CONNECT".equals(module)) {
            int countSUBPBA = Integer.parseInt(Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_SUBPBA)) + 1;
            FtUtil.log_d(CLASS_NAME, "openPopup", "USB Interface PBA: " + countSUBPBA);
            Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_SUBPBA, String.valueOf(countSUBPBA));
        } else if ("TSP_CONNECT".equals(module)) {
            int countTSP = Integer.parseInt(Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_TSP)) + 1;
            FtUtil.log_d(CLASS_NAME, "openPopup", "TSP: " + countTSP);
            Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_TSP, String.valueOf(countTSP));
        } else if ("UPPER_C2C_DETECT".equals(module)) {
            int countUPPER_PBA = Integer.parseInt(Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_UPPERPBA)) + 1;
            FtUtil.log_d(CLASS_NAME, "openPopup", "Sub PBA 1: " + countUPPER_PBA);
            Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_UPPERPBA, String.valueOf(countUPPER_PBA));
        } else if ("LOWER_C2C_DETECT".equals(module)) {
            int countLOWER_PBA = Integer.parseInt(Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_LOWERPBA)) + 1;
            FtUtil.log_d(CLASS_NAME, "openPopup", "Sub PBA 2: " + countLOWER_PBA);
            Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_LOWERPBA, String.valueOf(countLOWER_PBA));
        } else if ("MAIN_BAT_DETECT".equals(module)) {
            int countMAINBATT = Integer.parseInt(Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_MAINBATT)) + 1;
            FtUtil.log_d(CLASS_NAME, "openPopup", "Battery 1: " + countMAINBATT);
            Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_MAINBATT, String.valueOf(countMAINBATT));
        } else if ("SUB_BAT_DETECT".equals(module)) {
            int countSUBBATT = Integer.parseInt(Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_SUBBATT)) + 1;
            FtUtil.log_d(CLASS_NAME, "openPopup", "Battery 2" + countSUBBATT);
            Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_SUBBATT, String.valueOf(countSUBBATT));
        } else if ("UB_CONNECT_SUB".equals(module)) {
            int countSUBUB = Integer.parseInt(Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_SUBUB)) + 1;
            FtUtil.log_d(CLASS_NAME, "openPopup", "Sub UB" + countSUBUB);
            Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_SUBUB, String.valueOf(countSUBUB));
        } else if ("TOF_CONNECT".equals(module)) {
            int countTOFCAM = Integer.parseInt(Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_TOFCAM)) + 1;
            FtUtil.log_d(CLASS_NAME, "openPopup", "ToF CAM" + countTOFCAM);
            Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_TOFCAM, String.valueOf(countTOFCAM));
        } else if ("MAIN_DIGITIZER_DETECT".equals(module)) {
            int countMainDigi = Integer.parseInt(Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_MAINDIGI)) + 1;
            FtUtil.log_d(CLASS_NAME, "openPopup", "Main Digitizer" + countMainDigi);
            Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_MAINDIGI, String.valueOf(countMainDigi));
        } else if ("SUB_LOWER_DETECT".equals(module)) {
            int countSubDigi = Integer.parseInt(Support.Kernel.read(Support.Kernel.CABLE_DETECT_COUNT_SUBDIGI)) + 1;
            FtUtil.log_d(CLASS_NAME, "openPopup", "Sub Digitizer" + countSubDigi);
            Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_SUBDIGI, String.valueOf(countSubDigi));
        }
        if (!ModuleCommon.instance(this.mContext).getTopPackageName().contains("com.sec.OneJigBinary") || !EgisFingerprint.MAJOR_VERSION.equals(Support.Kernel.read(Support.Kernel.CABLE_DETECT_POPUP))) {
            this.mContext.startService(new Intent(this.mContext, CablePopup.class));
        }
    }

    public void initUEventObserver() {
        FtUtil.log_d(CLASS_NAME, "initUEventObserver", "startObserving");
        String mAvailablePins = Support.Kernel.read(Support.Kernel.AVAILABLE_PIN_CHECK);
        String ubsupportdata = Support.Kernel.read(Support.Kernel.CABLE_DETECT_UB);
        if (ubsupportdata != null && !ModuleCommunicationService.SMD_NOK.equals(ubsupportdata)) {
            mAvailablePins = "UB_CONNECT/" + mAvailablePins;
        }
        String ubsupportdata2 = Support.Kernel.read(Support.Kernel.CABLE_DETECT_SUB_UB);
        if (ubsupportdata2 != null && !ModuleCommunicationService.SMD_NOK.equals(ubsupportdata2)) {
            mAvailablePins = mAvailablePins + "/UB_CONNECT_SUB";
        }
        FtUtil.log_d(CLASS_NAME, "initUEventObserver", "mAvailablePins : " + mAvailablePins);
        if (EgisFingerprint.MAJOR_VERSION.equals(Support.Kernel.read(Support.Kernel.CABLE_DETECT_POPUP))) {
            Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_POPUP, "0");
        }
        this.mUEventObserver.startObserving("CONNECTOR_NAME");
        if (mAvailablePins != null) {
            if (mAvailablePins.contains("UB_CONNECT") && !Support.Kernel.isExistFile(Support.Kernel.CABLE_DETECT_COUNT_OCTA)) {
                FtUtil.log_d(CLASS_NAME, "initUEventObserver", "OCTA Count File is not exist, make new file");
                Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_OCTA, "0");
            }
            if (mAvailablePins.contains("CAM_CONNECT") && !Support.Kernel.isExistFile(Support.Kernel.CABLE_DETECT_COUNT_CAMERA)) {
                FtUtil.log_d(CLASS_NAME, "initUEventObserver", "Camera Count File is not exist, make new file");
                Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_CAMERA, "0");
            }
            if (mAvailablePins.contains("SUB_CONNECT") && !Support.Kernel.isExistFile(Support.Kernel.CABLE_DETECT_COUNT_SUBPBA)) {
                FtUtil.log_d(CLASS_NAME, "initUEventObserver", "USB Interface PBA File is not exist, make new file");
                Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_SUBPBA, "0");
            }
            if (mAvailablePins.contains("TSP_CONNECT") && !Support.Kernel.isExistFile(Support.Kernel.CABLE_DETECT_COUNT_TSP)) {
                FtUtil.log_d(CLASS_NAME, "initUEventObserver", "TSP File is not exist, make new file");
                Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_TSP, "0");
            }
            if (mAvailablePins.contains("UPPER_C2C_DETECT") && !Support.Kernel.isExistFile(Support.Kernel.CABLE_DETECT_COUNT_UPPERPBA)) {
                FtUtil.log_d(CLASS_NAME, "initUEventObserver", "Sub PBA #1 File is not exist, make new file");
                Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_UPPERPBA, "0");
            }
            if (mAvailablePins.contains("LOWER_C2C_DETECT") && !Support.Kernel.isExistFile(Support.Kernel.CABLE_DETECT_COUNT_LOWERPBA)) {
                FtUtil.log_d(CLASS_NAME, "initUEventObserver", "Sub PBA #2 File is not exist, make new file");
                Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_LOWERPBA, "0");
            }
            if (mAvailablePins.contains("MAIN_BAT_DETECT") && !Support.Kernel.isExistFile(Support.Kernel.CABLE_DETECT_COUNT_MAINBATT)) {
                FtUtil.log_d(CLASS_NAME, "initUEventObserver", "Batt #1 File is not exist, make new file");
                Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_MAINBATT, "0");
            }
            if (mAvailablePins.contains("SUB_BAT_DETECT") && !Support.Kernel.isExistFile(Support.Kernel.CABLE_DETECT_COUNT_SUBBATT)) {
                FtUtil.log_d(CLASS_NAME, "initUEventObserver", "Batt #2 File is not exist, make new file");
                Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_SUBBATT, "0");
            }
            if (mAvailablePins.contains("UB_CONNECT_SUB") && !Support.Kernel.isExistFile(Support.Kernel.CABLE_DETECT_COUNT_SUBUB)) {
                FtUtil.log_d(CLASS_NAME, "initUEventObserver", "Sub UB File is not exist, make new file");
                Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_SUBUB, "0");
            }
            if (mAvailablePins.contains("TOF_CONNECT") && !Support.Kernel.isExistFile(Support.Kernel.CABLE_DETECT_COUNT_TOFCAM)) {
                FtUtil.log_d(CLASS_NAME, "initUEventObserver", "ToF CAM File is not exist, make new file");
                Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_TOFCAM, "0");
            }
            if (mAvailablePins.contains("MAIN_DIGITIZER_DETECT") && !Support.Kernel.isExistFile(Support.Kernel.CABLE_DETECT_COUNT_MAINDIGI)) {
                FtUtil.log_d(CLASS_NAME, "initUEventObserver", "Main Digitier File is not exist, make new file");
                Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_MAINDIGI, "0");
            }
            if (mAvailablePins.contains("SUB_LOWER_DETECT") && !Support.Kernel.isExistFile(Support.Kernel.CABLE_DETECT_COUNT_SUBDIGI)) {
                FtUtil.log_d(CLASS_NAME, "initUEventObserver", "Sub Digitier File is not exist, make new file");
                Support.Kernel.writeNsync(Support.Kernel.CABLE_DETECT_COUNT_SUBDIGI, "0");
            }
        }
    }

    private void copytoSpenFW() {
        if (!Support.Kernel.isExistFilePath("/data/suota-fmware/spen-fw.img")) {
            FtUtil.log_d(CLASS_NAME, "copytoSpenFW", "not exist source file");
        } else if (Support.Kernel.isExistFilePath("/sdcard/suota-fmware/spen-fw.img")) {
            FtUtil.log_d(CLASS_NAME, "copytoSpenFW", "exist target file");
        } else {
            new Thread(new Runnable() {
                /* class com.sec.factory.entry.FactoryBinaryReceiver.AnonymousClass2 */

                public void run() {
                    FileInputStream fin = null;
                    FileOutputStream fout = null;
                    FileChannel in = null;
                    FileChannel out = null;
                    try {
                        File Dir = new File("/sdcard/suota-fmware");
                        if (!Dir.exists()) {
                            Dir.mkdir();
                        }
                        FileInputStream fin2 = new FileInputStream(new File("/data/suota-fmware/spen-fw.img"));
                        FileOutputStream fout2 = new FileOutputStream(new File("/sdcard/suota-fmware/spen-fw.img"));
                        FileChannel in2 = fin2.getChannel();
                        FileChannel out2 = fout2.getChannel();
                        in2.transferTo(0, in2.size(), out2);
                        fout2.getFD().sync();
                        FtUtil.log_d(FactoryBinaryReceiver.CLASS_NAME, "copytoSpenFW", "success to file copy");
                        try {
                            fin2.close();
                            fout2.close();
                            if (in2 != null) {
                                in2.close();
                            }
                            if (out2 != null) {
                                out2.close();
                            }
                        } catch (IOException e) {
                            FtUtil.log_e(e);
                        }
                    } catch (IOException e2) {
                        FtUtil.log_e(e2);
                        if (0 != 0) {
                            fin.close();
                        }
                        if (0 != 0) {
                            fout.close();
                        }
                        if (0 != 0) {
                            in.close();
                        }
                        if (0 != 0) {
                            out.close();
                        }
                    } catch (Throwable th) {
                        if (0 != 0) {
                            try {
                                fin.close();
                            } catch (IOException e3) {
                                FtUtil.log_e(e3);
                                throw th;
                            }
                        }
                        if (0 != 0) {
                            fout.close();
                        }
                        if (0 != 0) {
                            in.close();
                        }
                        if (0 != 0) {
                            out.close();
                        }
                        throw th;
                    }
                }
            }).start();
        }
    }

    private boolean checkHrmXtalkDataExists() {
        if (!new File("data/log/hrmxtalkavg.log").exists()) {
            FtUtil.log_d(CLASS_NAME, "checkHrmXtalkDataExists()", "No HRM Xtalk data!");
            return false;
        }
        FtUtil.log_d(CLASS_NAME, "checkHrmXtalkDataExists()", "HRM Xtalk data exists!");
        return true;
    }

    private void startSRSService(Context context) {
        FtUtil.log_d(CLASS_NAME, "startSRSService", "");
        if (Support.Feature.getBoolean(Support.Feature.SUPPORT_SRS_START_AUTOMATICALLY)) {
            FtUtil.log_d(CLASS_NAME, "startSRSService", "start srs automatically!");
            Intent intent = new Intent("com.android.samsungtest.REQUEST_SCR_RECORD_TURN_ONOFF");
            intent.addFlags(16777216);
            intent.putExtra("TURN_ONOFF", true);
            intent.putExtra("NEED_RESPONSE", false);
            context.sendBroadcast(intent);
        }
    }

    public void createRdmModelInfoFile(String[] data) {
        FtUtil.log_i(CLASS_NAME, "createRdmModelInfoFile", "");
        Support.Kernel.writeNsync(Support.Kernel.RDM_MODEL_INFO_PATH, data[0] + "\n" + data[1] + "\n" + data[2] + "\n" + data[3] + "\n" + data[4] + "\n");
    }
}
