package com.sec.factory.entry;

import android.content.BroadcastReceiver;
import android.content.ContentResolver;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.FactoryTest;
import android.os.Handler;
import android.os.Message;
import android.os.SystemProperties;
import android.provider.Settings;
import android.widget.Toast;
import com.sec.factory.aporiented.FtClient;
import com.sec.factory.modules.ModuleCommon;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import com.sec.xmldata.support.XMLDataStorage;
import egis.client.api.EgisFingerprint;
import java.io.File;

public class FactoryTestBroadcastReceiver extends BroadcastReceiver {
    private static final String ACTION_EM_AT_ACTIVATION_REQUEST = "com.sec.atd.em_at_activation_request";
    private static final String ACTION_EM_AT_REQUEST_RECONNECT = "com.sec.atd.em_at_request_reconnect";
    private static final String ACTION_REQUEST_RECONNECT = "com.sec.atd.request_reconnect";
    private static final String ACTION_REQUEST_STOP_FT_CLIENT = "com.sec.factory.stop_ftclient";
    public static String FTCLIENT_USAGE_PREF = "ModemSettingForFTClient";
    private static final int MODE = 0;
    private static final byte MSG_CHECK_FAIL_CONNECTION_DIGITIZER = 1;
    private static final int SCREEN_OFF_TIME_OUT = 600000;
    private static final String TAG = "FactoryTestBroadcastReceiver";
    private final Handler handler = new Handler() {
        /* class com.sec.factory.entry.FactoryTestBroadcastReceiver.AnonymousClass1 */

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    Toast.makeText(FactoryTestBroadcastReceiver.this.mContext, "Connection Fail with Digitizer", 1000).show();
                    return;
                default:
                    return;
            }
        }
    };
    private Context mContext;

    public void onReceive(Context context, Intent intent) {
        this.mContext = context;
        String action = intent.getAction();
        FtUtil.log_d(TAG, "onReceive", "onReceive action=" + action);
        if ("android.intent.action.PRE_BOOT_COMPLETED".equals(action)) {
            processIntentPreBootCompleted(context);
        } else if ("android.intent.action.BOOT_COMPLETED".equals(action)) {
            processIntentBootCompleted(context);
        } else if (ACTION_REQUEST_RECONNECT.equals(action)) {
            processIntentRequestReconnect(context);
        } else if (FtClient.CSC_MODEM_SETTING.equals(action)) {
            processIntentCscModemSetting(context, context.getSharedPreferences(FTCLIENT_USAGE_PREF, 0).edit());
        } else if (ACTION_REQUEST_STOP_FT_CLIENT.equals(action)) {
            processIntentStopFtclient(context);
        } else if (ACTION_EM_AT_REQUEST_RECONNECT.equals(action) || ACTION_EM_AT_ACTIVATION_REQUEST.equals(action)) {
            processIntentEmAtConnect(context, action);
        }
        String result = Support.Kernel.read(Support.Kernel.BATT_FACTORY_MODE);
        FtUtil.log_d(TAG, "onReceive", "onReceive boot mode = " + result);
    }

    private void processIntentEmAtConnect(Context context, String action) {
        FtUtil.log_i(TAG, "processIntentEmAtConnect", action);
        context.stopService(new Intent(context, FtClient.class));
        if (!XMLDataStorage.instance().parseXML(context)) {
            FtUtil.log_d(TAG, "processIntentEmAtConnect", "ACTION_EM_AT_REQUEST_RECONNECT => XML data parsing was failed.");
        }
        if ("0".equals(Support.Kernel.read(Support.Kernel.UART_ON_OFF))) {
            FtUtil.log_i(TAG, "processIntentEmAtConnect", "Enable UART - EM Token AT command installed");
            Support.Kernel.write(Support.Kernel.UART_ON_OFF, EgisFingerprint.MAJOR_VERSION);
        }
        if ("Qualcomm".equals(Support.Feature.getString(Support.Feature.CHIPSET_MANUFACTURE)) && !"running".equals(SystemProperties.get("init.svc.sec_diag_uart_log", Support.Properties.PROPERTIES_DEFAULT_STRING))) {
            FtUtil.log_i(TAG, "processIntentEmAtConnect", "start sec_diag_uart_log");
            SystemProperties.set("ctl.start", "sec_diag_uart_log");
        }
        startFactoryTestClientServiceAPO(ACTION_EM_AT_ACTIVATION_REQUEST.equals(action));
    }

    private void processIntentStopFtclient(Context context) {
        if (!XMLDataStorage.instance().parseXML(context)) {
            FtUtil.log_d(TAG, "processIntentStopFtclient", "ACTION_REQUEST_RECONNECT => XML data parsing was failed.");
        }
        stopFactoryTestClientServiceAPO();
    }

    private void processIntentCscModemSetting(Context context, SharedPreferences.Editor editor) {
        FtUtil.log_i(TAG, "processIntentCscModemSetting", "get CSC_MODEM_SETTING in FactoryTestBroadcastReceiver");
        editor.putBoolean("hasReceivedCSCModemSetting", true);
        editor.apply();
        if (!XMLDataStorage.instance().parseXML(context)) {
            FtUtil.log_d(TAG, "processIntentCscModemSetting", "CSC_MODEM_SETTING_FACTORY => XML data parsing was failed.");
        }
        if (ModuleCommon.instance(context).isConnectionModeNone()) {
            FtUtil.log_i(TAG, "processIntentCscModemSetting", "send CSC_MODEM_SETTING_FACTORY intent");
            this.mContext.sendBroadcast(new Intent(FtClient.CSC_MODEM_SETTING_FACTORY));
        }
        FtUtil.showFirstLog(false);
    }

    private void processIntentRequestReconnect(Context context) {
        if (FtUtil.isFactoryBinary() || FactoryTest.isRunningFactoryApp()) {
            FtUtil.log_i(TAG, "processIntentRequestReconnect", ACTION_REQUEST_RECONNECT);
            context.stopService(new Intent(context, FtClient.class));
            if (!XMLDataStorage.instance().parseXML(context)) {
                FtUtil.log_d(TAG, "processIntentRequestReconnect", "ACTION_REQUEST_RECONNECT => XML data parsing was failed.");
            }
            startFactoryTestClientServiceAPO();
            return;
        }
        FtUtil.log_i(TAG, "processIntentRequestReconnect", "not reconnect ft client");
    }

    private void processIntentPreBootCompleted(Context context) {
        if (FtUtil.isFactoryBinary()) {
            String UsbStatus = Support.Kernel.read(Support.Kernel.USB_CONFIG_CHECK);
            FtUtil.log_d(TAG, "Usb Configuration Status", "UsbStatus = " + UsbStatus);
        } else {
            FtUtil.showFirstLog(true);
        }
        if (!XMLDataStorage.instance().parseXML(context)) {
            FtUtil.log_d(TAG, "processIntentPreBootCompleted", "ACTION_PRE_BOOT_COMPLETED => XML data parsing was failed.");
        }
        initFactoryAppFiles();
        initFailhist();
        if (FtUtil.isFactoryBinary()) {
            ModuleCommon.instance(context).startForegroundService();
        }
    }

    private void processIntentBootCompleted(Context context) {
        FtUtil.log_d(TAG, "processIntentBootCompleted", FtUtil.setMspSeqMessage(0, "BOOTING COMPLETED", "ING : received IntentBootCompleted -> waiting connect FtClient"));
        processIntentBootCompletedWhenAllBinary(context);
        if (FtUtil.isFactoryBinary()) {
            processIntentBootCompletedWhenFactoryBinary(context);
        } else {
            processIntentBootCompletedWhenUserBinary(context);
        }
    }

    private void processIntentBootCompletedWhenAllBinary(Context context) {
        if (!XMLDataStorage.instance().parseXML(context)) {
            FtUtil.log_d(TAG, "processIntentBootCompletedWhenAllBinary", "ACTION_BOOT_COMPLETED => XML data parsing was failed.");
        }
        initFactoryAppFiles();
        writeColorBalanceValue();
    }

    private void writeColorBalanceValue() {
        if (!Support.Kernel.isExistFilePath(Support.Kernel.getFilePath(Support.Kernel.COLOUR_BALANCE_EFS_VER)) && Support.Kernel.isExistFilePath(Support.Kernel.getFilePath(Support.Kernel.COLOUR_BALANCE_EFS))) {
            FtUtil.log_d(TAG, "writeColorBalanceValue", "COLOUR_BALANCE_EFS_VER update");
            String efsValue = Support.Kernel.read(Support.Kernel.COLOUR_BALANCE_EFS);
            if (efsValue != null) {
                int Offset = Integer.parseInt(efsValue.split(" ")[0]);
                if (Offset == -2) {
                    Offset = -3;
                } else if (Offset == -4) {
                    Offset = -6;
                }
                Support.Kernel.writeNsync(Support.Kernel.COLOUR_BALANCE_EFS, Offset + " 0 " + Offset);
                Support.Kernel.writeNsync(Support.Kernel.COLOUR_BALANCE_EFS_VER, EgisFingerprint.MAJOR_VERSION);
                return;
            }
            FtUtil.log_d(TAG, "writeColorBalanceValue", "COLOUR_BALANCE_EFS is null");
        }
    }

    private void processIntentBootCompletedWhenUserBinary(Context context) {
        FtUtil.log_d(TAG, "processIntentBootCompletedWhenUserBinary", "Boot completed, IS_FACTORY_BINARY = USER MODE");
        boolean USBconnected = isUSBConnected(context);
        if (ModuleCommon.instance(context).connectedJIG() || USBconnected) {
            startFactoryTestClientServiceAPO();
        } else {
            if (!ModuleCommon.instance(this.mContext).isRunningFtClient()) {
                startDummyFtClientForBootCompleted();
            }
            if (!USBconnected && Support.Properties.PROPERTIES_DEFAULT_STRING.equals(Support.Properties.getProp("sys.factory.facm_mode")) && SystemProperties.getInt("ro.product.first_api_level", 0) >= 28) {
                FtUtil.log_d(TAG, "processIntentBootCompletedWhenUserBinary", "Stop at_distributor");
                if ("running".equals(SystemProperties.get("init.svc.at_distributor", Support.Properties.PROPERTIES_DEFAULT_STRING))) {
                    FtUtil.log_d(TAG, "processIntentBootCompletedWhenUserBinary", "stop at_distributor");
                    SystemProperties.set("ctl.stop", "at_distributor");
                }
                if ("running".equals(SystemProperties.get("init.svc.sec_diag_uart_log", Support.Properties.PROPERTIES_DEFAULT_STRING))) {
                    FtUtil.log_d(TAG, "processIntentBootCompletedWhenUserBinary", "stop sec_diag_uart_log");
                    SystemProperties.set("ctl.stop", "sec_diag_uart_log");
                }
            }
        }
        ModuleCommon.instance(context).disableFtClient();
    }

    private void processIntentBootCompletedWhenFactoryBinary(Context context) {
        FtUtil.log_d(TAG, "processIntentBootCompletedWhenFactoryBinary", "Boot completed, IS_FACTORY_BINARY = factory");
        FtUtil.log_d(TAG, "Usb Configuration Status", "UsbStatus = " + Support.Kernel.read(Support.Kernel.USB_CONFIG_CHECK));
        deleteOldBackupFile();
        Settings.System.putInt(context.getContentResolver(), "screen_off_timeout", SCREEN_OFF_TIME_OUT);
        if (Support.Feature.getBoolean(Support.Feature.SKIP_TRANSITION_ANIMATION_SCALE, false)) {
            Settings.Global.putInt(context.getContentResolver(), "transition_animation_scale", 0);
        }
        Settings.System.putIntForUser(context.getContentResolver(), "multi_window_enabled", 0, -2);
        Settings.Secure.putStringForUser(context.getContentResolver(), "immersive_mode_confirmations", "confirmed", -2);
        ModulePower.instance(context).setTouchLedTime(1500);
        boolean autoBrightness = false;
        ContentResolver contentResolver = context.getContentResolver();
        try {
            boolean z = true;
            if (Settings.System.getInt(contentResolver, "screen_brightness_mode") != 1) {
                z = false;
            }
            autoBrightness = z;
        } catch (Settings.SettingNotFoundException e) {
            e.printStackTrace();
        }
        if (autoBrightness) {
            Settings.System.putInt(contentResolver, "screen_brightness_mode", 0);
        }
        Settings.System.putIntForUser(this.mContext.getContentResolver(), "screen_brightness", 130, -2);
        Settings.System.putInt(contentResolver, "pen_detect_mode_disabled", 0);
        Support.Kernel.write(Support.Kernel.EPEN_SAVINGMODE, "0");
        ModuleCommon.instance(context).setSwitchFactoryState();
        ModuleCommon.instance(context).enableFtClient();
        sendRTCAlarmOffIntent();
        startFactoryTestSupportService();
        startFactoryTestNvObserver();
        CheckTouchkeyLedOnTime();
        CheckDigitizerConnection();
        ModuleCommon.instance(context).enable15Test();
        startFactoryTestClientServiceAPO();
        File fls = new File(Support.Kernel.getFilePath(Support.Kernel.FACTORY_FAILHIST_FLS));
        if (fls.exists()) {
            FtUtil.log_d(TAG, "readFailHist for FLS", "res = " + Support.Kernel.read(Support.Kernel.FACTORY_FAILHIST_FLS));
            FtUtil.log_d(TAG, "clear failhist for FLS", "file exits");
            fls.delete();
        } else {
            FtUtil.log_d(TAG, "clear failhist for FLS", "file not found");
        }
        FtUtil.setPressureTouchStatus("0");
        if (ProtectedFactoryTestBroadcastReceiver.mPrepare15Test) {
            launchFactoryTest();
            ProtectedFactoryTestBroadcastReceiver.mPrepare15Test = false;
        }
        if ("15mode".equalsIgnoreCase(Support.Feature.getString(Support.Feature.START_TYPE))) {
            ModuleCommon.instance(this.mContext).go15mode();
        }
    }

    private boolean isUSBConnected(Context context) {
        return FtUtil.isEMATCmd(context) && "CONFIGURED".equals(Support.Kernel.read(Support.Kernel.USB_CONFIG_CHECK));
    }

    private void initFactoryAppFiles() {
        String EFS_FACTORYAPP_ROOT_PATH_STRING = Support.Kernel.getFilePath(Support.Kernel.EFS_FACTORYAPP_ROOT_PATH);
        FtUtil.log_d(TAG, "ModuleCommon", "EFS_FACTORYAPP_ROOT PATH : " + EFS_FACTORYAPP_ROOT_PATH_STRING);
        if (Support.Properties.PROPERTIES_DEFAULT_STRING.equals(EFS_FACTORYAPP_ROOT_PATH_STRING)) {
            EFS_FACTORYAPP_ROOT_PATH_STRING = "/efs/FactoryApp/";
            FtUtil.log_d(TAG, "ModuleCommon", "EFS_FACTORYAPP_ROOT PATH : " + EFS_FACTORYAPP_ROOT_PATH_STRING);
        }
        if (!new File(EFS_FACTORYAPP_ROOT_PATH_STRING).exists()) {
            FtUtil.log_d(TAG, "ModuleCommon", "Create DIR_EFS_FACTORYAPP_ROOT");
            if (Support.Kernel.mkDir(EFS_FACTORYAPP_ROOT_PATH_STRING)) {
                Support.Kernel.setPermission(EFS_FACTORYAPP_ROOT_PATH_STRING, true, false, true, true, true, false);
            }
        }
        Support.Kernel.setPermission(Support.Kernel.getFilePath(Support.Kernel.SERIAL_NO), true, true, true, true, true, false);
        String value = ModuleCommon.instance(this.mContext).readFactoryMode();
        if (FtUtil.isFactoryBinary()) {
            if (!"OFF".equals(value)) {
                ModuleCommon.instance(this.mContext).writeFactoryMode("OFF");
                Support.Kernel.setPermission(Support.Kernel.getFilePath(Support.Kernel.FACTORY_MODE), true, true, true, true, true, false);
                FtUtil.log_d(TAG, "onReceive", "OFFis changed...");
            }
        } else if (!"ON".equals(value)) {
            ModuleCommon.instance(this.mContext).writeFactoryMode("ON");
            Support.Kernel.setPermission(Support.Kernel.getFilePath(Support.Kernel.FACTORY_MODE), true, true, true, true, true, false);
            FtUtil.log_d(TAG, "onReceive", "ONis changed...");
        }
        if (!new File(Support.Kernel.getFilePath(Support.Kernel.KEYSTRING_BLOCK)).exists()) {
            ModuleCommon.instance(this.mContext).writeKeyStringBlock("OFF");
            FtUtil.log_d(TAG, "onReceive", "KEYSTRING_BLOCK is created...");
        } else {
            FtUtil.log_d(TAG, "onReceive", "KEYSTRING_BLOCK is already existed...");
        }
        Support.Kernel.setPermission(Support.Kernel.getFilePath(Support.Kernel.KEYSTRING_BLOCK), true, true, true, true, true, false);
    }

    private void startFactoryTestClientServiceAPO() {
        FtUtil.log_i(TAG, "startFactoryTestClientServiceAPO", "start FactoryTestClient service for APO");
        startFactoryTestClientServiceAPO(false);
    }

    private void startFactoryTestClientServiceAPO(boolean sendResponse) {
        FtUtil.log_i(TAG, "startFactoryTestClientServiceAPO", "start FactoryTestClient service for APO, send response : " + sendResponse);
        Intent intent = new Intent();
        intent.setClassName("com.sec.factory", "com.sec.factory.aporiented.FtClient");
        intent.putExtra("SEND_RESPONSE", sendResponse);
        this.mContext.startService(intent);
        ModuleCommon.instance(this.mContext).setFtClientState(true);
    }

    private void stopFactoryTestClientServiceAPO() {
        FtUtil.log_i(TAG, "stopFactoryTestClientServiceAPO", "stop FactoryTestClient service for APO");
        Intent intent = new Intent();
        intent.setClassName("com.sec.factory", "com.sec.factory.aporiented.FtClient");
        this.mContext.stopService(intent);
    }

    private void startDummyFtClientForBootCompleted() {
        FtUtil.log_i(TAG, "startDummyFtClientForBootCompleted", "start DummyFtClient service for APO");
        Intent intent = new Intent();
        intent.setClassName("com.sec.factory", "com.sec.factory.aporiented.DummyFtClient");
        intent.addFlags(32);
        this.mContext.startService(intent);
    }

    private void launchFactoryTest() {
        if (XMLDataStorage.instance().wasCompletedParsing()) {
            FtUtil.log_d(TAG, "launchFactoryTest", "Launch FactoryTestMain");
            Intent i = new Intent("android.intent.action.MAIN");
            i.setClassName("com.sec.factory", "com.sec.factory.app.factorytest.FactoryTestMain");
            i.setFlags(872415232);
            i.addFlags(32);
            this.mContext.startActivity(i);
            return;
        }
        FtUtil.log_d(TAG, "launchFactoryTest", "XML data parsing was not completed.");
        Toast.makeText(this.mContext, "XML data parsing was not completed.", 0).show();
    }

    private void startFactoryTestSupportService() {
        FtUtil.log_i(TAG, "startFactoryTestSupportService", "Start FactoryTestSupportService");
        Intent intent = new Intent();
        intent.setClassName("com.sec.factory", "com.sec.factory.app.factorytest.FactoryTestSupportService");
        intent.setFlags(268435456);
        intent.addFlags(32);
        this.mContext.startService(intent);
    }

    private void startFactoryTestNvObserver() {
        FtUtil.log_i(TAG, "startFactoryTestNvObserver", "Start FactoryTestNvObserver");
        Intent intent = new Intent();
        intent.setClassName("com.sec.factory", "com.sec.factory.app.factorytest.FactoryTestNvObserver");
        intent.setFlags(268435456);
        intent.addFlags(32);
        this.mContext.startService(intent);
    }

    private void sendRTCAlarmOffIntent() {
        FtUtil.log_d(TAG, "sendRTCAlarmOffIntent", "android.intent.action.START_FACTORY_TEST");
        this.mContext.sendBroadcast(new Intent("android.intent.action.START_FACTORY_TEST"));
    }

    private void CheckDigitizerConnection() {
        String EPen_Check = Support.Kernel.read(Support.Kernel.EPEN_DIGITIZER_CHECK);
        if (EPen_Check != null && EPen_Check.contains("NG")) {
            FtUtil.log_d(TAG, "CheckDigitizer", "Checking Fail Connection Digitize.");
            Handler handler2 = this.handler;
            handler2.sendMessage(handler2.obtainMessage(1));
        }
    }

    private void CheckTouchkeyLedOnTime() {
        int mButtonLedTime = ModulePower.instance(this.mContext).getTouchLedTime();
        if (mButtonLedTime == 0 || mButtonLedTime == -1) {
            Settings.System.putInt(this.mContext.getContentResolver(), ModulePower.BUTTON_KEY_LIGHT, 1500);
            FtUtil.log_d(TAG, "CheckTouchkeyLedOnTime", "Forcely TouchKey Led Normal On Because mButtonLedTime = " + mButtonLedTime);
        }
    }

    public void deleteOldBackupFile() {
        FtUtil.log_d(TAG, "deleteOldBackupFile.");
        Support.Kernel.deleteFile(Support.Kernel.SECEFS_IMS_SETTING_BACKUP_FILE);
        Support.Kernel.deleteFile(Support.Kernel.SECEFS_IMS_SETTING_FILE);
    }

    public void initFailhist() {
        if ("V3".equalsIgnoreCase(Support.Feature.getString(Support.Feature.FAILHIST_VERSION))) {
            FtUtil.log_d(TAG, "initFailhist", "Failhist Version is V3");
            String[] failHistList = Support.Kernel.readNsyncContinuous(Support.Kernel.FACTORY_FAILHIST, false).split("\n");
            if (failHistList.length != 0) {
                FtUtil.log_d(TAG, "initFailhist", "fhFormat : " + failHistList[0]);
                if (failHistList[0].split(":").length == 5) {
                    FtUtil.log_d(TAG, "initFailhist", "failhist reset");
                    Support.Kernel.writeNsync(Support.Kernel.FACTORY_FAILHIST, "");
                    return;
                }
                FtUtil.log_d(TAG, "initFailhist", "normal format");
                return;
            }
            return;
        }
        FtUtil.log_d(TAG, "initFailhist", "Failhist Version is not V3");
    }
}
