package com.sec.factory.entry;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.FactoryTest;
import com.sec.factory.aporiented.UsbFtClient;
import com.sec.factory.modules.ModuleAudio;
import com.sec.factory.modules.ModuleCommon;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.modules.ModulePower;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import com.sec.xmldata.support.XMLDataStorage;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;

public class ProtectedFactoryTestBroadcastReceiver extends BroadcastReceiver {
    private static final String ACTION_REQUEST_FTCLIENT_START = "com.sec.factory.entry.REQUEST_FTCLIENT_START";
    private static final String ACTION_SECRET_CODE = "com.samsung.android.action.SECRET_CODE";
    private static final String ACTION_WAKELOCK_FROM_RIL = "com.sec.android.app.factorytest";
    private static final String REQUEST_FACTORY_RESET = "com.sec.factory.entry.REQUEST_FACTORY_RESET";
    private static final String TAG = "ProtectedFactoryTestBroadcastReceiver";
    public static boolean mPrepare15Test = false;
    private Context mContext;

    public void onReceive(Context context, Intent intent) {
        this.mContext = context;
        String action = intent.getAction();
        FtUtil.log_d(TAG, "onReceive", "onReceive action=" + action);
        if (ACTION_REQUEST_FTCLIENT_START.equals(action)) {
            if (!XMLDataStorage.instance().parseXML(context)) {
                FtUtil.log_d(TAG, "onReceive", "com.sec.factory.entry.REQUEST_FTCLIENT_START => XML data parsing was failed.");
            }
            startFactoryTestClientServiceAPO();
        } else if (UsbFtClient.ACTION_DISCONNECT_USB_CMD_CLIENT.equals(action)) {
            if (!XMLDataStorage.instance().parseXML(context)) {
                FtUtil.log_d(TAG, "onReceive", "com.sec.factory.entry.REQUEST_FTCLIENT_START => XML data parsing was failed.");
            }
            stopUsbCommandClient();
        } else if (UsbFtClient.ACTION_REQUEST_USB_CMD_CLIENT_START.equals(action)) {
            if (!XMLDataStorage.instance().parseXML(context)) {
                FtUtil.log_d(TAG, "onReceive", "com.sec.factory.entry.REQUEST_FTCLIENT_START => XML data parsing was failed.");
            }
            startUsbCommandClient();
        } else if (ACTION_SECRET_CODE.equals(action)) {
            FtUtil.log_i(TAG, "onReceive", ACTION_SECRET_CODE);
            String host = intent.getData().getHost();
            FtUtil.log_i(TAG, "onReceive", "Host=" + host);
            if (!XMLDataStorage.instance().parseXML(context)) {
                FtUtil.log_i(TAG, "onReceive", "ACTION_SECRET_CODE => XML data parsing was failed.");
            }
            if (!"$$15".equals(host) || !FactoryTest.isFactoryMode()) {
                if ("7547".equals(host)) {
                    launchMainHistoryView();
                } else if ("08".equals(host) && FactoryTest.isFactoryMode()) {
                    launchFactoryHistoryView();
                } else if ("775".equals(host)) {
                    launchSpkcal();
                } else if ("2015".equals(host) && FtUtil.isFactoryBinary()) {
                    launchDeviceCmdEntry();
                } else if ("6648".equals(host) && FtUtil.isFactoryBinary()) {
                    launchNVControl();
                } else if ("2013".equals(host) && FtUtil.isFactoryBinary()) {
                    launchSpk_Rcv_Test();
                } else if ("5667".equals(host) && FtUtil.isFactoryBinary()) {
                    launchLoopbackEP();
                } else if ("2538378".equals(host) && FtUtil.isFactoryBinary()) {
                    launchSpenBleTest();
                }
            } else if (ModuleCommon.instance(context).is15TestEnable()) {
                launchFactoryTest();
                mPrepare15Test = false;
            } else {
                mPrepare15Test = true;
            }
        } else if (REQUEST_FACTORY_RESET.equals(action)) {
            createFileNotiCheck();
        } else if (ACTION_WAKELOCK_FROM_RIL.equals(action)) {
            String data = intent.getStringExtra("COMMAND");
            FtUtil.log_d(TAG, "onReceive", "COMMAND : " + data);
            if (data == null || data.length() < 8) {
                FtUtil.log_w(TAG, "onReceive", "ACTION_WAKELOCK_FROM_RIL : Wrong IPC");
                return;
            }
            String data2 = data.substring(6, 8);
            if ("00".equals(data2)) {
                ModulePower.instance(context).setFactoryModeAtBatteryNode(false);
                if (Support.Feature.getBoolean(Support.Feature.NEED_NOTI_AUDIO_MANAGER, true)) {
                    ModuleAudio.instance(context).sendToAudioManagerFTAOnOff(false);
                }
                FtUtil.log_d(TAG, "onReceive", "Release wakelock because of RIL's intent");
            } else if ("01".equals(data2)) {
                ModulePower.instance(context).doWakeLock(true);
                ModulePower.instance(context).sendDvfsLockIntent();
                ModulePower.instance(context).sendAlarmManagerOnOff(false);
                ModulePower.instance(context).setFactoryModeAtBatteryNode(true);
                ModuleCommon.instance(context).setSwitchFactoryState();
                if (Support.Feature.getBoolean(Support.Feature.NEED_NOTI_AUDIO_MANAGER, true)) {
                    ModuleAudio.instance(context).sendToAudioManagerFTAOnOff(true);
                }
                if (Support.Feature.getBoolean(Support.Feature.NEED_LPM_MODE_SET, true)) {
                    ModuleDevice.instance(context).setLPMmode(ModuleDevice.LPM_MODE_DISABLE);
                }
                FtUtil.log_d(TAG, "onReceive", "Acquire wakelock because of RIL's intent");
            }
        }
    }

    private void launchSpkcal() {
        FtUtil.log_d(TAG, "launchSpkcal", "Launch UISpkcal");
        Intent i = new Intent();
        i.setClassName("com.sec.factory", "com.sec.factory.app.ui.UISpkcal");
        i.setFlags(268435456);
        this.mContext.startActivity(i);
    }

    private void launchSpk_Rcv_Test() {
        FtUtil.log_d(TAG, "launchSpk_Rcv_Test", "Launch UISpk_Rcv_Test");
        Intent i = new Intent();
        i.setClassName("com.sec.factory", "com.sec.factory.app.ui.UISpk_Rcv_Test");
        i.setFlags(268435456);
        this.mContext.startActivity(i);
    }

    private void launchLoopbackEP() {
        FtUtil.log_d(TAG, "launchLoopbackEP", "Launch LoopbackForWIFI");
        Intent i = new Intent();
        i.setClassName("com.sec.factory", "com.sec.factory.app.ui.UILoopbackForWIFI");
        i.setFlags(268435456);
        this.mContext.startActivity(i);
    }

    private void launchSpenBleTest() {
        FtUtil.log_d(TAG, "launchSpenBleTest", "launchSpenBleTest");
        Intent intent = new Intent();
        if (Support.Feature.getBoolean(Support.Feature.SUPPORT_SPEN_BLE_COLOR_SELECT_SKIP, false)) {
            if (Support.Feature.getBoolean(Support.Feature.SUPPORT_SPEN_BLE_ACCGYRO, false)) {
                intent.setClassName("com.sec.factory", "com.sec.factory.app.ui.UISpenBluetoothAccGyroTest");
            } else {
                intent.setClassName("com.sec.factory", "com.sec.factory.app.ui.UISpenBluetoothTest");
            }
            intent.putExtra("colorCode", "NA");
        } else {
            intent.setClassName("com.sec.factory", "com.sec.factory.app.ui.SpenBluetoothTestEntry");
        }
        intent.setFlags(335544320);
        this.mContext.startActivity(intent);
    }

    private void createFileNotiCheck() {
        File SecondAckFile = new File(Support.Kernel.getFilePath(Support.Kernel.SECEFS_RESET_FLAG_FILE));
        try {
            if (!SecondAckFile.exists()) {
                SecondAckFile.createNewFile();
                SecondAckFile.setReadable(true, false);
                SecondAckFile.setExecutable(true, true);
            }
            FtUtil.log_i(TAG, "createFileNotiCheck", "createFileNotiCheck - SecondAckFile");
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e2) {
            e2.printStackTrace();
        }
    }

    private void startUsbCommandClient() {
        FtUtil.log_i(TAG, "startUsbCommandClient", "start UsbCommandClient service");
        Intent intent = new Intent();
        intent.setClassName("com.sec.factory", "com.sec.factory.aporiented.UsbFtClient");
        this.mContext.startService(intent);
    }

    private void stopUsbCommandClient() {
        FtUtil.log_i(TAG, "stopUsbCommandClient", "stop UsbCommandClient service");
        Intent intent = new Intent();
        intent.setClassName("com.sec.factory", "com.sec.factory.aporiented.UsbFtClient");
        this.mContext.stopService(intent);
    }

    private void startFactoryTestClientServiceAPO() {
        FtUtil.log_i(TAG, "startFactoryTestClientServiceAPO", "start FactoryTestClient service for APO");
        Intent intent = new Intent();
        intent.setClassName("com.sec.factory", "com.sec.factory.aporiented.FtClient");
        this.mContext.startService(intent);
        ModuleCommon.instance(this.mContext).setFtClientState(true);
    }

    private void launchFactoryTest() {
        if (XMLDataStorage.instance().wasCompletedParsing()) {
            FtUtil.log_d(TAG, "launchFactoryTest", "Launch FactoryTestMain");
            Intent i = new Intent("android.intent.action.MAIN");
            i.setClassName("com.sec.factory", "com.sec.factory.app.factorytest.FactoryTestMain");
            i.setFlags(872415232);
            i.addFlags(32);
            this.mContext.startActivity(i);
            return;
        }
        FtUtil.log_d(TAG, "launchFactoryTest", "XML data parsing was not completed.");
    }

    private void launchMainHistoryView() {
        if (XMLDataStorage.instance().wasCompletedParsing()) {
            FtUtil.log_d(TAG, "launchMainHistoryView", "Launch UIFactoryHistory");
            Intent i = new Intent();
            i.setClassName("com.sec.factory", "com.sec.factory.app.ui.UIFactoryHistory");
            i.setFlags(268435456);
            this.mContext.startActivity(i);
            return;
        }
        FtUtil.log_d(TAG, "launchMainHistoryView", "XML data parsing was not completed.");
    }

    private void launchDeviceCmdEntry() {
        if (XMLDataStorage.instance().wasCompletedParsing()) {
            FtUtil.log_d(TAG, "launchDeviceCmdEntry", "Launch DeviceCmdEntry");
            Intent i = new Intent();
            i.setClassName("com.sec.factory", "com.sec.factory.app.ui.DeviceCmdEntry");
            i.setFlags(268435456);
            this.mContext.startActivity(i);
            return;
        }
        FtUtil.log_d(TAG, "launchDeviceCmdEntry", "XML data parsing was not completed.");
    }

    private void launchNVControl() {
        if (XMLDataStorage.instance().wasCompletedParsing()) {
            FtUtil.log_d(TAG, "launchNVControl", "Launch NVControl");
            Intent i = new Intent();
            i.setClassName("com.sec.factory", "com.sec.factory.app.ui.NvControl");
            i.setFlags(268435456);
            i.putExtra("writeable", false);
            this.mContext.startActivity(i);
            return;
        }
        FtUtil.log_d(TAG, "launchNVControl", "XML data parsing was not completed.");
    }

    private void launchFactoryHistoryView() {
        if (XMLDataStorage.instance().wasCompletedParsing()) {
            FtUtil.log_d(TAG, "launchFactoryHistoryView", "Launch UIFactoryTestNVView");
            Intent i = new Intent();
            i.setClassName("com.sec.factory", "com.sec.factory.app.ui.UIFactoryTestNVView");
            i.setFlags(268435456);
            this.mContext.startActivity(i);
            return;
        }
        FtUtil.log_d(TAG, "launchFactoryHistoryView", "XML data parsing was not completed.");
    }
}
