package com.sec.factory.entry;

import android.app.StatusBarManager;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.provider.Settings;
import android.service.persistentdata.PersistentDataBlockManager;
import com.sec.factory.modules.ModuleCommon;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.XMLDataStorage;

public class ProvisionReceiver extends BroadcastReceiver {
    private static final String TAG = "ProvisionReceiver";

    public void onReceive(Context context, Intent intent) {
        String action = intent.getAction();
        FtUtil.log_d(TAG, "onReceive", "onReceive action=" + action);
        if (!FtUtil.isFactoryBinary()) {
            FtUtil.log_w(TAG, "onReceive", "No FactoryBianry");
        } else if ("android.intent.action.PRE_BOOT_COMPLETED".equals(action)) {
            doProvision(context);
            if (FtUtil.isFactoryBinary()) {
                if (!XMLDataStorage.instance().parseXML(context)) {
                    FtUtil.log_d(TAG, "onReceive", "ACTION_PRE_BOOT_COMPLETED => XML data parsing was failed.");
                }
                if (!ModuleCommon.misForeground) {
                    ModuleCommon.instance(context).startForegroundService();
                }
            }
        } else if ("android.intent.action.BOOT_COMPLETED".equals(action)) {
            doProvision(context);
        }
    }

    private void doProvision(Context context) {
        int provision = 0;
        int setup_completed = 0;
        PersistentDataBlockManager mPdbManager = (PersistentDataBlockManager) context.getSystemService("persistent_data_block");
        if (mPdbManager == null) {
            FtUtil.log_d(TAG, "doProvision", "failed to load persistent manager");
        } else {
            try {
                if (mPdbManager.isEnabled()) {
                    FtUtil.log_d(TAG, "doProvision", "don't set setting DB with FRP");
                    return;
                }
            } catch (Exception e) {
                FtUtil.log_e(TAG, "doProvision", "failed to get FRP state");
                e.printStackTrace();
            }
        }
        try {
            provision = Settings.Secure.getInt(context.getContentResolver(), "device_provisioned");
            setup_completed = Settings.Secure.getInt(context.getContentResolver(), "user_setup_complete");
        } catch (Settings.SettingNotFoundException se) {
            FtUtil.log_e(se);
        }
        FtUtil.log_d(TAG, "doProvision", "provision=" + provision);
        if (provision == 0) {
            Settings.Secure.putInt(context.getContentResolver(), "device_provisioned", 1);
            Settings.Global.putInt(context.getContentResolver(), "device_provisioned", 1);
        }
        FtUtil.log_d(TAG, "doProvision", "setup_completed=" + setup_completed);
        if (setup_completed == 0) {
            Settings.Secure.putInt(context.getContentResolver(), "user_setup_complete", 1);
        }
        StatusBarManager mStatusBarManager = (StatusBarManager) context.getSystemService("statusbar");
        mStatusBarManager.disable(262144);
        mStatusBarManager.disable(0);
        FtUtil.log_d(TAG, "doProvision", "initialized mDisableNotificationEffects");
    }
}
