package com.sec.factory.entry;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.SystemProperties;
import android.telephony.TelephonyManager;
import android.telephony.UiccCardInfo;
import android.widget.Toast;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.modules.ModuleTouchScreen;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import com.sec.xmldata.support.XMLDataStorage;

public class SimSwitchingReceiver extends BroadcastReceiver {
    private static final String ACTION_SIM_SWITCH_TEST = "com.sec.factory.SIM_SWITCH_TEST";
    private static final String CLASS_NAME = "SimSwitchingReceiver";
    private static final int SIM_TYPE_ESIM = 1;
    private static boolean mReadySimSwitching = false;
    private static SimFunction mSimSwitchData = null;
    private static boolean mUpdatedSwitchedSIM = false;
    private Context mContext;

    /* access modifiers changed from: private */
    public enum SimFunction {
        CHANGE_TO_ESIM,
        CHANGE_TO_RSIM;
        
        private int enumSlot = -1;

        private SimFunction() {
        }

        /* access modifiers changed from: package-private */
        public void setSimSwitchSlot(int slot) {
            this.enumSlot = slot;
        }

        /* access modifiers changed from: package-private */
        public SimFunction callToSwitchSimSlot(Context context) {
            SimFunction result;
            FtUtil.log_d(SimSwitchingReceiver.CLASS_NAME, "callToSwitchSimSlot", "type : " + name() + " , simSwitchSlot : " + this.enumSlot);
            if (this == CHANGE_TO_ESIM) {
                ModuleDevice.instance(context).setSimSwitchESIM(this.enumSlot);
                Toast.makeText(context, "rSIM -> eSIM switching", 0).show();
                result = CHANGE_TO_RSIM;
            } else {
                ModuleDevice.instance(context).setSimSwitchRSIM(this.enumSlot);
                Toast.makeText(context, "eSIM -> rSIM switching", 0).show();
                result = CHANGE_TO_ESIM;
            }
            result.enumSlot = this.enumSlot;
            return result;
        }
    }

    public void onReceive(Context context, Intent intent) {
        String action = intent.getAction();
        FtUtil.log_d(CLASS_NAME, "onReceive", "onReceive action = " + action);
        this.mContext = context;
        if (!XMLDataStorage.instance().parseXML(context)) {
            FtUtil.log_d(CLASS_NAME, "onReceive", "XML data parsing was failed.");
        }
        if ("android.intent.action.SIM_STATE_CHANGED".equals(action)) {
            checkToNeedToSwitchSim(intent);
        } else if ("com.sec.factory.SIM_SWITCH_TEST".equalsIgnoreCase(action)) {
            runActionToSwitchSim();
        }
    }

    private void runActionToSwitchSim() {
        if (mReadySimSwitching) {
            FtUtil.log_d(CLASS_NAME, "runActionToSwitchSim", "This intent is only received once. But the log means that intent was received twice.");
            return;
        }
        mReadySimSwitching = true;
        SimFunction simFunction = mSimSwitchData;
        if (simFunction != null) {
            mSimSwitchData = simFunction.callToSwitchSimSlot(this.mContext);
        } else {
            FtUtil.log_d(CLASS_NAME, "runActionToSwitchSim", "Can't call a method to switch sim slot");
        }
    }

    private void checkToNeedToSwitchSim(Intent intent) {
        boolean isESIM = false;
        int slot = intent.getIntExtra(ModuleTouchScreen.TSP_DEVICE_TYPE__PHONE, 0);
        int simType = intent.getIntExtra("isEuicc", -1);
        int simSwitchSlot = ModuleDevice.instance(this.mContext).getSupportSimSwitch();
        int switchStat = SystemProperties.getInt("ril.simslottype" + simSwitchSlot, -1);
        String simState = intent.getStringExtra("ss");
        boolean isUpdatedESIM = Boolean.parseBoolean(SystemProperties.get("ro.factory.switchsimupdated", "false"));
        if (simType == 1 && switchStat == 1) {
            isESIM = true;
        }
        FtUtil.log_d(CLASS_NAME, "checkToNeedToSwitchSim", "sim slot - " + slot + " , state - " + simState + " , isEuicc - " + simType + " , ril.simslottype " + simSwitchSlot + " - " + switchStat);
        if (!isUpdatedESIM && slot == simSwitchSlot - 1) {
            if (isESIM) {
                checkNeedToSwitchToRSIM(this.mContext, simSwitchSlot, simState);
            } else if (!isESIM) {
                checkNeedToSwitchToESIM(this.mContext, simSwitchSlot, simState);
            }
        }
    }

    private void checkNeedToSwitchToRSIM(Context _context, int simSwitchSlot, String state) {
        SimFunction simFunction = mSimSwitchData;
        if (simFunction == null) {
            SimFunction simFunction2 = SimFunction.CHANGE_TO_RSIM;
            mSimSwitchData = simFunction2;
            simFunction2.setSimSwitchSlot(simSwitchSlot);
            FtUtil.log_d(CLASS_NAME, "checkNeedToSwitchToRSIM", "set mSimSwitchData to 'change to rsim'");
        } else if (simFunction == SimFunction.CHANGE_TO_ESIM) {
            FtUtil.log_d(CLASS_NAME, "checkNeedToSwitchToRSIM", "Sequence has a problem!!!");
            return;
        }
        if (!mUpdatedSwitchedSIM && saveEidOnEfs(this.mContext, state, simSwitchSlot)) {
            mUpdatedSwitchedSIM = true;
        }
        if (mReadySimSwitching && mUpdatedSwitchedSIM) {
            mSimSwitchData = mSimSwitchData.callToSwitchSimSlot(_context);
        }
    }

    private void checkNeedToSwitchToESIM(Context _context, int simSwitchSlot, String state) {
        if (mUpdatedSwitchedSIM) {
            FtUtil.log_d(CLASS_NAME, "checkNeedToSwitchToESIM", "Complete sim switching test");
            Support.Properties.setProp("ro.factory.switchsimupdated", "true");
        } else if ("LOADED".equals(state) || "ABSENT".equals(state)) {
            SimFunction simFunction = mSimSwitchData;
            if (simFunction == null) {
                SimFunction simFunction2 = SimFunction.CHANGE_TO_ESIM;
                mSimSwitchData = simFunction2;
                simFunction2.setSimSwitchSlot(simSwitchSlot);
                FtUtil.log_d(CLASS_NAME, "checkNeedToSwitchToESIM", "set mSimSwitchData to 'change to esim'");
            } else if (simFunction == SimFunction.CHANGE_TO_RSIM) {
                FtUtil.log_d(CLASS_NAME, "checkNeedToSwitchToESIM", "Sequence has a problem!!!");
                return;
            }
            if (mReadySimSwitching) {
                mSimSwitchData = mSimSwitchData.callToSwitchSimSlot(_context);
            }
        }
    }

    private boolean saveEidOnEfs(Context context, String state, int switchSlot) {
        if ("LOADED".equals(state) || "NOT_READY".equals(state)) {
            SharedPreferences.Editor editor = context.getSharedPreferences("SIM_SWITCH_PREF", 0).edit();
            for (UiccCardInfo cardInfo : ((TelephonyManager) this.mContext.getSystemService(ModuleTouchScreen.TSP_DEVICE_TYPE__PHONE)).getUiccCardsInfo()) {
                if (cardInfo.getSlotIndex() == switchSlot - 1) {
                    String eId = cardInfo.getEid();
                    if (eId != null) {
                        FtUtil.log_d(CLASS_NAME, "saveEidOnEfs", "eID - " + eId);
                    }
                    if (eId == null || eId.length() != 32) {
                        editor.putBoolean("SWITCHED_ESIM_STAT", false);
                    } else {
                        Support.Kernel.writeNsync(Support.Kernel.SECEFS_SWITCHED_SIM_EID, eId);
                        editor.putBoolean("SWITCHED_ESIM_STAT", true);
                    }
                }
            }
            editor.commit();
            return true;
        }
        FtUtil.log_d(CLASS_NAME, "saveEidOnEfs", "Invalid sim state!!");
        return false;
    }
}
