package com.sec.factory.modules;

import android.content.Context;
import android.hardware.SerialManager;
import android.hardware.SerialPort;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Iterator;

public class AccCoverManager {
    private static final int BAUD_RATE = 115200;
    private static String CLASS_NAME = "AccCoverManager";
    public static STATE CURRENT_STATE = STATE.INITIATING;
    private static final int MAX_BUFFER = 128;
    public static int NG = 0;
    public static int PASS_ = 1;
    public static int PATH_FAIL = 2;
    public static final String PWR_PATH;
    private static final String QUALCOMM = "Qualcomm";
    public static int SHORT_FAIL = 3;
    private static final String S_LSI = "S.LSI";
    public static final byte[] TESTCMD = {FactoryTestManager.TEST_NFC_CARD_MODE, 69, FactoryTestManager.TEST_LOOPBACK_SPK, 76, FactoryTestManager.TEST_RECORD, FactoryTestManager.TEST_NFC_CARD_MODE, 13, 10};
    public static final String UART_PATH;
    public static final byte[] VAL_OFF;
    public static final byte[] VAL_ON;
    private static Context mContext;
    private static AccCoverManager mInstance = null;
    private static final ArrayList<onReceiveListener> mListeners = new ArrayList<>();
    private static SerialPort mReadPort = null;
    private static SerialManager mSerialManager;
    private static SerialPort mWritePort = null;
    private static readThread rThread;
    private String mResult = "";

    public enum STATE {
        INITIATING,
        WAITING,
        READING
    }

    public interface onReceiveListener {
        void onReceive(String str);
    }

    static {
        String Chipset_Vendor = Support.Feature.getString(Support.Feature.CHIPSET_MANUFACTURE);
        if (QUALCOMM.equalsIgnoreCase(Chipset_Vendor)) {
            FtUtil.log_d("UIAccCover", "Static Block", "Chipset = QUALCOMM");
            UART_PATH = Support.Kernel.getFilePath(Support.Kernel.ACC_COVER_UART_QCOM);
            PWR_PATH = Support.Kernel.ACC_COVER_PWR_QCOM;
            VAL_ON = new byte[]{FactoryTestManager.TEST_IDDETECT, 32, FactoryTestManager.TEST_BARCODE_EMUL, 32, FactoryTestManager.TEST_SENSORHUB};
            VAL_OFF = new byte[]{FactoryTestManager.TEST_IDDETECT, 32, FactoryTestManager.TEST_BARCODE_EMUL, 32, FactoryTestManager.MACRO_AF};
        } else if (S_LSI.equalsIgnoreCase(Chipset_Vendor)) {
            FtUtil.log_d("UIAccCover", "Static Block", "Chipset = S.LSI");
            UART_PATH = Support.Kernel.getFilePath(Support.Kernel.ACC_COVER_UART_LSI);
            PWR_PATH = Support.Kernel.ACC_COVER_PWR_LSI;
            VAL_ON = new byte[]{118, FactoryTestManager.TEST_LEAKAGE_CURRENT_CHECK, 108, FactoryTestManager.TEST_ECHO_TEST, FactoryTestManager.TEST_IDDETECT, FactoryTestManager.TEST_ID_DETECT_CHECK};
            VAL_OFF = new byte[]{118, FactoryTestManager.TEST_LEAKAGE_CURRENT_CHECK, 108, FactoryTestManager.TEST_ECHO_TEST, FactoryTestManager.TEST_IDDETECT, FactoryTestManager.TEST_S_PEN_SIDE_TEST, FactoryTestManager.TEST_S_PEN_SIDE_TEST};
        } else {
            UART_PATH = null;
            PWR_PATH = null;
            VAL_ON = null;
            VAL_OFF = null;
        }
    }

    private AccCoverManager() {
    }

    public static AccCoverManager getInstance(Context c) {
        if (mInstance == null) {
            mInstance = new AccCoverManager();
            mContext = c;
        }
        return mInstance;
    }

    private class readThread extends Thread {
        private readThread() {
        }

        /* synthetic */ readThread(AccCoverManager x0, AnonymousClass1 x1) {
            this();
        }

        public void run() {
            try {
                if (AccCoverManager.mReadPort != null) {
                    while (AccCoverManager.CURRENT_STATE == STATE.READING) {
                        FtUtil.log_d(AccCoverManager.CLASS_NAME, "readThread", "read Start");
                        ByteBuffer bBuffer = ByteBuffer.allocateDirect(128);
                        int count = AccCoverManager.mReadPort.read(bBuffer);
                        String str = AccCoverManager.CLASS_NAME;
                        FtUtil.log_d(str, "readThread", "bBuffer = " + count);
                        AccCoverManager.this.sendData(bBuffer);
                    }
                } else {
                    FtUtil.log_d(AccCoverManager.CLASS_NAME, "readThread", "ReadPort isn't opened");
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
            FtUtil.log_d(AccCoverManager.CLASS_NAME, "readThread", "read End");
            super.run();
        }
    }

    public void registerListener(onReceiveListener r) {
        ArrayList<onReceiveListener> arrayList = mListeners;
        synchronized (arrayList) {
            if (r != null) {
                if (!arrayList.contains(r)) {
                    arrayList.add(r);
                }
            }
        }
    }

    public void unregisterListener(onReceiveListener r) {
        ArrayList<onReceiveListener> arrayList = mListeners;
        synchronized (arrayList) {
            if (r != null) {
                if (arrayList.contains(r)) {
                    arrayList.remove(r);
                }
            }
        }
    }

    public void pathTest() {
        Support.Kernel.write(PWR_PATH, VAL_ON);
        try {
            Thread.sleep(250);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        writeData(TESTCMD);
    }

    public void shortTest() {
        Support.Kernel.write(PWR_PATH, VAL_OFF);
        try {
            Thread.sleep(250);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        writeData(TESTCMD);
    }

    public void writeData(byte[] data) {
        synchronized (mListeners) {
            String str = CLASS_NAME;
            FtUtil.log_d(str, "writeData", "Writing... " + data.length);
            this.mResult = "";
            try {
                SerialPort serialPort = mWritePort;
                if (serialPort != null) {
                    serialPort.write(ByteBuffer.wrap(data), data.length);
                    try {
                        Thread.sleep(100);
                    } catch (InterruptedException e) {
                        e.printStackTrace();
                    }
                    String str2 = CLASS_NAME;
                    FtUtil.log_d(str2, "writeData", "Write data : " + new String(data));
                } else {
                    FtUtil.log_d(CLASS_NAME, "writeData", "WritePort isn't opened");
                }
            } catch (IOException e2) {
                e2.printStackTrace();
            }
        }
    }

    /* renamed from: com.sec.factory.modules.AccCoverManager$1  reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$sec$factory$modules$AccCoverManager$STATE;

        static {
            int[] iArr = new int[STATE.values().length];
            $SwitchMap$com$sec$factory$modules$AccCoverManager$STATE = iArr;
            try {
                iArr[STATE.INITIATING.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$com$sec$factory$modules$AccCoverManager$STATE[STATE.WAITING.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$com$sec$factory$modules$AccCoverManager$STATE[STATE.READING.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
        }
    }

    public void startRead() {
        switch (AnonymousClass1.$SwitchMap$com$sec$factory$modules$AccCoverManager$STATE[CURRENT_STATE.ordinal()]) {
            case 1:
                FtUtil.log_d(CLASS_NAME, "startRead", "Didn't Initialized");
                return;
            case 2:
                CURRENT_STATE = STATE.READING;
                readThread readthread = new readThread(this, null);
                rThread = readthread;
                readthread.start();
                FtUtil.log_d(CLASS_NAME, "startRead", "Switched to START");
                return;
            case 3:
                FtUtil.log_d(CLASS_NAME, "startRead", "already started");
                return;
            default:
                return;
        }
    }

    public void stopRead() {
        switch (AnonymousClass1.$SwitchMap$com$sec$factory$modules$AccCoverManager$STATE[CURRENT_STATE.ordinal()]) {
            case 1:
                FtUtil.log_d(CLASS_NAME, "stopRead", "Didn't Initialized");
                return;
            case 2:
                FtUtil.log_d(CLASS_NAME, "stopRead", "already stopped");
                return;
            case 3:
                CURRENT_STATE = STATE.WAITING;
                FtUtil.log_d(CLASS_NAME, "stopRead", "Switched to STOP");
                return;
            default:
                return;
        }
    }

    public void initialize() {
        switch (AnonymousClass1.$SwitchMap$com$sec$factory$modules$AccCoverManager$STATE[CURRENT_STATE.ordinal()]) {
            case 1:
                if (mSerialManager == null) {
                    mSerialManager = (SerialManager) mContext.getSystemService("serial");
                }
                String[] ports = mSerialManager.getSerialPorts();
                for (String p : ports) {
                    FtUtil.log_d(CLASS_NAME, "onCreate", "Port : " + p);
                }
                try {
                    SerialPort serialPort = mReadPort;
                    if (serialPort != null) {
                        serialPort.close();
                    }
                    SerialManager serialManager = mSerialManager;
                    String str = UART_PATH;
                    mReadPort = serialManager.openSerialPort(str, (int) BAUD_RATE);
                    SerialPort serialPort2 = mWritePort;
                    if (serialPort2 != null) {
                        serialPort2.close();
                    }
                    mWritePort = mSerialManager.openSerialPort(str, (int) BAUD_RATE);
                } catch (IOException e) {
                    e.printStackTrace();
                }
                CURRENT_STATE = STATE.WAITING;
                FtUtil.log_d(CLASS_NAME, "initialize", "Initialized");
                return;
            case 2:
                FtUtil.log_d(CLASS_NAME, "initialize", "Already Initialized");
                return;
            case 3:
                FtUtil.log_d(CLASS_NAME, "initialize", "Already Initialized");
                return;
            default:
                return;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sendData(ByteBuffer bB) {
        ArrayList<onReceiveListener> arrayList = mListeners;
        synchronized (arrayList) {
            String result = new String(bB.array()).replaceAll("[^a-zA-Z]", "");
            FtUtil.log_d(CLASS_NAME, "sendData", "read : " + result);
            String str = this.mResult + result;
            this.mResult = str;
            if (str.length() > 5) {
                FtUtil.log_d(CLASS_NAME, "sendData", "send to Listener : " + this.mResult);
                Iterator<onReceiveListener> it = arrayList.iterator();
                while (it.hasNext()) {
                    it.next().onReceive(this.mResult);
                }
                this.mResult = "";
            } else {
                FtUtil.log_d(CLASS_NAME, "sendData", "Stacking : " + this.mResult);
            }
        }
    }

    public void terminate() {
        try {
            String str = PWR_PATH;
            Support.Kernel.write(str, VAL_ON);
            mWritePort.sendBreak();
            mSerialManager = null;
            SerialPort serialPort = mReadPort;
            if (serialPort != null) {
                serialPort.close();
                mReadPort = null;
            }
            mWritePort.close();
            mWritePort = null;
            CURRENT_STATE = STATE.INITIATING;
            Support.Kernel.write(str, VAL_OFF);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
