package com.sec.factory.modules;

import android.app.Service;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModuleNfc;
import com.sec.factory.support.FtUtil;

public class FactoryNfc2TestService extends Service {
    private static final String ACTION_NFC_TEST_RESPONSE = "com.samsung.android.nfc.test.action.RESPONSE";
    public static final String CHECK_SEC_NFC_SIM_RESP = "com.sec.android.app.nfctest.NFC_CHECK_SIM_RESPONSE";
    private static final String CLASS_NAME = "FactoryNfc2TestService";
    private final byte MSG_DISABLE_DISCOVERY = 2;
    private final byte MSG_ENABLE_DISCOVERY = 1;
    private final byte MSG_FINISH_TEST = 3;
    private final byte MSG_SIM_TEST = 4;
    private final int NFC_DISCOVERY_CHANGE_DELAY = 500;
    private final int NFC_FINISH_DELAY = 1000;
    private final int NFC_TIMEOUT_DELAY = 10000;
    public Handler mHandler = new Handler() {
        /* class com.sec.factory.modules.FactoryNfc2TestService.AnonymousClass1 */

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    FtUtil.log_i(FactoryNfc2TestService.CLASS_NAME, "send Intent ENABLE_SEC_NFC_DISCOVERY");
                    FactoryNfc2TestService.this.sendBroadcast(ModuleNfc.NfcFunctions.NFC_ENABLE_DISCOVERY.getNfcIntent());
                    return;
                case 2:
                    FtUtil.log_i(FactoryNfc2TestService.CLASS_NAME, "send Intent DISABLE_SEC_NFC_DISCOVERY");
                    FactoryNfc2TestService.this.sendBroadcast(ModuleNfc.NfcFunctions.NFC_DISABLE_DISCOVERY.getNfcIntent());
                    return;
                case 3:
                    FtUtil.log_i(FactoryNfc2TestService.CLASS_NAME, "MSG_FINISH_TEST");
                    if (FactoryNfc2TestService.this.mIsPassed_reader) {
                        FtUtil.log_d(FactoryNfc2TestService.CLASS_NAME, "handleMessage", FtUtil.setMspSeqMessage(4, FactoryNfc2TestService.CLASS_NAME, "(NFC_FT) PASS - SWP & Read Test"));
                        FactoryNfc2TestService.this.setTestResult((byte) 61, (byte) 80);
                        FactoryNfc2TestService.this.stopSelf();
                    } else {
                        FtUtil.log_d(FactoryNfc2TestService.CLASS_NAME, "handleMessage", FtUtil.setMspSeqMessage(4, FactoryNfc2TestService.CLASS_NAME, "(NFC_FT) FAIL - SWP or Read Test"));
                        FactoryNfc2TestService.this.setTestResult((byte) 61, (byte) 70);
                    }
                    FactoryNfc2TestService.this.stopSelf();
                    return;
                case 4:
                    FtUtil.log_i(FactoryNfc2TestService.CLASS_NAME, "send Intent CHECK_SEC_NFC_SIM");
                    FactoryNfc2TestService.this.sendBroadcast(ModuleNfc.NfcFunctions.NFC_CHECK_SIM_TEST.getNfcIntent());
                    return;
                default:
                    return;
            }
        }
    };
    private boolean mIsPassed_reader = false;
    private final BroadcastReceiver mReceiver = new BroadcastReceiver() {
        /* class com.sec.factory.modules.FactoryNfc2TestService.AnonymousClass2 */

        public void onReceive(Context context, Intent intent) {
            if ("android.nfc.action.TAG_DISCOVERED".equals(intent.getAction())) {
                FtUtil.log_i(FactoryNfc2TestService.CLASS_NAME, "Received ACTION_TAG_DISCOVERED");
                FactoryNfc2TestService.this.mIsPassed_reader = true;
                FactoryNfc2TestService.this.mHandler.removeMessages(3);
                FactoryNfc2TestService.this.mHandler.sendEmptyMessageDelayed(3, 1000);
            }
        }
    };

    public void onCreate() {
        FtUtil.log_i(CLASS_NAME, "onCreate");
        super.onCreate();
        IntentFilter filter = new IntentFilter();
        filter.addAction("android.nfc.action.TAG_DISCOVERED");
        filter.addAction("com.sec.android.app.nfctest.NFC_CHECK_SIM_RESPONSE");
        filter.addAction("com.samsung.android.nfc.test.action.RESPONSE");
        registerReceiver(this.mReceiver, filter);
        sendBroadcast(ModuleNfc.NfcFunctions.NFC_START_SEC_NFC_TEST.getNfcIntent());
        nfctest();
    }

    public IBinder onBind(Intent intent) {
        return null;
    }

    public void onDestroy() {
        FtUtil.log_i(CLASS_NAME, "onDestroy");
        this.mHandler.removeMessages(2);
        this.mHandler.removeMessages(4);
        this.mHandler.removeMessages(1);
        this.mHandler.removeMessages(3);
        super.onDestroy();
        sendBroadcast(ModuleNfc.NfcFunctions.NFC_END_SEC_NFC_TEST.getNfcIntent());
        try {
            Thread.sleep(100);
        } catch (InterruptedException e) {
        }
        sendBroadcast(ModuleNfc.NfcFunctions.NFC_DISABLE_DISCOVERY.getNfcIntent());
        unregisterReceiver(this.mReceiver);
    }

    private void nfctest() {
        FtUtil.log_i(CLASS_NAME, "*** Start nfctest ***");
        this.mHandler.sendEmptyMessageDelayed(3, 10000);
        this.mHandler.sendEmptyMessageDelayed(2, 0);
        this.mHandler.sendEmptyMessageDelayed(1, 0 + 500);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setTestResult(byte id, byte result) {
        FtUtil.log_i(CLASS_NAME, "setTestResult", " ID : " + ((int) id) + " , RESULT :" + ((int) result));
        int itemid = FactoryTestManager.getItemPosition_ID(id);
        if (itemid > -1) {
            FtUtil.log_i(CLASS_NAME, "setTestResult", "itemID : " + itemid);
            FactoryTestManager.setItemResult(itemid, result);
            FactoryTestManager.notifyDataSetChanged();
        }
    }
}
