package com.sec.factory.modules;

import android.app.Service;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.nfc.Tag;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.modules.ModuleNfc;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.io.File;

public class FactoryNfcTestService extends Service {
    private static final String CLASS_NAME = "FactoryNfcTestService";
    private final byte MSG_DISABLE_DISCOVERY = 2;
    private final byte MSG_ENABLE_DISCOVERY = 1;
    private final byte MSG_FINISH_TEST = 3;
    private final int NFC_DISCOVERY_CHANGE_DELAY = 500;
    private final int NFC_FINISH_DELAY = 2000;
    private final int NFC_TIMEOUT_DELAY = 10000;
    private int mDetectingCount = 0;
    public Handler mHandler = new Handler() {
        /* class com.sec.factory.modules.FactoryNfcTestService.AnonymousClass1 */

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    FtUtil.log_i(FactoryNfcTestService.CLASS_NAME, "send Intent ENABLE_SEC_NFC_DISCOVERY");
                    FactoryNfcTestService.this.sendBroadcast(ModuleNfc.NfcFunctions.NFC_ENABLE_DISCOVERY.getNfcIntent());
                    return;
                case 2:
                    FtUtil.log_i(FactoryNfcTestService.CLASS_NAME, "send Intent DISABLE_SEC_NFC_DISCOVERY");
                    FactoryNfcTestService.this.sendBroadcast(ModuleNfc.NfcFunctions.NFC_DISABLE_DISCOVERY.getNfcIntent());
                    return;
                case 3:
                    FtUtil.log_i(FactoryNfcTestService.CLASS_NAME, "MSG_FINISH_TEST");
                    FactoryNfcTestService.this.mHandler.removeMessages(3);
                    if (FactoryNfcTestService.this.mIsPassed_reader) {
                        FtUtil.log_d(FactoryNfcTestService.CLASS_NAME, "handleMessage", FtUtil.setMspSeqMessage(4, FactoryNfcTestService.CLASS_NAME, "(NFC_FT) PASS - Reader Mode Test"));
                        FactoryNfcTestService.this.setTestResult((byte) 9, (byte) 80);
                        if (FactoryNfcTestService.this.mNfcDetectFile != null) {
                            Support.Kernel.writeToPathNsync(FactoryNfcTestService.this.mNfcDetectFile.getPath(), Integer.toString(FactoryNfcTestService.this.mDetectingCount));
                        }
                        FactoryNfcTestService.this.stopSelf();
                    } else {
                        FtUtil.log_d(FactoryNfcTestService.CLASS_NAME, "handleMessage", FtUtil.setMspSeqMessage(4, FactoryNfcTestService.CLASS_NAME, "(NFC_FT) FAIL - Reader Mode Test"));
                        FactoryNfcTestService.this.setTestResult((byte) 9, (byte) 70);
                    }
                    FactoryNfcTestService.this.stopSelf();
                    return;
                default:
                    return;
            }
        }
    };
    private boolean mIsPassed_reader = false;
    private File mNfcDetectFile;
    private final BroadcastReceiver mReceiver = new BroadcastReceiver() {
        /* class com.sec.factory.modules.FactoryNfcTestService.AnonymousClass2 */

        public void onReceive(Context context, Intent intent) {
            if ("android.nfc.action.TAG_DISCOVERED".equals(intent.getAction())) {
                FtUtil.log_i(FactoryNfcTestService.CLASS_NAME, "Received ACTION_TAG_DISCOVERED");
                if (0 == 1) {
                    FtUtil.log_d(FactoryNfcTestService.CLASS_NAME, "onReceive", "NFC Type is a SEN82AB Type.");
                    FactoryNfcTestService.this.mIsPassed_reader = true;
                } else {
                    String[] techList = ((Tag) intent.getParcelableExtra("android.nfc.extra.TAG")).getTechList();
                    boolean isJapan = context.getPackageManager().hasSystemFeature(ModuleNfc.NFC_GLOBAL_FELICA_FEATURE);
                    FtUtil.log_d(FactoryNfcTestService.CLASS_NAME, "onReceive", "FELICA : isJapan - " + isJapan);
                    if (techList == null) {
                        FtUtil.log_d(FactoryNfcTestService.CLASS_NAME, "onReceive", "tech list is null");
                    } else {
                        for (String tech : techList) {
                            if (!isJapan && ModuleNfc.NFC_TECH_TYPE_A.equals(tech)) {
                                FtUtil.log_d(FactoryNfcTestService.CLASS_NAME, "onReceive", "tech type : A is pass");
                                FactoryNfcTestService.this.mIsPassed_reader = true;
                            } else if (isJapan && ModuleNfc.NFC_TECH_TYPE_F.equals(tech)) {
                                FtUtil.log_d(FactoryNfcTestService.CLASS_NAME, "onReceive", "tech type : F is pass");
                                FactoryNfcTestService.this.mIsPassed_reader = true;
                            }
                        }
                    }
                }
                FactoryNfcTestService.access$308(FactoryNfcTestService.this);
                FactoryNfcTestService.this.mHandler.sendEmptyMessageDelayed(3, 2000);
            }
        }
    };

    static /* synthetic */ int access$308(FactoryNfcTestService x0) {
        int i = x0.mDetectingCount;
        x0.mDetectingCount = i + 1;
        return i;
    }

    public void onCreate() {
        FtUtil.log_i(CLASS_NAME, "onCreate");
        super.onCreate();
        try {
            FtUtil.log_i(CLASS_NAME, "Stability Delay (ms) : " + 1000);
            Thread.sleep((long) 1000);
        } catch (Exception e) {
            e.printStackTrace();
        }
        File file = new File("data/log/NfcDetecting_cmd.log");
        this.mNfcDetectFile = file;
        Support.Kernel.writeToPathNsync(file.getPath(), "0");
        IntentFilter filter = new IntentFilter();
        filter.addAction("android.nfc.action.TAG_DISCOVERED");
        registerReceiver(this.mReceiver, filter);
        sendBroadcast(ModuleNfc.NfcFunctions.NFC_START_SEC_NFC_TEST.getNfcIntent());
        nfctest();
    }

    public IBinder onBind(Intent intent) {
        return null;
    }

    public void onDestroy() {
        FtUtil.log_i(CLASS_NAME, "onDestroy");
        this.mHandler.removeMessages(2);
        this.mHandler.removeMessages(1);
        this.mHandler.removeMessages(3);
        super.onDestroy();
        sendBroadcast(ModuleNfc.NfcFunctions.NFC_END_SEC_NFC_TEST.getNfcIntent());
        try {
            Thread.sleep(100);
        } catch (InterruptedException e) {
        }
        sendBroadcast(ModuleNfc.NfcFunctions.NFC_DISABLE_DISCOVERY.getNfcIntent());
        unregisterReceiver(this.mReceiver);
    }

    private void nfctest() {
        FtUtil.log_i(CLASS_NAME, "*** Start nfctest ***");
        this.mHandler.sendEmptyMessageDelayed(3, 10000);
        this.mHandler.sendEmptyMessageDelayed(2, 0);
        this.mHandler.sendEmptyMessageDelayed(1, 0 + 500);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setTestResult(byte id, byte result) {
        FtUtil.log_i(CLASS_NAME, "setTestResult", "ID : " + ((int) id) + " , RESULT :" + ((int) result));
        int itemid = FactoryTestManager.getItemPosition_ID(id);
        if (itemid > -1) {
            FtUtil.log_i(CLASS_NAME, "setTestResult", "itemID : " + itemid);
            FactoryTestManager.setItemResult(itemid, result);
            FactoryTestManager.notifyDataSetChanged();
        }
    }
}
