package com.sec.factory.modules;

import android.app.Service;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.provider.Settings;
import com.sec.factory.aporiented.athandler.AtMulfuncf;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.common.CommonFingerprintEgis;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.NVAccessor;
import java.lang.ref.WeakReference;
import java.util.ArrayList;

public class FingerprintServiceEgis extends Service {
    private static final String CLASS_NAME = "FingerprintServiceEgis";
    private CommonFingerprintEgis mCommonFingerprintEgis;
    private final StatusHandler mHandler = new StatusHandler(this);
    private boolean mIsPassNormalScan = false;
    private boolean mIsPassSnr = false;
    private boolean mIsRunning = false;
    private BroadcastReceiver mReceiver;
    private CommonFingerprintEgis.STEP mSTEP = CommonFingerprintEgis.STEP.NOTEST;

    public void onCreate() {
        FtUtil.log_d(CLASS_NAME, "onCreate");
        CommonFingerprintEgis instance = CommonFingerprintEgis.instance(this);
        this.mCommonFingerprintEgis = instance;
        instance.setHandler(this.mHandler);
        registerReceiver();
        super.onCreate();
    }

    public IBinder onBind(Intent intent) {
        return null;
    }

    public int onStartCommand(Intent intent, int flags, int startId) {
        if (!this.mIsRunning) {
            FtUtil.log_d(CLASS_NAME, "onStartCommand");
            this.mIsRunning = true;
            this.mSTEP = CommonFingerprintEgis.STEP.NORMALSCAN;
            Settings.System.putString(getContentResolver(), "fp_test_step", this.mSTEP.name());
            new Thread(new Runnable() {
                /* class com.sec.factory.modules.FingerprintServiceEgis.AnonymousClass1 */

                public void run() {
                    ArrayList<CommonFingerprintEgis.FpTestItem> mListFpTestNormalScan = FingerprintServiceEgis.this.mCommonFingerprintEgis.startNormalScan();
                    FingerprintServiceEgis fingerprintServiceEgis = FingerprintServiceEgis.this;
                    fingerprintServiceEgis.mIsPassNormalScan = fingerprintServiceEgis.isPassTest(mListFpTestNormalScan, fingerprintServiceEgis.mSTEP.name());
                    if (!FingerprintServiceEgis.this.mIsPassNormalScan || CommonFingerprintEgis.isOptical()) {
                        FtUtil.log_d(FingerprintServiceEgis.CLASS_NAME, "onStartCommand", "stopSelf");
                        NVAccessor.setNV(67, (byte) 70);
                        FingerprintServiceEgis.this.stopSelf();
                        return;
                    }
                    FingerprintServiceEgis.this.mCommonFingerprintEgis.initSnrCapTest();
                }
            }).start();
            return 2;
        }
        FtUtil.log_e(CLASS_NAME, "onStartCommand", "isRunning");
        return 2;
    }

    public void onDestroy() {
        FtUtil.log_d(CLASS_NAME, "onDestroy");
        Settings.System.putString(getContentResolver(), "fp_test_step", CommonFingerprintEgis.STEP.NOTEST.name());
        Settings.System.putString(getContentResolver(), "fp_test_status", CommonFingerprintEgis.STATUS.NOTEST.name());
        unregisterReceiver();
        this.mCommonFingerprintEgis.setHandler(null);
        super.onDestroy();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean isPassTest(ArrayList<CommonFingerprintEgis.FpTestItem> listFpTestItem, String tag) {
        boolean isAllPass = true;
        for (int i = 0; i < listFpTestItem.size(); i++) {
            FtUtil.log_d(CLASS_NAME, "isPassTest[" + tag + "]", listFpTestItem.get(i).toString());
            if (!listFpTestItem.get(i).getIsPass()) {
                isAllPass = false;
            }
        }
        return isAllPass;
    }

    private void endTest() {
        FtUtil.log_d(CLASS_NAME, "endTest", "normalScan: " + this.mIsPassNormalScan + ", snr : " + this.mIsPassSnr);
        if (!this.mIsPassNormalScan || !this.mIsPassSnr) {
            NVAccessor.setNV(67, (byte) 70);
        } else {
            FactoryTestManager.setItemResult(FactoryTestManager.getItemPosition_ID(67), (byte) 80);
            FactoryTestManager.notifyDataSetChanged();
        }
        stopSelf();
    }

    private void registerReceiver() {
        FtUtil.log_d(CLASS_NAME, "RegisterReceiver");
        IntentFilter filter = new IntentFilter();
        filter.addAction(AtMulfuncf.MSG_SNR_START_BUTTON_PRESSED);
        AnonymousClass2 r1 = new BroadcastReceiver() {
            /* class com.sec.factory.modules.FingerprintServiceEgis.AnonymousClass2 */

            public void onReceive(Context context, Intent intent) {
                String action = intent.getAction();
                FtUtil.log_d(FingerprintServiceEgis.CLASS_NAME, "onReceive", " Action:" + action);
                if (AtMulfuncf.MSG_SNR_START_BUTTON_PRESSED.equals(action)) {
                    FtUtil.log_d(FingerprintServiceEgis.CLASS_NAME, "onReceive", "performClick by broadcasting");
                    FingerprintServiceEgis.this.mCommonFingerprintEgis.startSnrCapTest();
                }
            }
        };
        this.mReceiver = r1;
        registerReceiver(r1, filter);
    }

    private void unregisterReceiver() {
        if (this.mReceiver != null) {
            FtUtil.log_d(CLASS_NAME, "unregisterReceiver");
            unregisterReceiver(this.mReceiver);
            this.mReceiver = null;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleMessage(Message msg) {
        FtUtil.log_d(CLASS_NAME, "handleMessage", "msg.what : " + msg.what + ", msg.arg1 : " + msg.arg1 + ", msg.arg2 : " + msg.arg2);
        switch (msg.what) {
            case 208:
                this.mSTEP = CommonFingerprintEgis.STEP.SNR;
                Settings.System.putString(getContentResolver(), "fp_test_step", this.mSTEP.name());
                Settings.System.putString(getContentResolver(), "fp_test_status", CommonFingerprintEgis.STATUS.READY.name());
                return;
            case 500:
                if (this.mSTEP == CommonFingerprintEgis.STEP.SNR) {
                    this.mIsPassSnr = isPassTest((ArrayList) msg.obj, this.mSTEP.name());
                    endTest();
                    return;
                }
                return;
            default:
                return;
        }
    }

    private static class StatusHandler extends Handler {
        private final WeakReference<FingerprintServiceEgis> mService;

        public StatusHandler(FingerprintServiceEgis service) {
            this.mService = new WeakReference<>(service);
        }

        public void handleMessage(Message msg) {
            FingerprintServiceEgis service = this.mService.get();
            if (service != null) {
                service.handleMessage(msg);
            }
        }
    }
}
