package com.sec.factory.modules;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import com.sec.factory.support.FtUtil;

public class FirmwareVersionReaderIntent {
    public static final String ACTION_NFC_TEST_REQUEST = "com.samsung.android.nfc.test.action.REQUEST";
    public static final String ACTION_NFC_TEST_RESPONSE = "com.samsung.android.nfc.test.action.RESPONSE";
    public static final String ACTION_REQUEST_NFC_FIRMWARE = "services.nfc.action.GET_FIRMWARE_VERSION_SYSTEM";
    public static final String ACTION_REQUEST_NFC_FIRMWARE_LEGACY = "services.nfc.action.GET_FIRMWARE_VERSION";
    public static final String ACTION_REQUEST_WIFI_FIRMWARE = "com.sec.android.app.wlantest.WIFI_VER_INFO";
    public static final String ACTION_RESPONSE_NFC_FIRMWARE = "services.nfc.action.GET_FIRMWARE_VERSION_RESPONSE";
    public static final String ACTION_RESPONSE_WIFI_FIRMWARE = "com.sec.android.app.wlantest.WIFI_VER_RESPONSE";
    public static final int CHECK_FIRMWARE_VERSION = 8;
    public static final String EXTRA_ID = "com.samsung.android.nfc.test.extra.ID";
    private static final String EXTRA_NFC_VENDOR = "vendor";
    private static final String EXTRA_NFC_VERSION = "version";
    public static final String EXTRA_PACKAGE = "com.samsung.android.nfc.test.extra.PACKAGE";
    public static final String EXTRA_VENDOR = "com.samsung.android.nfc.test.extra.VENDOR";
    public static final String EXTRA_VERSION = "com.samsung.android.nfc.test.extra.VERSION";
    private static final String EXTRA_WIFI_VERSION = "S_DATA";
    private String CLASS_NAME;
    private BroadcastReceiver mBroadcastReceiver;
    private Context mContext;
    private FirmwareListener mFirmwareListener;
    private String mFirmwareVersion = null;
    private long mStartTime = -1;
    private long mTimeOut = -1;

    public interface FirmwareListener {
        void onUpdateResult(String str);
    }

    public FirmwareVersionReaderIntent(String TAG, Context context, FirmwareListener listener) {
        this.CLASS_NAME = TAG + "FirmwareVersionReaderIntent";
        this.mContext = context;
        this.mFirmwareListener = listener;
    }

    public void registerReceiver(String action, long timeOut) {
        this.mStartTime = System.currentTimeMillis();
        this.mTimeOut = timeOut;
        registerReceiver(action);
    }

    public void registerReceiver(String action) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "registerReceiver action = " + action);
        if (this.mBroadcastReceiver == null) {
            this.mBroadcastReceiver = new BroadcastReceiver() {
                /* class com.sec.factory.modules.FirmwareVersionReaderIntent.AnonymousClass1 */

                public void onReceive(Context context, Intent intent) {
                    FtUtil.log_d(FirmwareVersionReaderIntent.this.CLASS_NAME, "onReceive = " + intent.getAction());
                    if (FirmwareVersionReaderIntent.ACTION_RESPONSE_NFC_FIRMWARE.equalsIgnoreCase(intent.getAction())) {
                        String vendor2 = intent.getStringExtra(FirmwareVersionReaderIntent.EXTRA_NFC_VENDOR);
                        String version = intent.getStringExtra(FirmwareVersionReaderIntent.EXTRA_NFC_VERSION);
                        FtUtil.log_d(FirmwareVersionReaderIntent.this.CLASS_NAME, "vendor = " + vendor2, ", version = " + version);
                        FirmwareVersionReaderIntent.this.mFirmwareVersion = vendor2 + version;
                    } else if (FirmwareVersionReaderIntent.ACTION_RESPONSE_WIFI_FIRMWARE.equalsIgnoreCase(intent.getAction())) {
                        String version2 = intent.getStringExtra(FirmwareVersionReaderIntent.EXTRA_WIFI_VERSION);
                        FtUtil.log_d(FirmwareVersionReaderIntent.this.CLASS_NAME, ", version = " + version2);
                        FirmwareVersionReaderIntent.this.mFirmwareVersion = version2;
                    } else if ("com.samsung.android.nfc.test.action.RESPONSE".equalsIgnoreCase(intent.getAction())) {
                        if (intent.getIntExtra("com.samsung.android.nfc.test.extra.ID", -1) == 8) {
                            String vendor3 = intent.getStringExtra(FirmwareVersionReaderIntent.EXTRA_VENDOR);
                            String version3 = intent.getStringExtra(FirmwareVersionReaderIntent.EXTRA_VERSION);
                            FtUtil.log_d(FirmwareVersionReaderIntent.this.CLASS_NAME, "vendor = " + vendor3, ", version = " + version3);
                            FirmwareVersionReaderIntent.this.mFirmwareVersion = vendor3 + version3;
                        } else {
                            FtUtil.log_e(FirmwareVersionReaderIntent.this.CLASS_NAME, "Unknown ID: " + intent.getIntExtra("com.samsung.android.nfc.test.extra.ID", -1));
                        }
                    }
                    if (FirmwareVersionReaderIntent.this.mFirmwareVersion == null) {
                        FirmwareVersionReaderIntent.this.mFirmwareVersion = "N";
                    }
                    if (FirmwareVersionReaderIntent.this.mFirmwareListener == null) {
                        FtUtil.log_w(FirmwareVersionReaderIntent.this.CLASS_NAME, "onReceive = mFirmwareListener is null");
                        return;
                    }
                    FtUtil.log_d(FirmwareVersionReaderIntent.this.CLASS_NAME, "return = " + FirmwareVersionReaderIntent.this.mFirmwareVersion);
                    FirmwareVersionReaderIntent.this.mFirmwareListener.onUpdateResult(FirmwareVersionReaderIntent.this.mFirmwareVersion);
                }
            };
        }
        this.mContext.registerReceiver(this.mBroadcastReceiver, new IntentFilter(action));
    }

    public void unRegisterReceiver() {
        FtUtil.log_d(this.CLASS_NAME, "unRegisterReceiver");
        BroadcastReceiver broadcastReceiver = this.mBroadcastReceiver;
        if (broadcastReceiver == null) {
            FtUtil.log_w(this.CLASS_NAME, "unRegisterReceiver = mBroadcastReceiver is null");
            return;
        }
        this.mContext.unregisterReceiver(broadcastReceiver);
        this.mBroadcastReceiver = null;
    }

    public void sendRequest(String action) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "sendRequest = " + action);
        Intent intent = new Intent(action);
        intent.setFlags(268435456);
        intent.putExtra("package", this.mContext.getPackageName());
        this.mContext.sendBroadcast(intent);
    }

    public void sendRequest(Intent intent) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "sendRequest = " + intent.getAction());
        intent.setFlags(268435456);
        intent.putExtra(EXTRA_PACKAGE, this.mContext.getPackageName());
        this.mContext.sendBroadcast(intent);
    }

    public String getFirmwareVersion() {
        if (this.mStartTime == -1 || this.mTimeOut == -1) {
            String str = this.CLASS_NAME;
            FtUtil.log_d(str, "getFirmwareVersion not setted Time out return = " + this.mFirmwareVersion);
            return this.mFirmwareVersion;
        }
        while (this.mFirmwareVersion == null && System.currentTimeMillis() - this.mStartTime < this.mTimeOut) {
            FtUtil.Sleep.sleep(100);
        }
        String str2 = this.mFirmwareVersion;
        if (str2 == null || str2.isEmpty() || "null".equalsIgnoreCase(this.mFirmwareVersion)) {
            this.mFirmwareVersion = "N";
        }
        return this.mFirmwareVersion;
    }

    @Deprecated
    public void setListener(FirmwareListener listener) {
        FtUtil.log_w(this.CLASS_NAME, "setListener", listener.toString());
        this.mFirmwareListener = listener;
    }
}
