package com.sec.factory.modules;

import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.media.AudioManager;
import android.media.AudioRecord;
import android.media.AudioTrack;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import com.sec.factory.R;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import sec.audio.solution.FactoryRMS;

public class MicEchoService extends Service {
    private static final String CLASS_NAME = "MicEchoService";
    public static final int MIC1 = 0;
    public static final int MIC1MIC2 = 4;
    public static final int MIC2 = 1;
    public static final int MIC3 = 2;
    public static final int UPDATE_RMS = 0;
    public static final int UPDATE_RMS_FOR_3MIC = 1;
    private String DataDestpath = "/data/log";
    private String MicEchoFilePath = "/data/log/MicEchoData.txt";
    public int STATE = 4;
    private AudioPlayer mAudioPlayer;
    private AudioRecording mAudioRecording;
    FactoryRMS mFactoryRMS;
    public Handler mHandler = new Handler() {
        /* class com.sec.factory.modules.MicEchoService.AnonymousClass1 */

        public void handleMessage(Message msg) {
            if (msg.what == 0) {
                FtUtil.log_d(MicEchoService.CLASS_NAME, "mHandler.handleMessage", "UPDATE_RMS, msg.arg1=" + msg.arg1 + ", msg.arg2=" + msg.arg2);
                MicEchoService.this.update(new int[]{msg.arg1, msg.arg2});
            } else if (msg.what == 1) {
                FtUtil.log_d(MicEchoService.CLASS_NAME, "mHandler.handleMessage", "UPDATE_RMS, msg.arg1=" + msg.arg1 + ", msg.arg2=" + msg.arg2 + ", msg.obj=" + msg.obj);
                MicEchoService.this.update(new int[]{msg.arg1, msg.arg2, ((Integer) msg.obj).intValue()});
            }
        }
    };
    public boolean mIs3MicTest = false;
    TestInfo[] mTestItemInfo;

    public static class TestInfo {
        private static final String CLASS_NAME = "MicEchoService.TestInfo";
        public static int EMPTY_DATA = Integer.MIN_VALUE;
        public static int MEASURE_MAX_COUNT = 3;
        public static boolean SWAP_RMS_LEFT_RIGHT = false;
        public static boolean TESTCASE_MIC_SEQUENTIAL = false;
        public Context mContext;
        public boolean mIsSupport = false;
        public boolean mIsTestComplete = false;
        private ArrayList<Integer> mMeasuredData = new ArrayList<>();
        public int mSpecInCount = 0;
        public int mSpecMAX;
        public int mSpecMIN;
        private String mTag = "MIC";

        TestInfo(Context context) {
            this.mContext = context;
        }

        public void setTag(String tag) {
            this.mTag = tag;
        }

        public boolean addMeasure(int data) {
            if (this.mIsTestComplete) {
                FtUtil.log_d(CLASS_NAME, "addMeasure", "mIsTestComplete true, mTag: " + this.mTag);
                return true;
            } else if (data == EMPTY_DATA) {
                FtUtil.log_d(CLASS_NAME, "addMeasure", "skip rms empty data mTag: " + this.mTag);
                return false;
            } else {
                this.mMeasuredData.add(Integer.valueOf(data));
                if (this.mMeasuredData.size() < MEASURE_MAX_COUNT) {
                    return false;
                }
                this.mIsTestComplete = true;
                return true;
            }
        }

        public ArrayList<Integer> getMeasuredData() {
            return this.mMeasuredData;
        }

        public static void printCondition() {
            FtUtil.log_d(CLASS_NAME, "printCondition", "MEASURE_MAX_COUNT: " + MEASURE_MAX_COUNT);
            FtUtil.log_d(CLASS_NAME, "printCondition", "TESTCASE_MIC_SEQUENTIAL: " + TESTCASE_MIC_SEQUENTIAL);
            FtUtil.log_d(CLASS_NAME, "printCondition", "SWAP_RMS_LEFT_RIGHT: " + SWAP_RMS_LEFT_RIGHT);
        }
    }

    public int onStartCommand(Intent intent, int flags, int startId) {
        initialize();
        testStart();
        return super.onStartCommand(intent, flags, startId);
    }

    /* access modifiers changed from: protected */
    public void setTestFeature() {
        TestInfo.MEASURE_MAX_COUNT = 3;
        TestInfo.TESTCASE_MIC_SEQUENTIAL = true;
        this.mAudioPlayer.setEnable(true);
        TestInfo.SWAP_RMS_LEFT_RIGHT = false;
        if (containsTestCase("SWAP_RMS_LR")) {
            TestInfo.SWAP_RMS_LEFT_RIGHT = true;
        }
        TestInfo.printCondition();
    }

    private boolean containsTestCase(String param) {
        String testcase = Support.FactoryTestMenu.getTestCase(FactoryTestManager.convertorID_XML((byte) FactoryTestManager.TEST_ECHO_TEST));
        if (testcase == null || !testcase.toLowerCase().contains(param.toLowerCase())) {
            return false;
        }
        return true;
    }

    private boolean setTestItemInfo() {
        String specRaw = Support.FactoryTestMenu.getSpec(FactoryTestManager.convertorID_XML((byte) FactoryTestManager.TEST_ECHO_TEST));
        FtUtil.log_d(CLASS_NAME, "init", specRaw);
        String[] arraySpec = specRaw != null ? specRaw.split(",") : null;
        if (arraySpec == null) {
            FtUtil.log_e(CLASS_NAME, "init", "No Spec data");
            return false;
        }
        SetKindOfTest(arraySpec);
        this.mTestItemInfo = new TestInfo[arraySpec.length];
        for (int i = 0; i < arraySpec.length; i++) {
            this.mTestItemInfo[i] = new TestInfo(this);
            String[] minMaxSpec = arraySpec != null ? arraySpec[i].split("~") : null;
            if (minMaxSpec.length != 2) {
                FtUtil.log_e(CLASS_NAME, "init", "Wrong spec");
            } else {
                FtUtil.log_d(CLASS_NAME, "init", "arraySpec " + i + ": " + arraySpec[i]);
                try {
                    this.mTestItemInfo[i].mSpecMIN = Integer.parseInt(minMaxSpec[0]);
                    this.mTestItemInfo[i].mSpecMAX = Integer.parseInt(minMaxSpec[1]);
                } catch (NumberFormatException ne) {
                    this.mTestItemInfo[i].mSpecMIN = -1;
                    this.mTestItemInfo[i].mSpecMAX = -1;
                    FtUtil.log_e(ne);
                }
                this.mTestItemInfo[i].mIsSupport = true;
            }
            switch (i) {
                case 0:
                    this.mTestItemInfo[i].mTag = "MIC1";
                    break;
                case 1:
                    this.mTestItemInfo[i].mTag = "MIC2";
                    break;
                case 2:
                    this.mTestItemInfo[i].mTag = "MIC3";
                    break;
            }
        }
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void update(int[] rms) {
        FtUtil.log_d(CLASS_NAME, "update", null);
        boolean checkResult = true;
        if (this.mTestItemInfo.length > 0) {
            int i = 0;
            while (true) {
                TestInfo[] testInfoArr = this.mTestItemInfo;
                if (i >= testInfoArr.length) {
                    break;
                }
                if (!testInfoArr[i].addMeasure(rms[i])) {
                    checkResult = false;
                }
                i++;
            }
            FtUtil.log_d(CLASS_NAME, "update", "checkResult : " + checkResult);
            if (checkResult) {
                testStop();
            }
            if (checkResult()) {
                createLogFile();
            }
        }
    }

    private boolean checkResult() {
        boolean result = true;
        int i = 0;
        while (true) {
            TestInfo[] testInfoArr = this.mTestItemInfo;
            if (i < testInfoArr.length) {
                if (!testInfoArr[i].mIsSupport || !this.mTestItemInfo[i].mIsTestComplete) {
                    result = false;
                }
                i++;
            } else {
                FtUtil.log_d(CLASS_NAME, "checkResult", "result: " + result);
                return result;
            }
        }
    }

    private void testStop() {
        FtUtil.log_d(CLASS_NAME, "testStop", "");
        AudioRecording audioRecording = this.mAudioRecording;
        if (audioRecording != null && audioRecording.stopRecording()) {
            this.mAudioRecording = null;
        }
        this.mAudioPlayer.stopSound();
    }

    private void testStart() {
        FtUtil.log_d(CLASS_NAME, "testStart", "");
        this.STATE = 4;
        this.mAudioPlayer.playSound(1, 80);
        if (!TestInfo.TESTCASE_MIC_SEQUENTIAL) {
            this.mAudioRecording = new AudioRecording(this, this.mHandler);
        } else if (this.mIs3MicTest) {
            this.mAudioRecording = new AudioRecordingMic1Mic2Mic3Sequentially(this, this.mHandler);
        } else {
            this.mAudioRecording = new AudioRecordingMic1Mic2Sequentially(this, this.mHandler);
        }
        this.mAudioRecording.initInputSetting("factory_test_mic_check=main");
        this.mAudioRecording.startRecording();
    }

    public void SetKindOfTest(String[] arraySpec) {
        if (arraySpec.length == 3) {
            this.mIs3MicTest = true;
        }
    }

    public class AudioRecording {
        protected static final int AUDIO_FORMAT = 2;
        protected static final String AUDIO_PARAMETER_L_VALUE = "L_value=";
        protected static final String AUDIO_PARAMETER_R_VALUE = "R_value=";
        protected static final int CHANNEL_CONFIG = 12;
        protected static final int DURATION_MIC_TEST_ON_OFF = 200;
        protected static final int SAMPLE_RATE = 16000;
        protected String CLASS_NAME = "MicEchoService.AudioRecording";
        protected int audioSource = 5;
        byte[] buffer = null;
        public boolean initDataFlag = true;
        protected AudioManager mAudioManager;
        protected int mBufferSize = 0;
        protected Handler mHandler;
        protected boolean mIsRecording = false;
        protected int mReadBytes = 0;
        protected AudioRecord mRecorder = null;
        public Thread mThread = null;

        AudioRecording(Context context, Handler handler) {
            this.mAudioManager = (AudioManager) context.getSystemService("audio");
            this.mHandler = handler;
        }

        /* access modifiers changed from: protected */
        public boolean initInputSetting(String path) {
            int minBufferSize = AudioTrack.getMinBufferSize(SAMPLE_RATE, 12, 2);
            this.mBufferSize = minBufferSize;
            int i = minBufferSize * 5;
            this.mBufferSize = i;
            this.buffer = new byte[i];
            this.mRecorder = new AudioRecord(this.audioSource, SAMPLE_RATE, 12, 2, this.mBufferSize);
            this.mReadBytes = 0;
            return false;
        }

        /* access modifiers changed from: protected */
        public int getParameter(String keys, String target) {
            FtUtil.log_d(this.CLASS_NAME, "MicTestRecoder.getParameter", "target: " + target);
            if (keys == null || keys.isEmpty() || target == null || target.isEmpty()) {
                return -1;
            }
            String param = ModuleCommunicationService.SMD_NOK;
            if (keys.contains(target)) {
                String[] values = keys.split(";");
                for (String value : values) {
                    if (value.startsWith(target)) {
                        param = value.replaceAll(target, "");
                    }
                }
            }
            FtUtil.log_d(this.CLASS_NAME, "MicTestRecoder.getParameter", "target param: " + param);
            if (param == null) {
                return -1;
            }
            try {
                return Integer.parseInt(param);
            } catch (NumberFormatException ne) {
                FtUtil.log_e(ne);
                return -1;
            }
        }

        public String getRMS() {
            String value = this.mAudioManager.getParameters("rms_value");
            String str = this.CLASS_NAME;
            FtUtil.log_d(str, "getRMS", "value: " + value);
            return value;
        }

        public short[] getRMSValue(byte[] data, int size) {
            String str = this.CLASS_NAME;
            FtUtil.log_d(str, "getRMS", "data length = " + data.length + ", size = " + size);
            if (MicEchoService.this.mFactoryRMS == null) {
                FtUtil.log_w(this.CLASS_NAME, "getRMS", "mFactoryRMS is null");
                return null;
            } else if (data == null || size <= 0) {
                FtUtil.log_w(this.CLASS_NAME, "getRMS", "data is null or size is lower than 0");
                return null;
            } else {
                MicEchoService.this.mFactoryRMS.Calc_RMS_init(size);
                MicEchoService.this.mFactoryRMS.Calc_RMS_exe(data, size);
                short[] lr = new short[2];
                MicEchoService.this.mFactoryRMS.Calc_RMS_deinit(lr);
                String str2 = this.CLASS_NAME;
                FtUtil.log_d(str2, "getRMS", "L=" + ((int) lr[0]) + ", R=" + ((int) lr[1]));
                return lr;
            }
        }

        public boolean startRecording() {
            FtUtil.log_d(this.CLASS_NAME, "startRecording", null);
            Thread thread = new Thread(new Runnable() {
                /* class com.sec.factory.modules.MicEchoService.AudioRecording.AnonymousClass1 */

                public void run() {
                    if (AudioRecording.this.mRecorder != null) {
                        AudioRecording.this.mRecorder.startRecording();
                        AudioRecording.this.mAudioManager.setParameters("factory_test_mic_check=on");
                        while (AudioRecording.this.mRecorder != null) {
                            AudioRecording.this.mIsRecording = true;
                            while (AudioRecording.this.mRecorder.getRecordingState() != 3) {
                                FtUtil.log_d(AudioRecording.this.CLASS_NAME, "waiting recording...", null);
                                try {
                                    Thread.sleep(50);
                                } catch (InterruptedException ie) {
                                    FtUtil.log_e(ie);
                                }
                            }
                            if (MicEchoService.this.STATE == 2) {
                                AudioRecording.this.mAudioManager.setParameters("factory_test_mic_check=third");
                            } else {
                                AudioRecording.this.mAudioManager.setParameters("factory_test_mic_check=2mic");
                            }
                            try {
                                Thread.sleep(200);
                                AudioRecording audioRecording = AudioRecording.this;
                                audioRecording.mReadBytes = audioRecording.mRecorder.read(AudioRecording.this.buffer, 0, AudioRecording.this.mBufferSize);
                                AudioRecording audioRecording2 = AudioRecording.this;
                                short[] lr = audioRecording2.getRMSValue(audioRecording2.buffer, AudioRecording.this.mReadBytes);
                                short s = lr[0];
                                short s2 = lr[1];
                                if (!AudioRecording.this.initDataFlag) {
                                    if (TestInfo.SWAP_RMS_LEFT_RIGHT) {
                                        FtUtil.log_d(AudioRecording.this.CLASS_NAME, "MicTestRecoder.doInBackground", "SWAP_RMS_LEFT_RIGHT");
                                        s2 = s;
                                        s = s2;
                                    }
                                    AudioRecording.this.updateInternal(s2, s);
                                } else {
                                    FtUtil.log_d(AudioRecording.this.CLASS_NAME, "MicTestRecoder.doInBackground", "Initial RMS Value is skipped");
                                    AudioRecording.this.initDataFlag = false;
                                }
                                if (AudioRecording.this.mThread.isInterrupted()) {
                                    break;
                                }
                            } catch (InterruptedException ie2) {
                                FtUtil.log_e(ie2);
                            }
                        }
                        if (AudioRecording.this.mRecorder != null) {
                            if (AudioRecording.this.mRecorder.getState() == 3) {
                                AudioRecording.this.mRecorder.stop();
                            }
                            AudioRecording.this.mRecorder.release();
                            AudioRecording.this.mRecorder = null;
                        }
                        AudioRecording.this.mIsRecording = false;
                    }
                }
            });
            this.mThread = thread;
            thread.start();
            FtUtil.log_d(this.CLASS_NAME, "startRecording", "Started");
            return true;
        }

        /* access modifiers changed from: protected */
        public void updateInternal(int rmsR, int rmsL) {
            Handler handler = this.mHandler;
            handler.sendMessage(handler.obtainMessage(0, rmsR, rmsL));
        }

        public boolean stopRecording() {
            FtUtil.log_d(this.CLASS_NAME, "stopRecording", null);
            FtUtil.log_d(this.CLASS_NAME, "micCheckOnOff", "factory_test_mic_check=off");
            this.mAudioManager.setParameters("factory_test_mic_check=off");
            this.initDataFlag = true;
            Thread thread = this.mThread;
            if (thread != null) {
                thread.interrupt();
                while (this.mIsRecording) {
                    try {
                        Thread.sleep(100);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            }
            this.mThread = null;
            FtUtil.log_d(this.CLASS_NAME, "stopRecording", "Done: ");
            return true;
        }
    }

    public class AudioRecordingMic1Mic2Sequentially extends AudioRecording {
        private int mMeasureCount = 0;

        AudioRecordingMic1Mic2Sequentially(Context context, Handler handler) {
            super(context, handler);
            this.CLASS_NAME = "MicEchoService.AudioRecordingMic1Mic2Sequentially";
            this.mMeasureCount = 0;
        }

        /* access modifiers changed from: protected */
        @Override // com.sec.factory.modules.MicEchoService.AudioRecording
        public void updateInternal(int rmsR, int rmsL) {
            this.mMeasureCount++;
            FtUtil.log_d(this.CLASS_NAME, "updateInternal", "mMeasureCount: " + this.mMeasureCount);
            int mic1 = rmsR;
            int mic2 = rmsL;
            if (this.mMeasureCount <= TestInfo.MEASURE_MAX_COUNT) {
                mic2 = TestInfo.EMPTY_DATA;
                if (this.mMeasureCount == TestInfo.MEASURE_MAX_COUNT) {
                    FtUtil.log_d(this.CLASS_NAME, "updateInternal", "initDataFlag set true");
                    this.initDataFlag = true;
                    MicEchoService.this.mAudioPlayer.setPath(2);
                    MicEchoService.this.mAudioPlayer.setVolumn(100);
                }
            } else {
                mic1 = TestInfo.EMPTY_DATA;
            }
            FtUtil.log_d(this.CLASS_NAME, "updateInternal", "mic1: " + mic1 + ", mic2: " + mic2);
            this.mHandler.sendMessage(this.mHandler.obtainMessage(0, mic1, mic2));
        }
    }

    public class AudioRecordingMic1Mic2Mic3Sequentially extends AudioRecording {
        private int mMeasureCount = 0;

        AudioRecordingMic1Mic2Mic3Sequentially(Context context, Handler handler) {
            super(context, handler);
            this.CLASS_NAME = "MicEchoService.AudioRecordingMic1Mic2Mic3Sequentially";
            this.mMeasureCount = 0;
        }

        /* access modifiers changed from: protected */
        @Override // com.sec.factory.modules.MicEchoService.AudioRecording
        public void updateInternal(int rmsR, int rmsL) {
            this.mMeasureCount++;
            FtUtil.log_d(this.CLASS_NAME, "updateInternal", "mMeasureCount: " + this.mMeasureCount);
            int mic1 = rmsR;
            int mic2 = rmsL;
            int mic3 = rmsR;
            Message mMsg = this.mHandler.obtainMessage();
            if (this.mMeasureCount <= TestInfo.MEASURE_MAX_COUNT) {
                mic2 = TestInfo.EMPTY_DATA;
                mic3 = TestInfo.EMPTY_DATA;
                if (this.mMeasureCount == TestInfo.MEASURE_MAX_COUNT) {
                    FtUtil.log_d(this.CLASS_NAME, "updateInternal", "initDataFlag set true");
                    this.initDataFlag = true;
                    MicEchoService.this.mAudioPlayer.setPath(2);
                    MicEchoService.this.mAudioPlayer.setVolumn(100);
                }
            } else if (this.mMeasureCount <= TestInfo.MEASURE_MAX_COUNT * 2) {
                mic1 = TestInfo.EMPTY_DATA;
                mic3 = TestInfo.EMPTY_DATA;
                if (this.mMeasureCount == TestInfo.MEASURE_MAX_COUNT * 2) {
                    FtUtil.log_d(this.CLASS_NAME, "updateInternal", "initDataFlag set true secondly");
                    this.initDataFlag = true;
                    MicEchoService.this.mAudioPlayer.setPath(1);
                    MicEchoService.this.mAudioPlayer.setVolumn(80);
                    MicEchoService.this.STATE = 2;
                }
            } else {
                mic1 = TestInfo.EMPTY_DATA;
                mic2 = TestInfo.EMPTY_DATA;
            }
            FtUtil.log_d(this.CLASS_NAME, "updateInternal", "mic1: " + mic1 + ", mic2: " + mic2 + ", mic3: " + mic3);
            mMsg.obj = Integer.valueOf(mic3);
            this.mHandler.sendMessage(this.mHandler.obtainMessage(1, mic1, mic2, mMsg.obj));
        }
    }

    public static class AudioPlayer {
        private static final String CLASS_NAME = "MicEchoService.AudioPlayer";
        public static final int PATH_RCV = 2;
        public static final int PATH_SPK = 1;
        private static int mLatestPath = 1;
        private static ModuleAudio mModuleAudio;
        private static boolean mPlayerEnable = false;
        private Context mContext;

        public AudioPlayer(Context context) {
            this.mContext = context;
        }

        public void setEnable(boolean enable) {
            FtUtil.log_d(CLASS_NAME, "setEnable", "enable: " + enable);
            mModuleAudio = ModuleAudio.instance(this.mContext);
            mPlayerEnable = enable;
        }

        public void setPath(int path) {
            int audioPath;
            FtUtil.log_d(CLASS_NAME, "setPath", "mPlayerEnable: " + mPlayerEnable);
            if (mPlayerEnable) {
                FtUtil.log_d(CLASS_NAME, "playSound", "path: " + path);
                switch (path) {
                    case 1:
                        audioPath = 0;
                        break;
                    case 2:
                        audioPath = 1;
                        break;
                    default:
                        audioPath = 0;
                        break;
                }
                mModuleAudio.setAudioPath(audioPath);
                mLatestPath = path;
            }
        }

        public void setVolumn(int volume) {
            FtUtil.log_d(CLASS_NAME, "setVolumn", "mPlayerEnable: " + mPlayerEnable);
            if (mPlayerEnable) {
                FtUtil.log_d(CLASS_NAME, "playSound", "volume: " + volume);
                mModuleAudio.setStreamMusicVolume(volume);
            }
        }

        public void playSound(int path, int volume) {
            FtUtil.log_d(CLASS_NAME, "playSound", "mPlayerEnable: " + mPlayerEnable);
            if (mPlayerEnable) {
                setPath(path);
                setVolumn(volume);
                playSound(R.raw.echo1000hz);
            }
        }

        public void playSound(int resourceId) {
            FtUtil.log_d(CLASS_NAME, "playSound", "mPlayerEnable: " + mPlayerEnable);
            if (mPlayerEnable) {
                mModuleAudio.playMedia(resourceId, true);
            }
        }

        public void stopSound() {
            FtUtil.log_d(CLASS_NAME, "stopSound", "mPlayerEnable: " + mPlayerEnable);
            if (mPlayerEnable) {
                if (!mModuleAudio.isPlayingSound()) {
                    FtUtil.log_d(CLASS_NAME, "stopSound", "not isPlayingSound");
                    return;
                }
                mModuleAudio.stopMedia();
                switch (mLatestPath) {
                    case 2:
                        FtUtil.log_d(CLASS_NAME, "stopSound", "sleep 200ms to avoid pop sound when changed path rcv > path off");
                        FtUtil.Sleep.sleep(200);
                        break;
                }
                mModuleAudio.setAudioPath(4);
            }
        }
    }

    public IBinder onBind(Intent intent) {
        return null;
    }

    private void initialize() {
        FtUtil.log_d(CLASS_NAME, "initialize");
        this.mAudioPlayer = new AudioPlayer(this);
        this.mFactoryRMS = new FactoryRMS();
        setTestFeature();
        setTestItemInfo();
    }

    private void createLogFile() {
        FileOutputStream fos = null;
        String strData = new String();
        File dataLogDirectory = new File(this.DataDestpath);
        File MicEchoDataFile = new File(this.MicEchoFilePath);
        if (!dataLogDirectory.exists()) {
            dataLogDirectory.mkdir();
        }
        if (!MicEchoDataFile.exists()) {
            try {
                MicEchoDataFile.createNewFile();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        try {
            FtUtil.log_d(CLASS_NAME, "createLogFile", null);
            FileOutputStream fos2 = new FileOutputStream(MicEchoDataFile, true);
            int i = 0;
            while (true) {
                TestInfo[] testInfoArr = this.mTestItemInfo;
                if (i < testInfoArr.length) {
                    Iterator<Integer> itr = testInfoArr[i].mMeasuredData.iterator();
                    while (itr.hasNext()) {
                        strData = strData + itr.next() + ",";
                    }
                    i++;
                } else {
                    String strData2 = strData.substring(0, strData.length() - 1);
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append(strData2);
                    stringBuffer.append("\n");
                    fos2.write(stringBuffer.toString().getBytes());
                    fos2.close();
                    try {
                        fos2.close();
                        return;
                    } catch (IOException e2) {
                        e2.printStackTrace();
                        return;
                    }
                }
            }
        } catch (FileNotFoundException e3) {
            e3.printStackTrace();
            if (0 != 0) {
                fos.close();
            }
        } catch (IOException e4) {
            e4.printStackTrace();
            if (0 != 0) {
                fos.close();
            }
        } catch (Throwable th) {
            if (0 != 0) {
                try {
                    fos.close();
                } catch (IOException e5) {
                    e5.printStackTrace();
                }
            }
            throw th;
        }
    }
}
