package com.sec.factory.modules;

import android.app.Service;
import android.content.Intent;
import android.media.AudioManager;
import android.media.AudioRecord;
import android.media.AudioTrack;
import android.os.Binder;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.os.SystemClock;
import com.sec.factory.support.FtUtil;

public class ModuleAudioService extends Service {
    private static final int AUDIO_FORMAT = 2;
    private static final int CHANNEL_CONFIG = 12;
    private static final String CLASS_NAME = "ModuleAudioService";
    private static final int LOOPBACK_TIME = 5;
    private static final int LOOPBACK_TIME_NO_DELAYED = 1;
    private static final int RING_BUFFER_SIZE = 6;
    private static final int SAMPLE_RATE = 44100;
    public static final int STATE_EAR_EAR = 0;
    public static final int STATE_MIC2_SPK = 2;
    public static final int STATE_MIC_RCV = 1;
    public static final int STOP_LOOP = 1;
    private int audioSource = 7;
    byte[] buffer = null;
    private AudioManager mAudioManager;
    private AudioTrack mAudioTrack = null;
    private final IBinder mBinder = new LocalBinder();
    private int mBufferSize = 0;
    private int mCurrentState = 0;
    public Handler mHandler = new Handler() {
        /* class com.sec.factory.modules.ModuleAudioService.AnonymousClass1 */

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    if (ModuleAudioService.this.mAudioTrack != null) {
                        if (ModuleAudioService.this.mAudioTrack.getState() == 3) {
                            ModuleAudioService.this.mAudioTrack.flush();
                            ModuleAudioService.this.mAudioTrack.stop();
                        }
                        ModuleAudioService.this.mAudioTrack.release();
                        ModuleAudioService.this.mAudioTrack = null;
                    }
                    if (ModuleAudioService.this.mRecorder != null) {
                        if (ModuleAudioService.this.mRecorder.getState() == 3) {
                            ModuleAudioService.this.mRecorder.stop();
                        }
                        ModuleAudioService.this.mRecorder.release();
                        ModuleAudioService.this.mRecorder = null;
                        return;
                    }
                    return;
                default:
                    return;
            }
        }
    };
    private boolean mIsPlaying = false;
    private boolean mIsRecording = false;
    private boolean mNoDelayFlag = false;
    private int mReadBytes = 0;
    private AudioRecord mRecorder = null;
    private Thread mThread = null;
    private int mWrittenBytes = 0;
    byte[][] ringBuffer;

    public class LocalBinder extends Binder {
        public LocalBinder() {
        }

        /* access modifiers changed from: package-private */
        public ModuleAudioService getService() {
            return ModuleAudioService.this;
        }
    }

    public void InitLoopBack() {
        FtUtil.log_i(CLASS_NAME, CLASS_NAME, "InitLoopBack");
        this.mAudioManager = (AudioManager) getSystemService("audio");
        int minBufferSize = AudioTrack.getMinBufferSize(SAMPLE_RATE, 12, 2);
        this.mBufferSize = minBufferSize;
        if (this.mNoDelayFlag) {
            this.mBufferSize = minBufferSize * 1;
        } else {
            this.mBufferSize = minBufferSize * 5;
        }
        this.buffer = new byte[this.mBufferSize];
        this.mRecorder = new AudioRecord(this.audioSource, SAMPLE_RATE, 12, 2, this.mBufferSize);
        this.mAudioTrack = new AudioTrack(3, SAMPLE_RATE, 12, 2, this.mBufferSize, 1);
    }

    public void onDestroy() {
        StopLoopBack();
        super.onDestroy();
    }

    public void onCreate() {
        FtUtil.log_i(CLASS_NAME, CLASS_NAME, "onCreate");
    }

    public int onStartCommand(Intent intent, int flags, int startId) {
        FtUtil.log_i(CLASS_NAME, CLASS_NAME, "onStartCommand");
        if (intent == null) {
            FtUtil.log_i(CLASS_NAME, CLASS_NAME, "intent == null");
            return 1;
        }
        this.mCurrentState = intent.getIntExtra("STATE", 1);
        this.mNoDelayFlag = intent.getBooleanExtra("NO_DELAY", false);
        FtUtil.log_i(CLASS_NAME, CLASS_NAME, "getState=" + this.mCurrentState);
        InitLoopBack();
        Thread thread = new Thread(new Runnable() {
            /* class com.sec.factory.modules.ModuleAudioService.AnonymousClass2 */

            public void run() {
                ModuleAudioService.this.StartLoopBack();
            }
        });
        this.mThread = thread;
        thread.start();
        return 1;
    }

    public boolean onUnbind(Intent intent) {
        return super.onUnbind(intent);
    }

    public IBinder onBind(Intent intent) {
        FtUtil.log_i(CLASS_NAME, CLASS_NAME, "onBind");
        return this.mBinder;
    }

    public void StartLoopBack() {
        FtUtil.log_i(CLASS_NAME, CLASS_NAME, "StartLoopBack");
        if (this.mAudioTrack != null && this.mRecorder != null) {
            setStreamVolumeMax();
            this.mRecorder.startRecording();
            this.mIsRecording = true;
            while (true) {
                AudioRecord audioRecord = this.mRecorder;
                if (audioRecord != null) {
                    int read = audioRecord.read(this.buffer, 0, this.mBufferSize);
                    this.mReadBytes = read;
                    if (-3 != read) {
                        AudioTrack audioTrack = this.mAudioTrack;
                        if (audioTrack == null) {
                            break;
                        } else if (!this.mIsRecording) {
                            FtUtil.log_i(CLASS_NAME, CLASS_NAME, "mIsRecording: false");
                            break;
                        } else {
                            this.mWrittenBytes += audioTrack.write(this.buffer, 0, read);
                            FtUtil.log_i(CLASS_NAME, CLASS_NAME, "Audio recorder written bytes = " + this.mWrittenBytes);
                        }
                    } else {
                        FtUtil.log_i(CLASS_NAME, CLASS_NAME, "Audio recording failed!!!");
                    }
                    if (!this.mIsPlaying && this.mWrittenBytes > this.mBufferSize / 2) {
                        AudioTrack audioTrack2 = this.mAudioTrack;
                        if (audioTrack2 == null) {
                            FtUtil.log_i(CLASS_NAME, CLASS_NAME, "AudioTrack create fail");
                        } else if (audioTrack2.getPlayState() != 3) {
                            FtUtil.log_i(CLASS_NAME, CLASS_NAME, "AudioTrack start playing...");
                            this.mAudioTrack.play();
                            this.mIsPlaying = true;
                        }
                    }
                    if (!this.mIsRecording) {
                        break;
                    }
                } else {
                    break;
                }
            }
            FtUtil.log_i(CLASS_NAME, CLASS_NAME, "StartLoopBack finished");
        }
    }

    public void StopLoopBack() {
        FtUtil.log_i(CLASS_NAME, CLASS_NAME, "StopLoopBack");
        this.mIsRecording = false;
        this.mHandler.sendEmptyMessageDelayed(1, 200);
        SystemClock.sleep(100);
    }

    private void setStreamVolumeMax() {
        FtUtil.log_i(CLASS_NAME, CLASS_NAME, "setVolumeMax");
        setStreamMusicVolumeMax();
    }

    private void setStreamMusicVolumeMax() {
        setStreamMusicVolume(100);
    }

    private void setStreamMusicVolume(int volume) {
        int volume2 = volume > 100 ? 100 : volume;
        int volume3 = volume2 < 0 ? 0 : volume2;
        FtUtil.log_i(CLASS_NAME, "setStreamMusicVolume", "volme=" + volume3);
        if (volume3 == 0) {
            this.mAudioManager.setStreamVolume(3, 0, 0);
            return;
        }
        AudioManager audioManager = this.mAudioManager;
        audioManager.setStreamVolume(3, (audioManager.getStreamMaxVolume(3) * volume3) / 100, 0);
    }
}
