package com.sec.factory.modules;

import android.app.ActivityManager;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.hardware.Camera;
import android.hardware.camera2.CameraAccessException;
import android.hardware.camera2.CameraManager;
import android.os.FactoryTest;
import android.os.SystemProperties;
import android.provider.Settings;
import android.support.v4.os.EnvironmentCompat;
import android.telephony.TelephonyManager;
import android.text.TextUtils;
import com.google.common.primitives.UnsignedBytes;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.io.File;
import java.io.IOException;
import java.security.MessageDigest;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.Calendar;
import java.util.Locale;
import java.util.Scanner;

public class ModuleCommon extends ModuleObject {
    private static final String ChipSetManufacture = Support.Feature.getString(Support.Feature.CHIPSET_MANUFACTURE);
    public static final String FACTORY_MODE = "OFF";
    private static final String FIRST_BOOT_FLAG = "com.sec.android.app.factorymode.first_boot_flag";
    public static final int FRONT_CAM = 1;
    private static final String FTCLIENT_FLAG = "com.sec.android.app.factorymode.ftclient";
    private static final String FTCLIENT_KEY = "com.sec.android.app.factorymode.ftclient.key";
    public static final String HDCP_RETURN_VALUE_NG = "NG";
    public static final String HDCP_RETURN_VALUE_NG_FIELD = "NG_FIELD";
    public static final String HDCP_RETURN_VALUE_NG_KEY = "NG_KEY";
    public static final String HDCP_RETURN_VALUE_OK = "OK";
    public static final int ID_HDCP_CHECK_2_0_INSTALL = 1;
    public static final int ID_HDCP_CHECK_ENCRYPTED_WIDEVINE_KEY_INSTALL = 4;
    public static final String KEYSTR_BLOCK_OFF = "OFF";
    public static final String KEYSTR_BLOCK_ON = "ON";
    private static final String KEY_FIRST_BOOT_FLAG = "factorymode.shortcut.skipped";
    public static final int KEY_LOCK = 1;
    private static final String KEY_RUNNING_FTCLIENT = "sys.factory.runningFtClient";
    public static final int KEY_UNLOCK = 0;
    public static final int REAR_CAM = 0;
    private static final String TEST_READY_FLAG = "com.sec.android.app.factorymode.15_test_ready_flag";
    public static final int TYPE_4G = 0;
    public static final int TYPE_5G_MMWAVE = 2;
    public static final int TYPE_5G_SUB6 = 1;
    public static final int TYPE_5G_SUB6_AND_MMWAVE = 3;
    public static final String USER_MODE = "ON";
    private static ModuleCommon mInstance = null;
    private static boolean[] mIsOpenedCamera = {false, false};
    private static String mSalesCode = "";
    public static boolean misForeground = false;
    private final long WIDEVINE_KEBOX_SIZE = 144;
    private final boolean isMTK;
    private final boolean isQualcomm;
    private final boolean isSLSI;
    private final boolean isSPRD;
    private Camera[] mCamera = new Camera[2];

    private ModuleCommon(Context context) {
        super(context, "ModuleCommon");
        String str = ChipSetManufacture;
        this.isSLSI = "S.LSI".equalsIgnoreCase(str);
        this.isQualcomm = "qualcomm".equalsIgnoreCase(str);
        this.isSPRD = "Spreadtrum".equalsIgnoreCase(str);
        this.isMTK = "MediaTek".equalsIgnoreCase(str);
        FtUtil.log_i(this.CLASS_NAME, "ModuleCommon", "Create ModuleCommon");
        String upperCase = SystemProperties.get("persist.omc.sales_code", "NONE").trim().toUpperCase(Locale.ENGLISH);
        mSalesCode = upperCase;
        if ("".equals(upperCase) || "NONE".equals(mSalesCode)) {
            mSalesCode = SystemProperties.get("ro.csc.sales_code");
        }
    }

    public static synchronized ModuleCommon instance(Context context) {
        ModuleCommon moduleCommon;
        synchronized (ModuleCommon.class) {
            if (mInstance == null) {
                mInstance = new ModuleCommon(context);
            }
            moduleCommon = mInstance;
        }
        return moduleCommon;
    }

    public void sleepThread(int time) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "sleepThread", "Thread sleep during : " + time + "ms...");
        try {
            Thread.sleep((long) time);
        } catch (InterruptedException e) {
            FtUtil.log_e(e);
        }
    }

    public void startForegroundService() {
        if (!misForeground) {
            FtUtil.log_i(this.CLASS_NAME, "startForegroundService", "start ForegroundService service");
            Intent intent = new Intent();
            intent.setClassName("com.sec.factory", "com.sec.factory.aporiented.ForegroundService");
            mContext.startService(intent);
            misForeground = true;
        }
    }

    private boolean isTopActivity15() {
        String topActivity = ((ActivityManager) getSystemService("activity")).getRunningTasks(1).get(0).topActivity.getPackageName();
        FtUtil.log_i(this.CLASS_NAME, "topActivity: ", topActivity);
        if (!topActivity.contains("com.sec.factory")) {
            return false;
        }
        FtUtil.log_i(this.CLASS_NAME, "isTopActivity15(): ", "sendBroadcast");
        return true;
    }

    public String getTopPackageName() {
        String strTopPackageName = ((ActivityManager) getSystemService("activity")).getRunningTasks(1).get(0).topActivity.getPackageName();
        FtUtil.log_i(this.CLASS_NAME, "getTopPackageName", strTopPackageName);
        return strTopPackageName;
    }

    public void goIdle() {
        FtUtil.log_i(this.CLASS_NAME, "goIdle", "Launch Home Activity");
        if (isTopActivity15()) {
            Intent stopFactoryIntent = new Intent();
            stopFactoryIntent.setAction("com.sec.samsung.STOP_FACTORY_TEST");
            sendBroadcast(stopFactoryIntent);
        }
        Intent i = new Intent();
        i.setAction("android.intent.action.MAIN");
        i.addCategory("android.intent.category.HOME");
        i.addFlags(32768);
        i.setFlags(335544320);
        startActivity(i);
    }

    public void goLcdtest() {
        FtUtil.log_i(this.CLASS_NAME, "goLcdtest", "Launch Lcd test Activity");
        Intent i = new Intent();
        i.setClassName("com.sec.android.app.hwmoduletest", "com.sec.android.app.hwmoduletest.HwModuleTest");
        i.setFlags(335544320);
        startActivity(i);
    }

    public void go15mode() {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "go15mode", "Bin Type : " + Support.Properties.get(Support.Properties.BINARY_TYPE));
        if (FactoryTest.isFactoryMode()) {
            FtUtil.log_i(this.CLASS_NAME, "go15mode", "Launch 15 test Activity");
            sendBroadcast(new Intent("android.intent.action.CLOSE_SYSTEM_DIALOGS"));
            Intent i = new Intent();
            i.setClassName("com.sec.factory", "com.sec.factory.app.factorytest.FactoryTestMain");
            i.setFlags(872415232);
            i.putExtra("atfunctest", true);
            startActivity(i);
        }
    }

    public boolean Request15FunctionTest(int test) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "Request15FunctionTest: ", "" + test);
        Intent i = new Intent();
        i.setAction("com.sec.factory.app.factorytest.TestMode");
        i.putExtra("testmode", test);
        sendBroadcast(i);
        return true;
    }

    public boolean RequestPretest(int test) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "RequestPretest", "" + test);
        Intent i = new Intent();
        i.setAction("com.sec.factory.app.factorytest.OneJigTestMode");
        i.putExtra("testmode", test);
        sendBroadcast(i);
        return true;
    }

    public int getKeyLockState() {
        return Settings.System.getInt(getContentResolver(), Support.Kernel.SHOULD_SHUT_DOWN, -1);
    }

    public void setKeyLock(int state) {
        Settings.System.putInt(getContentResolver(), Support.Kernel.SHOULD_SHUT_DOWN, state);
    }

    public void setAutoRotate(int state) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setAutoRotate", "state=" + state);
        Settings.System.putInt(getContentResolver(), "accelerometer_rotation", state);
    }

    public String readProxiOffset() {
        if (Support.Feature.getBoolean(Support.Feature.IS_PROXIMITY_AUTO_CALIBRATION)) {
            String OffsetValue = Support.Kernel.read(Support.Kernel.PROXI_SENSOR_DEFAULT_TRIM);
            String str = this.CLASS_NAME;
            FtUtil.log_i(str, "readProxiOffset", "OffsetValue = " + OffsetValue);
            return OffsetValue;
        }
        String offsetValue = Support.Kernel.read(Support.Kernel.PROXI_SENSOR_OFFSET);
        if (offsetValue != null) {
            String type = offsetValue.split(",")[0];
            String str2 = this.CLASS_NAME;
            FtUtil.log_i(str2, "readProxiOffset", "type=" + type);
            return type;
        }
        String type2 = this.CLASS_NAME;
        FtUtil.log_i(type2, "readProxiOffset", "type=" + offsetValue);
        return null;
    }

    public String readIrisProxiOffset() {
        String offsetValue = Support.Kernel.read(Support.Kernel.IRIS_PROXI_SENSOR_OFFSET);
        if (offsetValue != null) {
            String type = offsetValue.split(",")[0];
            String str = this.CLASS_NAME;
            FtUtil.log_i(str, "readIrisProxiOffset", "type=" + type);
            return type;
        }
        String type2 = this.CLASS_NAME;
        FtUtil.log_i(type2, "readIrisProxiOffset", "type=" + offsetValue);
        return null;
    }

    public String readProxiADC() {
        String type = Support.Kernel.read(Support.Kernel.PROXI_SENSOR_ADC);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readProxiADC", "type=" + type);
        return type;
    }

    public String readIrisProxiADC() {
        String type = Support.Kernel.read(Support.Kernel.IRIS_PROXI_SENSOR_ADC);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readIrisProxiADC", "type=" + type);
        return type;
    }

    public String readLcdType() {
        String type = Support.Kernel.read(Support.Kernel.LCD_TYPE_PATH);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readLcdType", "type=" + type);
        return type;
    }

    public String readSubLcdType() {
        String type = Support.Kernel.read(Support.Kernel.SUBLCD_TYPE_PATH);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readSubLcdType", "type=" + type);
        return type;
    }

    public boolean checkCameraHardware() {
        String[] camList = null;
        try {
            camList = ((CameraManager) mContext.getSystemService("camera")).getCameraIdList();
        } catch (CameraAccessException e) {
            FtUtil.log_e(e);
        }
        return camList != null && camList.length > 0;
    }

    public synchronized boolean startCameraforFwRead(int camID) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "startCameraforFwRead", "openCameraDevice type : " + camID);
        if (Camera.getNumberOfCameras() < camID) {
            String str2 = this.CLASS_NAME;
            FtUtil.log_d(str2, "startCameraforFwRead", "no CAM devices ID = " + camID);
            return false;
        } else if (mIsOpenedCamera[camID]) {
            String str3 = this.CLASS_NAME;
            FtUtil.log_d(str3, "startCameraforFwRead", "mIsOpenedCamera[camID] = " + mIsOpenedCamera[camID]);
            return false;
        } else {
            Camera[] cameraArr = this.mCamera;
            if (cameraArr[camID] != null) {
                FtUtil.log_d(this.CLASS_NAME, "startCameraforFwRead", "mCamera[camID] is not null");
                return false;
            }
            try {
                cameraArr[camID] = Camera.open(camID);
                if (camID == 0) {
                    if ("EXYNOS5410".equalsIgnoreCase(Support.Feature.getString(Support.Feature.CHIPSET_NAME))) {
                        Camera[] cameraArr2 = this.mCamera;
                        if (cameraArr2[camID] != null) {
                            cameraArr2[camID].startPreview();
                        }
                    }
                } else if (1 == camID) {
                    this.mCamera[camID].startPreview();
                }
                mIsOpenedCamera[camID] = true;
                String str4 = this.CLASS_NAME;
                FtUtil.log_d(str4, "startCameraforFwRead", "openCameraDevice    [" + camID + "] success");
            } catch (Exception e) {
                FtUtil.log_e(e);
            }
            return mIsOpenedCamera[camID];
        }
    }

    public boolean stopCameraforFwRead(int camID) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "stopCameraforFwRead", "releaseCameraDevice type : " + camID);
        if (Camera.getNumberOfCameras() < camID) {
            String str2 = this.CLASS_NAME;
            FtUtil.log_d(str2, "startCameraforFwRead", "no CAM devices ID = " + camID);
            return false;
        }
        Camera[] cameraArr = this.mCamera;
        if (cameraArr[camID] == null) {
            String str3 = this.CLASS_NAME;
            FtUtil.log_d(str3, "stopCameraforFwRead", "mCamera[" + camID + "] is null");
            return false;
        }
        if (camID == 0) {
            if ("EXYNOS5410".equalsIgnoreCase(Support.Feature.getString(Support.Feature.CHIPSET_NAME))) {
                Camera[] cameraArr2 = this.mCamera;
                if (cameraArr2[camID] != null) {
                    cameraArr2[camID].stopPreview();
                }
            }
        } else if (1 == camID) {
            cameraArr[camID].stopPreview();
        }
        this.mCamera[camID].release();
        this.mCamera[camID] = null;
        String str4 = this.CLASS_NAME;
        FtUtil.log_d(str4, "stopCameraforFwRead", "stopCameraDevice[" + camID + "] success");
        return true;
    }

    public String readCameraRearType() {
        String type = Support.Kernel.read(Support.Kernel.CAMERA_REAR_TYPE);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readCameraRearType", "type=" + type);
        return type;
    }

    public String readCameraFrontType() {
        String type = Support.Kernel.read(Support.Kernel.CAMERA_FRONT_TYPE);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readCameraFrontType", "type=" + type);
        return type;
    }

    public String readCameraRearFWver() {
        String type = Support.Kernel.read(Support.Kernel.CAMERA_REAR_FW_VER);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readCameraRearFWver", "type=" + type);
        return type;
    }

    public String readCameraFrontFWver() {
        String type = Support.Kernel.read(Support.Kernel.CAMERA_FRONT_FW_VER);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readCameraFrontFWver", "type=" + type);
        return type;
    }

    public String readCameraRear2FWver() {
        String type = Support.Kernel.read(Support.Kernel.CAMERA_REAR2_FW_VER);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readCameraRear2FWver", "type=" + type);
        return type;
    }

    public String readCameraFront2FWver() {
        String type = Support.Kernel.read(Support.Kernel.CAMERA_FRONT2_FW_VER);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readCameraFront2FWver", "type=" + type);
        return type;
    }

    public String readHDMITestResult() {
        String result = Support.Kernel.read(Support.Kernel.HDMI_TEST_RESULT);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readHDMICheck", "result" + result);
        return result;
    }

    public String readFactoryMode() {
        String mode = Support.Kernel.read(Support.Kernel.FACTORY_MODE);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readFactoryMode", "mode: " + mode);
        return mode;
    }

    public boolean writeFactoryMode(String mode) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "writeFactoryMode", "mode=" + mode);
        boolean result = Support.Kernel.writeNsync(Support.Kernel.FACTORY_MODE, mode);
        if (result) {
            return mode.equalsIgnoreCase(Support.Kernel.read(Support.Kernel.FACTORY_MODE));
        }
        return result;
    }

    public String readPrePay() {
        String mode = Support.Kernel.read(Support.Kernel.PRE_PAY);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readPrePay", "mode: " + mode);
        return mode;
    }

    public void writePrePay(String mode) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "writePrePay", "mode=" + mode);
        Support.Kernel.writeNsync(Support.Kernel.PRE_PAY, mode);
    }

    public String readKeyStringBlock() {
        String block = Support.Kernel.read(Support.Kernel.KEYSTRING_BLOCK);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readKeyStringBlock", "block=" + block);
        return block;
    }

    public boolean writeKeyStringBlock(String block) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "writeKeyStringBlock", "KeyStringBlock=" + block);
        boolean result = Support.Kernel.writeNsync(Support.Kernel.KEYSTRING_BLOCK, block);
        if (result) {
            return block.equalsIgnoreCase(Support.Kernel.read(Support.Kernel.KEYSTRING_BLOCK));
        }
        return result;
    }

    public String readmBaroDelta() {
        String delta = Support.Kernel.read(Support.Kernel.BAROMETE_DELTA);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readmBaroDelta", "delta=" + delta);
        return delta;
    }

    public String readOCTAManufactureCode() {
        String OCTAMCode = Support.Kernel.read(Support.Kernel.OCTA_MANUFACTURE_CODE);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readOCTAManufactureCode", "code=" + OCTAMCode);
        return OCTAMCode;
    }

    public String readSubOCTAManufactureCode() {
        String subOCTAMCode = Support.Kernel.read(Support.Kernel.SUBOCTA_MANUFACTURE_CODE);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readSubOCTAManufactureCode", "code=" + subOCTAMCode);
        return subOCTAMCode;
    }

    public void writemBaroDelta(String delta) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "writemBaroDelta", "BaroDelta=" + delta);
        Support.Kernel.write(Support.Kernel.BAROMETE_DELTA, delta);
        Support.Kernel.write(Support.Kernel.BAROMETE_CALIBRATION, delta);
    }

    public String getUartPath() {
        String path = Support.Kernel.read(Support.Kernel.UART_SELECT);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getUartPath", "path=" + path);
        return path;
    }

    public boolean setUartPath(String path) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setUartPath", "path=" + path);
        return Support.Kernel.write(Support.Kernel.UART_SELECT, path);
    }

    public String getHWRevision() {
        String version = Support.Properties.get(Support.Properties.HW_REVISION);
        if (version.equalsIgnoreCase(Support.Properties.PROPERTIES_DEFAULT_STRING)) {
            version = SystemProperties.get("ro.revision", Support.Properties.PROPERTIES_DEFAULT_STRING);
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getHWRevision", "rev=" + version);
        return version;
    }

    public String getHWVer() {
        String ver;
        if (Support.Feature.getBoolean(Support.Feature.HW_VER_EFS)) {
            if (!new File(Support.Kernel.getFilePath(Support.Kernel.EFS_HW_PATH)).exists()) {
                setHWVer(Support.Feature.getString("Not Active"));
                Support.Kernel.setPermission(Support.Kernel.getFilePath(Support.Kernel.EFS_HW_PATH), true, true, true, true, true, false);
                FtUtil.log_d(this.CLASS_NAME, "getHWVer", "EFS_HW_PATH is created...");
            } else {
                FtUtil.log_d(this.CLASS_NAME, "getHWVer", "EFS_HW_PATHis already existed...");
            }
            ver = Support.Kernel.read(Support.Kernel.EFS_HW_PATH);
        } else {
            ver = Support.Properties.get(Support.Properties.HW_VERSION);
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getHWver", "version=" + ver);
        return ver;
    }

    public boolean checkRpEnabled() {
        String rpString = Support.Properties.get(Support.Properties.RP);
        boolean isRPUnder0 = false;
        try {
            if (Integer.parseInt(rpString) <= 0) {
                isRPUnder0 = true;
            }
        } catch (NumberFormatException nfe) {
            FtUtil.log_e(nfe);
        }
        if (Support.Properties.PROPERTIES_DEFAULT_STRING.equalsIgnoreCase(rpString) || "ARP".equals(rpString) || isRPUnder0) {
            return false;
        }
        return true;
    }

    public String getModelName() {
        String name = SystemProperties.get("ro.factory.model", Support.Properties.PROPERTIES_DEFAULT_STRING);
        if (Support.Properties.PROPERTIES_DEFAULT_STRING.equalsIgnoreCase(name)) {
            name = Support.Properties.get(Support.Properties.PRODUCT_NAME);
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getModelName", "name=" + name);
        if (name != null && name.contains("SAMSUNG-")) {
            name = name.replaceAll("SAMSUNG-", "");
        }
        boolean isThisChipsetNeedtoCheckMSTGPIO = Support.Feature.getBoolean(Support.Feature.LEGACY_MODEL_POLICY_FOR_POS, true);
        if (FtUtil.isFactoryBinary() || !isThisChipsetNeedtoCheckMSTGPIO) {
            return name;
        }
        boolean isDS = isDualSimModel();
        boolean isSupportMST = Support.Kernel.isExistFile(Support.Kernel.SUPPORT_MST_GPIO) && EgisFingerprint.MAJOR_VERSION.equals(Support.Kernel.read(Support.Kernel.SUPPORT_MST_GPIO));
        if (!isDS && isSupportMST) {
            return name + "/M";
        } else if (isDS && !isSupportMST) {
            return name + "/DS";
        } else if (!isDS || !isSupportMST) {
            return name;
        } else {
            return name + "/DSM";
        }
    }

    public boolean isDualSimModel() {
        return 2 == ((TelephonyManager) getSystemService(ModuleTouchScreen.TSP_DEVICE_TYPE__PHONE)).getPhoneCount();
    }

    public String getMainChipFeatureID() {
        String featureId = Support.Kernel.read(Support.Kernel.PATH_MAIN_CHIP_FEATURE_ID);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getMainChipFeatureID", "main chip feature ID=" + featureId);
        return featureId;
    }

    public String getMainChipName() {
        String ap_name = getAPNameReal();
        String cp_name = Support.Properties.get(Support.Properties.MAIN_CHIP_NAME_CP).toUpperCase(Locale.ENGLISH);
        if (isConnectionModeNone()) {
            FtUtil.log_i(this.CLASS_NAME, "getMainChipName", "name=" + ap_name);
            return ap_name;
        }
        if ("exynos3470".equals(ap_name) && "SS222".equals(cp_name)) {
            ap_name = "SHANNON222AP";
            cp_name = "SHANNON222AP";
        }
        String name = ap_name + "," + cp_name;
        FtUtil.log_i(this.CLASS_NAME, "getMainChipName", "name=" + name);
        return name;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:16:0x0059, code lost:
        if (0 == 0) goto L_0x0062;
     */
    public String getHiddenVer() {
        String HiddenVer = Support.Properties.get(Support.Properties.CONTENTS_VERSION);
        if (Support.Properties.PROPERTIES_DEFAULT_STRING.equals(HiddenVer)) {
            Scanner s = null;
            try {
                s = new Scanner(new File("/system/info.extra"));
                while (s.hasNextLine()) {
                    String line = s.nextLine();
                    if (line.contains("ro.build.hidden_ver")) {
                        HiddenVer = line.split("=")[1];
                    }
                }
            } catch (IOException e) {
                String str = this.CLASS_NAME;
                FtUtil.log_d(str, "getHiddenVer", "exception : " + e);
            } catch (Throwable th) {
                if (0 != 0) {
                    s.close();
                }
                throw th;
            }
            s.close();
        }
        String path = this.CLASS_NAME;
        FtUtil.log_i(path, "getHiddenVer", "HiddenVer=" + HiddenVer);
        return HiddenVer;
    }

    public String getContentsVer() {
        String ver = getHiddenVer();
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getContentsVer", "version=" + ver);
        return ver;
    }

    public String getPDAVer() {
        String ver;
        String PDAver = Support.Properties.get(Support.Properties.PDA_VERSION);
        String Hiddenver = getHiddenVer();
        if ("factory".equalsIgnoreCase(Support.Properties.get(Support.Properties.BINARY_TYPE)) || EnvironmentCompat.MEDIA_UNKNOWN.equalsIgnoreCase(Hiddenver.trim()) || PDAver.equals(Hiddenver)) {
            ver = PDAver;
        } else {
            ver = Hiddenver;
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getPDAVer", "version=" + ver);
        return ver;
    }

    public String getBootVer() {
        String ver = Support.Properties.get(Support.Properties.BOOT_VERSION);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getBootVer", "version=" + ver);
        return ver;
    }

    public String getPhoneVer() {
        if ("CTC".equals(mSalesCode)) {
            String ctc_ver = SystemProperties.get("ril.sw_ver", Support.Properties.PROPERTIES_DEFAULT_STRING);
            String str = this.CLASS_NAME;
            FtUtil.log_i(str, "getPhoneVer", "CTCversion=" + ctc_ver);
            return ctc_ver;
        }
        String ver = SystemProperties.get("ril.sw_ver", Support.Properties.PROPERTIES_DEFAULT_STRING);
        String str2 = this.CLASS_NAME;
        FtUtil.log_i(str2, "getPhoneVer", "version=" + ver);
        return ver;
    }

    public String getPhone2Ver() {
        String ver = SystemProperties.get("ril.sw_ver", Support.Properties.PROPERTIES_DEFAULT_STRING);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getPhone2Ver", "version=" + ver);
        return ver;
    }

    public String getCSCVer() {
        String ver = Support.Properties.get(Support.Properties.CSC_VERSION);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getCSCVer", "version=" + ver);
        return ver;
    }

    public String getIFWIVer() {
        String ver = Support.Kernel.read(Support.Kernel.SYSFS_IFWI_VERSION);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getIFWIVer", " version=" + ver);
        return ver;
    }

    public String getStandardVer() {
        String ver = Support.Feature.getString(Support.Version.FACTORY_TEST_COMMAND);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getStandardVer", "version=" + ver);
        return ver;
    }

    public String getBootloaderVer() {
        String ver = Support.Properties.get(Support.Properties.BOOTLOADER_VERSION);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getBootVer", "version=" + ver);
        return ver;
    }

    public String getUserDataVer() {
        String ver = Support.Kernel.readFromPath("/data/version.txt", true);
        if (ver == null) {
            ver = "N";
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getUserDataVer", "version=" + ver);
        return ver;
    }

    public String getCalDate() {
        String date = Support.Kernel.read(Support.Kernel.EFS_CALDATE_PATH);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getCalDate", "getCalDate=" + date);
        if (date == null) {
            return "none";
        }
        return date;
    }

    public boolean setCalDate(String value) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setCalDate", "setCalDate=" + value);
        return Support.Kernel.writeNsync(Support.Kernel.EFS_CALDATE_PATH, value);
    }

    public boolean setHWVer(String value) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setHWVer", "version=" + value);
        String hw_version = value.replaceAll("\"", "").replaceAll("~", "");
        String str2 = this.CLASS_NAME;
        FtUtil.log_i(str2, "setHWVer", "write version=" + hw_version);
        return Support.Kernel.writeNsync(Support.Kernel.EFS_HW_PATH, hw_version);
    }

    public boolean isConnectionModeNone() {
        String mConnectionMode = Support.Feature.getString(Support.Feature.MODEL_COMMUNICATION_MODE);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "isConnectionModeNone", "mConnectionMode = " + mConnectionMode);
        return "none".equals(mConnectionMode);
    }

    public boolean isVoiceCapable() {
        if ("true".equalsIgnoreCase(Support.Feature.getString(Support.Feature.SUPPORT_VOICE_CALL_FORCIBLY))) {
            FtUtil.log_i(this.CLASS_NAME, "isVoiceCapable", "SUPPORT_VOICE_CALL_FORCIBLY true return true");
            return true;
        } else if (Support.Properties.getProp("persist.sys.cpboot").equalsIgnoreCase("disable")) {
            FtUtil.log_i(this.CLASS_NAME, "isVoiceCapable", "forced return false");
            return false;
        } else {
            boolean r = true;
            if (mContext != null) {
                r = mContext.getResources().getBoolean(17891712);
                String str = this.CLASS_NAME;
                FtUtil.log_i(str, "isVoiceCapable", "config_voice_capable: " + r);
            }
            String str2 = this.CLASS_NAME;
            FtUtil.log_i(str2, "isVoiceCapable", "=" + r);
            return r;
        }
    }

    public String getAPNameReal() {
        String type = Support.Properties.get(Support.Properties.MAIN_CHIP_NAME_AP);
        if (type.equals(Support.Properties.PROPERTIES_DEFAULT_STRING)) {
            FtUtil.log_i(this.CLASS_NAME, "getAPNameReal", "read old property");
            type = Support.Properties.getProp("ro.hardware.chipname");
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getAPNameReal", "type=" + type);
        return type.toUpperCase(Locale.ENGLISH);
    }

    public String getFtaHwVer() {
        return Support.Feature.getString(Support.Feature.FTA_HW_VER);
    }

    public String getFtaSwVer() {
        return Support.Feature.getString(Support.Feature.FTA_SW_VER);
    }

    public String getUFSVerRead() {
        return Support.Kernel.read(Support.Kernel.UFS_FW_VERSION);
    }

    public String getEMMCFWVerRead() {
        return Support.Kernel.read(Support.Kernel.EMMC_FW_VERSION);
    }

    public String getIrisVerRead() {
        return Support.Kernel.read(Support.Kernel.IRIS_CAMERA_FW_VER);
    }

    public String getPDICModuleFW() {
        return Support.Kernel.read(Support.Kernel.PDIC_FW_MODULE);
    }

    public String getPDICBinaryFW() {
        return Support.Kernel.read(Support.Kernel.PDIC_FW_BINARY);
    }

    public String getMFCBinaryFW() {
        return Support.Kernel.read(Support.Kernel.IDT_PACKAGING_FIRMWARE_VERSION);
    }

    public String getMFCModuleFW() {
        if (!Support.Kernel.isExistFile(Support.Kernel.IDT_OTP_FIRMWARE_VERSION)) {
            FtUtil.log_i(this.CLASS_NAME, "getMFCBinaryFW", "not exist sysfs node");
            return null;
        }
        Support.Kernel.write(Support.Kernel.IDT_OTP_ON_OFF, EgisFingerprint.MAJOR_VERSION);
        sleepThread(1000);
        String resData = Support.Kernel.read(Support.Kernel.IDT_OTP_FIRMWARE_VERSION);
        Support.Kernel.write(Support.Kernel.IDT_OTP_ON_OFF, "0");
        return resData;
    }

    public boolean setFirstBoot() {
        FtUtil.log_i(this.CLASS_NAME, "setFirstBoot", "set");
        SharedPreferences.Editor editor = mContext.getSharedPreferences(FIRST_BOOT_FLAG, 0).edit();
        editor.putBoolean(KEY_FIRST_BOOT_FLAG, false);
        editor.apply();
        return true;
    }

    public boolean isFirstBoot() {
        boolean result = true;
        SharedPreferences preferences = mContext.getSharedPreferences(FIRST_BOOT_FLAG, 0);
        if (preferences != null) {
            result = preferences.getBoolean(KEY_FIRST_BOOT_FLAG, true);
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "isFirstBoot", "before : " + result);
        return result;
    }

    public String getOctaID() {
        String moduleId = Support.Kernel.read(Support.Kernel.OCTA_ID);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getOctaID", "OCTA ID=" + moduleId);
        return moduleId;
    }

    public String getSubOctaID() {
        String moduleId = Support.Kernel.read(Support.Kernel.SUBOCTA_ID);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getSubOctaID", "SUBOCTA ID=" + moduleId);
        return moduleId;
    }

    public String getDDIChipID() {
        String moduleId = Support.Kernel.read(Support.Kernel.DDICHIP_ID);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getDDIChipID", "DDIChip ID=" + moduleId);
        return moduleId;
    }

    public String getDDIChipID2() {
        String moduleId = Support.Kernel.read(Support.Kernel.DDICHIP_ID2);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getDDIChipID2", "DDIChip ID2=" + moduleId);
        return moduleId;
    }

    public String getApChipID() {
        String moduleId = Support.Kernel.read(Support.Kernel.AP_CHIP_ID);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getApChipID", "AP CHIP ID=" + moduleId);
        return moduleId;
    }

    public String getApChipID2() {
        String moduleId = null;
        if (Support.Kernel.isExistFileID(Support.Kernel.AP_CHIP_ID2)) {
            FtUtil.log_i(this.CLASS_NAME, "getApChipID2", "get ApChipId from sysfs");
            moduleId = Support.Kernel.read(Support.Kernel.AP_CHIP_ID2);
        }
        if (TextUtils.isEmpty(moduleId)) {
            FtUtil.log_i(this.CLASS_NAME, "getApChipID2", "get ApChipId from property");
            moduleId = Support.Properties.get(Support.Properties.BOOT_AP_SERIAL);
            if (moduleId.indexOf("0x") == 0) {
                moduleId = moduleId.substring(2);
            }
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getApChipID2", "AP CHIP ID2=" + moduleId);
        return moduleId;
    }

    public String getApChipLotID() {
        String moduleId = Support.Kernel.read(Support.Kernel.AP_CHIP_LOT_ID);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getApChipLotID", "AP CHIP Lot=" + moduleId);
        return moduleId;
    }

    public boolean setFtClientState(boolean state) {
        FtUtil.log_i(this.CLASS_NAME, "setFtClientState");
        SystemProperties.set(KEY_RUNNING_FTCLIENT, String.valueOf(state));
        return true;
    }

    public boolean isRunningFtClient() {
        String result = SystemProperties.get(KEY_RUNNING_FTCLIENT, "false");
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "isRunningFtClient", "RUNNING_FTCLIENT : " + result);
        return "true".equalsIgnoreCase(result);
    }

    public boolean enable15Test() {
        FtUtil.log_i(this.CLASS_NAME, "15 Test Ready flag", "set");
        SharedPreferences.Editor editor = mContext.getSharedPreferences(TEST_READY_FLAG, 0).edit();
        editor.putBoolean(TEST_READY_FLAG, true);
        editor.apply();
        return true;
    }

    public boolean is15TestEnable() {
        boolean result = true;
        SharedPreferences preferences = mContext.getSharedPreferences(TEST_READY_FLAG, 0);
        if (preferences != null) {
            result = preferences.getBoolean(TEST_READY_FLAG, true);
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "is15TestEnable", "TEST_READY_FLAG : " + result);
        return result;
    }

    public boolean disableFtClient() {
        FtUtil.log_i(this.CLASS_NAME, "disableFtClient", "...");
        SharedPreferences.Editor editor = mContext.getSharedPreferences(FTCLIENT_FLAG, 0).edit();
        editor.putBoolean(FTCLIENT_KEY, false);
        editor.apply();
        return true;
    }

    public boolean enableFtClient() {
        FtUtil.log_i(this.CLASS_NAME, "enableFtClient", "...");
        SharedPreferences.Editor editor = mContext.getSharedPreferences(FTCLIENT_FLAG, 0).edit();
        editor.putBoolean(FTCLIENT_KEY, true);
        editor.apply();
        return true;
    }

    public boolean connectedJIG() {
        FtUtil.log_i(this.CLASS_NAME, "connectedJIG", "...");
        String atdTtyValue = Support.Properties.get(Support.Properties.ATD_TTY_VALUE);
        boolean result = false;
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "connectedJIG", "atdTtyValue = " + atdTtyValue);
        if ("usb".equalsIgnoreCase(atdTtyValue)) {
            String bootmode = Support.Kernel.read(Support.Kernel.BATT_FACTORY_MODE, false);
            String ccStatus = Support.Kernel.read(Support.Kernel.CCIC_STATUS, false);
            String USBConnection = Support.Kernel.read(Support.Kernel.USB_CONFIG_CHECK);
            String str2 = this.CLASS_NAME;
            FtUtil.log_i(str2, "connectedJIG", "bootmode = " + bootmode + ", ccStatus = " + ccStatus + ", usb config = " + USBConnection);
            if (!EgisFingerprint.MAJOR_VERSION.equalsIgnoreCase(bootmode) || !"0".equalsIgnoreCase(ccStatus)) {
                return false;
            }
            if ("CONFIGURED".equalsIgnoreCase(USBConnection) || "CONNECTED".equalsIgnoreCase(USBConnection)) {
                return true;
            }
            return false;
        } else if (!Support.Kernel.isExistFileID(Support.Kernel.JIG_CONNECTION_CHECK) && !Support.Kernel.isExistFileID(Support.Kernel.JIG_CONNECTION_CHECK_ADC)) {
            return false;
        } else {
            String value = Support.Kernel.read(Support.Kernel.JIG_CONNECTION_CHECK);
            String str3 = this.CLASS_NAME;
            FtUtil.log_i(str3, "connectedJIG", "value = " + value + ", JIG_ON = " + "JIG" + ", JIG_ON_1KOHM = " + "FACTORY UART");
            if (value != null) {
                String value2 = value.toUpperCase(Locale.ENGLISH);
                if (value2.contains("JIG") || value2.contains("FACTORY UART")) {
                    result = true;
                }
            }
            String value3 = Support.Kernel.read(Support.Kernel.JIG_CONNECTION_CHECK_ADC);
            String str4 = this.CLASS_NAME;
            FtUtil.log_i(str4, "connectedJIG", "adc_value = " + value3);
            String raw_adc_value = Support.Kernel.read(Support.Kernel.JIG_CONNECTION_CHECK_ADC_RAW);
            String str5 = this.CLASS_NAME;
            FtUtil.log_i(str5, "connectedJIG", "raw_adc_value = " + raw_adc_value);
            if (value3 == null || !value3.toUpperCase(Locale.ENGLISH).contains("523K")) {
                return result;
            }
            return true;
        }
    }

    public String hdcpCheck(int id) {
        switch (id) {
            case 1:
                return Support.Kernel.read(Support.Kernel.HDCP_CHECK_2_0);
            case 4:
                long length = Support.Kernel.getFileLength(Support.Kernel.getFilePath(Support.Kernel.HDCP_CHECK_WIDEVINE_KEYBOX));
                String str = this.CLASS_NAME;
                FtUtil.log_d(str, "checkWidevineKey", "length : " + length);
                if (length == 144) {
                    return "OK";
                }
                return "NG";
            default:
                return "NG";
        }
    }

    public String hdcpReadSN() {
        return Support.Properties.get(Support.Properties.HDCP_SN);
    }

    public void setSwitchFactoryState() {
        if (this.isSLSI || this.isQualcomm || this.isSPRD || this.isMTK) {
            FtUtil.log_i(this.CLASS_NAME, "setSwitchFactoryState", "SwitchFactory= + FACTORY_START");
            Support.Kernel.write(Support.Kernel.SWITCH_FACTORY, "FACTORY_START");
            return;
        }
        FtUtil.log_i(this.CLASS_NAME, "setSwitchFactoryState", "Not SLSI or Qualcomm model");
    }

    /* access modifiers changed from: package-private */
    public int DoShellCmd(String cmd) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "DoShellCmd", "cmd = " + cmd);
        String[] shell_command = {"/system/bin/sh", "-c", cmd};
        try {
            FtUtil.log_d(this.CLASS_NAME, "DoShellCmd", "exec command");
            Runtime.getRuntime().exec(shell_command).waitFor();
            FtUtil.log_d(this.CLASS_NAME, "DoShellCmd", "exec done");
            FtUtil.log_d(this.CLASS_NAME, "DoShellCmd", "DoShellCmd done");
            return 1;
        } catch (IOException exception) {
            String str2 = this.CLASS_NAME;
            FtUtil.log_e(str2, "DoShellCmd", "DoShellCmd - IOException" + exception);
            return -1;
        } catch (SecurityException exception2) {
            String str3 = this.CLASS_NAME;
            FtUtil.log_e(str3, "DoShellCmd", "SecurityException" + exception2);
            return -1;
        } catch (InterruptedException e) {
            String str4 = this.CLASS_NAME;
            FtUtil.log_e(str4, "DoShellCmd", "InterruptedException" + e);
            return -1;
        }
    }

    public int fsync() {
        int nResult = DoShellCmd("sync");
        sleepThread(500);
        return nResult;
    }

    public void updateFailItem(String strProcess, String strItem, String strSpec, String strValue) {
        String cmd;
        String cmd2;
        String cmd3 = strProcess + ":" + strItem + ":";
        String mVersion = Support.Feature.getString(Support.Feature.FAILHIST_VERSION);
        if (strSpec.isEmpty()) {
            cmd = cmd3 + "NA";
        } else {
            cmd = cmd3 + strSpec;
        }
        String cmd4 = cmd + ":";
        if (strValue.isEmpty()) {
            cmd2 = cmd4 + "NA";
        } else {
            cmd2 = cmd4 + strValue;
        }
        FtUtil.log_d(this.CLASS_NAME, "setProperties", "cmd = " + cmd2);
        if ("V1".equals(mVersion)) {
            Support.Properties.set(Support.Properties.FACTORYAPP_FAILHIST, cmd2);
            Support.Properties.set(Support.Properties.FACTORYAPP_FAILHIST_TIME, getTimeToString());
        } else if ("V2".equals(mVersion) || "V3".equals(mVersion) || "V4".equals(mVersion)) {
            FtUtil.log_d(this.CLASS_NAME, "updateFailItem", "V2");
            String cmd5 = cmd2 + ":" + getTimeToString();
            boolean writeResult = false;
            if ("V2".equals(mVersion)) {
                writeResult = Support.Kernel.writeNsync(Support.Kernel.FACTORY_FAILHIST, cmd5);
            }
            if ("V3".equals(mVersion) || "V4".equals(mVersion)) {
                writeResult = Support.Kernel.writeNsyncContinuous(Support.Kernel.FACTORY_FAILHIST, (cmd5 + ":" + Support.Properties.get(Support.Properties.FACTORYAPP_FAILHIST_RDMKEY)) + "\n");
            }
            if (writeResult) {
                FtUtil.log_d(this.CLASS_NAME, "updateFailItem", "result = pass");
            } else {
                FtUtil.log_d(this.CLASS_NAME, "updateFailItem", "result = fail");
            }
        }
    }

    public String getTimeToString() {
        Calendar cal = Calendar.getInstance();
        DecimalFormat df = new DecimalFormat("00", DecimalFormatSymbols.getInstance(Locale.US));
        String month = df.format((long) (cal.get(2) + 1));
        String day = df.format((long) cal.get(5));
        String hour = df.format((long) cal.get(11));
        String min = df.format((long) cal.get(12));
        return cal.get(1) + "." + month + "." + day + " " + hour + min;
    }

    public String getDateTime() {
        Calendar cal = Calendar.getInstance();
        DecimalFormat df = new DecimalFormat("00", DecimalFormatSymbols.getInstance(Locale.US));
        String month = df.format((long) (cal.get(2) + 1));
        String day = df.format((long) cal.get(5));
        String hour = df.format((long) cal.get(11));
        String min = df.format((long) cal.get(12));
        String sec2 = df.format((long) cal.get(13));
        String msec = df.format((long) cal.get(14));
        return month + "-" + day + " " + hour + ":" + min + ":" + sec2 + "." + msec;
    }

    public boolean isStartNADTest() {
        String strRunningKQT = SystemProperties.get("ro.factory.running_kqt");
        if (strRunningKQT == null) {
            return false;
        }
        return "true".equals(strRunningKQT);
    }

    public String createChecksum(String data) {
        try {
            MessageDigest complete = MessageDigest.getInstance("MD5");
            complete.update(data.getBytes());
            byte[] byteData = complete.digest();
            StringBuffer sb = new StringBuffer();
            for (byte b : byteData) {
                sb.append(Integer.toString((b & UnsignedBytes.MAX_VALUE) + 256, 16).substring(1));
            }
            String MD5 = sb.toString();
            FtUtil.log_d(this.CLASS_NAME, "createChecksum", MD5);
            return MD5;
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    public String getMainChipType() {
        String ap_name = getAPNameReal();
        if (ap_name.contains("MSM") || ap_name.contains("SDM")) {
            FtUtil.log_d(this.CLASS_NAME, "getMainChipType", "qc");
            return "QC";
        } else if (ap_name.contains("EXYNOS")) {
            FtUtil.log_d(this.CLASS_NAME, "getMainChipType", "lsi");
            return "LSI";
        } else {
            FtUtil.log_d(this.CLASS_NAME, "getMainChipType", EnvironmentCompat.MEDIA_UNKNOWN);
            return "UNKNOWN";
        }
    }

    public int getType5G() {
        String strMode5GRF = SystemProperties.get("ril.5g_rf", Support.Properties.PROPERTIES_DEFAULT_STRING);
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "getType5G", "RF Mode : " + strMode5GRF);
        if (EgisFingerprint.MAJOR_VERSION.equals(strMode5GRF)) {
            return 1;
        }
        if ("2".equals(strMode5GRF)) {
            return 2;
        }
        if (egis.optical.client.api.EgisFingerprint.MAJOR_VERSION.equals(strMode5GRF)) {
            return 3;
        }
        return 0;
    }

    public void startSilentLogService() {
        if ("On".equalsIgnoreCase(String.valueOf(SystemProperties.get("dev.silentlog.on", "NULL")))) {
            FtUtil.log_d(this.CLASS_NAME, "Silent saving : start now! ");
            Intent SvcIntent = new Intent();
            SvcIntent.setClassName("com.sec.modem.settings", "com.sec.modem.settings.cplogging.SilentLogService");
            SvcIntent.putExtra("modem_profile", "default");
            SvcIntent.putExtra("action", 3);
            mContext.startService(SvcIntent);
        }
    }
}
