package com.sec.factory.modules;

import android.bluetooth.BluetoothAdapter;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.location.LocationManager;
import android.os.FileUtils;
import android.os.Process;
import android.os.SystemProperties;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.Locale;
import java.util.Timer;
import java.util.TimerTask;

public class ModuleCommunication extends ModuleObject {
    private static final int ACTION_BLUETOOTH_ANT_SWITCH_EDR_TX_MID = 81;
    private static final int ACTION_BLUETOOTH_AUDIO_TEST_START = 8;
    private static final int ACTION_BLUETOOTH_AUDIO_TEST_STOP = 9;
    private static final int ACTION_BLUETOOTH_BLE_DISCOVERY_START_WITH_ACK = 5;
    private static final int ACTION_BLUETOOTH_BLE_DISCOVERY_START_WITH_ACK_ON_10S = 6;
    private static final int ACTION_BLUETOOTH_BREDR_TEST_END = 36;
    private static final int ACTION_BLUETOOTH_BR_RX_HIGH = 45;
    private static final int ACTION_BLUETOOTH_BR_RX_LOW = 43;
    private static final int ACTION_BLUETOOTH_BR_RX_MID = 44;
    private static final int ACTION_BLUETOOTH_BR_TX_HIGH = 42;
    private static final int ACTION_BLUETOOTH_BR_TX_LOW = 40;
    private static final int ACTION_BLUETOOTH_BR_TX_MID = 41;
    private static final int ACTION_BLUETOOTH_DISCOVERY_START = 3;
    private static final int ACTION_BLUETOOTH_DISCOVERY_START_WITH_ACK = 4;
    private static final int ACTION_BLUETOOTH_DISCOVERY_STOP = 7;
    private static final int ACTION_BLUETOOTH_DUALBT_ACL_FRAME = 77;
    private static final int ACTION_BLUETOOTH_DUALBT_CHANNEL = 72;
    private static final int ACTION_BLUETOOTH_DUALBT_CORE_SELECT = 71;
    private static final int ACTION_BLUETOOTH_DUALBT_DATA_RATE = 73;
    private static final int ACTION_BLUETOOTH_DUALBT_PACKET_TYPE = 76;
    private static final int ACTION_BLUETOOTH_DUALBT_PA_MODE = 75;
    private static final int ACTION_BLUETOOTH_DUALBT_RX_GOODPACKET = 80;
    private static final int ACTION_BLUETOOTH_DUALBT_RX_START_STOP = 79;
    private static final int ACTION_BLUETOOTH_DUALBT_SIGNAL_SELECT = 70;
    private static final int ACTION_BLUETOOTH_DUALBT_TX_POWER = 74;
    private static final int ACTION_BLUETOOTH_DUALBT_TX_START_STOP = 78;
    private static final int ACTION_BLUETOOTH_EDR_RX_HIGH = 35;
    private static final int ACTION_BLUETOOTH_EDR_RX_LOW = 33;
    private static final int ACTION_BLUETOOTH_EDR_RX_MID = 34;
    private static final int ACTION_BLUETOOTH_EDR_TX_HIGH = 32;
    private static final int ACTION_BLUETOOTH_EDR_TX_LOW = 30;
    private static final int ACTION_BLUETOOTH_EDR_TX_MID = 31;
    private static final int ACTION_BLUETOOTH_HPM_TEST_HIGH = 38;
    private static final int ACTION_BLUETOOTH_HPM_TEST_LOW = 37;
    private static final int ACTION_BLUETOOTH_HPM_TEST_READ = 39;
    private static final int ACTION_BLUETOOTH_LE_CARRIER_HIGH = 22;
    private static final int ACTION_BLUETOOTH_LE_CARRIER_LOW = 20;
    private static final int ACTION_BLUETOOTH_LE_CARRIER_MID = 21;
    private static final int ACTION_BLUETOOTH_LE_INBAND_HIGH = 25;
    private static final int ACTION_BLUETOOTH_LE_INBAND_LOW = 23;
    private static final int ACTION_BLUETOOTH_LE_INBAND_MID = 24;
    private static final int ACTION_BLUETOOTH_LE_MOD_HIGH = 16;
    private static final int ACTION_BLUETOOTH_LE_MOD_HIGH_AA = 19;
    private static final int ACTION_BLUETOOTH_LE_MOD_LOW = 14;
    private static final int ACTION_BLUETOOTH_LE_MOD_LOW_AA = 17;
    private static final int ACTION_BLUETOOTH_LE_MOD_MID = 15;
    private static final int ACTION_BLUETOOTH_LE_MOD_MID_AA = 18;
    private static final int ACTION_BLUETOOTH_LE_OUTPUT_HIGH = 13;
    private static final int ACTION_BLUETOOTH_LE_OUTPUT_LOW = 11;
    private static final int ACTION_BLUETOOTH_LE_OUTPUT_MID = 12;
    private static final int ACTION_BLUETOOTH_LE_RX_CHANNEL = 65;
    private static final int ACTION_BLUETOOTH_LE_RX_HIGH = 28;
    private static final int ACTION_BLUETOOTH_LE_RX_LOW = 26;
    private static final int ACTION_BLUETOOTH_LE_RX_MID = 27;
    private static final int ACTION_BLUETOOTH_LE_RX_MOD_INDEX = 67;
    private static final int ACTION_BLUETOOTH_LE_RX_PHY = 66;
    private static final int ACTION_BLUETOOTH_LE_RX_TEST_RSSI_RESULT = 82;
    private static final int ACTION_BLUETOOTH_LE_TEST_1M = 46;
    private static final int ACTION_BLUETOOTH_LE_TEST_2M = 47;
    private static final int ACTION_BLUETOOTH_LE_TEST_END = 29;
    private static final int ACTION_BLUETOOTH_LE_TEST_READ = 48;
    private static final int ACTION_BLUETOOTH_LE_TX_CARRIER_CHANNEL = 63;
    private static final int ACTION_BLUETOOTH_LE_TX_INBAND_CHANNEL = 64;
    private static final int ACTION_BLUETOOTH_LE_TX_MOD_0F_CHANNEL = 61;
    private static final int ACTION_BLUETOOTH_LE_TX_MOD_AA_CHANNEL = 62;
    private static final int ACTION_BLUETOOTH_LE_TX_MOD_FF_CHANNEL = 69;
    private static final int ACTION_BLUETOOTH_LE_TX_MOD_PHY = 68;
    private static final int ACTION_BLUETOOTH_LE_TX_OUTPUT_CHANNEL = 60;
    private static final int ACTION_BLUETOOTH_OFF = 2;
    private static final int ACTION_BLUETOOTH_ON = 0;
    private static final int ACTION_BLUETOOTH_ON_WHERE_ATCMD = 1;
    private static final int ACTION_BLUETOOTH_RED_RX_RSSI_READ = 50;
    private static final int ACTION_BLUETOOTH_RED_TX_CAL_RESULT_READ = 51;
    private static final int ACTION_BLUETOOTH_SET_DISCOVERABLE = 10;
    protected static final String ACTION_BT_ID_READ = "com.sec.android.app.bluetoothtest.BT_ID_READ";
    public static final String ACTION_BT_ID_RESPONSE = "com.sec.android.app.bluetoothtest.BT_ID_RESPONSE";
    protected static final String ACTION_BT_ID_WRITE = "com.sec.android.app.bluetoothtest.BT_ID_WRITE";
    public static final String ACTION_BT_SERVICE_REQUEST = "com.sec.android.app.bluetoothtest.BT_SERVICE_REQUEST";
    public static final String ACTION_BT_SERVICE_RESPONSE = "com.sec.factory.intent.ACTION_BT_SERVICE_RESPONSE";
    private static final String ACTION_FELICA_LOCK_REQUEST = "com.samsung.felicalock.FELICA_LOCK_REQUEST";
    public static final String ACTION_FELICA_RESPONSE = "com.sec.factory.intent.ACTION_FELICA_RESPONSE";
    protected static final String ACTION_WIFI_ID_READ = "com.sec.android.app.wlantest.WIFI_ID_READ";
    protected static final String ACTION_WIFI_ID_WRITE = "com.sec.android.app.wlantest.WIFI_ID_WRITE";
    private static final int BEIDOU = 2;
    public static String BEIDOU_STARTED_PATH = "/data/beidou_started";
    public static final String BT_RESULT_FOUND = "FOUND";
    public static final String BT_RESULT_NG = "NG";
    public static final String BT_RESULT_NOT_FOUND = "NOT FOUND";
    public static final String BT_RESULT_OFF = "OFF";
    public static final String BT_RESULT_ON = "ON";
    public static String COMBO_BEIDOU_CNO_PATH = "/data/sv_cno_beidou.info";
    public static String COMBO_GLONASS_CNO_PATH = "/data/sv_cno_glonass.info";
    private static final int COMMUNICATION_CHECK = 0;
    public static final String EXTRA_BLE_DATA = "EXTRA_BT_DATA";
    public static final String EXTRA_KEY_BT_SERVICE_REQUEST = "CMDID";
    public static final String EXTRA_KEY_BT_SERVICE_RESPONSE = "result";
    public static final int FM_RADIO_EARPHONE = 0;
    public static final String FM_RADIO_FREQUENCY_RESPONSE = "test.mode.radio.freq.response";
    public static final int FM_RADIO_SPEAKER = 1;
    private static final String[] FM_RADIO_TARGET = {"earphone", "speaker"};
    public static final String FM_RADIO_TEST_OFF = "test.mode.radio.off";
    public static final String FM_RADIO_TEST_OFF_RESPONSE = "test.mode.radio.off.response";
    public static final String FM_RADIO_TEST_ON = "test.mode.radio.on.freq";
    public static final String FM_RADIO_TEST_ON_RESPONSE = "test.mode.radio.on.response";
    private static final int GLONASS = 0;
    public static String GLONASS_FCN_PATH = "/data/glonass_fcn";
    public static String GLONASS_STARTED_PATH = "/data/glonass_started";
    private static final int GPS = 1;
    public static String GPS_CNO_PATH = "/data/sv_cno.info";
    private static final int GPS_L5 = 3;
    public static String GPS_L5_CNO_PATH = "/data/sv_cno_gps_l5.info";
    public static String GPS_STARTED_PATH = "/data/gps_started";
    private static final int LNA_CHECK = 1;
    public static String LNA_STARTED_PATH = "/data/lna_started";
    public static String SMD_STARTED_PATH = "/data/smd_started";
    private static boolean isComboMode = false;
    private static boolean isOneCommand = false;
    private static ModuleCommunication mInstance;
    private final String AXEFUSE_SYSTEM_PROPERTY = "persist.eth.efuse";
    private final String EFUSE_OFF = "0";
    private final String EFUSE_ON = EgisFingerprint.MAJOR_VERSION;
    public final int ETHERNET_CONNECT_AP = 0;
    public final int ETHERNET_CONNECT_CABLE = 1;
    private final String ETHERNET_STATE_OFF = EgisFingerprint.MAJOR_VERSION;
    private final String ETHERNET_STATE_ON = "0";
    private final String ETHERNET_SWITCH_SYSTEM_PROPERTY = "persist.eth.on";
    private final int WORKING_DELAY_TIME = 1000;
    public boolean mGpsEnabledByFactory = false;
    private BroadcastReceiver mGpsReceiver = new BroadcastReceiver() {
        /* class com.sec.factory.modules.ModuleCommunication.AnonymousClass1 */

        public void onReceive(Context context, Intent intent) {
            if (intent.getAction().equals("com.sec.factory.intent.ACTION_GPS_SERVICE_RESPONSE")) {
                String result = intent.getStringExtra("result");
                String str = ModuleCommunication.this.CLASS_NAME;
                FtUtil.log_i(str, "mGpsReceiver.onReceive", "ACTION_GPS_SERVICE_RESPONSE result=" + result);
                if ("NG_CN0".equals(result)) {
                    ModuleCommunication.this.sendResponse("NG_CN0");
                } else if (result.equals(ModuleCommunicationService.SMD_NOK)) {
                    if ("SMD".equals(ModuleCommunicationService.GPS_MODE)) {
                        ModuleCommunication.this.sendResponse("NG");
                    } else {
                        ModuleCommunication.this.sendResponse("NG_TO");
                    }
                } else if (ModuleCommunication.isOneCommand) {
                    ModuleCommunication.this.sendResponse(result);
                } else if (!"SMD".equals(ModuleCommunicationService.GPS_MODE)) {
                    ModuleCommunication.this.sendStartOK();
                } else if (result.equals(ModuleCommunicationService.SMD_OK)) {
                    ModuleCommunication.this.sendStartOK();
                } else {
                    ModuleCommunication.this.sendResponse("OK," + result);
                }
                if ("SMD".equals(ModuleCommunicationService.GPS_MODE) || ModuleCommunication.isOneCommand) {
                    ModuleCommunication.deleteGpsFiles();
                    boolean unused = ModuleCommunication.isOneCommand = false;
                    ModuleCommunication.this.stopService(new Intent(ModuleCommunication.this.getApplicationContext(), ModuleCommunicationService.class));
                }
            }
        }
    };
    private boolean mIsRunningBtDevice = false;
    private LocationManager mLocationManager = ((LocationManager) getSystemService("location"));
    private String nfcChipName = "SLSI_NFC";

    private ModuleCommunication(Context context) {
        super(context, "ModuleCommunication");
        FtUtil.log_i(this.CLASS_NAME, "ModuleCommunication", "Create ModuleCommunication");
        updateGpsFilesPath();
        registerReceiver(this.mGpsReceiver, new IntentFilter("com.sec.factory.intent.ACTION_GPS_SERVICE_RESPONSE"));
    }

    public static ModuleCommunication instance(Context context) {
        if (mInstance == null) {
            mInstance = new ModuleCommunication(context);
        }
        return mInstance;
    }

    /* access modifiers changed from: protected */
    public void finalize() throws Throwable {
        unregisterReceiver(this.mGpsReceiver);
        mInstance = null;
        super.finalize();
    }

    private void gpsAction(String action) {
        Intent service = new Intent(getApplicationContext(), ModuleCommunicationService.class);
        service.putExtra("action", action);
        startService(service);
    }

    public void gpsDeactivation() {
        FtUtil.log_i(this.CLASS_NAME, "gpsDeactivation", "GPS Deactivation");
        deleteGpsFiles();
        stopService(new Intent(getApplicationContext(), ModuleCommunicationService.class));
        if (this.mGpsEnabledByFactory) {
            this.mLocationManager.setLocationEnabledForUser(false, Process.myUserHandle());
            this.mGpsEnabledByFactory = false;
        }
    }

    public void gpsActivation(Context context, int mode, boolean _isOneCommand) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "[GPS debug #1]gpsActivation", "GPS Activation - mode(GPS : 1, GLONASS : 0, BEIDOU : 2, GPS_L5 : 3) = " + mode + ",  isOneCommand = " + _isOneCommand);
        isComboMode = false;
        deleteGpsFiles();
        File filePath = null;
        isOneCommand = _isOneCommand;
        if (mode == 1) {
            isComboMode = true;
            filePath = new File(GPS_STARTED_PATH);
        } else if (mode == 0) {
            filePath = new File(GLONASS_STARTED_PATH);
        } else if (mode == 2) {
            filePath = new File(BEIDOU_STARTED_PATH);
        }
        if (filePath == null) {
            FtUtil.log_i(this.CLASS_NAME, "[GPS debug #1]gpsSmdActivation", "filePath == null");
            return;
        }
        try {
            filePath.createNewFile();
            FileUtils.setPermissions(filePath.toString(), 511, -1, -1);
        } catch (IOException e) {
            e.printStackTrace();
        }
        if (!this.mLocationManager.isLocationEnabledForUser(Process.myUserHandle())) {
            this.mLocationManager.setLocationEnabledForUser(true, Process.myUserHandle());
            this.mGpsEnabledByFactory = true;
            gpsAction(ModuleCommunicationService.ACTION_GPS_START_DELAY);
            return;
        }
        this.mGpsEnabledByFactory = false;
        gpsAction(ModuleCommunicationService.ACTION_GPS_START);
    }

    public void gpsSmdActivation(Context context, int mode) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "[GPS debug #1]gpsSmdActivation", "GPS SMD Activation- mode(COMMUNICATION_CHECK : 0, LNA_CHECK : 1) = " + mode);
        deleteGpsFiles();
        File filePath = null;
        if (mode == 0) {
            filePath = new File(SMD_STARTED_PATH);
        } else if (mode == 1) {
            filePath = new File(LNA_STARTED_PATH);
        }
        try {
            filePath.createNewFile();
            FileUtils.setPermissions(filePath.toString(), 511, -1, -1);
        } catch (IOException e) {
            e.printStackTrace();
        }
        if (!this.mLocationManager.isLocationEnabledForUser(Process.myUserHandle())) {
            this.mLocationManager.setLocationEnabledForUser(true, Process.myUserHandle());
            this.mGpsEnabledByFactory = true;
            gpsAction(ModuleCommunicationService.ACTION_SMD_START_DELAY);
            return;
        }
        this.mGpsEnabledByFactory = false;
        gpsAction(ModuleCommunicationService.ACTION_SMD_START);
    }

    public String gpsReadCN(Context context, int mode) {
        String cno = null;
        if (!isComboMode) {
            cno = readOneLine(GPS_CNO_PATH);
        } else if (mode == 1) {
            cno = readOneLine(GPS_CNO_PATH);
        } else if (mode == 0) {
            cno = readOneLine(COMBO_GLONASS_CNO_PATH);
        } else if (mode == 2) {
            cno = readOneLine(COMBO_BEIDOU_CNO_PATH);
        } else if (mode == 3) {
            cno = readOneLine(GPS_L5_CNO_PATH);
        }
        if (cno == null || cno.equals("") || "0".equals(cno)) {
            cno = "NG";
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "gpsReadCN_SingleChannle", "CNO=" + cno);
        return cno;
    }

    /* access modifiers changed from: protected */
    public void sendResponse(String msg) {
        Intent i = new Intent("com.android.samsungtest.GPS_RESPONSE");
        i.putExtra("RES", msg);
        i.addFlags(16777216);
        sendBroadcast(i);
    }

    /* access modifiers changed from: protected */
    public void sendStartOK() {
        Intent i = new Intent("com.android.samsungtest.GPS_OK");
        i.addFlags(16777216);
        sendBroadcast(i);
    }

    /* access modifiers changed from: protected */
    public String readOneLine(String filepath) {
        String result = "";
        BufferedReader buf = null;
        try {
            BufferedReader buf2 = new BufferedReader(new FileReader(filepath), 8096);
            String bufline = buf2.readLine();
            if (bufline != null) {
                result = bufline.trim();
            }
            try {
                buf2.close();
            } catch (IOException e) {
                FtUtil.log_i(this.CLASS_NAME, "readOneLine", "IOException");
            }
        } catch (FileNotFoundException e2) {
            FtUtil.log_i(this.CLASS_NAME, "readOneLine", "FileNotFoundException");
            if (0 != 0) {
                buf.close();
            }
        } catch (IOException e3) {
            FtUtil.log_i(this.CLASS_NAME, "readOneLine", "IOException");
            if (0 != 0) {
                buf.close();
            }
        } catch (Throwable th) {
            if (0 != 0) {
                try {
                    buf.close();
                } catch (IOException e4) {
                    FtUtil.log_i(this.CLASS_NAME, "readOneLine", "IOException");
                }
            }
            throw th;
        }
        return result;
    }

    public static void deleteGpsFiles() {
        try {
            new File(GPS_CNO_PATH).delete();
            new File(GPS_STARTED_PATH).delete();
            new File(GLONASS_STARTED_PATH).delete();
            new File(SMD_STARTED_PATH).delete();
            new File(LNA_STARTED_PATH).delete();
            new File(GLONASS_FCN_PATH).delete();
            new File(BEIDOU_STARTED_PATH).delete();
            new File(COMBO_GLONASS_CNO_PATH).delete();
            new File(COMBO_BEIDOU_CNO_PATH).delete();
            new File(GPS_L5_CNO_PATH).delete();
        } catch (Exception e) {
            FtUtil.log_i("ModuleCommunication", "deleteGpsFiles", "Exception");
        }
    }

    public static void updateGpsFilesPath() {
        GPS_CNO_PATH = "/data/vendor/gps/sv_cno.info";
        GPS_STARTED_PATH = "/data/vendor/gps/gps_started";
        GLONASS_STARTED_PATH = "/data/vendor/gps/glonass_started";
        GLONASS_FCN_PATH = "/data/vendor/gps/glonass_fcn";
        BEIDOU_STARTED_PATH = "/data/vendor/gps/beidou_started";
        COMBO_GLONASS_CNO_PATH = "/data/vendor/gps/sv_cno_glonass.info";
        COMBO_BEIDOU_CNO_PATH = "/data/vendor/gps/sv_cno_beidou.info";
        SMD_STARTED_PATH = "/data/vendor/gps/smd_started";
        LNA_STARTED_PATH = "/data/vendor/gps/lna_started";
        GPS_L5_CNO_PATH = "/data/vendor/gps/sv_cno_gps_l5.info";
    }

    public void requestActionToBTService(int extra) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "requestActionToBTService", "Request extra :" + extra);
        Intent intent = new Intent(ACTION_BT_SERVICE_REQUEST);
        intent.putExtra(EXTRA_KEY_BT_SERVICE_REQUEST, extra);
        intent.addFlags(268435456);
        intent.addFlags(16777216);
        intent.setPackage("com.sec.android.app.bluetoothtest");
        sendBroadcast(intent);
    }

    public void requestActionToBTService(int extra, int extraData) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "requestActionToBTService", "Request extra :" + extra);
        Intent intent = new Intent(ACTION_BT_SERVICE_REQUEST);
        intent.putExtra(EXTRA_KEY_BT_SERVICE_REQUEST, extra);
        intent.putExtra(EXTRA_BLE_DATA, extraData);
        intent.addFlags(268435456);
        intent.addFlags(16777216);
        intent.setPackage("com.sec.android.app.bluetoothtest");
        sendBroadcast(intent);
    }

    public void btActivation() {
        FtUtil.log_i(this.CLASS_NAME, "btActivation", "Bluetooth Activation");
        this.mIsRunningBtDevice = true;
        requestActionToBTService(0);
    }

    public void btActivationWhereAtcmd() {
        FtUtil.log_i(this.CLASS_NAME, "btActivationWhereAtcmd", "Bluetooth Activation where Atcmd");
        this.mIsRunningBtDevice = true;
        if (!"Marvell".equalsIgnoreCase(Support.Feature.getString(Support.Feature.CHIPSET_MANUFACTURE)) || !isEnabledBtDevice()) {
            requestActionToBTService(1);
        } else {
            new Timer().schedule(new TimerTask() {
                /* class com.sec.factory.modules.ModuleCommunication.AnonymousClass2 */

                public void run() {
                    ModuleCommunication.this.requestActionToBTService(1);
                }
            }, 600);
        }
    }

    public void btDeactivation() {
        FtUtil.log_i(this.CLASS_NAME, "btDeactivation", "Bluetooth Deactivation");
        this.mIsRunningBtDevice = true;
        requestActionToBTService(2);
    }

    public void btSearchStart() {
        FtUtil.log_i(this.CLASS_NAME, "btSearchStart", "Start Bluetooth Search");
        requestActionToBTService(3);
    }

    public void btSearchStartWithAck() {
        FtUtil.log_i(this.CLASS_NAME, "btSearchStartWithAck", "Start Bluetooth Search timeout=10sec");
        requestActionToBTService(4);
    }

    public void bleSearchStartWithAck() {
        FtUtil.log_i(this.CLASS_NAME, "bleSearchStartWithAck", "Start Bluetooth BLE Search timeout=20sec");
        requestActionToBTService(5);
    }

    public void bleSearchStartWithAckOn10s() {
        FtUtil.log_i(this.CLASS_NAME, "bleSearchStartWithAck", "Start Bluetooth BLE Search timeout=10sec");
        requestActionToBTService(6);
    }

    public void btSearchStop() {
        FtUtil.log_i(this.CLASS_NAME, "btSearchStop", "Stop Bluetooth Search");
        requestActionToBTService(7);
    }

    public void btREDRxRSSIRead() {
        FtUtil.log_i(this.CLASS_NAME, "btREDRxRSSIRead", "Read BT RED RX RSSI");
        requestActionToBTService(50);
    }

    public void btREDTxCalResultRead() {
        FtUtil.log_i(this.CLASS_NAME, "btREDTxCalResultRead", "Read BT RED TX Cal result");
        requestActionToBTService(51);
    }

    public void btAudioTestStart() {
        FtUtil.log_i(this.CLASS_NAME, "btAudioTestStart", "Start Bluetooth Audio Test");
        requestActionToBTService(8);
    }

    public void btAudioTestStop() {
        FtUtil.log_i(this.CLASS_NAME, "btAudioTestStop", "Stop Bluetooth Audio Test");
        requestActionToBTService(9);
    }

    public void btRfTestStart() {
        FtUtil.log_i(this.CLASS_NAME, "btAudioTestStart", "Start Bluetooth RF Test");
        Intent intent = new Intent();
        intent.setClassName("com.sec.android.app.bluetoothtest", "com.sec.android.app.bluetoothtest.BluetoothRfTest");
        intent.setFlags(268435456);
        startActivity(intent);
    }

    public void btRfTestStop() {
        FtUtil.log_i(this.CLASS_NAME, "btAudioTestStart", "Stop Bluetooth RF Test");
        Intent intent = new Intent("com.android.samsungtest.BluetoothRfTestOff");
        intent.addFlags(16777216);
        sendBroadcast(intent);
    }

    public void btSetDiscoverable() {
        FtUtil.log_i(this.CLASS_NAME, "btSetDiscoverable", "btSetDiscoverable()");
        requestActionToBTService(10);
    }

    public void setBtLeTxOutputCh(int ch) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setBtLeTxOutputCh", "setBtLeTxOutputCh ch : " + ch);
        requestActionToBTService(60, ch);
    }

    public void setBtLeTxMod0FCh(int ch) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setBtLeTxMod0FCh", "setBtLeTxMod0FCh ch : " + ch);
        requestActionToBTService(61, ch);
    }

    public void setBtLeTxModAACh(int ch) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setBtLeTxModAACh", "setBtLeTxModAACh ch : " + ch);
        requestActionToBTService(62, ch);
    }

    public void setBtLeTxCarrierCh(int ch) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setBtLeTxCarrierCh", "setBtLeTxCarrierCh ch : " + ch);
        requestActionToBTService(63, ch);
    }

    public void setBtLeTxInbandCh(int ch) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setBtLeTxInbandCh", "setBtLeTxInbandCh ch : " + ch);
        requestActionToBTService(64, ch);
    }

    public void setBtLeRxCh(int ch) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setBtLeRxCh", "setBtLeRxCh ch : " + ch);
        requestActionToBTService(65, ch);
    }

    public void setBtLeRxPhyCh(int ch) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setBtLeRxPhyCh", "setBtLeRxPhyCh ch : " + ch);
        requestActionToBTService(66, ch);
    }

    public void setBtLeRxModeIndexCh(int ch) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setBtLeRxModeIndexCh", "setBtLeRxModeIndexCh ch : " + ch);
        requestActionToBTService(67, ch);
    }

    public void setBtLeTxModPhyCh(int ch) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setBtLeTxModPhyCh", "setBtLeTxModPhyCh ch : " + ch);
        requestActionToBTService(68, ch);
    }

    public void setBtLeTxModCh(int ch) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setBtLeTxModCh", "setBtLeTxModCh ch : " + ch);
        requestActionToBTService(69, ch);
    }

    public void btLeTxOutputChLow() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxOutputChLow", "btLeTxOutputChLow()");
        requestActionToBTService(11);
    }

    public void btLeTxOutputChMid() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxOutputChMid", "btLeTxOutputChMid()");
        requestActionToBTService(12);
    }

    public void btLeTxOutputChHigh() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxOutputChHigh", "btLeTxOutputChHigh()");
        requestActionToBTService(13);
    }

    public void btLeTxModChLow() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxModChLow", "btLeTxModChLow()");
        requestActionToBTService(14);
    }

    public void btLeTxModChMid() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxModChMid", "btLeTxModChMid()");
        requestActionToBTService(15);
    }

    public void btLeTxModChHigh() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxModChMid", "btLeTxModChMid()");
        requestActionToBTService(16);
    }

    public void btLeTxModChLowAA() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxModChLowAA", "btLeTxModChLowAA()");
        requestActionToBTService(17);
    }

    public void btLeTxModChMidAA() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxModChLowAA", "btLeTxModChLowAA()");
        requestActionToBTService(18);
    }

    public void btLeTxModChHighAA() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxModChLowAA", "btLeTxModChLowAA()");
        requestActionToBTService(19);
    }

    public void btLeTxCarrierChLow() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxCarrierChLow", "btLeTxCarrierChLow()");
        requestActionToBTService(20);
    }

    public void btLeTxCarrierChMid() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxCarrierChLow", "btLeTxCarrierChLow()");
        requestActionToBTService(21);
    }

    public void btLeTxCarrierChHigh() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxCarrierChHigh", "btLeTxCarrierChHigh()");
        requestActionToBTService(22);
    }

    public void btLeTxInBandChLow() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxInBandChLow", "btLeTxInBandChLow()");
        requestActionToBTService(23);
    }

    public void btLeTxInBandChMid() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxInBandChMid", "btLeTxInBandChMid()");
        requestActionToBTService(24);
    }

    public void btLeTxInBandChHigh() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTxInBandChHigh", "btLeTxInBandChHigh()");
        requestActionToBTService(25);
    }

    public void btLeRxLow() {
        FtUtil.log_i(this.CLASS_NAME, "btLeRxLow", "btLeRxLow()");
        requestActionToBTService(26);
    }

    public void btLeRxMid() {
        FtUtil.log_i(this.CLASS_NAME, "btLeRxMid", "btLeRxMid()");
        requestActionToBTService(27);
    }

    public void btLeRxHigh() {
        FtUtil.log_i(this.CLASS_NAME, "btLeRxHigh", "btLeRxHigh()");
        requestActionToBTService(28);
    }

    public void btLeTestEnd() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTestEnd", "btLeTestEnd()");
        requestActionToBTService(29);
    }

    public void btLeRxTestResult(int arg) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "btLeRxTestResult", "btLeRxTestResult arg: " + arg);
        requestActionToBTService(82, arg);
    }

    public void btEdrTxLow() {
        FtUtil.log_i(this.CLASS_NAME, "btEdrTxLow", "btEdrTxLow()");
        requestActionToBTService(30);
    }

    public void btEdrTxMid() {
        FtUtil.log_i(this.CLASS_NAME, "btEdrTxMid", "btEdrTxMid()");
        requestActionToBTService(31);
    }

    public void btEdrTxHigh() {
        FtUtil.log_i(this.CLASS_NAME, "btEdrTxHigh", "btEdrTxHigh()");
        requestActionToBTService(32);
    }

    public void btEdrRxLow() {
        FtUtil.log_i(this.CLASS_NAME, "btEdrRxLow", "btEdrRxLow()");
        requestActionToBTService(33);
    }

    public void btEdrRxMid() {
        FtUtil.log_i(this.CLASS_NAME, "btEdrRxMid", "btEdrRxMid()");
        requestActionToBTService(34);
    }

    public void btEdrRxHigh() {
        FtUtil.log_i(this.CLASS_NAME, "btEdrRxHigh", "btEdrRxHigh()");
        requestActionToBTService(35);
    }

    public void btBrEdrTestEnd() {
        FtUtil.log_i(this.CLASS_NAME, "btBrEdrTestEnd", "btBrEdrTestEnd()");
        requestActionToBTService(36);
    }

    public void btHpmLowPath() {
        FtUtil.log_i(this.CLASS_NAME, "btHpmLowPath", "btHpmLowPath()");
        requestActionToBTService(37);
    }

    public void btHpmHighPath() {
        FtUtil.log_i(this.CLASS_NAME, "btHpmHighPath", "btHpmHighPath()");
        requestActionToBTService(38);
    }

    public void btHpmReadPath() {
        FtUtil.log_i(this.CLASS_NAME, "btHpmReadPath", "btHpmReadPath()");
        requestActionToBTService(39);
    }

    public void btBrTxLow() {
        FtUtil.log_i(this.CLASS_NAME, "btBrTxLow", "btBrTxLow()");
        requestActionToBTService(40);
    }

    public void btBrTxMid() {
        FtUtil.log_i(this.CLASS_NAME, "btBrTxMid", "btBrTxMid()");
        requestActionToBTService(41);
    }

    public void btBrTxHigh() {
        FtUtil.log_i(this.CLASS_NAME, "btBrTxHigh", "btBrTxHigh()");
        requestActionToBTService(42);
    }

    public void btBrRxLow() {
        FtUtil.log_i(this.CLASS_NAME, "btBrRxLow", "btBrRxLow()");
        requestActionToBTService(43);
    }

    public void btBrRxMid() {
        FtUtil.log_i(this.CLASS_NAME, "btBrRxMid", "btBrRxMid()");
        requestActionToBTService(44);
    }

    public void btBrRxHigh() {
        FtUtil.log_i(this.CLASS_NAME, "btBrRxHigh", "btBrRxHigh()");
        requestActionToBTService(45);
    }

    public void btLeTest1M() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTest1M", "btLeTest1M()");
        requestActionToBTService(46);
    }

    public void btLeTest2M() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTest2M", "btLeTest2M()");
        requestActionToBTService(47);
    }

    public void btLeTestRead() {
        FtUtil.log_i(this.CLASS_NAME, "btLeTestRead", "btLeTestRead()");
        requestActionToBTService(48);
    }

    public void dualBtSignalSelect(int arg) {
        FtUtil.log_i(this.CLASS_NAME, "dualBtSignalSelect", "dualBtSignalSelect()");
        requestActionToBTService(70, arg);
    }

    public void dualBtCoreSelect(int arg) {
        FtUtil.log_i(this.CLASS_NAME, "dualBtCoreSelect", "dualBtCoreSelect()");
        requestActionToBTService(71, arg);
    }

    public void dualBtChannel(int arg) {
        FtUtil.log_i(this.CLASS_NAME, "dualBtChannel", "dualBtChannel()");
        requestActionToBTService(72, arg);
    }

    public void dualBtDataRate(int arg) {
        FtUtil.log_i(this.CLASS_NAME, "dualBtDataRate", "dualBtDataRate()");
        requestActionToBTService(73, arg);
    }

    public void dualBtTxPower(int arg) {
        FtUtil.log_i(this.CLASS_NAME, "dualBtTxPower", "dualBtTxPower()");
        requestActionToBTService(74, arg);
    }

    public void dualBtPaMode(int arg) {
        FtUtil.log_i(this.CLASS_NAME, "dualBtPaMode", "dualBtPaMode()");
        requestActionToBTService(75, arg);
    }

    public void dualBtPacketType(int arg) {
        FtUtil.log_i(this.CLASS_NAME, "dualBtPacketType", "dualBtPacketType()");
        requestActionToBTService(76, arg);
    }

    public void dualBtAclFrame(int arg) {
        FtUtil.log_i(this.CLASS_NAME, "dualBtAclFrame", "dualBtAclFrame()");
        requestActionToBTService(77, arg);
    }

    public void dualBtTxStartStop(int arg) {
        FtUtil.log_i(this.CLASS_NAME, "dualBtTxStartStop", "dualBtTxStartStop()");
        requestActionToBTService(78, arg);
    }

    public void dualBtRxStartStop(int arg) {
        FtUtil.log_i(this.CLASS_NAME, "dualBtRxStartStop", "dualBtRxStartStop()");
        requestActionToBTService(79, arg);
    }

    public void dualBtRxGoodpacket() {
        FtUtil.log_i(this.CLASS_NAME, "dualBtRxGoodpacket", "dualBtRxGoodpacket()");
        requestActionToBTService(80);
    }

    public void btAntSwitchEdrTxMid() {
        FtUtil.log_i(this.CLASS_NAME, "btAntSwitchEdrTxMid", "btAntSwitchEdrTxMid()");
        requestActionToBTService(81);
    }

    public boolean isRunningBtDevice() {
        return this.mIsRunningBtDevice;
    }

    public boolean isEnabledBtDevice() {
        BluetoothAdapter mBtAdapter = BluetoothAdapter.getDefaultAdapter();
        if (mBtAdapter != null) {
            return mBtAdapter.isEnabled();
        }
        FtUtil.log_w(this.CLASS_NAME, "isEnabledBtDevice", "mBtAdapter is null");
        return false;
    }

    public void readBtId() {
        Intent intent = new Intent(ACTION_BT_ID_READ);
        intent.addFlags(268435456);
        intent.addFlags(16777216);
        sendBroadcast(intent);
    }

    public void writeBtId(String id) {
        String colonadded = "";
        for (int i = 0; i < id.length(); i += 2) {
            colonadded = i == id.length() - 2 ? colonadded + id.substring(i) : colonadded + id.substring(i, i + 2) + ":";
        }
        FtUtil.log_i(this.CLASS_NAME, "writeBtId", "colonadded=" + colonadded);
        Intent intent = new Intent(ACTION_BT_ID_WRITE);
        intent.putExtra("MAC_DATA", colonadded);
        intent.addFlags(268435456);
        intent.setPackage("com.sec.android.app.bluetoothtest");
        sendBroadcast(intent);
    }

    public void nfcOn() {
        Intent service = new Intent(getApplicationContext(), ModuleCommunicationService.class);
        service.putExtra("action", ModuleCommunicationService.ACTION_NFC_ON);
        startService(service);
    }

    public void nfcOff() {
        Intent service = new Intent(getApplicationContext(), ModuleCommunicationService.class);
        service.putExtra("action", ModuleCommunicationService.ACTION_NFC_OFF);
        startService(service);
    }

    public void readWifiId() {
        Intent intent = new Intent(ACTION_WIFI_ID_READ);
        intent.addFlags(268435456);
        intent.addFlags(16777216);
        sendBroadcast(intent);
    }

    public void writeWifiId(String id) {
        String colonadded = "";
        for (int i = 0; i < id.length(); i += 2) {
            colonadded = i == id.length() - 2 ? colonadded + id.substring(i) : colonadded + id.substring(i, i + 2) + ":";
        }
        Intent intent = new Intent(ACTION_WIFI_ID_WRITE);
        intent.putExtra("MAC_DATA", colonadded);
        intent.addFlags(268435456);
        intent.addFlags(16777216);
        sendBroadcast(intent);
    }

    public void fmRadioOn(String frequency, int target) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "fmRadioOn", "frequency: " + frequency);
        Intent intent = new Intent("test.mode.radio.on.freq");
        intent.putExtra("frequency", frequency);
        intent.putExtra("output", FM_RADIO_TARGET[target]);
        intent.setFlags(268435456);
        startActivity(intent);
    }

    public void fmRadioOff() {
        Intent intent = new Intent("test.mode.radio.off");
        intent.setFlags(268435456);
        startActivity(intent);
    }

    public void fmRadioReadFrequencyIntensity(String frequency) {
        Intent intent = new Intent("test.mode.radio.freq");
        intent.putExtra("frequency", frequency);
        intent.setFlags(268435456);
        startActivity(intent);
    }

    public void felicaSetDataNTxWhereAtcmd(int i_data) {
        if ("SENN3AB".equals(this.nfcChipName) || "SENN5ABP".equals(this.nfcChipName)) {
            Intent intent = new Intent("com.sec.android.app.felicatest.FELICA_TEST_INDICATION");
            intent.putExtra(EXTRA_KEY_BT_SERVICE_REQUEST, 1);
            intent.putExtra("I_DATA", i_data);
            intent.addFlags(16777216);
            getApplicationContext().sendBroadcast(intent);
            return;
        }
        Intent intent2 = new Intent("com.sec.android.app.felicatest.FELICA_SET_EDC");
        intent2.putExtra("I_DATA", i_data);
        intent2.addFlags(16777216);
        getApplicationContext().sendBroadcast(intent2);
    }

    public void felicaActivationWhereAtcmd() {
        if ("SENN3AB".equals(this.nfcChipName) || "SENN5ABP".equals(this.nfcChipName)) {
            FtUtil.log_i(this.CLASS_NAME, "felicaActivationWhereAtcmd", "Felica Activation where Atcmd");
            Intent intent = new Intent();
            intent.setClassName("com.sec.android.app.felicatest", "com.sec.android.app.felicatest.FeliCaTest");
            intent.setFlags(268435456);
            intent.putExtra("FeliCa_Start_Parameter", FactoryTestManager.TEST_REAR_CAMERA_MULTI_CAL);
            getApplicationContext().startActivity(intent);
        }
    }

    public void felicafelicaIDmReadWhereAtCmd() {
        if ("SENN3AB".equals(this.nfcChipName) || "SENN5ABP".equals(this.nfcChipName)) {
            Intent intent = new Intent();
            intent.setClassName("com.sec.android.app.felicatest", "com.sec.android.app.felicatest.FeliCaTest");
            intent.setFlags(268435456);
            intent.addFlags(268435456);
            FtUtil.log_i(this.CLASS_NAME, "felicaIDmRead", "felicafelicaIDmReadWhereAtCmd FLAG_RECEIVER_FOREGROUND");
            intent.putExtra("FeliCa_Start_Parameter", FactoryTestManager.TEST_SUB_TSP_OPEN_SHORT_PRESENTATION);
            getApplicationContext().startActivity(intent);
            return;
        }
        Intent intent2 = new Intent("com.sec.android.app.felicatest.FELICA_GET_IDM");
        intent2.addFlags(268435456);
        intent2.addFlags(16777216);
        getApplicationContext().sendBroadcast(intent2);
    }

    public void felicaSetDataPassWhereAtCmd() {
        if ("SENN3AB".equals(this.nfcChipName) || "SENN5ABP".equals(this.nfcChipName)) {
            Intent intent = new Intent("com.sec.android.app.felicatest.FELICA_TEST_PASS");
            intent.putExtra(EXTRA_KEY_BT_SERVICE_REQUEST, 0);
            intent.putExtra("I_DATA", 0);
            intent.addFlags(16777216);
            getApplicationContext().sendBroadcast(intent);
            return;
        }
        Intent intent2 = new Intent("com.sec.android.app.felicatest.FELICA_TEST_PASS");
        intent2.addFlags(16777216);
        getApplicationContext().sendBroadcast(intent2);
    }

    public void felicaSetDataFailWhereAtCmd() {
        if ("SENN3AB".equals(this.nfcChipName) || "SENN5ABP".equals(this.nfcChipName)) {
            Intent intent = new Intent("com.sec.android.app.felicatest.FELICA_TEST_FAIL");
            intent.putExtra(EXTRA_KEY_BT_SERVICE_REQUEST, 0);
            intent.putExtra("I_DATA", 0);
            intent.addFlags(16777216);
            getApplicationContext().sendBroadcast(intent);
            return;
        }
        Intent intent2 = new Intent("com.sec.android.app.felicatest.FELICA_TEST_FAIL");
        intent2.addFlags(16777216);
        getApplicationContext().sendBroadcast(intent2);
    }

    public void felicaDeactivationWhereAtCmd() {
        if ("SENN3AB".equals(this.nfcChipName) || "SENN5ABP".equals(this.nfcChipName)) {
            Intent intent = new Intent("com.sec.android.app.felicatest.FELICA_TEST_GETNV");
            intent.putExtra(EXTRA_KEY_BT_SERVICE_REQUEST, 3);
            intent.putExtra("I_DATA", 0);
            intent.addFlags(16777216);
            getApplicationContext().sendBroadcast(intent);
            return;
        }
        Intent intent2 = new Intent("com.sec.android.app.felicatest.FELICA_START_APC");
        intent2.addFlags(16777216);
        getApplicationContext().sendBroadcast(intent2);
    }

    public void felicaInitPassword() {
        FtUtil.log_i(this.CLASS_NAME, "felicaIDmRead", "Felica Init Password");
        Intent intent = new Intent(ACTION_FELICA_LOCK_REQUEST);
        intent.addFlags(268435456);
        FtUtil.log_i(this.CLASS_NAME, "felicaIDmRead", "felicaInitPassword FLAG_RECEIVER_FOREGROUND");
        intent.putExtra("CMD", 1);
        intent.addFlags(16777216);
        getApplicationContext().sendBroadcast(intent);
    }

    public void felicaReadPassword() {
        FtUtil.log_i(this.CLASS_NAME, "felicaReadPassword", "Felica Read Password");
        Intent intent = new Intent(ACTION_FELICA_LOCK_REQUEST);
        intent.addFlags(268435456);
        FtUtil.log_i(this.CLASS_NAME, "felicaReadPassword", "felicaReadPassword FLAG_RECEIVER_FOREGROUND");
        intent.putExtra("CMD", 2);
        intent.addFlags(16777216);
        getApplicationContext().sendBroadcast(intent);
    }

    private void EthernetSwitch(String action) {
        SystemProperties.set("persist.eth.on", action);
        try {
            Thread.sleep(1000);
            FtUtil.log_i(this.CLASS_NAME, "EthernetSwitch", "deley MountTime");
        } catch (Exception e) {
            FtUtil.log_e(e);
        }
    }

    private boolean EthernetState() {
        return SystemProperties.get("persist.eth.on", EgisFingerprint.MAJOR_VERSION).equals("0");
    }

    private void EfuseSwitch(String action) {
        SystemProperties.set("persist.eth.efuse", action);
    }

    public boolean WriteEthernetMac(String id) {
        File ethDirectory = new File(Support.Kernel.getFilePath(Support.Kernel.SECEFS_ETH_DIRECTORY));
        if (!ethDirectory.exists()) {
            FtUtil.log_i(this.CLASS_NAME, "WriteEthernetMac", "Create ETHERNET_MAC_ADDRESS_EFS directory...");
            ethDirectory.mkdir();
            ethDirectory.setExecutable(true, true);
            ethDirectory.setWritable(true, true);
            ethDirectory.setReadable(true, false);
        }
        boolean resData = Support.Kernel.write(Support.Kernel.ETHERNET_MAC_ADDRESS_EFS, id.toUpperCase(Locale.ENGLISH));
        if (!resData) {
            return resData;
        }
        if (!EthernetState()) {
            EthernetSwitch("0");
        }
        try {
            Thread.sleep(1000);
            EfuseSwitch(EgisFingerprint.MAJOR_VERSION);
            Thread.sleep(3000);
            EfuseSwitch("0");
            if (EthernetState()) {
                EthernetSwitch(EgisFingerprint.MAJOR_VERSION);
            }
            EthernetSwitch("0");
            return resData;
        } catch (Exception e) {
            FtUtil.log_e(e);
            return false;
        }
    }

    public String ReadEthernetMac() {
        String resData = null;
        if (!EthernetState()) {
            EthernetSwitch("0");
        }
        int count = 0;
        while (true) {
            if (count >= 10) {
                break;
            }
            resData = Support.Kernel.read(Support.Kernel.ETHERNET_MAC_ADDRESS);
            if (!"00:00:00:00:00:00".equals(resData)) {
                FtUtil.log_i(this.CLASS_NAME, "ReadEthernetMac", "Mount Success");
                break;
            }
            try {
                Thread.sleep(500);
                FtUtil.log_i(this.CLASS_NAME, "ReadEthernetMac", "deley MountTime");
            } catch (Exception e) {
                FtUtil.log_e(e);
            }
            count++;
        }
        String resData2 = resData.replaceAll(":", "").toUpperCase(Locale.ENGLISH);
        String resData_efs = Support.Kernel.read(Support.Kernel.ETHERNET_MAC_ADDRESS_EFS);
        if (resData2 == null || resData2.equals("") || !resData2.equals(resData_efs)) {
            return "NG";
        }
        return resData2;
    }

    public boolean ConnectionCheckEthernet(int condition) {
        if (!EthernetState()) {
            EthernetSwitch("0");
            try {
                Thread.sleep(2000);
                FtUtil.log_i(this.CLASS_NAME, "ConnectionCheckEthernet", "deley MountTime");
            } catch (Exception e) {
                FtUtil.log_e(e);
            }
        }
        switch (condition) {
            case 0:
                if (Support.Kernel.isExistFileID(Support.Kernel.ETHERNET_MAC_ADDRESS)) {
                    return true;
                }
                return false;
            case 1:
                String resData = Support.Kernel.read(Support.Kernel.ETHERNET_CONNECTION);
                if (resData == null || !resData.equals(EgisFingerprint.MAJOR_VERSION)) {
                    return false;
                }
                return true;
            default:
                return false;
        }
    }

    private String ConvertAddressColonFormat(String id) {
        String colonadded = "";
        for (int i = 0; i < id.length(); i += 2) {
            colonadded = i == id.length() - 2 ? colonadded + id.substring(i) : colonadded + id.substring(i, i + 2) + ":";
        }
        return colonadded;
    }
}
