package com.sec.factory.modules;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import com.sec.factory.aporiented.athandler.AtHaictest;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;

public class ModuleCoverID {
    private static final String ACCESS_PERMISSION = "com.samsung.accessory.manager.permission.AUTHENTICATION_CONTROL";
    public static final String ACTION_READ_STATE_REQUEST = "com.samsung.accessory.manager.action.AUTHENTICATION_STATE_REQUEST";
    public static final String ACTION_READ_STATE_RESULT = "com.samsung.accessory.manager.action.AUTHENTICATION_STATE_REPLY";
    public static final String ACTION_START_AUTHENTICATION_REQUEST = "com.samsung.accessory.manager.action.START_AUTHENTICATION";
    public static final String ACTION_START_AUTHENTICATION_RESULT = "com.samsung.accessory.manager.action.AUTHENTICATION_RESULT";
    private static final String EXTRA_ATTACH_INFO = "attachInfo";
    private static final String EXTRA_CONNECTIVITY_TYPE = "connectivity_type";
    private static final String EXTRA_DETACH_INFO = "detachInfo";
    private static final String EXTRA_ID = "id_factory";
    private static final String EXTRA_PACKAGE_NAME = "package_name";
    private static final String EXTRA_RESULT = "result_factory";
    private static final String EXTRA_SERIAL_NO = "serial_factory";
    private static final String VALUE_TYPE_NFC = "nfc";
    private String CLASS_NAME;
    private BroadcastReceiver mBroadcastReceiver;
    private boolean mCheckHallIC;
    private Context mContext;
    private CoverIDListener mCoverIDListener;

    public interface CoverIDListener {
        void onAuthenticationResult(String str, String str2, String str3, String str4, String str5);
    }

    public ModuleCoverID(String TAG, Context context, CoverIDListener listener) {
        this.mCheckHallIC = false;
        this.CLASS_NAME = TAG + "ModuleCoverID";
        this.mContext = context;
        this.mCoverIDListener = listener;
    }

    public ModuleCoverID(String TAG, Context context, CoverIDListener listener, boolean checkHallIC) {
        this(TAG, context, listener);
        this.mCheckHallIC = checkHallIC;
    }

    public void registerReceiver(final String action) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "registerReceiver = " + action);
        if (this.mBroadcastReceiver == null) {
            this.mBroadcastReceiver = new BroadcastReceiver() {
                /* class com.sec.factory.modules.ModuleCoverID.AnonymousClass1 */

                public void onReceive(Context context, Intent intent) {
                    FtUtil.log_d(ModuleCoverID.this.CLASS_NAME, "onReceive = " + action);
                    String result = intent.getStringExtra(ModuleCoverID.EXTRA_RESULT);
                    String serialNo = intent.getStringExtra(ModuleCoverID.EXTRA_SERIAL_NO);
                    String id = intent.getStringExtra(ModuleCoverID.EXTRA_ID);
                    String attachInfo = intent.getStringExtra(ModuleCoverID.EXTRA_ATTACH_INFO);
                    String detachInfo = intent.getStringExtra(ModuleCoverID.EXTRA_DETACH_INFO);
                    FtUtil.log_d(ModuleCoverID.this.CLASS_NAME, "result = " + result, ", serialNumber = " + serialNo + ", ID = " + id + ", AttachInfo = " + attachInfo + ", DetachInfo = " + detachInfo);
                    String str = ModuleCoverID.this.CLASS_NAME;
                    StringBuilder sb = new StringBuilder();
                    sb.append("mCheckHallIC : ");
                    sb.append(ModuleCoverID.this.mCheckHallIC);
                    FtUtil.log_d(str, sb.toString());
                    if (ModuleCoverID.this.mCheckHallIC && "OK".equalsIgnoreCase(result)) {
                        if (AtHaictest.HALL_IC_STATE.OPEN.toString().equals(new AtHaictest(ModuleCoverID.this.mContext).getResult(Support.Kernel.PATH_HALLIC_DETECT_STATE))) {
                            result = "NG_COVEROPEN";
                            FtUtil.log_d(ModuleCoverID.this.CLASS_NAME, "mCheckHallIC result = " + result);
                        }
                    }
                    if (ModuleCoverID.this.mCoverIDListener == null) {
                        FtUtil.log_w(ModuleCoverID.this.CLASS_NAME, "onReceive = mCoverIDListener is null");
                    } else {
                        ModuleCoverID.this.mCoverIDListener.onAuthenticationResult(result, serialNo, id, attachInfo, detachInfo);
                    }
                }
            };
        }
        this.mContext.registerReceiver(this.mBroadcastReceiver, new IntentFilter(action));
    }

    public void unRegisterReceiver() {
        FtUtil.log_d(this.CLASS_NAME, "unRegisterReceiver");
        BroadcastReceiver broadcastReceiver = this.mBroadcastReceiver;
        if (broadcastReceiver == null) {
            FtUtil.log_w(this.CLASS_NAME, "unRegisterReceiver = mBroadcastReceiver is null");
            return;
        }
        this.mContext.unregisterReceiver(broadcastReceiver);
        this.mBroadcastReceiver = null;
    }

    public void sendRequest(String action) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "sendRequest = " + action);
        Intent intent = new Intent(action);
        intent.putExtra(EXTRA_PACKAGE_NAME, this.mContext.getPackageName());
        intent.putExtra(EXTRA_CONNECTIVITY_TYPE, VALUE_TYPE_NFC);
        this.mContext.sendBroadcast(intent, ACCESS_PERMISSION);
    }

    public void setListener(CoverIDListener listener) {
        FtUtil.log_w(this.CLASS_NAME, "setListener", listener.toString());
        this.mCoverIDListener = listener;
    }
}
