package com.sec.factory.modules;

import android.content.Context;
import android.media.AudioManager;
import android.media.MediaPlayer;
import com.sec.factory.R;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;

public class ModuleForceTouch extends ModuleObject {
    private static final String CLASS_NAME = "ModuleForceTouch";
    public static final String FAIL = "FAIL";
    public static final String FORCE_CMD__GET_CHIP_VENDOR = "get_chip_vendor";
    public static final String FORCE_CMD__GET_PRESSURE_DATA_INDEX = "get_pressure_data_index";
    public static final String FORCE_CMD__GET_PRESSURE_STRENGTH = "get_pressure_strength";
    public static final String FORCE_CMD__RUN_FORCE_PRESSURE_CALIBRATION = "run_force_pressure_calibration";
    public static final String FORCE_CMD__RUN_PRESSURE_FILTERED_STRENGTH_READ_ALL = "run_pressure_filtered_strength_read_all";
    public static final String FORCE_CMD__RUN_PRESSURE_IX_DATA_READ_ALL = "run_pressure_ix_data_read_all";
    public static final String FORCE_CMD__RUN_PRESSURE_JITTER_P2P_READ = "run_pressure_jitter_p2p_read";
    public static final String FORCE_CMD__RUN_PRESSURE_OFFSET_READ_ALL = "run_pressure_offset_read_all";
    public static final String FORCE_CMD__RUN_PRESSURE_RAWDATA_READ_ALL = "run_pressure_rawdata_read_all";
    public static final String FORCE_CMD__RUN_PRESSURE_STRENGTH_READ_ALL = "run_pressure_strength_read_all";
    public static final String FORCE_CMD__SET_PRESSURE_DATA_INDEX = "set_pressure_data_index";
    public static final String FORCE_CMD__SET_PRESSURE_STRENGTH = "set_pressure_strength";
    public static final String FORCE_CMD__SET_PRESSURE_STRENGTH_CLEAR = "set_pressure_strength_clear";
    public static final String FORCE_CMD__SET_PRESSURE_TEST_MODE = "set_pressure_test_mode";
    public static final int INDEX_ASSY = 1;
    public static final int INDEX_BASE = 0;
    public static final int INDEX_BG = 3;
    public static final int INDEX_REAR = 2;
    public static final String NA = "NOT_APPLICABLE";
    public static final String NG = "NG";
    public static final String OK = "OK";
    public static final String PASS = "PASS";
    public static final String RUNNING = "RUNNING";
    public static final String WAITING = "WAITING";
    private static ModuleForceTouch mInstance = null;
    private String mVendor;

    public enum CHANNEL {
        LEFT,
        CENTER,
        RIGHT
    }

    private ModuleForceTouch(Context context) {
        super(context, CLASS_NAME);
        this.mVendor = null;
        this.mVendor = cmdHandler.getResult("get_chip_vendor");
    }

    public static synchronized ModuleForceTouch instance(Context context) {
        ModuleForceTouch moduleForceTouch;
        synchronized (ModuleForceTouch.class) {
            if (mInstance == null) {
                mInstance = new ModuleForceTouch(context);
            }
            moduleForceTouch = mInstance;
        }
        return moduleForceTouch;
    }

    public String getVendor() {
        return this.mVendor;
    }

    public String getStringForceResult(String command) {
        return cmdHandler.getResult(command);
    }

    public String getStringRawCap() {
        return cmdHandler.getResult(FORCE_CMD__RUN_PRESSURE_RAWDATA_READ_ALL);
    }

    public int getIntStrengthAvg(CHANNEL ch, int specMin, int specMax, int loopCnt) {
        String[] arrStringResult;
        ArrayList<Integer> strenghList = new ArrayList<>();
        FtUtil.log_d(CLASS_NAME, "getIntStrengthAvg", "Start - Channel : " + ch);
        for (int i = 0; i < loopCnt; i++) {
            if (ModuleTouchScreen.TSP_VENDOR_NAME__SEC.equalsIgnoreCase(getVendor())) {
                arrStringResult = cmdHandler.getResultArr(FORCE_CMD__RUN_PRESSURE_FILTERED_STRENGTH_READ_ALL);
            } else {
                arrStringResult = cmdHandler.getResultArr(FORCE_CMD__RUN_PRESSURE_STRENGTH_READ_ALL);
            }
            if (arrStringResult.length != CHANNEL.values().length) {
                return -1;
            }
            try {
                strenghList.add(Integer.valueOf(Integer.parseInt(arrStringResult[ch.ordinal()])));
            } catch (NumberFormatException e) {
                return -1;
            }
        }
        if (((Integer) Collections.min(strenghList)).intValue() < specMin) {
            return ((Integer) Collections.min(strenghList)).intValue();
        }
        if (((Integer) Collections.max(strenghList)).intValue() > specMax) {
            return ((Integer) Collections.max(strenghList)).intValue();
        }
        int sum = 0;
        for (int i2 = 0; i2 < strenghList.size(); i2++) {
            sum += strenghList.get(i2).intValue();
        }
        FtUtil.log_d(CLASS_NAME, "getIntStrengthAvg", "END - Channel : " + ch + " / avg : " + (sum / loopCnt));
        return sum / loopCnt;
    }

    public String getCalData(int index) {
        return cmdHandler.getResult("get_pressure_strength," + index);
    }

    public String getCalDataIndex() {
        return cmdHandler.getResult(FORCE_CMD__GET_PRESSURE_DATA_INDEX);
    }

    public boolean setCalDataIndex(int index) {
        FtUtil.log_d(CLASS_NAME, "setCalDataIndex", "");
        String stringResult = cmdHandler.getResult("set_pressure_data_index," + index);
        if (!stringResult.equalsIgnoreCase("NG") && !stringResult.equalsIgnoreCase("NOT_APPLICABLE")) {
            return true;
        }
        FtUtil.log_d(CLASS_NAME, "setCalDataIndex", "fail : " + stringResult);
        return false;
    }

    public boolean setTestMode(boolean isTestMode) {
        String subCmd;
        FtUtil.log_d(CLASS_NAME, "setTestMode", "");
        if (isTestMode) {
            subCmd = EgisFingerprint.MAJOR_VERSION;
        } else {
            subCmd = "0";
        }
        String stringResult = cmdHandler.getResult("set_pressure_test_mode," + subCmd);
        if (!stringResult.equalsIgnoreCase("NG") && !stringResult.equalsIgnoreCase("NOT_APPLICABLE")) {
            return true;
        }
        FtUtil.log_d(CLASS_NAME, "setTestMode", "fail : " + stringResult);
        return false;
    }

    public boolean setCalDataClear() {
        String stringResult = cmdHandler.getResult(FORCE_CMD__SET_PRESSURE_STRENGTH_CLEAR);
        if (!stringResult.equalsIgnoreCase("NG") && !stringResult.equalsIgnoreCase("NOT_APPLICABLE")) {
            return true;
        }
        FtUtil.log_d(CLASS_NAME, "setCalDataClear", "fail : " + stringResult);
        return false;
    }

    public boolean saveCalData(int index, int[] arrCalData) {
        String stringResult = cmdHandler.getResult("set_pressure_strength," + (index + "," + Arrays.toString(arrCalData).replaceAll("[^0-9\\,]", "")));
        if (!stringResult.equalsIgnoreCase("NG") && !stringResult.equalsIgnoreCase("NOT_APPLICABLE")) {
            return true;
        }
        FtUtil.log_d(CLASS_NAME, "saveCalData", "save fail : " + stringResult);
        return false;
    }

    public boolean runAutoTune() {
        FtUtil.log_d(CLASS_NAME, "runAutoTune", "");
        String stringResult = cmdHandler.getResult(FORCE_CMD__RUN_FORCE_PRESSURE_CALIBRATION);
        if (stringResult.equalsIgnoreCase("OK")) {
            return true;
        }
        FtUtil.log_d(CLASS_NAME, "runAutoTune", "fail : " + stringResult);
        return false;
    }

    public boolean saveCalDataInEFS(int[] arrCalData) {
        return Support.Kernel.writeNsync(Support.Kernel.PATH_FORCE_CAL_DATA_EFS, Arrays.toString(arrCalData).replaceAll("[^0-9\\,]", ""));
    }

    public String getCalDataForATCommand(int index) {
        String result = cmdHandler.getResult("get_pressure_strength," + index);
        String[] arrData = result.split(",");
        boolean[] mArrIsEnabledChannel = {true, true, true};
        mArrIsEnabledChannel[0] = Support.TestCase.getEnabled(Support.TestCase.FORCE_TOUCH_TEST_LEFT);
        mArrIsEnabledChannel[1] = Support.TestCase.getEnabled(Support.TestCase.FORCE_TOUCH_TEST_CENTER);
        mArrIsEnabledChannel[2] = Support.TestCase.getEnabled(Support.TestCase.FORCE_TOUCH_TEST_RIGHT);
        for (int i = 0; i < arrData.length; i++) {
            try {
                if (!mArrIsEnabledChannel[i]) {
                    arrData[i] = "NONE";
                }
            } catch (ArrayIndexOutOfBoundsException e) {
                FtUtil.log_e(e);
                return "NA";
            }
        }
        if (Support.Kernel.isExistFile(Support.Kernel.PATH_FORCE_CAL_DATA_EFS)) {
            String calInEFS = Support.Kernel.read(Support.Kernel.PATH_FORCE_CAL_DATA_EFS);
            if (calInEFS == null) {
                FtUtil.log_d(CLASS_NAME, "getCalDataForATCommand", "[Mismatch] There is no file in EFS(null case)");
            } else if (!calInEFS.equals(result)) {
                FtUtil.log_d(CLASS_NAME, "getCalDataForATCommand", "[Mismatch] IC : " + result + " / EFS : " + calInEFS);
            }
        } else {
            FtUtil.log_d(CLASS_NAME, "getCalDataForATCommand", "[Mismatch] There is no file in EFS");
        }
        return arrData[0] + "," + arrData[1] + "," + arrData[2];
    }

    public String getCalAllDataForATCommand() {
        boolean isSuccessLoad;
        boolean[] mArrIsEnabledChannel = {true, true, true};
        BufferedReader in = null;
        ArrayList<String> listCalData = new ArrayList<>();
        StringBuilder Result = new StringBuilder();
        if (Support.Kernel.isExistFilePath("/data/log/ForceCalData.log")) {
            try {
                BufferedReader in2 = new BufferedReader(new FileReader("/data/log/ForceCalData.log"));
                boolean hasMore = true;
                while (hasMore) {
                    String tempString = in2.readLine();
                    if (tempString != null) {
                        listCalData.add(tempString);
                    } else {
                        hasMore = false;
                    }
                }
                isSuccessLoad = true;
                try {
                    in2.close();
                } catch (IOException e) {
                    FtUtil.log_e(CLASS_NAME, "loadDataFromFile", e.getMessage());
                }
            } catch (IOException e2) {
                e2.printStackTrace();
                isSuccessLoad = false;
                if (0 != 0) {
                    in.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        in.close();
                    } catch (IOException e3) {
                        FtUtil.log_e(CLASS_NAME, "loadDataFromFile", e3.getMessage());
                    }
                }
                throw th;
            }
            if (!isSuccessLoad) {
                return "NG";
            }
            for (int j = 0; j < listCalData.size(); j++) {
                String[] arrData = listCalData.get(j).split(" ");
                mArrIsEnabledChannel[0] = Support.TestCase.getEnabled(Support.TestCase.FORCE_TOUCH_TEST_LEFT);
                mArrIsEnabledChannel[1] = Support.TestCase.getEnabled(Support.TestCase.FORCE_TOUCH_TEST_CENTER);
                mArrIsEnabledChannel[2] = Support.TestCase.getEnabled(Support.TestCase.FORCE_TOUCH_TEST_RIGHT);
                for (int i = 0; i < arrData.length; i++) {
                    if (!mArrIsEnabledChannel[i]) {
                        arrData[i] = "NA";
                    }
                }
                if (listCalData.size() - 1 == j) {
                    Result.append(arrData[0] + "," + arrData[1] + "," + arrData[2]);
                } else {
                    Result.append(arrData[0] + "," + arrData[1] + "," + arrData[2] + ",");
                }
            }
            try {
                return Result.toString();
            } catch (ArrayIndexOutOfBoundsException e4) {
                FtUtil.log_e(e4);
                return "NG";
            }
        } else {
            FtUtil.log_d(CLASS_NAME, "getCalAllDataForATCommand", "there is no file");
            return "NONE";
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:16:?, code lost:
        r9.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0059, code lost:
        r8 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x005a, code lost:
        r8.printStackTrace();
     */
    public String getCalDataSDCForATCommand() {
        BufferedReader in = null;
        boolean isStrengthValue = false;
        boolean isSuccessLoad = false;
        boolean hasMore = true;
        String calValue = "";
        try {
            BufferedReader in2 = new BufferedReader(new FileReader(Support.Kernel.getFilePath(Support.Kernel.PATH_FORCE_CFOFFSET_STRENGTH)));
            while (true) {
                if (hasMore) {
                    String tempString = in2.readLine();
                    if (tempString != null) {
                        FtUtil.log_d(CLASS_NAME, "getCalDataSDCForATCommand", "data : " + tempString);
                        if (tempString.contains("STRENGTH")) {
                            isStrengthValue = true;
                        }
                        if (isStrengthValue && tempString.contains("SDC")) {
                            calValue = tempString;
                            FtUtil.log_d(CLASS_NAME, "getCalDataSDCForATCommand", tempString);
                            isSuccessLoad = true;
                            break;
                        }
                    } else {
                        hasMore = false;
                    }
                }
            }
        } catch (IOException e) {
            e.printStackTrace();
            isSuccessLoad = false;
            if (0 != 0) {
                in.close();
            }
        } catch (Throwable th) {
            if (0 != 0) {
                try {
                    in.close();
                } catch (IOException e2) {
                    e2.printStackTrace();
                }
            }
            throw th;
        }
        if (!isSuccessLoad) {
            return null;
        }
        String[] arrRawValue = calValue.split(" ");
        FtUtil.log_d(CLASS_NAME, "getCalDataSDCForATCommand", "calValue arr index : " + arrRawValue.length);
        if (arrRawValue.length == 2) {
            return arrRawValue[1].replaceAll("\t", ",");
        }
        return null;
    }

    private static class cmdHandler {
        private static final String CMD_NODE = Support.Kernel.getFilePath(Support.Kernel.TSP_COMMAND_CMD);
        private static final String CMD_RESULT = Support.Kernel.getFilePath(Support.Kernel.TSP_COMMAND_RESULT);
        private static final String CMD_STATUS = Support.Kernel.getFilePath(Support.Kernel.TSP_COMMAND_STATUS);
        private static final int RETRY_READ_CNT = 5;
        private static final int RETRY_READ_DELAY = 100;

        private cmdHandler() {
        }

        public static String[] getResultArr(String command) {
            String rawData = getResult(command);
            if (!rawData.equalsIgnoreCase("NG") && !rawData.equalsIgnoreCase("NOT_APPLICABLE")) {
                return rawData.split(",");
            }
            return new String[]{rawData, rawData, rawData};
        }

        public static String getResult(String command) {
            if (!write(CMD_NODE, command)) {
                FtUtil.log_d(ModuleForceTouch.CLASS_NAME, "getResult", "Failed write command: " + command);
                int waitCnt = 5;
                boolean cmdSuccess = false;
                while (true) {
                    int waitCnt2 = waitCnt - 1;
                    if (waitCnt <= 0) {
                        break;
                    }
                    try {
                        Thread.sleep(100);
                    } catch (InterruptedException e) {
                        FtUtil.log_d(ModuleForceTouch.CLASS_NAME, "getResult", "InterruptedException");
                    }
                    if (write(CMD_NODE, command)) {
                        cmdSuccess = true;
                        break;
                    }
                    waitCnt = waitCnt2;
                }
                if (!cmdSuccess) {
                    return "FAIL";
                }
            }
            String status = read(CMD_STATUS);
            if (status == null) {
                FtUtil.log_d(ModuleForceTouch.CLASS_NAME, "getResult", "status is null");
                return null;
            }
            if (ModuleForceTouch.RUNNING.equals(status.trim()) || ModuleForceTouch.WAITING.equals(status.trim())) {
                int waitCnt3 = 5;
                while (true) {
                    int waitCnt4 = waitCnt3 - 1;
                    if (waitCnt3 <= 0) {
                        break;
                    }
                    try {
                        Thread.sleep(100);
                    } catch (InterruptedException e2) {
                        FtUtil.log_d(ModuleForceTouch.CLASS_NAME, "getResult", "InterruptedException");
                    }
                    status = read(CMD_STATUS);
                    if (status != null) {
                        FtUtil.log_d(ModuleForceTouch.CLASS_NAME, "getResult", "status: " + status + ", waitCnt: " + waitCnt4 + " / " + 5);
                        if (!ModuleForceTouch.RUNNING.equals(status.trim()) && !ModuleForceTouch.WAITING.equals(status.trim())) {
                            break;
                        }
                        waitCnt3 = waitCnt4;
                    } else {
                        FtUtil.log_d(ModuleForceTouch.CLASS_NAME, "getResult", "status is null");
                        return null;
                    }
                }
            }
            if (!"OK".equals(status.trim())) {
                read(CMD_RESULT);
                return "FAIL";
            }
            String value = read(CMD_RESULT);
            String parsedValue = "";
            if (value == null) {
                FtUtil.log_d(ModuleForceTouch.CLASS_NAME, "getResult", "result is null");
            } else {
                parsedValue = runParse(value);
            }
            if (parsedValue == null) {
                FtUtil.log_d(ModuleForceTouch.CLASS_NAME, "getResult", "parsedValue is invalid, value: " + value);
            }
            FtUtil.log_d(ModuleForceTouch.CLASS_NAME, "getResult", "Returned value: " + value + ", parsed: " + parsedValue);
            return parsedValue;
        }

        private static String runParse(String value) {
            String[] split = value.split(":");
            if (split.length >= 2) {
                return split[1].replaceAll(" ", "");
            }
            FtUtil.log_i(ModuleForceTouch.CLASS_NAME, "getTspData", "split.length < 2");
            return null;
        }

        private static boolean write(String path, String value) {
            if (!isWriteable(path)) {
                FtUtil.log_i(ModuleForceTouch.CLASS_NAME, "write", "Failed isWriteable: " + path);
                return false;
            }
            FileOutputStream out = null;
            try {
                out = new FileOutputStream(path);
                out.write(value.getBytes());
                out.flush();
                FtUtil.log_i(ModuleForceTouch.CLASS_NAME, "write", "finish, path: " + path + ", value: " + value);
                try {
                    out.close();
                    return true;
                } catch (IOException e) {
                    return false;
                }
            } catch (IOException e2) {
                FtUtil.log_e(e2);
                if (out != null) {
                    try {
                        out.close();
                    } catch (IOException e3) {
                        return false;
                    }
                }
                return false;
            } catch (Throwable e4) {
                if (out != null) {
                    try {
                        out.close();
                    } catch (IOException e5) {
                        return false;
                    }
                }
                throw e4;
            }
        }

        private static String read(String path) {
            if (!isReadable(path)) {
                FtUtil.log_i(ModuleForceTouch.CLASS_NAME, "read", "Failed isReadable: " + path);
                return null;
            }
            StringBuilder sb = new StringBuilder();
            BufferedReader reader = null;
            try {
                BufferedReader reader2 = new BufferedReader(new FileReader(path));
                while (true) {
                    String line = reader2.readLine();
                    if (line == null) {
                        break;
                    }
                    sb.append(line);
                    sb.append("\n");
                }
                FtUtil.log_i(ModuleForceTouch.CLASS_NAME, "read", "finish,  path: " + path + ", value: " + sb.toString().trim());
                try {
                    reader2.close();
                } catch (IOException e) {
                    FtUtil.log_e(e);
                }
            } catch (IOException e2) {
                FtUtil.log_e(e2);
                if (0 != 0) {
                    reader.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        reader.close();
                    } catch (IOException e3) {
                        FtUtil.log_e(e3);
                    }
                }
                throw th;
            }
            return sb.toString().trim();
        }

        private static boolean isReadable(String... paths) {
            for (String path : paths) {
                File file = new File(path);
                boolean bExist = file.exists();
                if (bExist) {
                    boolean bCanRead = file.canRead();
                    if (!bCanRead) {
                        FtUtil.log_i(ModuleForceTouch.CLASS_NAME, "isReadable", path + " canRead: " + bCanRead);
                        return false;
                    }
                } else {
                    FtUtil.log_i(ModuleForceTouch.CLASS_NAME, "isReadable", path + " exists: " + bExist);
                    return false;
                }
            }
            return true;
        }

        private static boolean isWriteable(String... paths) {
            for (String path : paths) {
                File file = new File(path);
                boolean bExist = file.exists();
                if (bExist) {
                    boolean bCanWrite = file.canWrite();
                    if (!bCanWrite) {
                        FtUtil.log_i(ModuleForceTouch.CLASS_NAME, "isWriteable", path + " canWrite: " + bCanWrite);
                        return false;
                    }
                } else {
                    FtUtil.log_i(ModuleForceTouch.CLASS_NAME, "isWriteable", path + " exists: " + bExist);
                    return false;
                }
            }
            return true;
        }
    }

    public static class KeySoundHandler {
        private static boolean mEnable = true;
        private static MediaPlayer mMediaPlayer = null;
        private static int mOldVolumeIndex;

        public static synchronized void onStart(Context context) {
            synchronized (KeySoundHandler.class) {
                if (mEnable) {
                    mMediaPlayer = MediaPlayer.create(context, (int) R.raw.button);
                    AudioManager am = (AudioManager) context.getSystemService("audio");
                    mOldVolumeIndex = am.getStreamVolume(3);
                    am.setStreamVolume(3, am.getStreamMaxVolume(3), 0);
                }
            }
        }

        public static synchronized void onFinish(Context context) {
            synchronized (KeySoundHandler.class) {
                if (mEnable) {
                    MediaPlayer mediaPlayer = mMediaPlayer;
                    if (mediaPlayer != null) {
                        mediaPlayer.release();
                        mMediaPlayer = null;
                    }
                    ((AudioManager) context.getSystemService("audio")).setStreamVolume(3, mOldVolumeIndex, 0);
                }
            }
        }

        public static synchronized void playKeySound(Context context) {
            MediaPlayer mediaPlayer;
            synchronized (KeySoundHandler.class) {
                if (mEnable && (mediaPlayer = mMediaPlayer) != null) {
                    if (mediaPlayer.isPlaying()) {
                        try {
                            mMediaPlayer.seekTo(0);
                        } catch (IllegalStateException e) {
                        }
                        return;
                    }
                    mMediaPlayer.start();
                }
            }
        }
    }
}
