package com.sec.factory.modules;

import android.content.Context;
import android.content.Intent;
import android.hardware.display.DisplayManager;
import android.os.Handler;
import android.os.Message;
import android.os.PowerManager;
import android.os.SystemClock;
import android.provider.Settings;
import android.view.View;
import com.android.internal.display.BrightnessSynchronizer;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.util.Locale;

public class ModulePower extends ModuleObject {
    public static final int AUTO_BRIGHTNESS_MODE_OFF = 0;
    public static final int AUTO_BRIGHTNESS_MODE_ON = 1;
    public static final String BUTTON_KEY_LIGHT = "button_key_light";
    public static final int BUTTON_KEY_LIGHT_ALWAYS_ON = -1;
    public static final int BUTTON_KEY_LIGHT_OFF = 0;
    public static final int BUTTON_KEY_LIGHT_ON_1500 = 1500;
    public static final int BUTTON_KEY_LIGHT_ON_3000 = 3000;
    public static final int BUTTON_KEY_LIGHT_ON_6000 = 6000;
    public static final byte REBOOT_MODE_DOWNLOAD = 1;
    public static final byte REBOOT_MODE_NOMAL = 0;
    public static final byte REBOOT_MODE_WIFI_DOWNLOAD = 2;
    private static Context mContext = null;
    private static ModulePower mInstance = null;
    private PowerManager.WakeLock mMediaScanWakeLock = null;
    private PowerManager.WakeLock mPartialWakeLock = null;
    private PowerManager.WakeLock mWakeLock = null;

    private ModulePower(Context context) {
        super(context, "ModulePower");
        FtUtil.log_i(this.CLASS_NAME, "ModulePower", "Create ModulePower");
    }

    public static ModulePower instance(Context context) {
        if (mInstance == null) {
            mInstance = new ModulePower(context);
            mContext = context;
        }
        return mInstance;
    }

    public void reboot(byte mode) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "reboot", "mode=" + ((int) mode));
        Handler handler = new Handler(getApplicationContext().getMainLooper()) {
            /* class com.sec.factory.modules.ModulePower.AnonymousClass1 */

            public void handleMessage(Message msg) {
                if (msg.what == 0) {
                    ((PowerManager) msg.obj).reboot("normal");
                } else if (msg.what == 1) {
                    ((PowerManager) msg.obj).reboot("download");
                } else if (msg.what == 2) {
                    ((PowerManager) msg.obj).reboot("wdownload");
                }
            }
        };
        handler.sendMessageDelayed(handler.obtainMessage(mode, (PowerManager) getSystemService("power")), 1000);
    }

    public void sleep() {
        FtUtil.log_i(this.CLASS_NAME, "sleep", "Power Sleep");
        if (Support.Kernel.isExistFileID(Support.Kernel.SYS_POWER_FTM_SLEEP)) {
            if (Support.Kernel.write(Support.Kernel.SYS_POWER_FTM_SLEEP, EgisFingerprint.MAJOR_VERSION)) {
                FtUtil.log_i(this.CLASS_NAME, "sleep pgm", "set : OK");
            } else {
                FtUtil.log_i(this.CLASS_NAME, "sleep pgm", "set : NG");
            }
        }
        doWakeLock(false);
        doPartialWakeLock(false);
        doMediaScanWakeLock(false);
        ((PowerManager) getSystemService("power")).goToSleep(SystemClock.uptimeMillis());
    }

    public void gotosleep() {
        FtUtil.log_i(this.CLASS_NAME, "goToSleep", "Power Sleep");
        ((PowerManager) getSystemService("power")).goToSleep(SystemClock.uptimeMillis());
    }

    public void doWakeLock(boolean wake) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "doWakeLock", "wake=" + wake);
        if (wake) {
            if (this.mWakeLock == null) {
                this.mWakeLock = ((PowerManager) getSystemService("power")).newWakeLock(805306394, this.CLASS_NAME);
            }
            if (!this.mWakeLock.isHeld()) {
                this.mWakeLock.acquire();
                FtUtil.log_i(this.CLASS_NAME, "doWakeLock", "FULL WAKELOCK ON");
                return;
            }
            return;
        }
        PowerManager.WakeLock wakeLock = this.mWakeLock;
        if (wakeLock != null) {
            if (wakeLock.isHeld()) {
                this.mWakeLock.release();
                FtUtil.log_i(this.CLASS_NAME, "doWakeLock", "FULL WAKELOCK OFF");
            }
            this.mWakeLock = null;
        }
    }

    public void doMediaScanWakeLock(boolean wake) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "doMediaScanWakeLock", "wake=" + wake);
        if (wake) {
            if (this.mMediaScanWakeLock == null) {
                this.mMediaScanWakeLock = ((PowerManager) getSystemService("power")).newWakeLock(805306394, this.CLASS_NAME + "Media");
            }
            if (!this.mMediaScanWakeLock.isHeld()) {
                this.mMediaScanWakeLock.acquire();
                FtUtil.log_i(this.CLASS_NAME, "doMediaScanWakeLock", "FULL WAKELOCK ON");
                return;
            }
            return;
        }
        PowerManager.WakeLock wakeLock = this.mMediaScanWakeLock;
        if (wakeLock != null) {
            if (wakeLock.isHeld()) {
                this.mMediaScanWakeLock.release();
                FtUtil.log_i(this.CLASS_NAME, "doMediaScanWakeLock", "FULL WAKELOCK OFF");
            }
            this.mMediaScanWakeLock = null;
        }
    }

    public void doPartialWakeLock(boolean wake) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "doPartialWakeLock", "wake=" + wake);
        if (wake) {
            if (this.mPartialWakeLock == null) {
                this.mPartialWakeLock = ((PowerManager) getSystemService("power")).newWakeLock(1, this.CLASS_NAME + "Partial");
            }
            if (!this.mPartialWakeLock.isHeld()) {
                this.mPartialWakeLock.acquire();
                FtUtil.log_i(this.CLASS_NAME, "doPartialWakeLock", "PARTIAL WAKELOCK ON");
                return;
            }
            return;
        }
        PowerManager.WakeLock wakeLock = this.mPartialWakeLock;
        if (wakeLock != null) {
            if (wakeLock.isHeld()) {
                this.mPartialWakeLock.release();
                FtUtil.log_i(this.CLASS_NAME, "doPartialWakeLock", "PARTIAL WAKELOCK OFF");
            }
            this.mPartialWakeLock = null;
        }
    }

    public boolean isHeldWakeLock() {
        PowerManager.WakeLock wakeLock = this.mWakeLock;
        if (wakeLock == null) {
            return false;
        }
        return wakeLock.isHeld();
    }

    public void sendDvfsLockIntent() {
        FtUtil.log_i(this.CLASS_NAME, "sendDvfsLockIntent", "...");
        sendBroadcast(new Intent("com.sec.android.intent.action.DVFS_FACTORY_CPU_LOCK"));
    }

    public void sendAlarmManagerOnOff(boolean alarm) {
        if (!alarm) {
            FtUtil.log_i(this.CLASS_NAME, "sendAlarmOnOffIntent", "sendAlarmOnOffIntentandroid.intent.action.START_FACTORY_TEST");
            sendBroadcast(new Intent("android.intent.action.START_FACTORY_TEST"));
            return;
        }
        FtUtil.log_i(this.CLASS_NAME, "sendAlarmOnOffIntent", "sendAlarmOnOffIntentandroid.intent.action.STOP_FACTORY_TEST");
        sendBroadcast(new Intent("android.intent.action.STOP_FACTORY_TEST"));
    }

    public void setFactoryModeAtBatteryNode(boolean factoryMode) {
        if (factoryMode) {
            if (Support.Kernel.write(Support.Kernel.BATTRY_FACTORYMODE, EgisFingerprint.MAJOR_VERSION)) {
                FtUtil.log_i(this.CLASS_NAME, "setFactoryModeAtBatteryNode", "set : 1");
            } else {
                FtUtil.log_i(this.CLASS_NAME, "setFactoryModeAtBatteryNode", "set : on Failed");
            }
        } else if (Support.Kernel.write(Support.Kernel.BATTRY_FACTORYMODE, "0")) {
            FtUtil.log_i(this.CLASS_NAME, "setFactoryModeAtBatteryNode", "set : 0");
        } else {
            FtUtil.log_i(this.CLASS_NAME, "setFactoryModeAtBatteryNode", "set off : Failed");
        }
    }

    public void setDisplayColor(View view, int color) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setDisplayColor", "color=" + color);
        view.setBackgroundColor(color);
    }

    public void setBrightness(int brightness) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setBrightness", "brightness=" + brightness);
        try {
            ((DisplayManager) getSystemService("display")).semSetTemporaryBrightness(BrightnessSynchronizer.brightnessIntToFloat(brightness));
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public int getBrightness() {
        int brightness = Settings.System.getInt(getContentResolver(), "screen_brightness", -1);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getBrightness", "brightness=" + brightness);
        if (brightness != -1) {
            return brightness;
        }
        FtUtil.Sleep.sleep(500);
        int brightness2 = Settings.System.getInt(getContentResolver(), "screen_brightness", -1);
        String str2 = this.CLASS_NAME;
        FtUtil.log_i(str2, "getBrightness", "re-try : brightness=" + brightness2);
        if (brightness2 != -1) {
            return brightness2;
        }
        String str3 = this.CLASS_NAME;
        FtUtil.log_i(str3, "getBrightness", "force set : brightness=" + 0);
        return 0;
    }

    public void setScreenState(boolean b) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setScreenState", "state=" + b);
        PowerManager pm = (PowerManager) getSystemService("power");
        if (b) {
            pm.userActivity(SystemClock.uptimeMillis(), false);
            doPartialWakeLock(false);
            return;
        }
        doPartialWakeLock(true);
        pm.goToSleep(SystemClock.uptimeMillis());
    }

    public void setLCDState(boolean b) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setLCDState", "state=" + b);
        if (b) {
            doWakeLock(true);
            setScreenState(true);
            doWakeLock(false);
            return;
        }
        doWakeLock(false);
        setScreenState(false);
    }

    public void setLCDStateForCurrent(boolean b) {
        setLCDState(b);
        if (!b && Support.Feature.getBoolean(Support.Feature.NEED_LPA_MODE_SET, true)) {
            ModuleDevice.instance(mContext).setLPAmode(ModuleDevice.LPA_MODE_DISABLE);
        }
    }

    public void setScreenBrightnessMode(int mode) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "setScreenBrightnessMode", "mode=" + mode);
        Settings.System.putInt(getContentResolver(), "screen_brightness_mode", mode);
    }

    public int getScreenBrightnessMode() {
        int mode = Settings.System.getInt(getContentResolver(), "screen_brightness_mode", -1);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "getScreenBrightnessMode", "mode=" + mode);
        return mode;
    }

    public boolean isScreenOn() {
        return ((PowerManager) getSystemService("power")).isScreenOn();
    }

    public void setTouchLed(boolean on) {
        if (!Support.Kernel.isExistFileID(Support.Kernel.TOUCH_KEY_BRIGHTNESS)) {
            FtUtil.log_i(this.CLASS_NAME, "setTouchLed", "TOUCH_KEY_BRIGHTNESS isn't existed...");
        } else if (on) {
            Support.Kernel.write(Support.Kernel.TOUCH_KEY_BRIGHTNESS, EgisFingerprint.MAJOR_VERSION);
        } else {
            Support.Kernel.write(Support.Kernel.TOUCH_KEY_BRIGHTNESS, "0");
        }
    }

    public void setTouchLedTime(int time) {
        Settings.System.putInt(getContentResolver(), BUTTON_KEY_LIGHT, time);
    }

    public int getTouchLedTime() {
        return Settings.System.getInt(getContentResolver(), BUTTON_KEY_LIGHT, 1500);
    }

    public String readBatteryStatus() {
        return "";
    }

    public String readBatteryVoltage() {
        String voltage;
        if (Support.Kernel.isExistFile(Support.Kernel.VPH_VOLT)) {
            FtUtil.log_i(this.CLASS_NAME, "readBatteryVoltage", "Read Node : VPH_VOLT");
            voltage = Support.Kernel.read(Support.Kernel.VPH_VOLT);
        } else {
            FtUtil.log_i(this.CLASS_NAME, "readBatteryVoltage", "Read Node : BATTERY_VOLT");
            voltage = Support.Kernel.read(Support.Kernel.BATTERY_VOLT);
        }
        if (voltage == null) {
            return null;
        }
        String voltage2 = voltage.trim();
        if (voltage2.length() <= 4) {
            String str = this.CLASS_NAME;
            FtUtil.log_i(str, "readBatteryVoltage", "voltage=" + voltage2);
            return String.valueOf(Float.valueOf(voltage2).floatValue() / 100.0f);
        }
        String str2 = this.CLASS_NAME;
        FtUtil.log_i(str2, "readBatteryVoltage", "voltage=" + voltage2);
        return String.format(Locale.US, "%.2f", Float.valueOf(Float.valueOf(voltage2).floatValue() / 1000000.0f));
    }

    public String readInBatteryVoltage() {
        String voltage = Support.Kernel.read(Support.Kernel.BATTERY_INBAT_VOLTAGE);
        if (voltage == null) {
            return null;
        }
        String voltage2 = voltage.trim();
        if (voltage2.length() <= 4) {
            String str = this.CLASS_NAME;
            FtUtil.log_i(str, "readInBatteryVoltage", "voltage=" + voltage2);
            return String.valueOf(Float.valueOf(voltage2).floatValue() / 100.0f);
        }
        String str2 = this.CLASS_NAME;
        FtUtil.log_i(str2, "readInBatteryVoltage", "voltage=" + voltage2);
        return String.format(Locale.US, "%.2f", Float.valueOf(Float.valueOf(voltage2).floatValue() / 1000000.0f));
    }

    public boolean resetFuelGaugeIC() {
        FtUtil.log_i(this.CLASS_NAME, "resetFuelGaugeIC", "Fuel Gauge IC reset");
        return Support.Kernel.write(Support.Kernel.FUEL_GAUGE_RESET, EgisFingerprint.MAJOR_VERSION);
    }

    public String readFuelGaugeSOC() {
        String soc = Support.Kernel.read(Support.Kernel.BATTERY_CAPACITY);
        if (soc != null) {
            soc = String.valueOf(Integer.parseInt(soc) * 100);
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readFuelGaugeSOC", "soc=" + soc);
        return soc;
    }

    public String readBatteryTemp() {
        int data;
        String temp = Support.Kernel.read(Support.Kernel.BATTERY_TEMP);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readBatteryTemp", "sysfs temp=" + temp);
        if (temp != null) {
            try {
                if (temp.length() >= 3) {
                    data = Integer.parseInt(temp) / 10;
                } else {
                    data = Integer.parseInt(temp.substring(0, 2));
                }
                temp = String.valueOf(data);
            } catch (Exception e) {
                e.printStackTrace();
                temp = "0";
            }
        }
        String str2 = this.CLASS_NAME;
        FtUtil.log_i(str2, "readBatteryTemp", "return temp=" + temp);
        return temp;
    }

    @Deprecated
    public String readBatteryTempRTRChip() {
        return null;
    }

    @Deprecated
    public String readBatteryTempRF2Chip() {
        return null;
    }

    public String readBatteryTempAdc() {
        String adc = Support.Kernel.read(Support.Kernel.BATTERY_TEMP_ADC);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readBatteryTempAdc", "adc=" + adc);
        return adc;
    }

    public String readXoOscTemp() {
        int data;
        String temp = Support.Kernel.read(Support.Kernel.XO_OSC_THERMISTER_TEMP);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readXoOscTemp", "sysfs value=" + temp);
        if (temp != null) {
            try {
                if (temp.length() >= 5) {
                    data = Integer.parseInt(temp) / 1000;
                } else {
                    data = Integer.parseInt(temp.substring(0, 2));
                }
                temp = String.valueOf(data);
            } catch (Exception e) {
                e.printStackTrace();
                temp = "0";
            }
        }
        String str2 = this.CLASS_NAME;
        FtUtil.log_i(str2, "readXoOscTemp", "syyfs temp=" + temp);
        return temp;
    }

    public String readExternalApChipTemp() {
        int data;
        String ext_temp = ModuleCommunicationService.SMD_NOK;
        boolean isMinusValue = false;
        String rawData = Support.Kernel.read(Support.Kernel.SEC_EXT_THERMISTER_TEMP);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readExternalApChipTemp", "sysfs value=" + rawData);
        if (rawData == null) {
            return "NG";
        }
        if (rawData.contains("-")) {
            isMinusValue = true;
            rawData = rawData.replace("-", "");
            String str2 = this.CLASS_NAME;
            FtUtil.log_i(str2, "readExternalApChipTemp", "replace value=" + rawData);
        }
        try {
            if (rawData.length() >= 3) {
                int decimal = Integer.parseInt(rawData.substring(2, 3));
                data = Integer.parseInt(rawData.substring(0, 2));
                if (decimal >= 5) {
                    data++;
                }
            } else {
                data = Integer.parseInt(rawData);
            }
            if (isMinusValue) {
                data *= -1;
            }
            ext_temp = String.valueOf(data);
        } catch (Exception e) {
            FtUtil.log_e(e);
        }
        String str3 = this.CLASS_NAME;
        FtUtil.log_i(str3, "readExternalApChipTemp", "return ext_temp=" + ext_temp);
        return ext_temp;
    }

    public String read_humitemp_thermistor_PAM() {
        String data = Support.Kernel.read(Support.Kernel.HUMITEMP_THERMISTER_PAM);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "read_humitemp_thermistor_PAM", "sysfs data=" + data);
        return data;
    }

    public String readApChipTemp() {
        String adc;
        if (Support.TestCase.getEnabled(Support.TestCase.NEED_POWER_POLICY_ENABLE)) {
            FtUtil.log_i(this.CLASS_NAME, "readApChipTemp", "APCHIP_TEMP_POWER_POLICY Elabled");
            if (!Support.Kernel.write(Support.Kernel.APCHIP_TEMP_POWER_POLICY, "always_on")) {
                FtUtil.log_i(this.CLASS_NAME, "readApChipTemp", "APCHIP_TEMP_POWER_POLICY [always_on] write fail");
                return null;
            }
            FtUtil.Sleep.sleep(100);
            adc = Support.Kernel.readAllLine(Support.Kernel.APCHIP_TEMP_ADC, true);
            if (!Support.Kernel.write(Support.Kernel.APCHIP_TEMP_POWER_POLICY, "coarse_demand")) {
                FtUtil.log_i(this.CLASS_NAME, "readApChipTemp", "APCHIP_TEMP_POWER_POLICY [coarse_demand] write fail");
                return null;
            }
        } else {
            adc = Support.Kernel.readAllLine(Support.Kernel.APCHIP_TEMP_ADC, true);
        }
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readApChipTemp", "adc=" + adc);
        return adc;
    }

    public String readApChipTemp_MultiThermistor() {
        String adc = "";
        int numOfThermistor = Support.Feature.getInt(Support.Feature.NUMBER_OF_AP_THERMISTOR);
        int divider = Support.Feature.getInt(Support.Feature.MULTICORE_THERMISTER_CELCIUS_DIVIDER);
        for (int i = 0; i < numOfThermistor; i++) {
            String path = "APCHIP_TEMP_THERMISTOR" + Integer.toString(i);
            FtUtil.log_i(this.CLASS_NAME, "readApChipTemp_MultiCore", "path = " + path);
            adc = adc + (Integer.valueOf(Support.Kernel.readSysfs(path)).intValue() / divider);
            if (numOfThermistor - 1 != i) {
                adc = adc + ",";
            }
        }
        return adc;
    }

    public String readWifiTemp() {
        int data;
        String temp = Support.Kernel.read(Support.Kernel.WIFI_TEMP_THERMISTOR);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readWifiTemp", "sysfs temp=" + temp);
        if (temp != null) {
            try {
                if (temp.length() >= 3) {
                    data = Integer.parseInt(temp) / 10;
                } else {
                    data = Integer.parseInt(temp.substring(0, 2));
                }
                temp = String.valueOf(data);
            } catch (Exception e) {
                e.printStackTrace();
                temp = "0";
            }
        }
        String str2 = this.CLASS_NAME;
        FtUtil.log_i(str2, "readWifiTemp", "return temp=" + temp);
        return temp;
    }

    @Deprecated
    public String readBatteryTempAdcRTRChip() {
        return null;
    }

    @Deprecated
    public String readBatteryTempAdcRF2Chip() {
        return null;
    }

    public String readBatteryAdcCal() {
        String adc_cal = Support.Kernel.read(Support.Kernel.BATTERY_VOLT_ADC_CAL);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readBatteryAdcCal", "adc_cal=" + adc_cal);
        return adc_cal;
    }

    public void writeBatteryAdcCal(String value) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "writeBatteryAdcCal", "value=" + value);
        Support.Kernel.write(Support.Kernel.BATTERY_VOLT_ADC_CAL, value);
    }

    public String readBatteryCal() {
        if (!Support.Kernel.isExistFileID(Support.Kernel.BATTERY_VOLT_ADC_CAL)) {
            return null;
        }
        String cal = Support.Kernel.read(Support.Kernel.BATTERY_VOLT_ADC_CAL);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readBatteryCal", "cal=" + cal);
        return cal;
    }

    public void writeBatteryCal(String value) {
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "writeBatteryCal", "value=" + value);
        Support.Kernel.write(Support.Kernel.BATTERY_VOLT_ADC_CAL, value);
    }

    public String readAFChargerTempAdc() {
        String temp = Support.Kernel.read(Support.Kernel.CHG_TEMP_ADC);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readAFChargerTempAdc", "sysfs data=" + temp);
        return temp;
    }

    public String readAFChargerTemp() {
        String temp = String.valueOf(Integer.parseInt(Support.Kernel.read(Support.Kernel.CHG_TEMP)) / 10);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readAFChargerTemp", "sysfs data=" + temp);
        return temp;
    }

    public String readCamFlashTemp() {
        String temp = String.valueOf(Integer.parseInt(Support.Kernel.read(Support.Kernel.FLASH_LED_THERM)) / 10);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readCamFlashTemp", "sysfs data=" + temp);
        return temp;
    }

    public String readCamFlashTempAdc() {
        String temp = Support.Kernel.read(Support.Kernel.CAMERA_FLASH_TEMP_ADC);
        String str = this.CLASS_NAME;
        FtUtil.log_i(str, "readCamFlashTempAdc", "sysfs data=" + temp);
        return temp;
    }
}
