package com.sec.factory.modules;

import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.os.VibrationEffect;
import android.os.Vibrator;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.io.File;
import java.util.Timer;
import java.util.TimerTask;

public class MotorService extends Service {
    private static final String CLASS_NAME = "MotorService";
    private final int[] FEED_BACK_AMPLITUDE = {0, -1};
    private final long[] FEED_BACK_PATTERN = {0, 5000};
    private final int MAX_DATA = 2;
    private final double MOTOR_SPEC = 0.5d;
    private final long TIMER_TIME = 500;
    private final Handler UIUpdateHandler = new Handler() {
        /* class com.sec.factory.modules.MotorService.AnonymousClass2 */

        public void handleMessage(Message msg) {
            MotorService.this.setTestResult();
        }
    };
    private int count;
    private Sensor mAcceSensor;
    private float[] mAcceSensorValues = new float[3];
    private int mAccelerometer1GValue = 256;
    private int mAccelerometerBitCount = 10;
    private int mAccelerometerFullScale = 2;
    private Context mContext;
    private TimerTask mDeltaCheck;
    private double mGX;
    private double mGY;
    private double mGZ;
    private boolean mIsAutoResponse = false;
    private boolean mIsPass;
    private int mMaxMagnitude;
    private final int[] mRawData = new int[3];
    private AccelSensorListener mSensorListener = new AccelSensorListener();
    private SensorManager mSensorManager;
    private final int mTestID = 0;
    private Timer mTimer;
    private Vibrator mVibrator;
    private double mXDeltaAvgData;
    private int[] mXDeltaData;
    private int mXMax;
    private int mXMin;
    private double mYDeltaAvgData;
    private int[] mYDeltaData;
    private int mYMax;
    private int mYMin;
    private double mZDeltaAvgData;
    private int[] mZDeltaData;
    private int mZMax;
    private int mZMin;
    private boolean usingSubAcc = false;

    static /* synthetic */ int access$108(MotorService x0) {
        int i = x0.count;
        x0.count = i + 1;
        return i;
    }

    public MotorService() {
        FtUtil.log_d(CLASS_NAME, CLASS_NAME, CLASS_NAME);
    }

    private void startTest() {
        FtUtil.log_d(CLASS_NAME, "startTest", "Test Start!");
        this.mXDeltaData = new int[2];
        this.mYDeltaData = new int[2];
        this.mZDeltaData = new int[2];
        this.count = 0;
        Support.Kernel.writeToPathNsync(new File("data/log/MOTOR_Data.log").getPath(), "");
        VibrationEffect waveform = VibrationEffect.createWaveform(this.FEED_BACK_PATTERN, this.FEED_BACK_AMPLITUDE, 0);
        waveform.semSetMagnitudeType(VibrationEffect.SemMagnitudeType.TYPE_MAX);
        this.mVibrator.vibrate(waveform);
        this.mDeltaCheck = new TimerTask() {
            /* class com.sec.factory.modules.MotorService.AnonymousClass1 */

            public void run() {
                FtUtil.log_d(MotorService.CLASS_NAME, "Timer_RUN", (MotorService.this.count + 1) + " times running..");
                FtUtil.log_d(MotorService.CLASS_NAME, "startTest", "X = " + MotorService.this.mXMax + " / " + MotorService.this.mXMin);
                FtUtil.log_d(MotorService.CLASS_NAME, "startTest", "Y = " + MotorService.this.mYMax + " / " + MotorService.this.mYMin);
                FtUtil.log_d(MotorService.CLASS_NAME, "startTest", "Z = " + MotorService.this.mZMax + " / " + MotorService.this.mZMin);
                MotorService.this.mXDeltaData[MotorService.this.count] = MotorService.this.mXMax - MotorService.this.mXMin;
                MotorService.this.mXMax = 0;
                MotorService.this.mXMin = 0;
                MotorService.this.mYDeltaData[MotorService.this.count] = MotorService.this.mYMax - MotorService.this.mYMin;
                MotorService.this.mYMax = 0;
                MotorService.this.mYMin = 0;
                MotorService.this.mZDeltaData[MotorService.access$108(MotorService.this)] = MotorService.this.mZMax - MotorService.this.mZMin;
                MotorService.this.mZMax = 0;
                MotorService.this.mZMin = 0;
                if (MotorService.this.count == 2) {
                    MotorService.this.checkDeltaData();
                    MotorService.this.UIUpdateHandler.sendEmptyMessage(0);
                    MotorService.this.mTimer.cancel();
                    MotorService.this.mVibrator.cancel();
                    MotorService.this.sensorUnregister();
                }
            }
        };
        Timer timer = new Timer();
        this.mTimer = timer;
        timer.schedule(this.mDeltaCheck, 500, 500);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void checkDeltaData() {
        FtUtil.log_d(CLASS_NAME, "checkDeltaData", "Start Delta Check");
        this.mXDeltaAvgData = 0.0d;
        this.mYDeltaAvgData = 0.0d;
        this.mZDeltaAvgData = 0.0d;
        for (int i = 0; i < 2; i++) {
            this.mXDeltaAvgData += (double) this.mXDeltaData[i];
            this.mYDeltaAvgData += (double) this.mYDeltaData[i];
            this.mZDeltaAvgData += (double) this.mZDeltaData[i];
        }
        this.mXDeltaAvgData = Math.abs(this.mXDeltaAvgData / 2.0d);
        this.mYDeltaAvgData = Math.abs(this.mYDeltaAvgData / 2.0d);
        double abs = Math.abs(this.mZDeltaAvgData / 2.0d);
        this.mZDeltaAvgData = abs;
        double d = this.mXDeltaAvgData;
        int i2 = this.mAccelerometer1GValue;
        this.mGX = d / ((double) i2);
        this.mGY = this.mYDeltaAvgData / ((double) i2);
        this.mGZ = abs / ((double) i2);
        FtUtil.log_d(CLASS_NAME, "checkDeltaData", "mGX: " + this.mGX + "mGY: " + this.mGY + "mGZ: " + this.mGZ);
        if (this.mGX > 0.5d || this.mGY > 0.5d || this.mGZ > 0.5d) {
            FtUtil.log_d(CLASS_NAME, "checkDeltaData", "Spec In: PASS");
            this.mIsPass = true;
            return;
        }
        FtUtil.log_d(CLASS_NAME, "checkDeltaData", "Spec Out: FAIL");
        this.mIsPass = false;
    }

    private void sensorRegister() {
        FtUtil.log_d(CLASS_NAME, "sensorRegister", "Sensor Registering now...");
        this.mVibrator = (Vibrator) getSystemService("vibrator");
        SensorManager sensorManager = (SensorManager) getSystemService("sensor");
        this.mSensorManager = sensorManager;
        if (this.usingSubAcc) {
            this.mAcceSensor = sensorManager.getDefaultSensor(65687);
        } else {
            this.mAcceSensor = sensorManager.getDefaultSensor(1);
        }
        this.mSensorManager.registerListener(this.mSensorListener, this.mAcceSensor, 2);
        turnLPFOnOff(false);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sensorUnregister() {
        FtUtil.log_d(CLASS_NAME, "sensorUnregister", "Sensor Unregistering now...");
        turnLPFOnOff(true);
        SensorManager sensorManager = this.mSensorManager;
        if (sensorManager != null) {
            sensorManager.unregisterListener(this.mSensorListener);
        }
        this.mSensorManager = null;
        this.mSensorListener = null;
        this.mAcceSensor = null;
    }

    private void turnLPFOnOff(boolean isOn) {
        String lpfPath = this.usingSubAcc ? Support.Kernel.SUB_MOTOR_LPF : Support.Kernel.MOTOR_LPF;
        if (isOn) {
            Support.Kernel.write(lpfPath, EgisFingerprint.MAJOR_VERSION);
        }
        if (!isOn) {
            Support.Kernel.write(lpfPath, "0");
        }
        StringBuilder sb = new StringBuilder();
        sb.append("Turn motor LPF to ");
        sb.append(isOn ? "On" : "Off");
        FtUtil.log_d(CLASS_NAME, "turnLPFOnOff", sb.toString());
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setTestResult() {
        FtUtil.log_d(CLASS_NAME, "setTestResult", "mIsPass: " + this.mIsPass);
        String path = new File("data/log/MOTOR_Data.log").getPath();
        Object[] objArr = new Object[7];
        objArr[0] = Integer.valueOf((int) this.mXDeltaAvgData);
        objArr[1] = Integer.valueOf((int) this.mYDeltaAvgData);
        objArr[2] = Integer.valueOf((int) this.mZDeltaAvgData);
        objArr[3] = Double.valueOf(this.mGX);
        objArr[4] = Double.valueOf(this.mGY);
        objArr[5] = Double.valueOf(this.mGZ);
        objArr[6] = this.mIsPass ? "P" : "F";
        Support.Kernel.writeToPathNsync(path, String.format("%d,%d,%d,%.01f,%.01f,%.01f,%s", objArr));
        if (this.mIsAutoResponse) {
            Context context = this.mContext;
            if (context != null) {
                context.sendBroadcast(new Intent("com.sec.factory.MotorService.DONE"));
            }
        } else if (this.mIsPass) {
            doNVUpdate(true);
            FtUtil.log_d(CLASS_NAME, "setTestResult", FtUtil.setMspSeqMessage(4, FactoryTestManager.getItemName_RequestCode(100), "Pass"));
        } else {
            FtUtil.log_d(CLASS_NAME, "setTestResult", FtUtil.setMspSeqMessage(4, FactoryTestManager.getItemName_RequestCode(100), "Fail"));
        }
        stopSelf();
    }

    private void doNVUpdate(boolean isPass) {
        int id = FactoryTestManager.getItemPosition_ID(100);
        if (id > -1) {
            FtUtil.log_d(CLASS_NAME, "doNVUpdate", "id = " + id + " / result = " + isPass);
            FactoryTestManager.setItemResult(id, isPass ? (byte) 80 : 70);
            FactoryTestManager.notifyDataSetChanged();
        }
    }

    /* access modifiers changed from: private */
    public class AccelSensorListener implements SensorEventListener {
        private AccelSensorListener() {
        }

        public void onAccuracyChanged(Sensor arg0, int arg1) {
        }

        public void onSensorChanged(SensorEvent event) {
            MotorService.this.mAcceSensorValues = (float[]) event.values.clone();
            try {
                String[] rawDatas = Support.Kernel.read(MotorService.this.usingSubAcc ? Support.Kernel.SUB_ACCEL_SENSOR_RAW : Support.Kernel.ACCEL_SENSOR_RAW, true).trim().split(",");
                MotorService.this.mRawData[0] = Integer.parseInt(rawDatas[0].trim());
                MotorService.this.mRawData[1] = Integer.parseInt(rawDatas[1].trim());
                MotorService.this.mRawData[2] = Integer.parseInt(rawDatas[2].trim());
            } catch (NumberFormatException e) {
                MotorService.this.mRawData[0] = (int) ((((double) MotorService.this.mAcceSensorValues[0]) * 1024.0d) / 9.81d);
                MotorService.this.mRawData[1] = (int) ((((double) MotorService.this.mAcceSensorValues[1]) * 1024.0d) / 9.81d);
                MotorService.this.mRawData[2] = (int) ((((double) MotorService.this.mAcceSensorValues[2]) * 1024.0d) / 9.81d);
            }
            if (MotorService.this.mZMax == 0) {
                MotorService motorService = MotorService.this;
                motorService.mXMax = motorService.mRawData[0];
                MotorService motorService2 = MotorService.this;
                motorService2.mXMin = motorService2.mRawData[0];
                MotorService motorService3 = MotorService.this;
                motorService3.mYMax = motorService3.mRawData[1];
                MotorService motorService4 = MotorService.this;
                motorService4.mYMin = motorService4.mRawData[1];
                MotorService motorService5 = MotorService.this;
                motorService5.mZMax = motorService5.mRawData[2];
                MotorService motorService6 = MotorService.this;
                motorService6.mZMin = motorService6.mRawData[2];
            }
            if (MotorService.this.mXMax < MotorService.this.mRawData[0]) {
                MotorService motorService7 = MotorService.this;
                motorService7.mXMax = motorService7.mRawData[0];
            }
            if (MotorService.this.mXMin > MotorService.this.mRawData[0]) {
                MotorService motorService8 = MotorService.this;
                motorService8.mXMin = motorService8.mRawData[0];
            }
            if (MotorService.this.mYMax < MotorService.this.mRawData[1]) {
                MotorService motorService9 = MotorService.this;
                motorService9.mYMax = motorService9.mRawData[1];
            }
            if (MotorService.this.mYMin > MotorService.this.mRawData[1]) {
                MotorService motorService10 = MotorService.this;
                motorService10.mYMin = motorService10.mRawData[1];
            }
            if (MotorService.this.mZMax < MotorService.this.mRawData[2]) {
                MotorService motorService11 = MotorService.this;
                motorService11.mZMax = motorService11.mRawData[2];
            }
            if (MotorService.this.mZMin > MotorService.this.mRawData[2]) {
                MotorService motorService12 = MotorService.this;
                motorService12.mZMin = motorService12.mRawData[2];
            }
        }
    }

    public IBinder onBind(Intent arg0) {
        return null;
    }

    public int onStartCommand(Intent intent, int flags, int startId) {
        this.mContext = this;
        this.usingSubAcc = Support.Feature.getBoolean(Support.Feature.SUPPORT_SUB_ACC);
        sensorRegister();
        this.mIsAutoResponse = intent.getBooleanExtra("isAutoResponse", false);
        this.mAccelerometerBitCount = Integer.parseInt(Support.TestCase.getString(Support.TestCase.SENSOR_TEST_ACC_BIT));
        int accelerometerFullScale = SensorCalculator.getAccelerometerFullScale(this.mContext);
        this.mAccelerometerFullScale = accelerometerFullScale;
        this.mAccelerometer1GValue = SensorCalculator.getAccelerometer1GValue(this.mAccelerometerBitCount, accelerometerFullScale);
        FtUtil.log_d(CLASS_NAME, "onStartCommand", "mAccelerometerBitCount : " + this.mAccelerometerBitCount + ", mAccelerometerFullScale : " + this.mAccelerometerFullScale + ", mAccelerometer1GValue : " + this.mAccelerometer1GValue);
        startTest();
        return super.onStartCommand(intent, flags, startId);
    }
}
