package com.sec.factory.modules;

import android.app.IntentService;
import android.content.Intent;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.NVAccessor;
import com.sec.xmldata.support.Support;
import egis.optical.client.api.EgisFingerprint;
import java.io.File;

public class OisService extends IntentService {
    private static final String CLASS_NAME = "OisService";
    private String[] InitialData;
    private boolean IsSelfTest;
    private final String OIS_DATA = "data/log/OIS_Data.log";
    private final int OIS_DATA_NV = 91;
    private final String OIS_SELFDATA = "data/log/OIS_SelfData.log";
    private final int OIS_SELFDATA_NV = 178;
    private String[] SelfData;
    private final int TIME_OUT = 10000;
    private final Handler UpdateHandler = new Handler() {
        /* class com.sec.factory.modules.OisService.AnonymousClass1 */

        public void handleMessage(Message msg) {
            FtUtil.log_d(OisService.CLASS_NAME, "handleMessage", "doNVUpdate");
            OisService.this.doNVUpdate(true);
        }
    };
    private String mData;
    private double mDiff_X;
    private double mDiff_Y;
    private String mFileName;
    private String mHwResult;
    private boolean mIsPass;
    private final int mNv = 0;
    private int mTestID = 0;
    private TimeOutThread mTimeoutThread;

    public OisService() {
        super(CLASS_NAME);
    }

    private void init() {
        this.mDiff_X = 0.0d;
        this.mDiff_Y = 0.0d;
        this.mData = "";
        this.mHwResult = "";
        this.mFileName = "";
        this.SelfData = null;
        this.mIsPass = false;
    }

    /* access modifiers changed from: protected */
    public void onHandleIntent(Intent intent) {
        this.mTestID = intent.getIntExtra("testID", 98);
        this.mTimeoutThread = new TimeOutThread(10000);
        init();
        OisSensorOnOff(true);
        this.mTimeoutThread.start();
        startTest();
    }

    private void startTest() {
        if (this.mTestID == 98) {
            startGyroTest();
        } else {
            startSelfTest();
        }
    }

    private void startGyroTest() {
        String str = "0";
        FtUtil.log_d(CLASS_NAME, "startGyroTest", "Test Start!");
        try {
            Thread.sleep(100);
            String[] split = Support.Kernel.read(Support.Kernel.GYRO_OIS_SELFTEST).split(",");
            this.SelfData = split;
            this.mIsPass = str.equals(split[0]);
        } catch (Exception e) {
            e.printStackTrace();
        }
        this.mData = (str.equals(this.SelfData[0]) ? "OK" : "NG") + "," + this.SelfData[1] + "," + this.SelfData[2] + "," + this.InitialData[0] + "," + this.InitialData[1];
        this.mDiff_X = Double.parseDouble(this.InitialData[0]) - Double.parseDouble(this.SelfData[1]);
        this.mDiff_Y = Double.parseDouble(this.InitialData[1]) - Double.parseDouble(this.SelfData[2]);
        StringBuilder sb = new StringBuilder();
        sb.append(this.mData);
        sb.append(",");
        sb.append(String.format("%.3f", Double.valueOf(this.mDiff_X)));
        sb.append(",");
        sb.append(String.format("%.3f", Double.valueOf(this.mDiff_Y)));
        this.mData = sb.toString();
        if (!"2".equals(this.SelfData[0]) && !EgisFingerprint.MAJOR_VERSION.equals(this.SelfData[0])) {
            str = egis.client.api.EgisFingerprint.MAJOR_VERSION;
        }
        this.mHwResult = str;
        this.mData += "," + this.mHwResult;
        FtUtil.log_d(CLASS_NAME, "startGyroTest", "Result : " + this.mData);
        checkResult();
    }

    private void startSelfTest() {
        FtUtil.log_d(CLASS_NAME, "startSelfTest", "Test Start!");
        String[] mTempData = Support.Kernel.read(Support.Kernel.GYRO_OIS_DIFF).split(",");
        String model_spec = Support.FactoryTestMenu.getSpec(FactoryTestManager.convertorID_XML(this.mTestID));
        int Spec_min = Integer.parseInt(model_spec.split("~")[0]);
        int Spec_max = Integer.parseInt(model_spec.split("~")[1]);
        if (mTempData.length != 0) {
            try {
                Thread.sleep(1000);
                int diff_x = Integer.parseInt(mTempData[1]);
                int diff_y = Integer.parseInt(mTempData[2]);
                this.mIsPass = true;
                this.IsSelfTest = true;
                if (diff_x < Spec_min || diff_y < Spec_min || diff_x > Spec_max || diff_y > Spec_max) {
                    this.mIsPass = false;
                    FtUtil.log_d(CLASS_NAME, "startSelfTest", "Spec Fail - Spec : " + Spec_min + " ~ " + Spec_max + " X-Y : " + diff_x + "," + diff_y);
                }
                if (this.mIsPass) {
                    this.mData += "OK," + diff_x + "," + diff_y;
                } else {
                    this.mData += "NG," + diff_x + "," + diff_y;
                }
                boolean isCalPass = false;
                String fw_ver = Support.Kernel.read(Support.Kernel.CAMERA_REAR_OIS_FW_VER);
                if (fw_ver != null) {
                    FtUtil.log_d(CLASS_NAME, "startSelfTest", "FW Ver : " + fw_ver);
                    String module_ver = fw_ver.split(" ")[0];
                    if (!"NG_CD2".equalsIgnoreCase(module_ver) && !"NG_FW2".equalsIgnoreCase(module_ver) && !"NULL".equalsIgnoreCase(module_ver)) {
                        isCalPass = true;
                    }
                }
                StringBuilder sb = new StringBuilder();
                sb.append(this.mData);
                sb.append(isCalPass ? ",OK" : ",NG");
                this.mData = sb.toString();
                FtUtil.log_d(CLASS_NAME, "startSelfTest", "Result : " + this.mData);
            } catch (Exception e) {
                e.printStackTrace();
                this.mIsPass = false;
            }
        }
        checkResult();
    }

    private boolean OisSensorOnOff(boolean param) {
        boolean result = Support.Kernel.write(Support.Kernel.GYRO_OIS_POWER, param ? egis.client.api.EgisFingerprint.MAJOR_VERSION : "0");
        if (param && this.mTestID == 98) {
            this.InitialData = Support.Kernel.read(Support.Kernel.GYRO_OIS_RAWDATA).split(",");
        }
        return result;
    }

    private void checkResult() {
        TimeOutThread timeOutThread = this.mTimeoutThread;
        if (timeOutThread != null) {
            timeOutThread.interrupt();
        }
        Support.Kernel.writeToPathNsync((this.IsSelfTest ? new File("data/log/OIS_SelfData.log") : new File("data/log/OIS_Data.log")).getPath(), this.mData);
        FtUtil.log_d(CLASS_NAME, "checkResult", "Write to file ...");
        if (this.mIsPass) {
            setTestResult();
        }
        OisSensorOnOff(false);
    }

    private void setTestResult() {
        FtUtil.log_d(CLASS_NAME, "setTestResult", "mIsPass: " + this.mIsPass);
        if (this.mIsPass) {
            FtUtil.log_d(CLASS_NAME, "onDestroy", FtUtil.setMspSeqMessage(4, CLASS_NAME, "Pass"));
            this.UpdateHandler.sendEmptyMessage(0);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void doNVUpdate(boolean isPass) {
        int id = FactoryTestManager.getItemPosition_ID(this.mTestID);
        FtUtil.log_d(CLASS_NAME, "doNVUpdate", "ID : " + id + " / TestID : " + this.mTestID);
        if (id == -1 && !this.IsSelfTest) {
            id = FactoryTestManager.getItemPosition_ID(98);
            FtUtil.log_d(CLASS_NAME, "doNVUpdate", "changed to TEST_OIS_TEST id value ...");
        }
        byte b = 80;
        if (id > -1) {
            FtUtil.log_d(CLASS_NAME, "doNVUpdate", "id = " + id + " / result = " + isPass);
            if (!isPass) {
                b = 70;
            }
            FactoryTestManager.setItemResult(id, b);
            FactoryTestManager.notifyDataSetChanged();
            return;
        }
        NVAccessor.setNV(178, (byte) 80);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void TimeOutProcess() {
        FtUtil.log_d(CLASS_NAME, "TimeOutProcess", "TimeOut -> StopService");
        super.stopSelf();
    }

    /* access modifiers changed from: private */
    public class TimeOutThread extends Thread {
        int mTimeOut = 0;
        long startTime = System.currentTimeMillis();

        public TimeOutThread(int time) {
            this.mTimeOut = time;
        }

        public void run() {
            FtUtil.log_d(OisService.CLASS_NAME, "TimeoutThread", "Starting... Time_Out Setting : " + this.mTimeOut);
            while (System.currentTimeMillis() - this.startTime < ((long) this.mTimeOut)) {
                try {
                    Thread.sleep(100);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                    FtUtil.log_d(OisService.CLASS_NAME, "TimeoutThread", "No TimeOut ...");
                    return;
                }
            }
            FtUtil.log_d(OisService.CLASS_NAME, "TimeoutThread", "Time out !!!");
            OisService.this.TimeOutProcess();
        }
    }

    public IBinder onBind(Intent arg0) {
        return null;
    }

    public int onStartCommand(Intent intent, int flags, int startId) {
        FtUtil.log_d(CLASS_NAME, "onStartCommand", FtUtil.setMspSeqMessage(4, CLASS_NAME, "Start Service"));
        return super.onStartCommand(intent, flags, startId);
    }

    public void onDestroy() {
        FtUtil.log_d(CLASS_NAME, "onDestroy", FtUtil.setMspSeqMessage(4, CLASS_NAME, "Stop Service"));
        super.onDestroy();
    }
}
