package com.sec.factory.modules;

import android.content.Context;
import android.hardware.SensorManager;
import com.sec.factory.modules.SensorSpec;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;

public class SensorCalculator {
    private static final String CLASS_NAME = "SensorCalculator";
    private static final boolean DEBUG = true;
    private static String RESULT_VALUE_NG = "NG";
    private static String RESULT_VALUE_NOTSUPPORTED = SensorRead.RETURN_DATA_ARRAY_INDEX_1_NONE;
    private static String RESULT_VALUE_OK = "OK";
    private static final float STANDARD_GRAVITY = 9.80665f;
    private static float mAccelerometerRawDataWeight = -1.0f;
    private static SensorSpec mSensorSpec;

    public static void initialize() {
        FtUtil.log_d(CLASS_NAME, "initialize", null);
        SensorSpec sensorSpec = new SensorSpec();
        mSensorSpec = sensorSpec;
        specLog(sensorSpec.getSpecAccel(), "AccelSelf");
        specLog(mSensorSpec.getSpecGeomagnetic_DAC(), "MagneticDAC");
        specLog(mSensorSpec.getSpecGeomagnetic_ADC(), "MagneticADC");
        specLog(mSensorSpec.getSpecGeomagnetic_ADC2(), "MagneticADC2");
        specLog(mSensorSpec.getSpecGeomagnetic_Self(), "MagneticSelf");
    }

    public static SensorSpec getSensorSpec() {
        return mSensorSpec;
    }

    private static float getAccelerometerRawDataWeight(int bitCount, int scale) {
        return ((float) getAccelerometer1GValue(bitCount, scale)) / STANDARD_GRAVITY;
    }

    public static float getAccelerometerRawDataWeight_Spec(Context context) {
        if (mAccelerometerRawDataWeight < 0.0f) {
            if (mSensorSpec.getSpecAccel() != null) {
                int bitCountFromSensorSpec = mSensorSpec.getSpecAccel().mBitCount;
                FtUtil.log_d(CLASS_NAME, "getAccelerometerRawDataWeight_Spec", "bitCount(Spec) : " + bitCountFromSensorSpec);
                int accelerometerFullScale = getAccelerometerFullScale(context);
                FtUtil.log_d(CLASS_NAME, "getAccelerometerRawDataWeight_Spec", "accelerometerFullScale value : " + accelerometerFullScale);
                mAccelerometerRawDataWeight = getAccelerometerRawDataWeight(bitCountFromSensorSpec, accelerometerFullScale);
            } else {
                FtUtil.log_e(CLASS_NAME, "getAccelerometerRawDataWeight_Spec", "bitCount(Spec) : None => return 0");
                mAccelerometerRawDataWeight = 0.0f;
            }
        }
        return mAccelerometerRawDataWeight;
    }

    public static float getAccelerometerRawDataWeight_Feature(Context context) {
        if (mAccelerometerRawDataWeight < 0.0f) {
            String bit = Support.TestCase.getString(Support.TestCase.SENSOR_TEST_ACC_BIT);
            if (bit.equals("")) {
                FtUtil.log_d(CLASS_NAME, "getAccelerometerRawDataWeight_Feature", " bitCount(feature) : None => return 0");
                mAccelerometerRawDataWeight = 0.0f;
            } else {
                FtUtil.log_d(CLASS_NAME, "getAccelerometerRawDataWeight_Feature", " bitCount(feature) : " + bit);
                mAccelerometerRawDataWeight = getAccelerometerRawDataWeight(Integer.parseInt(bit), getAccelerometerFullScale(context));
            }
        }
        return mAccelerometerRawDataWeight;
    }

    public static String[] getAccelerometerAngle(int[] data) {
        float realg = (float) Math.sqrt((double) ((data[0] * data[0]) + (data[1] * data[1]) + (data[2] * data[2])));
        return new String[]{"" + ((int) (((float) Math.asin((double) (((float) data[0]) / realg))) * 57.29578f)), "" + ((int) (((float) Math.asin((double) (((float) data[1]) / realg))) * 57.29578f)), "" + ((int) (((((float) Math.acos((double) (((float) data[2]) / realg))) * 57.29578f) - 90.0f) * -1.0f))};
    }

    public static float getAccelerometerAngleMagnitude(float xValue, float yValue, float zValue) {
        return (float) Math.sqrt((double) ((xValue * xValue) + (yValue * yValue) + (zValue * zValue)));
    }

    public static float getAccelerometerAngleDeviation(float magnitude) {
        return Math.abs(magnitude - STANDARD_GRAVITY);
    }

    public static int getAccelerometerAngleXY(float xValue, float yValue) {
        return (int) (((float) (-Math.atan2((double) xValue, (double) yValue))) * 57.29578f);
    }

    public static String getResultAccelerometerSelf(int x, int y, int z) {
        String returnValue;
        String returnValue2;
        String returnValue3;
        specLog(mSensorSpec.getSpecAccel(), "AccelSelf");
        SensorSpec.Accelerometer spec = mSensorSpec.getSpecAccel();
        if (spec != null) {
            if (spec.mRange.mIsSupportRange1_X) {
                if (x < spec.mRange.mRange1_X_Min || spec.mRange.mRange1_X_Max < x) {
                    returnValue = "" + "F";
                } else {
                    returnValue = "" + "P";
                }
                FtUtil.log_i(CLASS_NAME, "getResultAccelerometerSelf", "" + spec.mRange.mRange1_X_Min + " [" + x + "] " + spec.mRange.mRange1_X_Max);
            } else {
                returnValue = "" + "P";
            }
            if (spec.mRange.mIsSupportRange1_Y) {
                if (y < spec.mRange.mRange1_Y_Min || spec.mRange.mRange1_Y_Max < y) {
                    returnValue2 = returnValue + "F";
                } else {
                    returnValue2 = returnValue + "P";
                }
                FtUtil.log_i(CLASS_NAME, "getResultAccelerometerSelf", "" + spec.mRange.mRange1_Y_Min + " [" + y + "] " + spec.mRange.mRange1_Y_Max);
            } else {
                returnValue2 = returnValue + "P";
            }
            if (spec.mRange.mIsSupportRange1_Z) {
                if (z < spec.mRange.mRange1_Z_Min || spec.mRange.mRange1_Z_Max < z) {
                    returnValue3 = returnValue2 + "F";
                } else {
                    returnValue3 = returnValue2 + "P";
                }
                FtUtil.log_i(CLASS_NAME, "getResultAccelerometerSelf", "" + spec.mRange.mRange1_Z_Min + " [" + z + "] " + spec.mRange.mRange1_Z_Max);
            } else {
                returnValue3 = returnValue2 + "P";
            }
            FtUtil.log_i(CLASS_NAME, "getResultAccelerometerSelf", returnValue3);
            return returnValue3;
        }
        FtUtil.log_e(CLASS_NAME, "getResultAccelerometerSelf", "FFF - Spec null");
        return "FFF";
    }

    public static int getAccelerometer1GValue(int bitCount) {
        FtUtil.log_d(CLASS_NAME, "getAccelerometer1GValue", " bitCount : " + bitCount + ", scale : default (8G)");
        return getAccelerometer1GValue(bitCount, 8);
    }

    public static int getAccelerometer1GValue(int bitCount, int scale) {
        FtUtil.log_d(CLASS_NAME, "getAccelerometer1GValue", " bitCount : " + bitCount + ", scale : " + scale);
        int accelerometer1GReferenceValue = (((int) Math.pow(2.0d, (double) bitCount)) / 2) / scale;
        FtUtil.log_d(CLASS_NAME, "getAccelerometer1GValue", " accelerometer1GReferenceValue : " + accelerometer1GReferenceValue + ", scale : " + scale);
        return accelerometer1GReferenceValue;
    }

    public static int getAccelerometerFullScale(Context context) {
        int fullscale = 8;
        if (context == null) {
            FtUtil.log_d(CLASS_NAME, "getAccelerometerFullScale", "context is null");
        } else {
            FtUtil.log_d(CLASS_NAME, "getAccelerometerFullScale", "context : " + context);
            try {
                fullscale = (int) (((SensorManager) context.getSystemService("sensor")).getDefaultSensor(1).getMaximumRange() / STANDARD_GRAVITY);
            } catch (Exception e) {
                FtUtil.log_i(CLASS_NAME, "getAccelerometerFullScale", "Sensor Exception");
            }
        }
        FtUtil.log_d(CLASS_NAME, "getAccelerometerFullScale", "fullscale : " + fullscale);
        return fullscale;
    }

    public static String checkSpecMagneticDAC(int x, int y, int z) {
        FtUtil.log_d(CLASS_NAME, "checkSpecMagneticDAC", null);
        specLog(mSensorSpec.getSpecGeomagnetic_DAC(), "MagneticDAC");
        return getResult(x, y, z, mSensorSpec.getSpecGeomagnetic_DAC());
    }

    public static String checkSpecMagneticADC(int x, int y, int z) {
        FtUtil.log_d(CLASS_NAME, "checkSpecMagneticADC", null);
        specLog(mSensorSpec.getSpecGeomagnetic_ADC(), "MagneticADC");
        return getResult(x, y, z, mSensorSpec.getSpecGeomagnetic_ADC());
    }

    public static String checkSpecMagneticADC2(int x, int y, int z) {
        FtUtil.log_d(CLASS_NAME, "checkSpecMagneticADC2", null);
        specLog(mSensorSpec.getSpecGeomagnetic_ADC2(), "MagneticADC2");
        return getResult(x, y, z, mSensorSpec.getSpecGeomagnetic_ADC2());
    }

    public static String checkSpecMagneticSelf(int x, int y, int z) {
        FtUtil.log_d(CLASS_NAME, "checkSpecMagneticSelf", null);
        specLog(mSensorSpec.getSpecGeomagnetic_Self(), "MagneticSelf");
        return getResult(x, y, z, mSensorSpec.getSpecGeomagnetic_Self());
    }

    private static String getResult(int x, int y, int z, SensorSpec.Range range) {
        if (range == null) {
            FtUtil.log_e(CLASS_NAME, "getResult", "Fail - Spec null");
            return RESULT_VALUE_NOTSUPPORTED;
        } else if (range.mRangeCount == 1) {
            FtUtil.log_i(CLASS_NAME, "getResult", "mRangeCount : 1");
            if (range.mIsSupportRange1_X && !isSpecIn(x, range.mRange1_X_Min, range.mRange1_X_Max)) {
                FtUtil.log_e(CLASS_NAME, "getResult", "Fail - X");
                return RESULT_VALUE_NG;
            } else if (range.mIsSupportRange1_Y && !isSpecIn(y, range.mRange1_Y_Min, range.mRange1_Y_Max)) {
                FtUtil.log_e(CLASS_NAME, "getResult", "Fail - Y");
                return RESULT_VALUE_NG;
            } else if (!range.mIsSupportRange1_Z || isSpecIn(z, range.mRange1_Z_Min, range.mRange1_Z_Max)) {
                return RESULT_VALUE_OK;
            } else {
                FtUtil.log_e(CLASS_NAME, "getResult", "Fail - Z");
                return RESULT_VALUE_NG;
            }
        } else if (range.mRangeCount == 2) {
            FtUtil.log_i(CLASS_NAME, "getResult", "mRangeCount : 2");
            if (!range.mIsSupportRange1_X || !range.mIsSupportRange2_X) {
                if (!range.mIsSupportRange1_X || range.mIsSupportRange2_X) {
                    if (!range.mIsSupportRange1_X && range.mIsSupportRange2_X && !isSpecIn(x, range.mRange2_X_Min, range.mRange2_X_Max)) {
                        FtUtil.log_e(CLASS_NAME, "getResult", "[Range2] Fail - X");
                        return RESULT_VALUE_NG;
                    }
                } else if (!isSpecIn(x, range.mRange1_X_Min, range.mRange1_X_Max)) {
                    FtUtil.log_e(CLASS_NAME, "getResult", "[Range1] Fail - X");
                    return RESULT_VALUE_NG;
                }
            } else if (!isSpecIn(x, range.mRange1_X_Min, range.mRange1_X_Max) && !isSpecIn(x, range.mRange2_X_Min, range.mRange2_X_Max)) {
                FtUtil.log_e(CLASS_NAME, "getResult", "[All] Fail - X");
                return RESULT_VALUE_NG;
            }
            if (!range.mIsSupportRange1_Y || !range.mIsSupportRange2_Y) {
                if (!range.mIsSupportRange1_Y || range.mIsSupportRange2_Y) {
                    if (!range.mIsSupportRange1_Y && range.mIsSupportRange2_Y && !isSpecIn(y, range.mRange2_Y_Min, range.mRange2_Y_Max)) {
                        FtUtil.log_e(CLASS_NAME, "getResult", "[Range2] Fail - Y");
                        return RESULT_VALUE_NG;
                    }
                } else if (!isSpecIn(y, range.mRange1_Y_Min, range.mRange1_Y_Max)) {
                    FtUtil.log_e(CLASS_NAME, "getResult", "[Range1] Fail - Y");
                    return RESULT_VALUE_NG;
                }
            } else if (!isSpecIn(y, range.mRange1_Y_Min, range.mRange1_Y_Max) && !isSpecIn(y, range.mRange2_Y_Min, range.mRange2_Y_Max)) {
                FtUtil.log_e(CLASS_NAME, "getResult", "[All] Fail - Y");
                return RESULT_VALUE_NG;
            }
            if (!range.mIsSupportRange1_Z || !range.mIsSupportRange2_Z) {
                if (!range.mIsSupportRange1_Z || range.mIsSupportRange2_Z) {
                    if (!range.mIsSupportRange1_Z && range.mIsSupportRange2_Z && !isSpecIn(z, range.mRange2_Z_Min, range.mRange2_Z_Max)) {
                        FtUtil.log_e(CLASS_NAME, "getResult", "[Range2] Fail - Z");
                        return RESULT_VALUE_NG;
                    }
                } else if (!isSpecIn(z, range.mRange1_Z_Min, range.mRange1_Z_Max)) {
                    FtUtil.log_e(CLASS_NAME, "getResult", "[Range1] Fail - Z");
                    return RESULT_VALUE_NG;
                }
            } else if (!isSpecIn(z, range.mRange1_Z_Min, range.mRange1_Z_Max) && !isSpecIn(z, range.mRange2_Z_Min, range.mRange2_Z_Max)) {
                FtUtil.log_e(CLASS_NAME, "getResult", "[All] Fail - Z");
                return RESULT_VALUE_NG;
            }
            return RESULT_VALUE_OK;
        } else {
            FtUtil.log_e(CLASS_NAME, "getResult", "mRangeCount : Unknown");
            return RESULT_VALUE_NOTSUPPORTED;
        }
    }

    private static boolean isSpecIn(int value, int rangeMin, int rangeMax) {
        if (rangeMin > value || value > rangeMax) {
            FtUtil.log_e(CLASS_NAME, "isSpecIn", "Fail => [" + rangeMin + " <= (" + value + ") <= " + rangeMax + "]");
            return false;
        }
        FtUtil.log_i(CLASS_NAME, "isSpecIn", "Pass => [" + rangeMin + " <= (" + value + ") <= " + rangeMax + "]");
        return true;
    }

    private static void specLog(SensorSpec.Range data, String name) {
        String message;
        String message2;
        String message3;
        String message4 = "<" + name + "> ";
        if (data != null) {
            if (data.mIsSupportRange1_X) {
                message2 = message4 + "X(" + data.mRange1_X_Min + "," + data.mRange1_X_Max + ") , ";
            } else {
                message2 = message4 + "X(not supported) , ";
            }
            if (data.mIsSupportRange1_Y) {
                message3 = message2 + "Y(" + data.mRange1_Y_Min + "," + data.mRange1_Y_Max + ") , ";
            } else {
                message3 = message2 + "Y(not supported) , ";
            }
            if (data.mIsSupportRange1_Z) {
                message = message3 + "Z(" + data.mRange1_Z_Min + "," + data.mRange1_Z_Max + ")";
            } else {
                message = message3 + "Z(not supported)";
            }
        } else {
            message = "<" + name + "> null";
        }
        FtUtil.log_d(CLASS_NAME, "specLog", message);
    }

    private static void specLog(SensorSpec.Accelerometer data, String name) {
        if (data != null) {
            specLog(data.mRange, name);
        } else {
            specLog((SensorSpec.Range) null, name);
        }
    }
}
