package com.sec.factory.modules;

import android.content.Context;
import android.hardware.SensorManager;
import com.sec.factory.modules.SensorReadManager;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.optical.client.api.EgisFingerprint;
import java.text.DecimalFormat;
import java.util.Arrays;

public class SensorRead {
    public static final String RETURN_DATA_ARRAY_INDEX_1_NG = "NG";
    public static final String RETURN_DATA_ARRAY_INDEX_1_NONE = "None";
    public static final String RETURN_DATA_ARRAY_INDEX_1_OK = "OK";
    private static final float STANDARD_GRAVITY = 9.80665f;
    public static final int TARGET_FILE = 2;
    public static final int TARGET_INTENT = 3;
    public static final int TARGET_MANAGER = 1;
    public static final int TARGET_MANAGER_WIFI = 4;
    private final String CLASS_NAME = "SensorRead";
    private final int RETURN_DATA_ARRAY_SIZE_MAX = 18;
    private final String mAccelBitCntXML = Support.TestCase.getString(Support.TestCase.SENSOR_TEST_ACC_BIT);
    private final String mAccelSensorVendor = Support.Kernel.getAccSensorVendor();
    private Context mContext;
    private final String mFeature_Gyroscope = SensorDeviceInfo.getSensorName(SensorDeviceInfo.TYPE_GYRO, SensorDeviceInfo.TARGET_XML);
    private final String mFeature_Magnetic = SensorDeviceInfo.getSensorName(SensorDeviceInfo.TYPE_GEOMAGNETIC, SensorDeviceInfo.TARGET_XML);
    private final boolean mIsAccelReverse = Support.TestCase.getEnabled(Support.TestCase.IS_SENSOR_TEST_ACC_REVERSE);
    private SensorManager mSensorManager;
    private SensorReadFile mSensorReadFile = null;
    private SensorReadIntent mSensorReadIntent = null;
    private SensorReadManager mSensorReadManager = null;
    private SensorReadManager.MagneticExpansionData mTemp_Magnetic = null;

    SensorRead() {
        if (this.mSensorReadFile == null) {
            this.mSensorReadFile = new SensorReadFile(null);
        }
    }

    public synchronized void SensorOn(Context context, SensorManager sm, int[] idManager, int[] idFile, int[] idIntent) {
        this.mContext = context;
        if (idManager != null) {
            SensorReadManager sensorReadManager = this.mSensorReadManager;
            if (sensorReadManager == null) {
                this.mSensorReadManager = new SensorReadManager(idManager, sm);
            } else {
                sensorReadManager.turnOnOffSensor(idManager, sm, true);
            }
        }
        if (idFile != null) {
            SensorReadFile sensorReadFile = this.mSensorReadFile;
            if (sensorReadFile == null) {
                this.mSensorReadFile = new SensorReadFile(idFile);
            } else {
                sensorReadFile.sensorOn(idFile);
            }
        }
        if (idIntent != null) {
            this.mSensorReadIntent = new SensorReadIntent(this.mContext, idIntent);
        }
        FtUtil.log_d("SensorRead", "SensorOn", "mAccelBitCntXML : " + this.mAccelBitCntXML);
        FtUtil.log_d("SensorRead", "SensorOn", "mIsAccelReverse : " + this.mIsAccelReverse);
    }

    public void SensorOff(int[] idManager, int[] idFile, SensorManager sm) {
        String str = "null";
        if (this.mSensorReadFile != null) {
            StringBuilder sb = new StringBuilder();
            sb.append("File, ID=");
            sb.append(idFile != null ? Arrays.toString(idFile) : str);
            FtUtil.log_i("SensorRead", "SensorOff", sb.toString());
            this.mSensorReadFile.sensorOff(idFile);
        }
        if (this.mSensorReadManager != null) {
            StringBuilder sb2 = new StringBuilder();
            sb2.append("Manager, ID=");
            if (idManager != null) {
                str = Arrays.toString(idManager);
            }
            sb2.append(str);
            FtUtil.log_i("SensorRead", "SensorOff", sb2.toString());
            this.mSensorReadManager.sensorOff(idManager, sm);
        }
    }

    public void setLoop_ReadFile(int[] sensorID) {
        if (!(this.mSensorReadFile == null || sensorID == null)) {
            for (int i : sensorID) {
                if (ModuleSensor.ID_COUNT_MANAGER <= i) {
                    this.mSensorReadFile.startLoop(i);
                }
            }
        }
    }

    public boolean isSensorOn(int sensorID) {
        boolean result = false;
        if (this.mSensorReadManager != null && ModuleSensor.ID_SCOPE_MIN <= sensorID && sensorID < ModuleSensor.ID_COUNT_MANAGER) {
            result = this.mSensorReadManager.isSensorOn(sensorID);
        } else if (this.mSensorReadFile != null && ModuleSensor.ID_COUNT_MANAGER <= sensorID && sensorID < ModuleSensor.ID_COUNT_MANAGER + ModuleSensor.ID_COUNT_FILE) {
            result = this.mSensorReadFile.isSensorOn(sensorID);
        } else if (this.mSensorReadIntent == null || ModuleSensor.ID_COUNT_MANAGER + ModuleSensor.ID_COUNT_FILE > sensorID || sensorID > ModuleSensor.ID_SCOPE_MAX) {
            FtUtil.log_e("SensorRead", "SensorOn", "null / ID unknown");
        } else {
            result = this.mSensorReadIntent.isSensorOn(sensorID);
        }
        FtUtil.log_d("SensorRead", "isSensorOn", "sensorID[" + sensorID + "] result = " + result);
        return result;
    }

    public boolean isSensorReady(int sensorID) {
        boolean result = false;
        if (this.mSensorReadManager == null) {
            FtUtil.log_e("SensorRead", "isSensorReady", "SensorManager is null + , sensorID = " + sensorID);
            return false;
        }
        if (ModuleSensor.ID_SCOPE_MIN <= sensorID && sensorID < ModuleSensor.ID_COUNT_MANAGER) {
            result = this.mSensorReadManager.isSensorReady(sensorID);
        } else if (this.mSensorReadFile != null && ModuleSensor.ID_COUNT_MANAGER <= sensorID && sensorID < ModuleSensor.ID_COUNT_MANAGER + ModuleSensor.ID_COUNT_FILE) {
            FtUtil.log_w("SensorRead", "isSensorReady", "Not support + , sensorID = " + sensorID);
            result = true;
        } else if (this.mSensorReadIntent == null || ModuleSensor.ID_COUNT_MANAGER + ModuleSensor.ID_COUNT_FILE > sensorID || sensorID > ModuleSensor.ID_SCOPE_MAX) {
            FtUtil.log_e("SensorRead", "isSensorReady", "null / ID unknown");
        } else {
            FtUtil.log_w("SensorRead", "isSensorReady", "Not support + , sensorID = " + sensorID);
            result = true;
        }
        FtUtil.log_d("SensorRead", "isSensorReady", "sensorID[" + sensorID + "] result = " + result);
        return result;
    }

    public String[] getAccelermeterXYZ(int target) {
        SensorReadFile sensorReadFile;
        SensorReadManager sensorReadManager;
        double rawDataWeight;
        String[] returnData = new String[18];
        if (target == 1 && (sensorReadManager = this.mSensorReadManager) != null) {
            float[] tempFloat = sensorReadManager.returnAccelermeter();
            if (tempFloat != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getAccelermeterXYZ", " Count : " + tempFloat.length);
                }
                returnData[0] = "4";
                returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                if (this.mAccelSensorVendor.equals("MAXIM")) {
                    rawDataWeight = 1529.5743408203125d;
                    FtUtil.log_d("SensorRead", "getAccelermeterXYZ(MAXIM)", " Weight : " + 1529.5743408203125d);
                } else if (this.mAccelBitCntXML.equals("")) {
                    if (ModuleSensor.LOG_LEVEL <= 1) {
                        FtUtil.log_d("SensorRead", "getAccelermeterXYZ", " bitCount(feature) : Unknown");
                    }
                    rawDataWeight = (double) SensorCalculator.getAccelerometerRawDataWeight_Spec(this.mContext);
                } else {
                    if (ModuleSensor.LOG_LEVEL <= 1) {
                        FtUtil.log_d("SensorRead", "getAccelermeterXYZ", " bitCount(feature) : Known");
                    }
                    rawDataWeight = (double) SensorCalculator.getAccelerometerRawDataWeight_Feature(this.mContext);
                }
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getAccelermeterXYZ", " Weight : " + rawDataWeight);
                }
                if (this.mIsAccelReverse) {
                    returnData[2] = "" + (((int) (((double) tempFloat[1]) * rawDataWeight)) * -1);
                    returnData[3] = "" + (((int) (((double) tempFloat[0]) * rawDataWeight)) * -1);
                } else {
                    returnData[2] = "" + ((int) (((double) tempFloat[0]) * rawDataWeight));
                    returnData[3] = "" + ((int) (((double) tempFloat[1]) * rawDataWeight));
                }
                returnData[4] = "" + ((int) (((double) tempFloat[2]) * rawDataWeight));
            } else {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getAccelermeterXYZ", "null");
                }
                return null;
            }
        } else if (target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        } else {
            String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____ACCELEROMETER);
            if (tempString != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getAccelermeterXYZ", "Count : " + tempString.length);
                }
                returnData[0] = "4";
                returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                returnData[2] = tempString[0];
                returnData[3] = tempString[1];
                returnData[4] = tempString[2];
            } else {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getAccelermeterXYZ", "null");
                }
                return null;
            }
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getAccelermeterXYZ", dataCheck(returnData));
        }
        return returnData;
    }

    public String[] getSubAccelermeterXYZ(int target) {
        SensorReadFile sensorReadFile;
        SensorReadManager sensorReadManager;
        double rawDataWeight;
        String[] returnData = new String[18];
        if (target == 1 && (sensorReadManager = this.mSensorReadManager) != null) {
            float[] tempFloat = sensorReadManager.returnSubAccelermeter();
            if (tempFloat != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getSubAccelermeterXYZ", " Count : " + tempFloat.length);
                }
                returnData[0] = "4";
                returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                if (this.mAccelBitCntXML.equals("")) {
                    if (ModuleSensor.LOG_LEVEL <= 1) {
                        FtUtil.log_d("SensorRead", "getSubAccelermeterXYZ", " bitCount(feature) : Unknown");
                    }
                    rawDataWeight = (double) SensorCalculator.getAccelerometerRawDataWeight_Spec(this.mContext);
                } else {
                    if (ModuleSensor.LOG_LEVEL <= 1) {
                        FtUtil.log_d("SensorRead", "getSubAccelermeterXYZ", " bitCount(feature) : Known");
                    }
                    rawDataWeight = (double) SensorCalculator.getAccelerometerRawDataWeight_Feature(this.mContext);
                }
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getSubAccelermeterXYZ", " Weight : " + rawDataWeight);
                }
                if (this.mIsAccelReverse) {
                    returnData[2] = "" + (((int) (((double) tempFloat[1]) * rawDataWeight)) * -1);
                    returnData[3] = "" + (((int) (((double) tempFloat[0]) * rawDataWeight)) * -1);
                } else {
                    returnData[2] = "" + ((int) (((double) tempFloat[0]) * rawDataWeight));
                    returnData[3] = "" + ((int) (((double) tempFloat[1]) * rawDataWeight));
                }
                returnData[4] = "" + ((int) (((double) tempFloat[2]) * rawDataWeight));
            } else {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getSubAccelermeterXYZ", "null");
                }
                return null;
            }
        } else if (target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        } else {
            String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____SUB_ACCELEROMETER);
            if (tempString != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getSubAccelermeterXYZ", "Count : " + tempString.length);
                }
                returnData[0] = "4";
                returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                returnData[2] = tempString[0];
                returnData[3] = tempString[1];
                returnData[4] = tempString[2];
            } else {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getSubAccelermeterXYZ", "null");
                }
                return null;
            }
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getAccelermeterXYZ", dataCheck(returnData));
        }
        return returnData;
    }

    public String[] getAccelermeterXYZnAngle(int target) {
        SensorReadIntent sensorReadIntent;
        double changeBit;
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        String[] tempString = getAccelermeterXYZ(target);
        int[] tempInt = new int[3];
        if (tempString == null) {
            return null;
        }
        tempInt[0] = Integer.parseInt(tempString[2].trim());
        tempInt[1] = Integer.parseInt(tempString[3].trim());
        tempInt[2] = Integer.parseInt(tempString[4].trim());
        String[] tempString2 = SensorCalculator.getAccelerometerAngle(tempInt);
        if (target == 1 && (sensorReadManager = this.mSensorReadManager) != null) {
            float[] tempFloat = sensorReadManager.returnAccelermeter();
            if (!(tempFloat == null || tempString2 == null)) {
                returnData[0] = "10";
                returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                returnData[2] = "" + tempInt[0];
                returnData[3] = "" + tempInt[1];
                returnData[4] = "" + tempInt[2];
                returnData[5] = tempString2[0];
                returnData[6] = tempString2[1];
                returnData[7] = tempString2[2];
                returnData[8] = "" + SensorCalculator.getAccelerometerAngleMagnitude(tempFloat[0], tempFloat[1], tempFloat[2]);
                returnData[9] = "" + SensorCalculator.getAccelerometerAngleDeviation(Float.valueOf(returnData[8]).floatValue());
                returnData[10] = "" + SensorCalculator.getAccelerometerAngleXY(tempFloat[0], tempFloat[1]);
            }
        } else if (target == 2 && this.mSensorReadFile != null) {
            returnData[0] = "7";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = "" + tempInt[0];
            returnData[3] = "" + tempInt[1];
            returnData[4] = "" + tempInt[2];
            returnData[5] = tempString2[0];
            returnData[6] = tempString2[1];
            returnData[7] = tempString2[2];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getAccelermeterXYZNAngle", dataCheck(returnData));
            }
        } else if (target != 3 || (sensorReadIntent = this.mSensorReadIntent) == null) {
            return null;
        } else {
            int[] tempInt2 = sensorReadIntent.returnCPsAccelerometerData();
            float[] tempFloat2 = new float[3];
            if (tempInt2 != null) {
                tempString2 = SensorCalculator.getAccelerometerAngle(tempInt2);
            }
            if (tempInt2 != null && tempString2 != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getAccelermeterXYZnAngle");
                }
                returnData[0] = "10";
                returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                returnData[2] = "" + tempInt2[0];
                returnData[3] = "" + tempInt2[1];
                returnData[4] = "" + tempInt2[2];
                returnData[5] = tempString2[0];
                returnData[6] = tempString2[1];
                returnData[7] = tempString2[2];
                if ("12".equals(Support.TestCase.getString(Support.TestCase.SENSOR_TEST_ACC_BIT))) {
                    changeBit = 104.48979591836734d;
                } else {
                    changeBit = 24.0d;
                }
                tempFloat2[0] = ((float) (((double) tempInt2[1]) / changeBit)) * -1.0f;
                tempFloat2[1] = ((float) (((double) tempInt2[0]) / changeBit)) * -1.0f;
                tempFloat2[2] = (float) (((double) tempInt2[2]) / changeBit);
                returnData[8] = "" + SensorCalculator.getAccelerometerAngleMagnitude(tempFloat2[0], tempFloat2[1], tempFloat2[2]);
                returnData[9] = "" + SensorCalculator.getAccelerometerAngleDeviation(Float.valueOf(returnData[8]).floatValue());
                returnData[10] = "" + SensorCalculator.getAccelerometerAngleXY(tempFloat2[0], tempFloat2[1]);
                FtUtil.log_i("SensorRead", "getAccelermeterXYZnAngle", "CP: coordinates_x :" + returnData[2] + ", coordinates_y :" + returnData[3] + ", coordinates_z :" + returnData[4]);
                FtUtil.log_i("SensorRead", "getAccelermeterXYZnAngle", "CP: X_Angle :" + returnData[5] + ", Y_Angle :" + returnData[6] + ", z_Angle :" + returnData[7]);
                StringBuilder sb = new StringBuilder();
                sb.append("CP: magnitude :");
                sb.append(returnData[8]);
                sb.append(", deviation :");
                sb.append(returnData[9]);
                FtUtil.log_i("SensorRead", "getAccelermeterXYZnAngle", sb.toString());
                FtUtil.log_i("SensorRead", "getAccelermeterXYZnAngle", "CP: XY_value :" + returnData[10]);
            } else if (ModuleSensor.LOG_LEVEL > 2) {
                return null;
            } else {
                FtUtil.log_d("SensorRead", "getAccelermeterXYZnAngle", "null");
                return null;
            }
        }
        if (ModuleSensor.LOG_LEVEL <= 3) {
            FtUtil.log_d("SensorRead", "getAccelermeterSelf", dataCheck(returnData));
        }
        return returnData;
    }

    public String[] getSubAccelermeterXYZnAngle(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        String[] tempString = getSubAccelermeterXYZ(target);
        int[] tempInt = new int[3];
        if (tempString == null) {
            return null;
        }
        tempInt[0] = Integer.parseInt(tempString[2].trim());
        tempInt[1] = Integer.parseInt(tempString[3].trim());
        tempInt[2] = Integer.parseInt(tempString[4].trim());
        String[] tempString2 = SensorCalculator.getAccelerometerAngle(tempInt);
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnSubAccelermeter();
        if (!(tempFloat == null || tempString2 == null)) {
            returnData[0] = "10";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = "" + tempInt[0];
            returnData[3] = "" + tempInt[1];
            returnData[4] = "" + tempInt[2];
            returnData[5] = tempString2[0];
            returnData[6] = tempString2[1];
            returnData[7] = tempString2[2];
            returnData[8] = "" + SensorCalculator.getAccelerometerAngleMagnitude(tempFloat[0], tempFloat[1], tempFloat[2]);
            returnData[9] = "" + SensorCalculator.getAccelerometerAngleDeviation(Float.valueOf(returnData[8]).floatValue());
            returnData[10] = "" + SensorCalculator.getAccelerometerAngleXY(tempFloat[0], tempFloat[1]);
        }
        if (ModuleSensor.LOG_LEVEL <= 3) {
            FtUtil.log_d("SensorRead", "getSubAccelermeterXYZnAngle", dataCheck(returnData));
        }
        return returnData;
    }

    public String[] getAccelermeterSelf(int target) {
        String[] returnData = new String[18];
        String[] tempString = getAccelermeterXYZ(target);
        int[] tempInt = new int[3];
        if (tempString != null) {
            tempInt[0] = Integer.parseInt(tempString[2].trim());
            tempInt[1] = Integer.parseInt(tempString[3].trim());
            tempInt[2] = Integer.parseInt(tempString[4].trim());
            returnData[0] = "2";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = SensorCalculator.getResultAccelerometerSelf(tempInt[0], tempInt[1], tempInt[2]);
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getAccelermeterSelf", dataCheck(returnData));
            }
            return returnData;
        } else if (ModuleSensor.LOG_LEVEL > 2) {
            return null;
        } else {
            FtUtil.log_d("SensorRead", "getAccelermeterSelf", "null");
            return null;
        }
    }

    public String[] getAccelermeterSelfTest(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if (target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            FtUtil.log_w("SensorRead", "getAccelermeterSelfTest", "Not supported Sensor Interface");
            return null;
        }
        String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____ACCELEROMETER_SELFTEST);
        if (tempString != null) {
            if (tempString.length <= 1) {
                tempString = tempString[0].split(" ");
            }
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getAccelermeterSelfTest", "Count : " + tempString.length);
            }
            returnData[0] = String.valueOf(tempString.length);
            for (int index = 0; index < tempString.length; index++) {
                returnData[index + 1] = tempString[index];
            }
            return returnData;
        }
        FtUtil.log_w("SensorRead", "getAccelermeterSelfTest", "No SensorData");
        return null;
    }

    public String[] getSubAccelermeterSelfTest(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if (target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            FtUtil.log_w("SensorRead", "getSubAccelermeterSelfTest", "Not supported Sensor Interface");
            return null;
        }
        String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____SUB_ACCELEROMETER_SELFTEST);
        if (tempString != null) {
            if (tempString.length <= 1) {
                tempString = tempString[0].split(" ");
            }
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getSubAccelermeterSelfTest", "Count : " + tempString.length);
            }
            returnData[0] = String.valueOf(tempString.length);
            for (int index = 0; index < tempString.length; index++) {
                returnData[index + 1] = tempString[index];
            }
            return returnData;
        }
        FtUtil.log_w("SensorRead", "getSubAccelermeterSelfTest", "No SensorData");
        return null;
    }

    public String[] getAccelermeterCal(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if ((target == 1 && this.mSensorReadManager != null) || target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        }
        String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____ACCELEROMETER_CAL);
        if (tempString != null) {
            if (tempString.length <= 1) {
                tempString = tempString[0].split(" ");
            }
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getAccelermeterCal", "Count : " + tempString.length);
            }
            returnData[0] = "4";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = tempString[0];
            returnData[3] = tempString[1];
            returnData[4] = tempString[2];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getAccelermeterCal", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getAccelermeterCal", "null");
        }
        return null;
    }

    public String[] getAccelermeterIntpin(int target) {
        String[] returnData = new String[18];
        if ((target == 1 && this.mSensorReadManager != null) || target != 2 || this.mSensorReadFile == null) {
            return null;
        }
        if (Support.Kernel.write(Support.Kernel.ACCEL_SENSOR_INTPIN, "2")) {
            FtUtil.Sleep.sleep(300);
            String[] tempString = this.mSensorReadFile.returnData(ModuleSensor.ID_FILE____ACCELEROMETER_INTPIN);
            if (tempString != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getAccelermeterIntpin", "Count : " + tempString.length);
                }
                returnData[0] = "2";
                returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                returnData[2] = tempString[0];
                Support.Kernel.write(Support.Kernel.ACCEL_SENSOR_INTPIN, "0");
            } else {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getAccelermeterIntpin", "null");
                }
                return null;
            }
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getAccelermeterIntpin", dataCheck(returnData));
        }
        return returnData;
    }

    public String[] getBarometer(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnBarometer();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getBarometer", "Count : " + tempFloat.length);
            }
            DecimalFormat format = new DecimalFormat("#.##");
            returnData[0] = "4";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = String.valueOf(format.format((double) tempFloat[0]));
            returnData[3] = String.valueOf(format.format((double) SensorManager.getAltitude(1013.25f, tempFloat[0])));
            returnData[4] = Support.Kernel.read(Support.Kernel.BAROMETE_TEMPERATURE);
            replaceData(returnData);
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getBarometer", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getBarometer", "null");
        }
        return null;
    }

    public String[] getBarometerEEPROM(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if ((target == 1 && this.mSensorReadManager != null) || target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        }
        String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____BAROMETER_EEPROM);
        if (tempString != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getBarometerEEPROM", "Count : " + tempString.length);
            }
            returnData[0] = "2";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = tempString[0];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getBarometerEEPROM", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getBarometerEEPROM", "null");
        }
        return null;
    }

    public String[] getGrip(int target) {
        SensorReadIntent sensorReadIntent;
        SensorReadFile sensorReadFile;
        SensorReadManager sensorReadManager;
        SensorReadManager sensorReadManager2;
        String[] returnData = new String[18];
        int i = -1;
        if (target == 1 && (sensorReadManager2 = this.mSensorReadManager) != null) {
            float[] tempFloat = sensorReadManager2.returnGrip();
            if (tempFloat != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getGrip", "Count : " + tempFloat.length);
                }
                returnData[0] = EgisFingerprint.MAJOR_VERSION;
                StringBuilder sb = new StringBuilder();
                sb.append("");
                sb.append(tempFloat.length > 0 ? (int) tempFloat[0] : -1);
                returnData[1] = sb.toString();
                StringBuilder sb2 = new StringBuilder();
                sb2.append("");
                sb2.append(tempFloat.length > 1 ? (int) tempFloat[1] : -1);
                returnData[2] = sb2.toString();
                StringBuilder sb3 = new StringBuilder();
                sb3.append("");
                if (tempFloat.length > 2) {
                    i = (int) tempFloat[2];
                }
                sb3.append(i);
                returnData[3] = sb3.toString();
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getGrip", dataCheck(returnData));
                }
            } else {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getGrip", "null");
                }
                return null;
            }
        } else if (target == 4 && (sensorReadManager = this.mSensorReadManager) != null) {
            float[] tempFloat2 = sensorReadManager.returnGrip_Wifi();
            if (tempFloat2 != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getGrip_Wifi", "Count : " + tempFloat2.length);
                }
                returnData[0] = EgisFingerprint.MAJOR_VERSION;
                StringBuilder sb4 = new StringBuilder();
                sb4.append("");
                sb4.append(tempFloat2.length > 0 ? (int) tempFloat2[0] : -1);
                returnData[1] = sb4.toString();
                StringBuilder sb5 = new StringBuilder();
                sb5.append("");
                sb5.append(tempFloat2.length > 1 ? (int) tempFloat2[1] : -1);
                returnData[2] = sb5.toString();
                StringBuilder sb6 = new StringBuilder();
                sb6.append("");
                if (tempFloat2.length > 2) {
                    i = (int) tempFloat2[2];
                }
                sb6.append(i);
                returnData[3] = sb6.toString();
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getGrip_Wifi", dataCheck(returnData));
                }
            } else {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getGrip_Wifi", "null");
                }
                return null;
            }
        } else if (target == 2 && (sensorReadFile = this.mSensorReadFile) != null) {
            String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____GRIP_RAW);
            if (tempString != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getGrip", "Count : " + tempString.length);
                }
                returnData[0] = EgisFingerprint.MAJOR_VERSION;
                returnData[1] = tempString[0];
                returnData[2] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                returnData[3] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getGrip", dataCheck(returnData));
                }
            } else {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getGrip", "null");
                }
                return null;
            }
        } else if (target != 3 || (sensorReadIntent = this.mSensorReadIntent) == null) {
            return null;
        } else {
            int[] tempInt = sensorReadIntent.returnGrip();
            if (tempInt != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getGrip", "Count : " + tempInt.length);
                }
                returnData[0] = EgisFingerprint.MAJOR_VERSION;
                returnData[1] = "" + tempInt[0];
                returnData[2] = "" + tempInt[1];
                returnData[3] = "" + tempInt[2];
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getGrip", dataCheck(returnData));
                }
            } else {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getGrip", "null");
                }
                return null;
            }
        }
        return returnData;
    }

    public String[] getGrip_Sub(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnGrip_Sub();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getGrip_Sub", "Count : " + tempFloat.length);
            }
            returnData[0] = EgisFingerprint.MAJOR_VERSION;
            StringBuilder sb = new StringBuilder();
            sb.append("");
            int i = -1;
            sb.append(tempFloat.length > 0 ? (int) tempFloat[0] : -1);
            returnData[1] = sb.toString();
            StringBuilder sb2 = new StringBuilder();
            sb2.append("");
            sb2.append(tempFloat.length > 1 ? (int) tempFloat[1] : -1);
            returnData[2] = sb2.toString();
            StringBuilder sb3 = new StringBuilder();
            sb3.append("");
            if (tempFloat.length > 2) {
                i = (int) tempFloat[2];
            }
            sb3.append(i);
            returnData[3] = sb3.toString();
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getGrip_Sub", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getGrip_Sub", "null");
        }
        return null;
    }

    public String[] getGrip_Sub2(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnGrip_Sub2();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getGrip_Sub2", "Count : " + tempFloat.length);
            }
            returnData[0] = EgisFingerprint.MAJOR_VERSION;
            StringBuilder sb = new StringBuilder();
            sb.append("");
            int i = -1;
            sb.append(tempFloat.length > 0 ? (int) tempFloat[0] : -1);
            returnData[1] = sb.toString();
            StringBuilder sb2 = new StringBuilder();
            sb2.append("");
            sb2.append(tempFloat.length > 1 ? (int) tempFloat[1] : -1);
            returnData[2] = sb2.toString();
            StringBuilder sb3 = new StringBuilder();
            sb3.append("");
            if (tempFloat.length > 2) {
                i = (int) tempFloat[2];
            }
            sb3.append(i);
            returnData[3] = sb3.toString();
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getGrip_Sub2", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getGrip_Sub2", "null");
        }
        return null;
    }

    public String[] getGrip_Sub3(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnGrip_Sub3();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getGrip_Sub3", "Count : " + tempFloat.length);
            }
            returnData[0] = EgisFingerprint.MAJOR_VERSION;
            StringBuilder sb = new StringBuilder();
            sb.append("");
            int i = -1;
            sb.append(tempFloat.length > 0 ? (int) tempFloat[0] : -1);
            returnData[1] = sb.toString();
            StringBuilder sb2 = new StringBuilder();
            sb2.append("");
            sb2.append(tempFloat.length > 1 ? (int) tempFloat[1] : -1);
            returnData[2] = sb2.toString();
            StringBuilder sb3 = new StringBuilder();
            sb3.append("");
            if (tempFloat.length > 2) {
                i = (int) tempFloat[2];
            }
            sb3.append(i);
            returnData[3] = sb3.toString();
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getGrip_Sub3", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getGrip_Sub3", "null");
        }
        return null;
    }

    public String[] getGripThreshold(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if ((target == 1 && this.mSensorReadManager != null) || target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        }
        String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____GRIP_THRESHOLD);
        if (tempString != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getGrip", "Count : " + tempString.length);
            }
            returnData[0] = "4";
            returnData[1] = tempString[0];
            returnData[2] = tempString[1];
            returnData[3] = tempString[2];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getGrip", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getGrip", "null");
        }
        return null;
    }

    public String[] getGripTouch(int target, int id) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if (target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        }
        String[] tempString = sensorReadFile.returnData(id);
        if (tempString != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getGripTouch", "Count : " + tempString.length);
            }
            returnData[0] = String.valueOf(tempString.length);
            for (int i = 1; i <= tempString.length; i++) {
                returnData[i] = tempString[i - 1];
            }
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getGrip", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getGripTouch", "null");
        }
        return null;
    }

    public String[] getGyro(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnGyro();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getGyro", "Count : " + tempFloat.length);
            }
            returnData[0] = "4";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = "" + (tempFloat[0] * 57.295776f);
            returnData[3] = "" + (tempFloat[1] * 57.295776f);
            returnData[4] = "" + (tempFloat[2] * 57.295776f);
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getGyro", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getGyro", "null");
        }
        return null;
    }

    public String[] getGyroTemperature(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if ((target == 1 && this.mSensorReadManager != null) || target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        }
        String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____GYRO_TEMPERATURE);
        if (tempString != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getGyroTemperature", "Count : " + tempString.length);
            }
            returnData[0] = "2";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = tempString[0];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getGyroTemperature", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getGyroTemperature", "null");
        }
        return null;
    }

    public String[] getGyroSelf(int target) {
        SensorReadFile sensorReadFile;
        String resultValue;
        String zerocalResult;
        String[] returnData = new String[18];
        if (target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        }
        String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____GYRO_SELFTEST);
        if (tempString != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getGyroSelf", "Count : " + tempString.length);
            }
            if (!tempString[6].equals(egis.client.api.EgisFingerprint.MAJOR_VERSION) || !tempString[7].equals(egis.client.api.EgisFingerprint.MAJOR_VERSION)) {
                resultValue = ModuleCommunicationService.SMD_NOK;
            } else {
                resultValue = "0";
            }
            returnData[0] = "7";
            returnData[1] = "" + resultValue;
            returnData[2] = "" + tempString[0];
            returnData[3] = "" + tempString[1];
            returnData[4] = "" + tempString[2];
            returnData[5] = "" + tempString[3];
            returnData[6] = "" + tempString[4];
            returnData[7] = "" + tempString[5];
            if (this.mFeature_Gyroscope.contains(SensorFeature.FEATURE_GYROSCOP_STMICRO_SMARTPHONE)) {
                returnData[0] = "8";
                returnData[8] = "" + tempString[6];
            } else if (this.mFeature_Gyroscope.contains(SensorFeature.FEATURE_GYROSCOP_STMICRO_TABLET)) {
                FtUtil.log_d("SensorRead", "getGyroSelfTest", "FEATURE TABLET(CAL)");
                returnData[0] = "8";
                if (!tempString[13].equals(egis.client.api.EgisFingerprint.MAJOR_VERSION) || !tempString[14].equals(egis.client.api.EgisFingerprint.MAJOR_VERSION)) {
                    zerocalResult = ModuleCommunicationService.SMD_NOK;
                } else {
                    zerocalResult = "0";
                }
                returnData[1] = "" + zerocalResult;
                returnData[8] = "" + tempString[14];
            }
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getGyroSelf", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getGyroSelfTest", "null");
        }
        return null;
    }

    public String[] getLight(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnLight();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getLight", "Count : " + tempFloat.length);
            }
            returnData[0] = "2";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = "" + tempFloat[0];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getLight", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getLight", "null");
        }
        return null;
    }

    public String[] getLightCCT(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnLightCCT();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getLightCCT", "Count : " + tempFloat.length);
            }
            returnData[0] = "2";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = "" + tempFloat[1];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getLightCCT", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getLightCCT", "null");
        }
        return null;
    }

    public String[] getLightADC(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if ((target == 1 && this.mSensorReadManager != null) || target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        }
        String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____LIGHT_ADC);
        if (tempString != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getLightADC", "Count : " + tempString.length);
            }
            returnData[0] = "2";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = "" + tempString[0];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getLightADC", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getLightADC", "null");
        }
        return null;
    }

    public String[] getLightRGBW(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if ((target == 1 && this.mSensorReadManager != null) || target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        }
        String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____LIGHT_RGBW);
        if (tempString != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getLightRGBW", "Count : " + tempString.length);
            }
            returnData[0] = "5";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = "" + tempString[0];
            returnData[3] = "" + tempString[1];
            returnData[4] = "" + tempString[2];
            returnData[5] = "" + tempString[3];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getLightRGBW", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getLightRGBW", "null");
        }
        return null;
    }

    public String[] getMagnetic(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnMagnetic();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getMagnetic", "Count : " + tempFloat.length);
            }
            returnData[0] = "4";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = "" + tempFloat[0];
            returnData[3] = "" + tempFloat[1];
            returnData[4] = "" + tempFloat[2];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getMagnetic", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getMagnetic", "null");
        }
        return null;
    }

    public String[] getMagneticPowerOn(int target) {
        int i;
        SensorReadFile sensorReadFile;
        char c;
        char c2;
        String[] returnData = new String[18];
        if (target == 1 && this.mSensorReadManager != null) {
            if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C_MANAGER) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8973) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8975) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09916C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09918C)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD006A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD008A)) {
                this.mTemp_Magnetic = this.mSensorReadManager.returnMagneticExpansion_Alps(1);
            } else if (this.mFeature_Magnetic.equals("BMC150") || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_POWER_NOISE)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO_LSM303AH)) {
                this.mTemp_Magnetic = this.mSensorReadManager.returnMagneticExpansion_STMicro(1);
            }
            SensorReadManager.MagneticExpansionData magneticExpansionData = this.mTemp_Magnetic;
            if (magneticExpansionData != null && magneticExpansionData.mPowerOn != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getMagneticPowerOn", "Count : " + this.mTemp_Magnetic.mPowerOn.length);
                }
                returnData[0] = "2";
                returnData[1] = this.mTemp_Magnetic.mPowerOn[0];
                returnData[2] = this.mTemp_Magnetic.mPowerOn[1];
                i = 2;
            } else if (ModuleSensor.LOG_LEVEL > 2) {
                return null;
            } else {
                FtUtil.log_d("SensorRead", "getMagneticPowerOn", "null");
                return null;
            }
        } else if (target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        } else {
            String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____MAGNETIC_POWER_ON);
            if (tempString != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getMagneticPowerOn", "Count : " + tempString.length);
                }
                returnData[0] = "2";
                if (!this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532)) {
                    if (this.mFeature_Magnetic.equals("BMC150")) {
                        c = 1;
                        i = 2;
                    } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_POWER_NOISE)) {
                        c = 1;
                        i = 2;
                    } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_COMBINATION)) {
                        Support.Kernel.write(Support.Kernel.GEOMAGNETIC_SENSOR_POWER, egis.client.api.EgisFingerprint.MAJOR_VERSION);
                        tempString[0] = Support.Kernel.read(Support.Kernel.GEOMAGNETIC_SENSOR_POWER);
                        FtUtil.log_d("SensorRead", "getMagneticPowerOn", "GEOMAGNETIC_SENSOR_POWER : " + tempString[0]);
                        if (egis.client.api.EgisFingerprint.MAJOR_VERSION.equalsIgnoreCase(tempString[0])) {
                            c2 = 1;
                            i = 2;
                        } else if ("2".equalsIgnoreCase(tempString[0])) {
                            c2 = 1;
                            i = 2;
                        } else {
                            returnData[1] = "NG";
                            i = 2;
                            returnData[2] = ModuleCommunicationService.SMD_NOK;
                        }
                        returnData[c2] = "OK";
                        returnData[i] = egis.client.api.EgisFingerprint.MAJOR_VERSION;
                    } else {
                        i = 2;
                        returnData[1] = "NG";
                        returnData[2] = ModuleCommunicationService.SMD_NOK;
                    }
                    if (egis.client.api.EgisFingerprint.MAJOR_VERSION.equalsIgnoreCase(tempString[0])) {
                        returnData[c] = "OK";
                        returnData[i] = egis.client.api.EgisFingerprint.MAJOR_VERSION;
                    } else {
                        returnData[c] = "NG";
                        returnData[i] = ModuleCommunicationService.SMD_NOK;
                    }
                } else if (tempString.length <= 0 || !"0".equalsIgnoreCase(tempString[0])) {
                    i = 2;
                    returnData[1] = "NG";
                    returnData[2] = ModuleCommunicationService.SMD_NOK;
                } else {
                    returnData[1] = "OK";
                    i = 2;
                    returnData[2] = egis.client.api.EgisFingerprint.MAJOR_VERSION;
                }
            } else if (ModuleSensor.LOG_LEVEL > 2) {
                return null;
            } else {
                FtUtil.log_d("SensorRead", "getMagneticPowerOn", "null");
                return null;
            }
        }
        if (ModuleSensor.LOG_LEVEL > i) {
            return returnData;
        }
        FtUtil.log_d("SensorRead", "getMagneticPowerOn", dataCheck(returnData));
        return returnData;
    }

    public String[] getMagneticPowerOff(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if (target == 1 && this.mSensorReadManager != null) {
            if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C_MANAGER) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8973) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8975) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09916C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09918C)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD006A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD008A)) {
                this.mTemp_Magnetic = this.mSensorReadManager.returnMagneticExpansion_Alps(2);
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO_LSM303AH)) {
                this.mTemp_Magnetic = this.mSensorReadManager.returnMagneticExpansion_STMicro(2);
            }
            SensorReadManager.MagneticExpansionData magneticExpansionData = this.mTemp_Magnetic;
            if (magneticExpansionData == null || magneticExpansionData.mPowerOff == null) {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getMagneticPowerOff", "null");
                }
                return null;
            }
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getMagneticPowerOff", "Count : " + this.mTemp_Magnetic.mPowerOff.length);
            }
            returnData[0] = "2";
            returnData[1] = this.mTemp_Magnetic.mPowerOff[0];
            returnData[2] = this.mTemp_Magnetic.mPowerOff[1];
        } else if (target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        } else {
            String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____MAGNETIC_POWER_OFF);
            if (tempString != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getMagneticPowerOff", "Count : " + tempString.length);
                }
                if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_COMBINATION)) {
                    Support.Kernel.write(Support.Kernel.GEOMAGNETIC_SENSOR_POWER, "2");
                    tempString[0] = Support.Kernel.read(Support.Kernel.GEOMAGNETIC_SENSOR_POWER);
                    FtUtil.log_d("SensorRead", "getMagneticPowerOFF", "GEOMAGNETIC_SENSOR_POWER : " + tempString[0]);
                    if ("2".equalsIgnoreCase(tempString[0])) {
                        returnData[0] = "2";
                        returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                        returnData[2] = tempString[0];
                    } else {
                        returnData[0] = "0";
                        returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                        returnData[2] = tempString[0];
                    }
                } else {
                    returnData[0] = "2";
                    returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                    returnData[2] = tempString[0];
                }
            } else {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getMagneticPowerOff", "null");
                }
                return null;
            }
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getMagneticPowerOff", dataCheck(returnData));
        }
        return returnData;
    }

    public String[] getMagneticStatus(int target) {
        String str;
        String str2;
        int i;
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if (target == 1 && this.mSensorReadManager != null) {
            if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C_MANAGER) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8973) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8975) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09916C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09918C)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD006A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD008A)) {
                this.mTemp_Magnetic = this.mSensorReadManager.returnMagneticExpansion_Alps(3);
            } else if (this.mFeature_Magnetic.equals("BMC150") || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_POWER_NOISE)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            }
            SensorReadManager.MagneticExpansionData magneticExpansionData = this.mTemp_Magnetic;
            if (magneticExpansionData != null && magneticExpansionData.mStatus != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getMagneticStatus", "Count : " + this.mTemp_Magnetic.mStatus.length);
                }
                returnData[0] = "2";
                returnData[1] = this.mTemp_Magnetic.mStatus[0];
                returnData[2] = this.mTemp_Magnetic.mStatus[1];
                i = 2;
                str2 = "SensorRead";
                str = "getMagneticStatus";
            } else if (ModuleSensor.LOG_LEVEL > 2) {
                return null;
            } else {
                FtUtil.log_d("SensorRead", "getMagneticStatus", "null");
                return null;
            }
        } else if (target == 2 && (sensorReadFile = this.mSensorReadFile) != null) {
            String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____MAGNETIC_STATUS);
            if (tempString != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getMagneticStatus", "Count : " + tempString.length);
                }
                str2 = "SensorRead";
                str = "getMagneticStatus";
                if (tempString.length > 2 && (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539))) {
                    returnData[0] = "2";
                    if ("0".equals(tempString[2])) {
                        returnData[1] = "OK";
                        returnData[2] = egis.client.api.EgisFingerprint.MAJOR_VERSION;
                        i = 2;
                    } else {
                        returnData[1] = "NG";
                        returnData[2] = "0";
                        i = 2;
                    }
                } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD006A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD008A) || this.mFeature_Magnetic.equals("BMC150") || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_POWER_NOISE) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_COMBINATION)) {
                    returnData[0] = "2";
                    if (tempString[0].equals(egis.client.api.EgisFingerprint.MAJOR_VERSION)) {
                        returnData[1] = "OK";
                    } else {
                        returnData[1] = "NG";
                    }
                    i = 2;
                    returnData[2] = tempString[0];
                } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO_LSM303AH)) {
                    returnData[0] = "2";
                    if (tempString[0].equals(egis.client.api.EgisFingerprint.MAJOR_VERSION)) {
                        returnData[1] = "OK";
                    } else {
                        returnData[1] = "NG";
                    }
                    i = 2;
                    returnData[2] = tempString[0];
                } else {
                    returnData[0] = "2";
                    if (tempString[0].equals("OK")) {
                        returnData[1] = "OK";
                        i = 2;
                        returnData[2] = egis.client.api.EgisFingerprint.MAJOR_VERSION;
                    } else {
                        i = 2;
                        returnData[1] = "NG";
                        returnData[2] = "0";
                    }
                }
            } else {
                str2 = "SensorRead";
                str = "getMagneticStatus";
                i = 2;
            }
        } else if (ModuleSensor.LOG_LEVEL > 2) {
            return null;
        } else {
            FtUtil.log_d("SensorRead", "getMagneticStatus", "null");
            return null;
        }
        if (ModuleSensor.LOG_LEVEL > i) {
            return returnData;
        }
        FtUtil.log_d(str2, str, dataCheck(returnData));
        return returnData;
    }

    public String[] getMagneticTemperature(int target) {
        String[] returnData = new String[18];
        if (target == 1 && this.mSensorReadManager != null) {
            if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD006A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD008A)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO_LSM303AH)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            }
            SensorReadManager.MagneticExpansionData magneticExpansionData = this.mTemp_Magnetic;
            if (magneticExpansionData == null || magneticExpansionData.mTemperature == null) {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getMagneticTemperature", "null");
                }
                return null;
            }
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getMagneticTemperature", "Count : " + this.mTemp_Magnetic.mTemperature.length);
            }
            returnData[0] = "2";
            returnData[1] = this.mTemp_Magnetic.mTemperature[0];
            returnData[2] = this.mTemp_Magnetic.mTemperature[1];
        } else if (target != 2 || this.mSensorReadFile == null) {
            return null;
        } else {
            if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8973) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529)) {
                String[] tempString = this.mSensorReadFile.returnData(ModuleSensor.ID_FILE____MAGNETIC_TEMPERATURE);
                if (tempString != null) {
                    if (ModuleSensor.LOG_LEVEL <= 1) {
                        FtUtil.log_d("SensorRead", "getMagneticTemperature", "Count : " + tempString.length);
                    }
                    returnData[0] = "2";
                    returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                    returnData[2] = "" + tempString[0];
                } else {
                    if (ModuleSensor.LOG_LEVEL <= 2) {
                        FtUtil.log_d("SensorRead", "getMagneticTemperature", "null");
                    }
                    return null;
                }
            } else {
                returnData[0] = "2";
                returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                returnData[2] = "0";
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getMagneticTemperature", dataCheck(returnData));
                }
                return returnData;
            }
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getMagneticTemperature", dataCheck(returnData));
        }
        return returnData;
    }

    public String[] getMagneticDAC(int target) {
        String str;
        int i;
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if (target != 1 || this.mSensorReadManager == null) {
            str = "SensorRead";
            if (target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
                return null;
            }
            String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____MAGNETIC_DAC);
            if (tempString != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d(str, "getMagneticDAC", "Count : " + tempString.length);
                }
                if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C_MANAGER) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8975) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09916C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09918C)) {
                    returnData[0] = "4";
                    returnData[1] = tempString[0];
                    if (tempString[0].equals("OK")) {
                        i = 2;
                        returnData[2] = egis.client.api.EgisFingerprint.MAJOR_VERSION;
                    } else {
                        i = 2;
                        returnData[2] = "0";
                    }
                    returnData[3] = "0";
                    returnData[4] = "0";
                } else if (tempString.length <= 3 || (!this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530A) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539))) {
                    returnData[0] = "4";
                    returnData[1] = tempString[0];
                    returnData[2] = tempString[1];
                    returnData[3] = tempString[2];
                    returnData[4] = tempString[3];
                    i = 2;
                } else {
                    returnData[0] = "4";
                    returnData[1] = tempString[0];
                    returnData[2] = tempString[1];
                    returnData[3] = tempString[2];
                    returnData[4] = tempString[3];
                    i = 2;
                }
            } else if (ModuleSensor.LOG_LEVEL > 2) {
                return null;
            } else {
                FtUtil.log_d(str, "getMagneticDAC", "null");
                return null;
            }
        } else {
            if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C_MANAGER) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8973) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8975) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09916C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09918C)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD006A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD008A)) {
                this.mTemp_Magnetic = this.mSensorReadManager.returnMagneticExpansion_Alps(4);
            } else if (this.mFeature_Magnetic.equals("BMC150") || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_POWER_NOISE)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO_LSM303AH)) {
                this.mTemp_Magnetic = this.mSensorReadManager.returnMagneticExpansion_STMicro(4);
            }
            SensorReadManager.MagneticExpansionData magneticExpansionData = this.mTemp_Magnetic;
            if (magneticExpansionData != null && magneticExpansionData.mDAC != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    str = "SensorRead";
                    FtUtil.log_d(str, "getMagneticDAC", "Count : " + this.mTemp_Magnetic.mDAC.length);
                } else {
                    str = "SensorRead";
                }
                returnData[0] = "4";
                returnData[1] = this.mTemp_Magnetic.mDAC[0];
                returnData[2] = this.mTemp_Magnetic.mDAC[1];
                returnData[3] = this.mTemp_Magnetic.mDAC[2];
                returnData[4] = this.mTemp_Magnetic.mDAC[3];
                i = 2;
            } else if (ModuleSensor.LOG_LEVEL > 2) {
                return null;
            } else {
                FtUtil.log_d("SensorRead", "getMagneticDAC", "null");
                return null;
            }
        }
        if (ModuleSensor.LOG_LEVEL > i) {
            return returnData;
        }
        FtUtil.log_d(str, "getMagneticDAC", dataCheck(returnData));
        return returnData;
    }

    public String[] getMagneticADC(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if (target == 1 && this.mSensorReadManager != null) {
            if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C_MANAGER) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8973) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8975) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09916C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09918C)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD006A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD008A)) {
                this.mTemp_Magnetic = this.mSensorReadManager.returnMagneticExpansion_Alps(5);
            } else if (this.mFeature_Magnetic.equals("BMC150") || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_POWER_NOISE)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO_LSM303AH)) {
                this.mTemp_Magnetic = this.mSensorReadManager.returnMagneticExpansion_STMicro(5);
            }
            SensorReadManager.MagneticExpansionData magneticExpansionData = this.mTemp_Magnetic;
            if (magneticExpansionData != null && magneticExpansionData.mADC != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getMagneticADC", "Count : " + this.mTemp_Magnetic.mADC.length);
                }
                returnData[0] = "4";
                returnData[1] = this.mTemp_Magnetic.mADC[0];
                returnData[2] = this.mTemp_Magnetic.mADC[1];
                returnData[3] = this.mTemp_Magnetic.mADC[2];
                returnData[4] = this.mTemp_Magnetic.mADC[3];
            } else if (ModuleSensor.LOG_LEVEL > 2) {
                return null;
            } else {
                FtUtil.log_d("SensorRead", "getMagneticADC", "null");
                return null;
            }
        } else if (target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        } else {
            String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____MAGNETIC_ADC);
            if (tempString != null && tempString.length == 4) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getMagneticADC", "Count : " + tempString.length);
                }
                returnData[0] = "4";
                returnData[1] = tempString[0];
                returnData[2] = tempString[1];
                returnData[3] = tempString[2];
                returnData[4] = tempString[3];
            } else if (ModuleSensor.LOG_LEVEL > 2) {
                return null;
            } else {
                FtUtil.log_d("SensorRead", "getMagneticADC", "null");
                return null;
            }
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getMagneticADC", dataCheck(returnData));
        }
        return returnData;
    }

    public String[] getMagneticSelf(int target) {
        int i;
        SensorReadFile sensorReadFile;
        String str;
        String str2;
        String[] returnData = new String[18];
        if (target == 1 && this.mSensorReadManager != null) {
            if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C_MANAGER) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8973) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8975) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09916C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09918C)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals("BMC150") || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_POWER_NOISE) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_COMBINATION)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD006A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD008A)) {
                this.mTemp_Magnetic = this.mSensorReadManager.returnMagneticExpansion_Alps(6);
            } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO_LSM303AH)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            }
            SensorReadManager.MagneticExpansionData magneticExpansionData = this.mTemp_Magnetic;
            if (magneticExpansionData == null || magneticExpansionData.mSelf == null) {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getMagneticSelf", "null");
                }
                return null;
            }
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getMagneticSelf", "Count : " + this.mTemp_Magnetic.mSelf.length);
            }
            if (this.mFeature_Magnetic.equals("BMC150") || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_POWER_NOISE)) {
                returnData[0] = "2";
                returnData[1] = this.mTemp_Magnetic.mSelf[0];
                returnData[2] = this.mTemp_Magnetic.mSelf[1];
                i = 2;
            } else {
                returnData[0] = "4";
                returnData[1] = this.mTemp_Magnetic.mSelf[0];
                returnData[2] = this.mTemp_Magnetic.mSelf[1];
                returnData[3] = this.mTemp_Magnetic.mSelf[2];
                returnData[4] = this.mTemp_Magnetic.mSelf[3];
                i = 2;
            }
        } else if (target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        } else {
            String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____MAGNETIC_SELF);
            if (tempString != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getMagneticSelf", "Count : " + tempString.length);
                }
                if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004)) {
                    str = "2";
                } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004A)) {
                    str = "2";
                } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD006A)) {
                    str = "2";
                } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD008A)) {
                    str = "2";
                } else if (tempString.length <= 9 || (!this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530A) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539))) {
                    if (this.mFeature_Magnetic.equals("BMC150")) {
                        str2 = "2";
                    } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_POWER_NOISE)) {
                        str2 = "2";
                    } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_COMBINATION)) {
                        Support.Kernel.write(Support.Kernel.GEOMAGNETIC_SENSOR_SELFTEST, "2");
                        FtUtil.Sleep.sleep(1000);
                        String[] tempString2 = this.mSensorReadFile.returnData(ModuleSensor.ID_FILE____MAGNETIC_SELF);
                        if (tempString2 != null) {
                            returnData[0] = "2";
                            returnData[1] = tempString2[0];
                            returnData[2] = tempString2[1];
                            Support.Kernel.write(Support.Kernel.GEOMAGNETIC_SENSOR_POWER, EgisFingerprint.MAJOR_VERSION);
                            FtUtil.Sleep.sleep(30);
                            Support.Kernel.write(Support.Kernel.GEOMAGNETIC_SENSOR_POWER, egis.client.api.EgisFingerprint.MAJOR_VERSION);
                            i = 2;
                        } else {
                            i = 2;
                        }
                    } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09916C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09918C)) {
                        if (tempString.length > 9) {
                            for (int i2 = 0; i2 < 10; i2++) {
                                returnData[i2] = tempString[i2];
                            }
                            i = 2;
                        } else {
                            returnData[0] = ModuleCommunicationService.SMD_NOK;
                            FtUtil.log_d("SensorRead", "getMagneticSelf", "Sysfs data is too short, wrong data");
                            i = 2;
                        }
                    } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_NEWEST)) {
                        if (tempString.length == 6) {
                            for (int i3 = 0; i3 < tempString.length; i3++) {
                                returnData[i3] = tempString[i3];
                            }
                            i = 2;
                        } else {
                            returnData[0] = ModuleCommunicationService.SMD_NOK;
                            FtUtil.log_d("SensorRead", "getMagneticSelf", "Sysfs data is too short, wrong data");
                            i = 2;
                        }
                    } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO_LSM303AH)) {
                        if ("OK".equals(tempString[0])) {
                            returnData[0] = egis.client.api.EgisFingerprint.MAJOR_VERSION;
                        } else {
                            returnData[0] = "2";
                        }
                        returnData[1] = tempString[1];
                        returnData[2] = tempString[2];
                        returnData[3] = tempString[3];
                        i = 2;
                    } else {
                        returnData[0] = "4";
                        returnData[1] = tempString[0];
                        returnData[2] = tempString[1];
                        returnData[3] = tempString[2];
                        returnData[4] = tempString[3];
                        i = 2;
                    }
                    returnData[0] = str2;
                    returnData[1] = tempString[0];
                    i = 2;
                    returnData[2] = tempString[1];
                } else {
                    if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539)) {
                        returnData[0] = "17";
                    } else {
                        returnData[0] = "16";
                    }
                    int count = Integer.parseInt(returnData[0]);
                    for (int i4 = 0; i4 < count; i4++) {
                        returnData[i4 + 1] = tempString[i4];
                    }
                    i = 2;
                }
                returnData[0] = str;
                returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
                i = 2;
                returnData[2] = tempString[0];
            } else {
                if (ModuleSensor.LOG_LEVEL <= 2) {
                    FtUtil.log_d("SensorRead", "getMagneticSelf", "null");
                }
                return null;
            }
        }
        if (ModuleSensor.LOG_LEVEL > i) {
            return returnData;
        }
        FtUtil.log_d("SensorRead", "getMagneticSelf", dataCheck(returnData));
        return returnData;
    }

    public String[] getMagneticOffsetH(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if (target == 1 && this.mSensorReadManager != null) {
            if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532)) {
                this.mTemp_Magnetic = new SensorReadManager.MagneticExpansionData();
            }
            SensorReadManager.MagneticExpansionData magneticExpansionData = this.mTemp_Magnetic;
            if (magneticExpansionData != null && magneticExpansionData.mOffset_H != null) {
                if (ModuleSensor.LOG_LEVEL <= 1) {
                    FtUtil.log_d("SensorRead", "getMagneticOffsetH", "Count : " + this.mTemp_Magnetic.mOffset_H.length);
                }
                returnData[0] = "4";
                returnData[1] = this.mTemp_Magnetic.mOffset_H[0];
                returnData[2] = this.mTemp_Magnetic.mOffset_H[1];
                returnData[3] = this.mTemp_Magnetic.mOffset_H[2];
                returnData[4] = this.mTemp_Magnetic.mOffset_H[3];
            } else if (ModuleSensor.LOG_LEVEL > 2) {
                return null;
            } else {
                FtUtil.log_d("SensorRead", "getMagneticOffsetH", "null");
                return null;
            }
        } else if (target == 2 && (sensorReadFile = this.mSensorReadFile) != null) {
            String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____MAGNETIC_OFFSETH);
            if (tempString == null || tempString.length <= 11) {
                return null;
            }
            if (!this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530A) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539)) {
                return null;
            }
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getMagneticSelf", "Count : " + tempString.length);
            }
            if ("0".equalsIgnoreCase(tempString[12])) {
                returnData[0] = "4";
                returnData[1] = "OK";
                returnData[2] = tempString[13];
                returnData[3] = tempString[14];
                returnData[4] = tempString[15];
            } else {
                returnData[0] = "4";
                returnData[1] = "NG";
                returnData[2] = tempString[13];
                returnData[3] = tempString[14];
                returnData[4] = tempString[15];
            }
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getMagneticOffsetH", dataCheck(returnData));
        }
        return returnData;
    }

    public String[] getProximity(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnProximity();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getProximity", "Count : " + tempFloat.length);
            }
            returnData[0] = "2";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = "" + tempFloat[0];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getProximity", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getProximity", "null");
        }
        return null;
    }

    public String[] getProximityADC(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if ((target == 1 && this.mSensorReadManager != null) || target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        }
        String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____PROXIMITY_ADC);
        if (tempString != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getProximityADC", "Count : " + tempString.length);
            }
            returnData[0] = "2";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = tempString[0];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getProximityADC", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getProximityADC", "null");
        }
        return null;
    }

    public String[] getProximityAVG(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if ((target == 1 && this.mSensorReadManager != null) || target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        }
        String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____PROXIMITY_AVG);
        if (tempString != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getProximityAVG", "Count : " + tempString.length);
            }
            returnData[0] = "2";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = tempString[0];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getProximityAVG", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getProximityAVG", "null");
        }
        return null;
    }

    public String[] getProximityOffset(int target) {
        SensorReadFile sensorReadFile;
        String[] returnData = new String[18];
        if ((target == 1 && this.mSensorReadManager != null) || target != 2 || (sensorReadFile = this.mSensorReadFile) == null) {
            return null;
        }
        String[] tempString = sensorReadFile.returnData(ModuleSensor.ID_FILE____PROXIMITY_OFFSET);
        if (tempString != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getProximityOffset", "Count : " + tempString.length);
            }
            returnData[0] = EgisFingerprint.MAJOR_VERSION;
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = tempString[0];
            returnData[3] = tempString[1];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getProximityOffset", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getProximityOffset", "null");
        }
        return null;
    }

    public String[] getIrisProximity(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnIrisProximity();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getIrisProximity", "Count : " + tempFloat.length);
            }
            returnData[0] = "2";
            returnData[1] = RETURN_DATA_ARRAY_INDEX_1_NONE;
            returnData[2] = "" + tempFloat[0];
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getIrisProximity", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getIrisProximity", "null");
        }
        return null;
    }

    public String[] getTemperature(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnTemperature();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getTemperature", "Count : " + returnData.length);
            }
            returnData[0] = EgisFingerprint.MAJOR_VERSION;
            returnData[1] = String.format("%.2f", Float.valueOf(tempFloat[0]));
            returnData[2] = String.format("%.2f", Float.valueOf(tempFloat[1]));
            returnData[3] = String.valueOf(tempFloat[2]);
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getTemperature", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getTemperature", "null");
        }
        return null;
    }

    public String[] getHumidity(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnHumidity();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getHumidity", "Count : " + returnData.length);
            }
            returnData[0] = EgisFingerprint.MAJOR_VERSION;
            returnData[1] = String.format("%.2f", Float.valueOf(tempFloat[0]));
            returnData[2] = String.format("%.2f", Float.valueOf(tempFloat[1]));
            returnData[3] = String.valueOf(tempFloat[2]);
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getHumidity", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getHumidity", "null");
        }
        return null;
    }

    public String[] getBio(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnBio();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getBio", "Count : " + tempFloat.length);
            }
            returnData[0] = "4";
            returnData[1] = String.valueOf(tempFloat[0]);
            returnData[2] = String.valueOf(tempFloat[1]);
            returnData[3] = String.valueOf(tempFloat[2]);
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getBio", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getLight", "null");
        }
        return null;
    }

    public String[] getBioAlc(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnBioAlc();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getBioAlc", "Count : " + tempFloat.length);
            }
            returnData[0] = egis.client.api.EgisFingerprint.MAJOR_VERSION;
            returnData[1] = String.valueOf(tempFloat[0]);
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getBioAlc", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getBioAlc", "null");
        }
        return null;
    }

    public String[] getHrm(int target) {
        SensorReadManager sensorReadManager;
        String[] returnData = new String[18];
        if (target != 1 || (sensorReadManager = this.mSensorReadManager) == null) {
            return null;
        }
        float[] tempFloat = sensorReadManager.returnHrm();
        if (tempFloat != null) {
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "getHrm", "Count : " + tempFloat.length);
            }
            returnData[0] = EgisFingerprint.MAJOR_VERSION;
            returnData[1] = String.valueOf(tempFloat[0]);
            returnData[2] = String.valueOf(tempFloat[1]);
            returnData[3] = String.valueOf(tempFloat[2]);
            if (ModuleSensor.LOG_LEVEL <= 2) {
                FtUtil.log_d("SensorRead", "getHrm", dataCheck(returnData));
            }
            return returnData;
        }
        if (ModuleSensor.LOG_LEVEL <= 2) {
            FtUtil.log_d("SensorRead", "getLight", "null");
        }
        return null;
    }

    private String dataCheck(String[] data) {
        String result = "";
        if (data != null) {
            int length = Integer.parseInt(data[0]);
            if (ModuleSensor.LOG_LEVEL <= 1) {
                FtUtil.log_d("SensorRead", "dataCheck", "length : " + length);
            }
            for (int i = 0; i < length + 1; i++) {
                result = result + data[i];
                if (i < length) {
                    result = result + " , ";
                }
            }
        }
        return result;
    }

    private void replaceData(String[] data) {
        if (data != null) {
            int length = Integer.parseInt(data[0]);
            for (int i = 0; i < length + 1; i++) {
                data[i] = data[i].replaceAll(",", ".");
            }
        }
        FtUtil.log_d("SensorRead", "replaceData", "data : " + dataCheck(data));
    }
}
