package com.sec.factory.modules;

import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.util.Arrays;
import java.util.Timer;
import java.util.TimerTask;

public class SensorReadFile {
    private static final String CLASS_NAME = "SensorReadFile";
    private int SENSOR_READ_INTERVAL = 50;
    private String mFeature_Magnetic = SensorDeviceInfo.getSensorName(SensorDeviceInfo.TYPE_GEOMAGNETIC, SensorDeviceInfo.TARGET_XML);
    private Info[] mInfo = null;
    private String[] mTemp_String = null;
    private Timer mTimer = null;

    /* access modifiers changed from: private */
    public static class Info {
        public String[] mBuffer_SensorValue;
        public String mFilePath;
        public boolean mIsExistFile;
        public boolean mIsLoopTest = false;
        private boolean mIsON = false;
        public String mName;

        public Info(String name, String filePath) {
            this.mName = name;
            this.mFilePath = filePath;
            this.mIsExistFile = Support.Kernel.isExistFilePath(Support.Kernel.getFilePath(filePath));
            this.mBuffer_SensorValue = null;
        }

        public void setOn(boolean on) {
            this.mIsON = on;
        }

        public boolean getOn() {
            return this.mIsON;
        }
    }

    public SensorReadFile(int[] moduleSensorID) {
        StringBuilder sb = new StringBuilder();
        sb.append("Sensor On : ");
        sb.append(moduleSensorID != null ? Arrays.toString(moduleSensorID) : "null");
        FtUtil.log_d(CLASS_NAME, CLASS_NAME, sb.toString());
        initSysfs();
        sensorOn(moduleSensorID);
    }

    public boolean sensorOn(int[] moduleSensorID) {
        StringBuilder sb = new StringBuilder();
        sb.append("Sensor On : ");
        sb.append(moduleSensorID != null ? Arrays.toString(moduleSensorID) : "null");
        FtUtil.log_d(CLASS_NAME, "sensorOn", sb.toString());
        if (this.mInfo == null) {
            FtUtil.log_e(CLASS_NAME, "sensorOn", "mInfo is null");
            return false;
        }
        if (moduleSensorID != null) {
            for (int i : moduleSensorID) {
                Integer i2 = Integer.valueOf(i);
                this.mInfo[ConverterID(i2.intValue())].setOn(true);
                FtUtil.log_d(CLASS_NAME, "sensorOn", "sensorOn : " + ModuleSensor.getString_ID(i2.intValue()));
            }
        }
        return true;
    }

    public void sensorOff(int[] moduleSensorID) {
        StringBuilder sb = new StringBuilder();
        sb.append("Sensor Off : ");
        sb.append(moduleSensorID != null ? Arrays.toString(moduleSensorID) : "null");
        FtUtil.log_d(CLASS_NAME, "sensorOff", sb.toString());
        if (this.mInfo == null) {
            FtUtil.log_e(CLASS_NAME, "sensorOff", "mInfo is null");
            return;
        }
        if (moduleSensorID != null) {
            for (int i : moduleSensorID) {
                int id = ConverterID(Integer.valueOf(i).intValue());
                this.mInfo[id].setOn(false);
                this.mInfo[id].mIsLoopTest = false;
            }
        }
        if (this.mTimer != null) {
            int i2 = 0;
            while (true) {
                Info[] infoArr = this.mInfo;
                if (i2 >= infoArr.length || infoArr[i2] == null) {
                    this.mTimer.cancel();
                    this.mTimer = null;
                    FtUtil.log_d(CLASS_NAME, "mTimer canceled", "...");
                } else if (!infoArr[i2].getOn() || !this.mInfo[i2].mIsLoopTest) {
                    i2++;
                } else {
                    return;
                }
            }
            this.mTimer.cancel();
            this.mTimer = null;
            FtUtil.log_d(CLASS_NAME, "mTimer canceled", "...");
        }
    }

    private synchronized void initSysfs() {
        FtUtil.log_d(CLASS_NAME, "initSysfs", "ModuleSensor.ID_COUNT_FILE : " + ModuleSensor.ID_COUNT_FILE);
        if (this.mInfo == null) {
            Info[] infoArr = new Info[ModuleSensor.ID_COUNT_FILE];
            this.mInfo = infoArr;
            int infoArrayIndex = 0 + 1;
            infoArr[0] = new Info("ID_FILE____ACCELEROMETER", Support.Kernel.ACCEL_SENSOR_RAW);
            int infoArrayIndex2 = infoArrayIndex + 1;
            this.mInfo[infoArrayIndex] = new Info("ID_FILE____ACCELEROMETER_N_ANGLE", Support.Kernel.ACCEL_SENSOR_RAW);
            int infoArrayIndex3 = infoArrayIndex2 + 1;
            this.mInfo[infoArrayIndex2] = new Info("ID_FILE____ACCELEROMETER_SELF", Support.Kernel.ACCEL_SENSOR_RAW);
            int infoArrayIndex4 = infoArrayIndex3 + 1;
            this.mInfo[infoArrayIndex3] = new Info("ID_FILE____ACCELEROMETER_SELFTEST", Support.Kernel.ACCEL_SENSOR_SELFTEST);
            int infoArrayIndex5 = infoArrayIndex4 + 1;
            this.mInfo[infoArrayIndex4] = new Info("ID_FILE____ACCELEROMETER_CAL", Support.Kernel.ACCEL_SENSOR_CAL);
            int infoArrayIndex6 = infoArrayIndex5 + 1;
            this.mInfo[infoArrayIndex5] = new Info("ID_FILE____ACCELEROMETER_INTPIN", Support.Kernel.ACCEL_SENSOR_INTPIN);
            int infoArrayIndex7 = infoArrayIndex6 + 1;
            this.mInfo[infoArrayIndex6] = new Info("ID_FILE____SUB_ACCELEROMETER", Support.Kernel.SUB_ACCEL_SENSOR_RAW);
            int infoArrayIndex8 = infoArrayIndex7 + 1;
            this.mInfo[infoArrayIndex7] = new Info("ID_FILE____SUB_ACCELEROMETER_SELFTEST", Support.Kernel.SUB_ACCEL_SENSOR_SELFTEST);
            int infoArrayIndex9 = infoArrayIndex8 + 1;
            this.mInfo[infoArrayIndex8] = new Info("ID_FILE____SUB_ACCELEROMETER_CAL", Support.Kernel.SUB_ACCEL_SENSOR_CAL);
            int infoArrayIndex10 = infoArrayIndex9 + 1;
            this.mInfo[infoArrayIndex9] = new Info("ID_FILE____BAROMETER_EEPROM", Support.Kernel.BAROME_EEPROM);
            int infoArrayIndex11 = infoArrayIndex10 + 1;
            this.mInfo[infoArrayIndex10] = new Info("ID_FILE____GYRO_TEMPERATURE", Support.Kernel.GYRO_SENSOR_TEMP);
            int infoArrayIndex12 = infoArrayIndex11 + 1;
            this.mInfo[infoArrayIndex11] = new Info("ID_FILE____GYRO_SELF", Support.Kernel.GYRO_SENSOR_SELFTEST);
            int infoArrayIndex13 = infoArrayIndex12 + 1;
            this.mInfo[infoArrayIndex12] = new Info("ID_FILE____LIGHT_ADC", Support.Kernel.LIGHT_SENSOR_RAW);
            int infoArrayIndex14 = infoArrayIndex13 + 1;
            this.mInfo[infoArrayIndex13] = new Info("ID_FILE____LIGHT_RGBW", Support.Kernel.LIGHT_SENSOR_RAW);
            int infoArrayIndex15 = infoArrayIndex14 + 1;
            this.mInfo[infoArrayIndex14] = new Info("ID_FILE____MAGNETIC_POWER_ON", Support.Kernel.GEOMAGNETIC_SENSOR_POWER);
            int infoArrayIndex16 = infoArrayIndex15 + 1;
            this.mInfo[infoArrayIndex15] = new Info("ID_FILE____MAGNETIC_POWER_OFF", Support.Kernel.GEOMAGNETIC_SENSOR_POWER);
            int infoArrayIndex17 = infoArrayIndex16 + 1;
            this.mInfo[infoArrayIndex16] = new Info("ID_FILE____MAGNETIC_STATUS", Support.Kernel.GEOMAGNETIC_SENSOR_STATUS);
            int infoArrayIndex18 = infoArrayIndex17 + 1;
            this.mInfo[infoArrayIndex17] = new Info("ID_FILE____MAGNETIC_TEMPERATURE", Support.Kernel.GEOMAGNETIC_SENSOR_TEMP);
            int infoArrayIndex19 = infoArrayIndex18 + 1;
            this.mInfo[infoArrayIndex18] = new Info("ID_FILE____MAGNETIC_DAC", Support.Kernel.GEOMAGNETIC_SENSOR_DAC);
            int infoArrayIndex20 = infoArrayIndex19 + 1;
            this.mInfo[infoArrayIndex19] = new Info("ID_FILE____MAGNETIC_ADC", Support.Kernel.GEOMAGNETIC_SENSOR_ADC);
            int infoArrayIndex21 = infoArrayIndex20 + 1;
            this.mInfo[infoArrayIndex20] = new Info("ID_FILE____MAGNETIC_SELF", Support.Kernel.GEOMAGNETIC_SENSOR_SELFTEST);
            int infoArrayIndex22 = infoArrayIndex21 + 1;
            this.mInfo[infoArrayIndex21] = new Info("ID_FILE____MAGNETIC_OFFSETH", Support.Kernel.GEOMAGNETIC_SENSOR_SELFTEST);
            int infoArrayIndex23 = infoArrayIndex22 + 1;
            this.mInfo[infoArrayIndex22] = new Info("ID_FILE____PROXIMITY_ADC", Support.Kernel.PROXI_SENSOR_ADC);
            int infoArrayIndex24 = infoArrayIndex23 + 1;
            this.mInfo[infoArrayIndex23] = new Info("ID_FILE____PROXIMITY_AVG", Support.Kernel.PROXI_SENSOR_ADC_AVG);
            int infoArrayIndex25 = infoArrayIndex24 + 1;
            this.mInfo[infoArrayIndex24] = new Info("ID_FILE____PROXIMITY_OFFSET", Support.Kernel.PROXI_SENSOR_OFFSET);
            int infoArrayIndex26 = infoArrayIndex25 + 1;
            this.mInfo[infoArrayIndex25] = new Info("ID_FILE____GRIP_RAW", Support.Kernel.GRIP_SENSOR_RAWDATA);
            int infoArrayIndex27 = infoArrayIndex26 + 1;
            this.mInfo[infoArrayIndex26] = new Info("ID_FILE____GRIP_THRESHOLD", Support.Kernel.GRIP_SENSOR_THRESHOLD);
            int infoArrayIndex28 = infoArrayIndex27 + 1;
            this.mInfo[infoArrayIndex27] = new Info("ID_FILE____GRIP_TOUCH", Support.Kernel.GRIP_TOUCH_SENSOR_CHECK);
            int infoArrayIndex29 = infoArrayIndex28 + 1;
            this.mInfo[infoArrayIndex28] = new Info("ID_FILE____GRIP_TOUCH_2", Support.Kernel.GRIP_TOUCH_SENSOR_CHECK_2);
            int infoArrayIndex30 = infoArrayIndex29 + 1;
            this.mInfo[infoArrayIndex29] = new Info("ID_FILE____GRIP_TOUCH_3", Support.Kernel.GRIP_TOUCH_SENSOR_CHECK_3);
            int infoArrayIndex31 = infoArrayIndex30 + 1;
            this.mInfo[infoArrayIndex30] = new Info("ID_FILE____GRIP_TOUCH_4", Support.Kernel.GRIP_TOUCH_SENSOR_CHECK_4);
            int infoArrayIndex32 = infoArrayIndex31 + 1;
            this.mInfo[infoArrayIndex31] = new Info("ID_FILE____GRIP_TOUCH_5", Support.Kernel.GRIP_TOUCH_SENSOR_CHECK_5);
            int infoArrayIndex33 = infoArrayIndex32 + 1;
            this.mInfo[infoArrayIndex32] = new Info("ID_FILE____GRIP_TOUCH_6", Support.Kernel.GRIP_TOUCH_SENSOR_CHECK_6);
            for (int i = 0; i < infoArrayIndex33; i++) {
                FtUtil.log_i(CLASS_NAME, "initSysfs", "index[" + i + "] mInfo - mName : " + this.mInfo[i].mName + ", mFilePath : " + this.mInfo[i].mFilePath + ", mIsExistFile : " + this.mInfo[i].mIsExistFile);
            }
            return;
        }
        FtUtil.log_d(CLASS_NAME, "init", "mInfo is already initialized ");
    }

    public boolean isSensorOn(int moduleSensorID) {
        int infoArrayIndex = ConverterID(moduleSensorID);
        Info[] infoArr = this.mInfo;
        if (infoArr == null || infoArr[infoArrayIndex] == null) {
            return false;
        }
        FtUtil.log_i(CLASS_NAME, "isSensorOn", "mInfo - mName : " + this.mInfo[infoArrayIndex].mName + ", mFilePath : " + this.mInfo[infoArrayIndex].mFilePath + ", mIsExistFile : " + this.mInfo[infoArrayIndex].mIsExistFile + ", on : " + this.mInfo[infoArrayIndex].getOn());
        if (!this.mInfo[infoArrayIndex].mIsExistFile || !this.mInfo[infoArrayIndex].getOn()) {
            return false;
        }
        return true;
    }

    public void getSensorReadData() {
        String mTemp;
        if (this.mInfo == null) {
            FtUtil.log_e(CLASS_NAME, "getSensorReadData", "mInfo is null");
            return;
        }
        int i = 0;
        while (true) {
            Info[] infoArr = this.mInfo;
            if (i < infoArr.length && infoArr[i] != null) {
                if (infoArr[i].getOn() && this.mInfo[i].mIsExistFile && this.mInfo[i].mIsLoopTest) {
                    if (ModuleSensor.LOG_LEVEL <= 1) {
                        mTemp = Support.Kernel.read(this.mInfo[i].mFilePath);
                    } else {
                        mTemp = Support.Kernel.read(this.mInfo[i].mFilePath, false);
                    }
                    if (mTemp != null) {
                        try {
                            this.mInfo[i].mBuffer_SensorValue = mTemp.split(",");
                        } catch (Exception e) {
                            FtUtil.log_d(CLASS_NAME, "SensorReadThread-run", "execption : " + e);
                        }
                    }
                }
                i++;
            } else {
                return;
            }
        }
    }

    public void startLoop(int moduleSensorID) {
        int infoArrayIndex = ConverterID(moduleSensorID);
        Info[] infoArr = this.mInfo;
        if (infoArr == null || infoArr[infoArrayIndex] == null) {
            FtUtil.log_e(CLASS_NAME, "startLoop", "failed");
            return;
        }
        infoArr[infoArrayIndex].mIsLoopTest = true;
        if (this.mTimer == null) {
            Timer timer = new Timer();
            this.mTimer = timer;
            timer.schedule(new TimerTask() {
                /* class com.sec.factory.modules.SensorReadFile.AnonymousClass1 */

                public void run() {
                    SensorReadFile.this.getSensorReadData();
                }
            }, 0, (long) this.SENSOR_READ_INTERVAL);
        }
    }

    public String[] returnData(int moduleSensorID) {
        int infoArrayIndex = ConverterID(moduleSensorID);
        Info[] infoArr = this.mInfo;
        if (infoArr == null || infoArr[infoArrayIndex] == null) {
            return null;
        }
        if (!infoArr[infoArrayIndex].mIsLoopTest && -1 < infoArrayIndex && this.mInfo[infoArrayIndex].mIsExistFile) {
            FtUtil.log_d(CLASS_NAME, "returnData", this.mInfo[infoArrayIndex].mName);
            String mTemp = Support.Kernel.read(this.mInfo[infoArrayIndex].mFilePath);
            if (mTemp != null) {
                this.mInfo[infoArrayIndex].mBuffer_SensorValue = mTemp.split(",");
            }
        }
        removeWhiteSpace(infoArrayIndex);
        if (moduleSensorID == ModuleSensor.ID_FILE____MAGNETIC_DAC || moduleSensorID == ModuleSensor.ID_FILE____MAGNETIC_ADC || moduleSensorID == ModuleSensor.ID_FILE____MAGNETIC_SELF) {
            checkSpec(moduleSensorID, infoArrayIndex);
        }
        return this.mInfo[infoArrayIndex].mBuffer_SensorValue;
    }

    private void checkSpec(int moduleSensorID, int infoArrayIndex) {
        String specResult = "";
        if (this.mInfo[infoArrayIndex].mBuffer_SensorValue != null) {
            if (moduleSensorID == ModuleSensor.ID_FILE____MAGNETIC_DAC) {
                FtUtil.log_d(CLASS_NAME, "checkSpec", "ID_FILE____MAGNETIC_DAC");
                if (this.mInfo[infoArrayIndex].mBuffer_SensorValue.length == 4) {
                    specResult = SensorCalculator.checkSpecMagneticDAC(Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[1]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[2]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[3]).intValue());
                } else if (this.mInfo[infoArrayIndex].mBuffer_SensorValue.length > 6 && (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532))) {
                    String[] strArr = this.mInfo[infoArrayIndex].mBuffer_SensorValue;
                    this.mTemp_String = strArr;
                    if ("0".equalsIgnoreCase(strArr[3])) {
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[1] = this.mTemp_String[4];
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[2] = this.mTemp_String[5];
                        String[] strArr2 = this.mInfo[infoArrayIndex].mBuffer_SensorValue;
                        String[] strArr3 = this.mTemp_String;
                        strArr2[3] = strArr3[6];
                        specResult = SensorCalculator.checkSpecMagneticDAC(Integer.valueOf(strArr3[4]).intValue(), Integer.valueOf(this.mTemp_String[5]).intValue(), Integer.valueOf(this.mTemp_String[6]).intValue());
                    } else {
                        FtUtil.log_d(CLASS_NAME, "checkSpec", "DAC [errNo] : " + this.mTemp_String[3]);
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[1] = this.mTemp_String[4];
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[2] = this.mTemp_String[5];
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[3] = this.mTemp_String[6];
                        specResult = "NG";
                    }
                }
            } else if (moduleSensorID == ModuleSensor.ID_FILE____MAGNETIC_ADC) {
                FtUtil.log_d(CLASS_NAME, "checkSpec", "ID_FILE____MAGNETIC_ADC");
                if (this.mInfo[infoArrayIndex].mBuffer_SensorValue.length == 4) {
                    specResult = SensorCalculator.checkSpecMagneticADC(Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[1]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[2]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[3]).intValue());
                } else if (this.mInfo[infoArrayIndex].mBuffer_SensorValue.length == 3) {
                    this.mTemp_String = this.mInfo[infoArrayIndex].mBuffer_SensorValue;
                    this.mInfo[infoArrayIndex].mBuffer_SensorValue = new String[4];
                    this.mInfo[infoArrayIndex].mBuffer_SensorValue[1] = this.mTemp_String[0];
                    this.mInfo[infoArrayIndex].mBuffer_SensorValue[2] = this.mTemp_String[1];
                    this.mInfo[infoArrayIndex].mBuffer_SensorValue[3] = this.mTemp_String[2];
                    specResult = SensorCalculator.checkSpecMagneticADC(Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[1]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[2]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[3]).intValue());
                } else if (this.mInfo[infoArrayIndex].mBuffer_SensorValue.length > 8 && (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532))) {
                    this.mTemp_String = this.mInfo[infoArrayIndex].mBuffer_SensorValue;
                    this.mInfo[infoArrayIndex].mBuffer_SensorValue = new String[4];
                    if ("0".equalsIgnoreCase(this.mTemp_String[7])) {
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[1] = this.mTemp_String[8];
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[2] = "0";
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[3] = "0";
                        specResult = SensorCalculator.checkSpecMagneticADC(Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[1]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[2]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[3]).intValue());
                    } else {
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[1] = this.mTemp_String[8];
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[2] = "0";
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[3] = "0";
                        specResult = "NG";
                    }
                }
            } else if (moduleSensorID == ModuleSensor.ID_FILE____MAGNETIC_SELF) {
                FtUtil.log_d(CLASS_NAME, "checkSpec", "ID_FILE____MAGNETIC_SELF");
                if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD006A) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD008A)) {
                    this.mTemp_String = this.mInfo[infoArrayIndex].mBuffer_SensorValue;
                    if (this.mInfo[infoArrayIndex].mBuffer_SensorValue.length == 2) {
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue = new String[2];
                        String specResult2 = this.mTemp_String[0];
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[0] = this.mTemp_String[0];
                        return;
                    }
                    return;
                } else if (!this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532) && !this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_NEWEST)) {
                    if (this.mFeature_Magnetic.equals("BMC150") || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_POWER_NOISE) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_COMBINATION)) {
                        this.mTemp_String = this.mInfo[infoArrayIndex].mBuffer_SensorValue;
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue = new String[2];
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[0] = SensorCalculator.checkSpecMagneticSelf(0, 0, Integer.valueOf(this.mTemp_String[0]).intValue());
                        this.mInfo[infoArrayIndex].mBuffer_SensorValue[1] = this.mTemp_String[0];
                    } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO) || this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO_LSM303AH)) {
                        specResult = SensorCalculator.checkSpecMagneticSelf(Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[1]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[2]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[3]).intValue());
                    } else if (this.mInfo[infoArrayIndex].mBuffer_SensorValue.length == 4) {
                        specResult = SensorCalculator.checkSpecMagneticSelf(Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[1]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[2]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[3]).intValue());
                    }
                }
            } else if (moduleSensorID == ModuleSensor.ID_FILE____MAGNETIC_OFFSETH) {
                FtUtil.log_d(CLASS_NAME, "checkSpec", "ID_FILE____MAGNETIC_OFFSETH");
                this.mTemp_String = this.mInfo[infoArrayIndex].mBuffer_SensorValue;
                if (this.mInfo[infoArrayIndex].mBuffer_SensorValue.length > 6) {
                    this.mInfo[infoArrayIndex].mBuffer_SensorValue[1] = this.mTemp_String[4];
                    this.mInfo[infoArrayIndex].mBuffer_SensorValue[2] = this.mTemp_String[5];
                    this.mInfo[infoArrayIndex].mBuffer_SensorValue[3] = this.mTemp_String[6];
                    specResult = SensorCalculator.checkSpecMagneticDAC(Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[4]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[5]).intValue(), Integer.valueOf(this.mInfo[infoArrayIndex].mBuffer_SensorValue[6]).intValue());
                }
            }
            if (specResult.equals("OK") || specResult.equals("NG")) {
                this.mInfo[infoArrayIndex].mBuffer_SensorValue[0] = specResult;
            }
        }
    }

    private void removeWhiteSpace(int infoArrayIndex) {
        try {
            if (this.mInfo[infoArrayIndex].mBuffer_SensorValue != null) {
                for (int i = 0; i < this.mInfo[infoArrayIndex].mBuffer_SensorValue.length; i++) {
                    this.mInfo[infoArrayIndex].mBuffer_SensorValue[i] = this.mInfo[infoArrayIndex].mBuffer_SensorValue[i].replace(" ", "");
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private int ConverterID(int moduleSensorID) {
        int infoArrayIndex = moduleSensorID - ModuleSensor.ID_COUNT_MANAGER;
        FtUtil.log_d(CLASS_NAME, "ConverterID", "moduleSensorID[" + moduleSensorID + "] to [" + infoArrayIndex + "]");
        return infoArrayIndex;
    }
}
