package com.sec.factory.modules;

import android.support.v4.app.NotificationManagerCompat;
import com.goodix.fingerprint.ShenzhenConstants;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import org.apache.poi.util.CodePageUtil;

public class SensorSpec {
    private final String CLASS_NAME;
    private final int RANGE_MAX_INTEGER;
    private Accelerometer mAccelerometer;
    private final String mFeature_Accelerometer;
    private final String mFeature_Accelerometer_vendor;
    private final String mFeature_Magnetic;
    private Range mMagneticRangeADC;
    private Range mMagneticRangeADC2;
    private Range mMagneticRangeDAC;
    private Range mMagneticRangeSelf;

    public static class Accelerometer {
        public int mBitCount;
        public int mFlatness_Max;
        public int mFlatness_Min;
        public boolean mIsSupport_INT_Pin;
        public Range mRange = null;

        public Accelerometer(int bitCount, int xMin, int xMax, int yMin, int yMax, int zMin, int zMax, int flatnessMin, int flatnessMax, boolean isSupport_INT_Pin) {
            this.mBitCount = bitCount;
            this.mRange = new Range(xMin, xMax, yMin, yMax, zMin, zMax);
            this.mFlatness_Min = flatnessMin;
            this.mFlatness_Max = flatnessMax;
            this.mIsSupport_INT_Pin = isSupport_INT_Pin;
        }

        public int getBitCount() {
            return this.mBitCount;
        }
    }

    public static class Range {
        public boolean mIsSupportRange1_X;
        public boolean mIsSupportRange1_Y;
        public boolean mIsSupportRange1_Z;
        public boolean mIsSupportRange2_X;
        public boolean mIsSupportRange2_Y;
        public boolean mIsSupportRange2_Z;
        public int mRange1_X_Max;
        public int mRange1_X_Min;
        public int mRange1_Y_Max;
        public int mRange1_Y_Min;
        public int mRange1_Z_Max;
        public int mRange1_Z_Min;
        public int mRange2_X_Max;
        public int mRange2_X_Min;
        public int mRange2_Y_Max;
        public int mRange2_Y_Min;
        public int mRange2_Z_Max;
        public int mRange2_Z_Min;
        public int mRangeCount = 1;

        public Range(int xMin, int xMax, int yMin, int yMax, int zMin, int zMax) {
            this.mRange1_X_Min = xMin;
            this.mRange1_X_Max = xMax;
            this.mRange1_Y_Min = yMin;
            this.mRange1_Y_Max = yMax;
            this.mRange1_Z_Min = zMin;
            this.mRange1_Z_Max = zMax;
            if (xMin != xMax) {
                this.mIsSupportRange1_X = true;
            }
            if (yMin != yMax) {
                this.mIsSupportRange1_Y = true;
            }
            if (zMin != zMax) {
                this.mIsSupportRange1_Z = true;
            }
        }

        public Range(int range1_X_Min, int range1_X_Max, int range1_Y_Min, int range1_Y_Max, int range1_Z_Min, int range1_Z_Max, int range2_X_Min, int range2_X_Max, int range2_Y_Min, int range2_Y_Max, int range2_Z_Min, int range2_Z_Max) {
            this(range1_X_Min, range1_X_Max, range1_Y_Min, range1_Y_Max, range1_Z_Min, range1_Z_Max);
            this.mRange2_X_Min = range2_X_Min;
            this.mRange2_X_Max = range2_X_Max;
            this.mRange2_Y_Min = range2_Y_Min;
            this.mRange2_Y_Max = range2_Y_Max;
            this.mRange2_Z_Min = range2_Z_Min;
            this.mRange2_Z_Max = range2_Z_Max;
            if (range2_X_Min != range2_X_Max) {
                this.mIsSupportRange2_X = true;
            }
            if (range2_Y_Min != range2_Y_Max) {
                this.mIsSupportRange2_Y = true;
            }
            if (range2_Z_Min != range2_Z_Max) {
                this.mIsSupportRange2_Z = true;
            }
        }
    }

    public SensorSpec() {
        this(SensorDeviceInfo.TARGET_XML);
    }

    public SensorSpec(int readTarget) {
        this.CLASS_NAME = "SensorSpec";
        this.RANGE_MAX_INTEGER = Integer.MAX_VALUE;
        this.mAccelerometer = null;
        this.mMagneticRangeDAC = null;
        this.mMagneticRangeADC = null;
        this.mMagneticRangeADC2 = null;
        this.mMagneticRangeSelf = null;
        String sensorName = SensorDeviceInfo.getSensorName(SensorDeviceInfo.TYPE_ACCELEROMETER, SensorDeviceInfo.TARGET_FILE);
        this.mFeature_Accelerometer = sensorName;
        String sensorVendor = SensorDeviceInfo.getSensorVendor(SensorDeviceInfo.TYPE_ACCELEROMETER);
        this.mFeature_Accelerometer_vendor = sensorVendor;
        FtUtil.log_d("SensorSpec", "SensorSpec", "mFeature_Accelerometer : " + sensorName + " / mFeature_Accelerometer_vendor : " + sensorVendor);
        setSpecAccel();
        String sensorName2 = SensorDeviceInfo.getSensorName(SensorDeviceInfo.TYPE_GEOMAGNETIC, readTarget);
        this.mFeature_Magnetic = sensorName2;
        FtUtil.log_d("SensorSpec", "SensorSpec", "mFeature_Magnetic : " + sensorName2);
        setSpecMagnetic();
    }

    private void setSpecAccel() {
        String str = this.mFeature_Accelerometer;
        if (str == null) {
            FtUtil.log_d("SensorSpec", "setSpecAccel", "mAccelerometer set null");
            this.mAccelerometer = null;
        } else if (str.equals(SensorFeature.FEATURE_ACCELEROMETER_BOSCH_SMB380)) {
            this.mAccelerometer = new Accelerometer(10, -52, 52, -52, 52, 192, 320, 0, 24, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_BOSCH_BMA250)) {
            this.mAccelerometer = new Accelerometer(10, -52, 52, -52, 52, 190, 322, 0, 24, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_BOSCH_BMA022)) {
            this.mAccelerometer = new Accelerometer(10, -52, 52, -52, 52, 185, 327, 0, 24, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_BOSCH_BMA023)) {
            this.mAccelerometer = new Accelerometer(10, -56, 56, -56, 56, 181, FactoryTestManager.TEST_SUB_MCD_PRESENTATION, 0, 24, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_BOSCH_BMA222)) {
            this.mAccelerometer = new Accelerometer(8, -15, 15, -15, 15, 44, 84, 0, 6, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_BOSCH_BMA220)) {
            this.mAccelerometer = new Accelerometer(6, -6, 6, -6, 6, 9, 23, 0, 0, false);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_BOSCH_BMA254)) {
            this.mAccelerometer = new Accelerometer(12, -181, 181, -181, 181, 786, 1262, 0, 100, false);
        } else if (this.mFeature_Accelerometer.equals("BMC150")) {
            this.mAccelerometer = new Accelerometer(12, -181, 181, -181, 181, 786, 1262, 0, 100, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_BOSCH_BMI055)) {
            this.mAccelerometer = new Accelerometer(12, -191, 191, -191, 191, -1261, -787, 0, 100, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_BOSCH_BMI058)) {
            this.mAccelerometer = new Accelerometer(12, -989, 989, -661, 661, 3199, 4993, 0, 100, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_BOSCH_BMI160)) {
            this.mAccelerometer = new Accelerometer(12, -989, 989, -661, 661, 3199, 4993, 0, 100, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_BOSCH_BMI168)) {
            this.mAccelerometer = new Accelerometer(12, -989, 989, -661, 661, 3199, 4993, 0, 100, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_STMICRO_KR3DH)) {
            this.mAccelerometer = new Accelerometer(12, -102, 102, -102, 102, 849, 1199, 0, 100, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_STMICRO_K2DH)) {
            this.mAccelerometer = new Accelerometer(12, -154, 154, -154, 154, 798, CodePageUtil.CP_WINDOWS_1250, 0, 100, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_STMICRO_K2HH)) {
            this.mAccelerometer = new Accelerometer(16, -2054, 2054, -2054, 2054, 13302, 19466, 0, ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_STMICRO_K3DH)) {
            this.mAccelerometer = new Accelerometer(12, -154, 154, -154, 154, 798, CodePageUtil.CP_WINDOWS_1250, 0, 100, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_STMICRO_K2DM)) {
            this.mAccelerometer = new Accelerometer(8, -12, 12, -12, 12, 48, 80, 0, 6, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_STMICRO_KR3DM)) {
            this.mAccelerometer = new Accelerometer(8, -12, 12, -12, 12, 48, 80, 0, 6, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_STMICRO_LSM330DLC)) {
            this.mAccelerometer = new Accelerometer(12, -154, 154, -154, 154, 798, CodePageUtil.CP_WINDOWS_1250, 0, 100, false);
        } else if (this.mFeature_Accelerometer.contains(SensorFeature.FEATURE_ACCELEROMETER_STMICRO_K6DS3)) {
            this.mAccelerometer = new Accelerometer(16, -1476, 1476, -1476, 1476, 6475, 9919, 0, ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_KIONIX_KXUD9)) {
            this.mAccelerometer = new Accelerometer(12, -151, 151, -151, 151, 642, 996, 0, 100, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_KIONIX_KXTF9)) {
            this.mAccelerometer = new Accelerometer(12, -133, 133, -133, 133, 846, 1202, 0, 100, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_INVENSENSE_MPU6050)) {
            this.mAccelerometer = new Accelerometer(16, -2054, 2054, -2054, 2054, 13302, 19466, 0, ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_INVENSENSE_MPU6051)) {
            this.mAccelerometer = new Accelerometer(16, -2054, 2054, -2054, 2054, 13302, 19466, 0, ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_INVENSENSE_MPU6515M)) {
            this.mAccelerometer = new Accelerometer(16, -2054, 2054, -2054, 2054, 13302, 19466, 0, ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS, true);
        } else if (this.mFeature_Accelerometer.equals(SensorFeature.FEATURE_ACCELEROMETER_INVENSENSE_MPU6500)) {
            this.mAccelerometer = new Accelerometer(16, -2054, 2054, -2054, 2054, 13302, 19466, 0, ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS, true);
        } else if ("MAXIM".equals(this.mFeature_Accelerometer_vendor)) {
            this.mAccelerometer = new Accelerometer(16, -2054, 2054, -2054, 2054, 13302, 19466, 0, ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS, true);
        } else {
            FtUtil.log_e("SensorSpec", "setSpecAccel", "feature : Unknown => return null");
            this.mAccelerometer = null;
        }
    }

    private void setSpecMagnetic() {
        String str = this.mFeature_Magnetic;
        if (str == null) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = null;
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = null;
            return;
        }
        if (str.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-6500, 6500, -6500, 6500, -6500, 6500);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(-200, 200, -200, 200, -3200, -800);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-6500, 6500, -6500, 6500, -6500, 6500);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(-200, 200, -200, 200, -3200, -800);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8963C_MANAGER)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-6500, 6500, -6500, 6500, -6500, 6500);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(-200, 200, -200, 200, -3200, -800);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8973)) {
            this.mMagneticRangeDAC = new Range(0, 126, 0, 126, 0, 126, 128, 254, 128, 254, 128, 254);
            this.mMagneticRangeADC = new Range(88, 168, 88, 168, 88, 168);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = null;
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK8975)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-2000, 2000, -2000, 2000, -2000, 2000);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(-100, 100, -100, 100, NotificationManagerCompat.IMPORTANCE_UNSPECIFIED, -300);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-1600, ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS, -1600, ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS, -1600, ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(-30, 30, -30, 30, -400, -50);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09911C)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-1600, ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS, -1600, ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS, -1600, ShenzhenConstants.CMD_TEST_SZ_SET_LOW_BRIGHTNESS);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(-30, 30, -30, 30, -400, -50);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09916C)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-6500, 6500, -6500, 6500, -6500, 6500);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(-30, 30, -30, 30, -400, -50);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ASAHI_AK09918C)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-6500, 6500, -6500, 6500, -6500, 6500);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(-30, 30, -30, 30, -400, -50);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS529)) {
            this.mMagneticRangeDAC = new Range(5, 32, 5, 32, 5, 32);
            this.mMagneticRangeADC = new Range(0, 359, 0, 0, 0, 0);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(80, Integer.MAX_VALUE, 107, Integer.MAX_VALUE, 0, 0);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530)) {
            this.mMagneticRangeDAC = new Range(-30, 30, -30, 30, -30, 30);
            this.mMagneticRangeADC = new Range(0, 359, 0, 0, 0, 0);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(133, Integer.MAX_VALUE, 160, Integer.MAX_VALUE, 0, 0);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530A)) {
            this.mMagneticRangeDAC = new Range(-30, 30, -30, 30, -30, 30);
            this.mMagneticRangeADC = new Range(0, 359, 0, 0, 0, 0);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(133, Integer.MAX_VALUE, 160, Integer.MAX_VALUE, 0, 0);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS530C)) {
            this.mMagneticRangeDAC = new Range(-30, 30, -30, 30, -30, 30);
            this.mMagneticRangeADC = new Range(0, 359, 0, 0, 0, 0);
            this.mMagneticRangeADC2 = new Range(-400, 400, -400, 400, -400, 400);
            this.mMagneticRangeSelf = new Range(133, Integer.MAX_VALUE, 160, Integer.MAX_VALUE, 0, 0);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532)) {
            this.mMagneticRangeDAC = new Range(-30, 30, -30, 30, -30, 30);
            this.mMagneticRangeADC = new Range(0, 359, 0, 0, 0, 0);
            this.mMagneticRangeADC2 = new Range(-600, 600, -600, 600, -600, 600);
            this.mMagneticRangeSelf = new Range(17, Integer.MAX_VALUE, 22, Integer.MAX_VALUE, 0, 0);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS537)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = null;
            this.mMagneticRangeADC2 = new Range(NotificationManagerCompat.IMPORTANCE_UNSPECIFIED, 1000, NotificationManagerCompat.IMPORTANCE_UNSPECIFIED, 1000, NotificationManagerCompat.IMPORTANCE_UNSPECIFIED, 1000);
            this.mMagneticRangeSelf = new Range(24, Integer.MAX_VALUE, 31, Integer.MAX_VALUE, 0, 0);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS539)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = null;
            this.mMagneticRangeADC2 = new Range(NotificationManagerCompat.IMPORTANCE_UNSPECIFIED, 1000, NotificationManagerCompat.IMPORTANCE_UNSPECIFIED, 1000, NotificationManagerCompat.IMPORTANCE_UNSPECIFIED, 1000);
            this.mMagneticRangeSelf = new Range(24, Integer.MAX_VALUE, 31, Integer.MAX_VALUE, 0, 0);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_YAMAHA_YAS532B)) {
            this.mMagneticRangeDAC = new Range(-30, 30, -30, 30, -30, 30);
            this.mMagneticRangeADC = new Range(0, 359, 0, 0, 0, 0);
            this.mMagneticRangeADC2 = new Range(-600, 600, -600, 600, -600, 600);
            this.mMagneticRangeSelf = new Range(17, Integer.MAX_VALUE, 22, Integer.MAX_VALUE, 0, 0);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_MEMSIC_MMC3140MS)) {
            this.mMagneticRangeDAC = new Range(204, 614, 204, 614, 204, 614);
            this.mMagneticRangeADC = new Range(204, 614, 204, 614, 204, 614);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = null;
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_MEMSIC_MMC3280MS)) {
            this.mMagneticRangeDAC = new Range(204, 614, 204, 614, 204, 614);
            this.mMagneticRangeADC = new Range(204, 614, 204, 614, 204, 614);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = null;
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_AMOTECH)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = null;
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = null;
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC022)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-4096, 4096, -4096, 4096, -16384, 16384);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(0, 0, 0, 0, 2880, 3840);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC050)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-4096, 4096, -4096, 4096, -16384, 16384);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(0, 0, 0, 0, 2880, 3840);
        } else if (this.mFeature_Magnetic.equals("BMC150")) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-2048, 2048, -2048, 2048, -8192, 8192);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(0, 0, 0, 0, 2880, 3840);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_POWER_NOISE)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-10400, 10400, -10400, 10400, -20000, 20000);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(0, 0, 0, 0, 2880, 3840);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_BOSCH_BMC150_COMBINATION)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-10400, 10400, -10400, 10400, -20000, 20000);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(0, 0, 0, 0, 2880, 3840);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD004A)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-2000, 2000, -2000, 2000, -2000, 2000);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = null;
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD006A)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-2000, 2000, -2000, 2000, -2000, 2000);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = null;
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_ALPS_HSCDTD008A)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-8192, 8192, -8192, 8192, -8192, 8192);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = null;
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-16384, 16384, -16384, 16384, -16384, 16384);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(-5133, -1711, -5133, -1711, -1711, -171);
        } else if (this.mFeature_Magnetic.equals(SensorFeature.FEATURE_MAGENTIC_STMICRO_LSM303AH)) {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = new Range(-16384, 16384, -16384, 16384, -16384, 16384);
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = new Range(10, FactoryTestManager.TEST_SUB_TSP_OPEN_SHORT_PRESENTATION, 10, FactoryTestManager.TEST_SUB_TSP_OPEN_SHORT_PRESENTATION, 10, FactoryTestManager.TEST_SUB_TSP_OPEN_SHORT_PRESENTATION);
        } else {
            this.mMagneticRangeDAC = null;
            this.mMagneticRangeADC = null;
            this.mMagneticRangeADC2 = null;
            this.mMagneticRangeSelf = null;
        }
        String spec_adc = Support.Spec.getString(Support.Spec.GEOMAGNETIC_SPEC_ADC);
        if (!ModuleCommunicationService.SMD_NOK.equals(spec_adc)) {
            String[] specArray = spec_adc.split(",");
            this.mMagneticRangeADC = new Range(Integer.parseInt(specArray[0]), Integer.parseInt(specArray[1]), Integer.parseInt(specArray[2]), Integer.parseInt(specArray[3]), Integer.parseInt(specArray[4]), Integer.parseInt(specArray[5]));
        }
    }

    public Accelerometer getSpecAccel() {
        return this.mAccelerometer;
    }

    public Range getSpecGeomagnetic_DAC() {
        return this.mMagneticRangeDAC;
    }

    public Range getSpecGeomagnetic_ADC() {
        return this.mMagneticRangeADC;
    }

    public Range getSpecGeomagnetic_ADC2() {
        return this.mMagneticRangeADC2;
    }

    public Range getSpecGeomagnetic_Self() {
        return this.mMagneticRangeSelf;
    }
}
