package com.sec.factory.modules;

import android.app.Activity;
import android.app.Presentation;
import android.content.Context;
import android.graphics.Color;
import android.hardware.display.DisplayManager;
import android.os.Bundle;
import android.view.Display;
import android.view.View;
import com.sec.factory.R;
import com.sec.factory.app.ui.CrossTalkView;
import com.sec.factory.support.FtUtil;

public class SubDisplayPresentation extends Activity {
    private static final String CLASS_NAME = "SubDisplayPresentation";
    private String ResourcePath = "";
    private DisplayManager mDisplayManager = null;
    private SubPresentation mPresentation = null;
    private int mTestDisplayId = -1;
    Display selectedDisplay = null;

    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.sub_display_presentation);
        init();
        String test_mode = getIntent().getStringExtra("test_mode");
        String rgbData = getIntent().getStringExtra("rgb");
        FtUtil.log_i(CLASS_NAME, "onCreate", "test_mode : " + test_mode);
        FtUtil.log_i(CLASS_NAME, "onCreate", "rgbData : " + rgbData);
        if ("PRESENTATION_OFF".equals(test_mode)) {
            testFinish();
        } else if ("SUB_PRESENTATION_SHARPNESS".equals(test_mode)) {
            showSubSharpness();
        } else if (rgbData != null) {
            String[] rgb = rgbData.split("_");
            int red = Integer.parseInt(rgb[0]);
            int green = Integer.parseInt(rgb[1]);
            int blue = Integer.parseInt(rgb[2]);
            FtUtil.log_i(CLASS_NAME, "onCreate", "Red : " + red + " Green : " + green + " Blue : " + blue);
            showSubDisplay(red, green, blue);
        }
    }

    private void init() {
        DisplayManager displayManager = (DisplayManager) getApplicationContext().getSystemService("display");
        this.mDisplayManager = displayManager;
        if (displayManager != null) {
            Display[] presentationDisplays = displayManager.getDisplays("com.samsung.android.hardware.display.category.BUILTIN");
            FtUtil.log_i(CLASS_NAME, "init", "presentationDisplays.length : " + presentationDisplays.length);
            if (presentationDisplays.length > 0) {
                for (Display iterDisplay : presentationDisplays) {
                    FtUtil.log_i(CLASS_NAME, "init", "Display #" + iterDisplay + " is founded.");
                    this.selectedDisplay = iterDisplay;
                }
            }
        }
    }

    private void testFinish() {
        FtUtil.log_i(CLASS_NAME, "testFinish", "");
        dismissPresentation();
        finish();
    }

    public void onResume() {
        super.onResume();
    }

    public void onPause() {
        super.onPause();
    }

    public void onDestroy() {
        testFinish();
        super.onDestroy();
    }

    public void showSubDisplay(int r, int g, int b) {
        FtUtil.log_i(CLASS_NAME, "showSubDisplay");
        showPresentation(this.selectedDisplay);
        changeBackgoundColor(r, g, b);
    }

    private void showSubSharpness() {
        FtUtil.log_i(CLASS_NAME, "showSubSharpness");
        showPresentation(this.selectedDisplay);
        this.mPresentation.showSharpness();
    }

    private void showPresentation(Display display) {
        FtUtil.log_i(CLASS_NAME, "showPresentation", "Show presentation to sub display.");
        if (this.mPresentation == null) {
            this.mTestDisplayId = display.getDisplayId();
            SubPresentation subPresentation = new SubPresentation(getApplicationContext(), display);
            this.mPresentation = subPresentation;
            subPresentation.show();
        }
    }

    private void dismissPresentation() {
        if (this.mPresentation != null) {
            FtUtil.log_i(CLASS_NAME, "dismissPresentation", "mPresentation is not null");
            this.mPresentation.dismiss();
            this.mPresentation = null;
            this.mTestDisplayId = -1;
            return;
        }
        FtUtil.log_i(CLASS_NAME, "dismissPresentation", "mPresentation is null");
    }

    public void changeBackgoundColor(int r, int g, int b) {
        FtUtil.log_i(CLASS_NAME, "changeBackgoundColor", "");
        this.mPresentation.changeBackgroundColor(r, g, b);
    }

    /* access modifiers changed from: private */
    public final class SubPresentation extends Presentation {
        private final String CLASS_NAME = "SubPresentation";
        private View mBackground;
        private CrossTalkView mCrossTalkView;

        public SubPresentation(Context context, Display display) {
            super(context, display);
        }

        /* access modifiers changed from: protected */
        public void onCreate(Bundle savedInstanceState) {
            FtUtil.log_i("SubPresentation", "SubPresentation-onCreate", "Create presentation for sub display");
            super.onCreate(savedInstanceState);
            setContentView(R.layout.sub_presentation);
            View findViewById = findViewById(R.id.background);
            this.mBackground = findViewById;
            findViewById.setBackgroundColor(getResources().getColor(R.color.white));
            getWindow().addFlags(2097152);
            CrossTalkView crossTalkView = (CrossTalkView) findViewById(R.id.disptest_crosstalkview);
            this.mCrossTalkView = crossTalkView;
            crossTalkView.setVisibility(8);
        }

        public void changeBackgroundColor(int r, int g, int b) {
            FtUtil.log_i("SubPresentation", "SubPresentation-changeBackgoundColor", "");
            this.mBackground.setBackgroundColor(Color.rgb(r, g, b));
        }

        public void showSharpness() {
            FtUtil.log_i("SubPresentation", "SubPresentation-showSharpness", "");
            this.mCrossTalkView.setVisibility(0);
        }
    }
}
