package com.sec.factory.modules;

import android.app.Service;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.IBinder;
import android.util.Log;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.util.Arrays;

public class WirelessChargeService extends Service {
    private static final String CLASS_NAME = "WirelessChargeService";
    private final int INIT_DELAY = 1000;
    private final int TEST_COUNT = 5;
    private final int TEST_TERM_DELAY = 400;
    private int[] currents;
    private BroadcastReceiver mBroadcastReceiver = new BroadcastReceiver() {
        /* class com.sec.factory.modules.WirelessChargeService.AnonymousClass2 */

        public void onReceive(Context context, Intent intent) {
            if ("android.intent.action.BATTERY_CHANGED".equals(intent.getAction()) && intent.getIntExtra("plugged", 0) == 4 && intent.getIntExtra("online", 0) == 10) {
                FtUtil.log_d(WirelessChargeService.CLASS_NAME, "Battery State: plugged(4), online(10)");
                WirelessChargeService.this.testStart.start();
            }
        }
    };
    private ModulePower mModulePower;
    private int specMAX;
    private int specMIN;
    private Thread testStart = new Thread() {
        /* class com.sec.factory.modules.WirelessChargeService.AnonymousClass1 */

        public void run() {
            if (WirelessChargeService.this.mModulePower.isScreenOn()) {
                WirelessChargeService.this.mModulePower.doPartialWakeLock(true);
                WirelessChargeService.this.mModulePower.doWakeLock(false);
                WirelessChargeService.this.mModulePower.gotosleep();
            }
            FtUtil.Sleep.sleep(1000);
            for (int i = 0; i < 5; i++) {
                WirelessChargeService.this.getCurrent(i);
            }
            Arrays.sort(WirelessChargeService.this.currents);
            int avg = 0;
            for (int i2 = 1; i2 < 4; i2++) {
                avg += WirelessChargeService.this.currents[i2];
            }
            int avg2 = avg / 3;
            if (WirelessChargeService.this.specMIN > avg2 || avg2 > WirelessChargeService.this.specMAX) {
                FtUtil.log_e(WirelessChargeService.CLASS_NAME, "FAIL : Average(" + avg2 + ")");
                WirelessChargeService.this.setTestResult(FactoryTestManager.TEST_WIRELESS_CHARGE_BUILTIN, (byte) 70);
            } else {
                FtUtil.log_i(WirelessChargeService.CLASS_NAME, "PASS : Average(" + avg2 + ")");
                WirelessChargeService.this.setTestResult(FactoryTestManager.TEST_WIRELESS_CHARGE_BUILTIN, (byte) 80);
            }
            WirelessChargeService.this.mModulePower.doWakeLock(true);
            WirelessChargeService wirelessChargeService = WirelessChargeService.this;
            wirelessChargeService.unregisterReceiver(wirelessChargeService.mBroadcastReceiver);
            WirelessChargeService.this.stopSelf();
        }
    };

    public void onCreate() {
        Log.i(CLASS_NAME, "onCreate");
        super.onCreate();
        this.currents = new int[5];
        this.specMIN = Support.Spec.getInt(Support.Spec.WIRELESS_CURRENT_SPEC_MIN);
        this.specMAX = Support.Spec.getInt(Support.Spec.WIRELESS_CURRENT_SPEC_MAX);
        this.mModulePower = ModulePower.instance(this);
        IntentFilter mIntentFilter = new IntentFilter();
        mIntentFilter.addAction("android.intent.action.BATTERY_CHANGED");
        registerReceiver(this.mBroadcastReceiver, mIntentFilter);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private synchronized void getCurrent(int address) {
        this.currents[address] = Integer.parseInt(Support.Kernel.read(Support.Kernel.HV_CHARGE_CURRENT)) / 1000;
        FtUtil.log_d(CLASS_NAME, "Current : " + this.currents[address]);
        if (address < 4) {
            FtUtil.Sleep.sleep(400);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setTestResult(byte id, byte result) {
        FtUtil.log_i(CLASS_NAME, "setTestResult", "id: " + ((int) id) + " , result:" + ((int) result));
        int itemid = FactoryTestManager.getItemPosition_ID(id);
        if (itemid > -1) {
            FtUtil.log_i(CLASS_NAME, "setTestResult", "itemid: " + itemid);
            FactoryTestManager.setItemResult(itemid, result);
        }
    }

    public IBinder onBind(Intent intent) {
        return null;
    }

    public void onDestroy() {
        Log.i(CLASS_NAME, "onDestroy");
        super.onDestroy();
    }
}
