package com.sec.factory.modules.check;

import com.sec.factory.modules.ModuleTouchScreen;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import java.lang.reflect.Array;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Locale;

public class CheckCxDataGap {
    public static final int DIRECTION_ADJACENT_X = 1000;
    public static final int DIRECTION_ADJACENT_Y = 1001;
    private String CLASS_NAME = "CheckCxDataGap";
    private int _gapMax;
    private int _gapOnlyCornerMax;
    private int[][] _nodes;
    private boolean isTSP_SEC = Support.TestCase.getEnabled(Support.TestCase.IS_TSP_SELFTEST_SEC);
    private String mVendorCmdRet;
    private int xChannel = 18;
    private int yChannel = 32;

    public CheckCxDataGap(int x, int y) {
        this.xChannel = x;
        this.yChannel = y;
        Support.Kernel.write(Support.Kernel.TSP_COMMAND_CMD, "get_chip_vendor");
        if ("OK".equalsIgnoreCase(Support.Kernel.read(Support.Kernel.TSP_COMMAND_STATUS))) {
            this.mVendorCmdRet = Support.Kernel.read(Support.Kernel.TSP_COMMAND_RESULT);
        } else {
            this.mVendorCmdRet = null;
        }
        FtUtil.log_d(this.CLASS_NAME, "CheckCxDataGap", this.mVendorCmdRet);
        String str = this.mVendorCmdRet;
        if (str != null) {
            this.mVendorCmdRet = str.toUpperCase(Locale.ENGLISH);
        }
    }

    private int computeGap(int lhs, int rhs) {
        double d;
        double d2;
        if (!this.isTSP_SEC || !this.mVendorCmdRet.contains(ModuleTouchScreen.TSP_VENDOR_NAME__SEC)) {
            return Math.abs(lhs - rhs);
        }
        if (lhs > rhs) {
            d2 = (double) rhs;
            d = (double) lhs;
        } else {
            d2 = (double) lhs;
            d = (double) rhs;
        }
        return 100 - ((int) (100.0d * (d2 / d)));
    }

    private int[][] makeNearNodeGap(int[][] temp, int direction) throws Exception {
        this._nodes = temp;
        int[][] result = null;
        try {
            int i = this.yChannel;
            int[] iArr = new int[2];
            iArr[1] = this.xChannel;
            iArr[0] = i;
            result = (int[][]) Array.newInstance(int.class, iArr);
            switch (direction) {
                case 1000:
                    for (int y = 0; y < this.yChannel; y++) {
                        for (int x = 0; x < this.xChannel - 1; x++) {
                            int[][] iArr2 = this._nodes;
                            result[y][x] = computeGap(iArr2[y][x], iArr2[y][x + 1]);
                        }
                    }
                    break;
                case 1001:
                    for (int x2 = 0; x2 < this.xChannel; x2++) {
                        for (int y2 = 0; y2 < this.yChannel - 1; y2++) {
                            int[][] iArr3 = this._nodes;
                            result[y2][x2] = computeGap(iArr3[y2][x2], iArr3[y2 + 1][x2]);
                        }
                    }
                    break;
            }
        } catch (NumberFormatException e) {
            FtUtil.log_e(this.CLASS_NAME, "makeNearNodeGap", "NumberFormatException");
        }
        return result;
    }

    public int getMaxAdjacentNodeGap(int[][] temp, int direction) throws Exception {
        int[][] nearGap = makeNearNodeGap(temp, direction);
        int max = 0;
        for (int[] linear : nearGap) {
            for (int value : linear) {
                if (value > max) {
                    max = value;
                    FtUtil.log_d(this.CLASS_NAME, "getMaxAdjacentNodeGap", "max: " + max);
                }
            }
        }
        FtUtil.log_d(this.CLASS_NAME, "getMaxAdjacentNodeGap", "max: " + max);
        this._gapMax = max;
        return max;
    }

    public int[] getMaxAdjacentNodeGapGreatStyle(int[][] temp, int direction) throws Exception {
        int[][] nearGap = makeNearNodeGap(temp, direction);
        int[] retValue = new int[3];
        int gapXCenterMax = 0;
        int gapXSideMax = 0;
        int gapY1Max = 0;
        int gapY2Max = 0;
        int gapY3Max = 0;
        switch (direction) {
            case 1000:
                for (int y = 0; y < this.yChannel; y++) {
                    for (int x = 0; x < this.xChannel - 1; x++) {
                        if (x == 0 || x == 14) {
                            if (nearGap[y][x] > gapXSideMax) {
                                gapXSideMax = nearGap[y][x];
                            }
                        } else if (nearGap[y][x] > gapXCenterMax) {
                            gapXCenterMax = nearGap[y][x];
                        }
                    }
                }
                String str = this.CLASS_NAME;
                FtUtil.log_d(str, "getMaxAdjacentNodeGapGreatStyle", "gapXCenterMax : " + gapXCenterMax + "/ gapXSideMax : " + gapXSideMax);
                retValue[0] = gapXCenterMax;
                retValue[1] = gapXSideMax;
                break;
            case 1001:
                for (int y2 = 0; y2 < this.yChannel - 1; y2++) {
                    for (int x2 = 0; x2 < this.xChannel; x2++) {
                        if (y2 == 0) {
                            if (nearGap[y2][x2] > gapY2Max) {
                                gapY2Max = nearGap[y2][x2];
                            }
                        } else if (y2 == 15) {
                            if (nearGap[y2][x2] > gapY3Max) {
                                gapY3Max = nearGap[y2][x2];
                            }
                        } else if (nearGap[y2][x2] > gapY1Max) {
                            gapY1Max = nearGap[y2][x2];
                        }
                    }
                }
                String str2 = this.CLASS_NAME;
                FtUtil.log_d(str2, "getMaxAdjacentNodeGapGreatStyle", "gapY1Max : " + gapY1Max + "/ gapY2Max : " + gapY2Max + "/ gapY3Max : " + gapY3Max);
                retValue[0] = gapY1Max;
                retValue[1] = gapY2Max;
                retValue[2] = gapY3Max;
                break;
        }
        return retValue;
    }

    public int[] getMaxAdjacentNodeGapSplitCorner(int[][] temp, int direction) throws Exception {
        int[][] nearGap = makeNearNodeGap(temp, direction);
        int max = 0;
        int onlyCornerMax = 0;
        int[] retValue = new int[2];
        ArrayList<Integer> cornerDataList = new ArrayList<>();
        switch (direction) {
            case 1000:
                int index = 0;
                for (int y = 0; y < this.yChannel; y++) {
                    for (int x = 0; x < this.xChannel - 1; x++) {
                        if (checkCornerPosition(x, y, direction)) {
                            String str = this.CLASS_NAME;
                            FtUtil.log_d(str, "getMaxAdjacentNodeGapSplitCorner", "skip corner node x:" + x + ", y:" + y + ", index:" + index);
                            cornerDataList.add(Integer.valueOf(nearGap[y][x]));
                            index++;
                        } else if (nearGap[y][x] > max) {
                            max = nearGap[y][x];
                        }
                    }
                }
                break;
            case 1001:
                int index2 = 0;
                int y2 = 0;
                for (int i = 1; y2 < this.yChannel - i; i = 1) {
                    for (int x2 = 0; x2 < this.xChannel; x2++) {
                        if (checkCornerPosition(x2, y2, direction)) {
                            String str2 = this.CLASS_NAME;
                            FtUtil.log_d(str2, "getMaxAdjacentNodeGapSplitCorner", "skip corner node x:" + x2 + ", y:" + y2 + ", index:" + index2);
                            cornerDataList.add(Integer.valueOf(nearGap[y2][x2]));
                            index2++;
                        } else if (nearGap[y2][x2] > max) {
                            max = nearGap[y2][x2];
                        }
                    }
                    y2++;
                }
                break;
        }
        String str3 = this.CLASS_NAME;
        FtUtil.log_d(str3, "getMaxAdjacentNodeGapSplitCorner", "max: " + max);
        this._gapMax = max;
        retValue[0] = max;
        Iterator<Integer> it = cornerDataList.iterator();
        while (it.hasNext()) {
            Integer cornerData = it.next();
            if (cornerData.intValue() > onlyCornerMax) {
                onlyCornerMax = cornerData.intValue();
            }
        }
        String str4 = this.CLASS_NAME;
        FtUtil.log_d(str4, "getMaxAdjacentNodeGapSplitCorner", "onlyCornerMax: " + onlyCornerMax);
        this._gapOnlyCornerMax = onlyCornerMax;
        retValue[1] = onlyCornerMax;
        return retValue;
    }

    private boolean checkCornerPosition(int x, int y, int direction) {
        switch (direction) {
            case 1000:
                if (!(x == 0 && y == 0)) {
                    int i = this.xChannel;
                    if (!((x == i - 2 && y == 0) || ((x == 0 && y == this.yChannel - 1) || (x == i - 2 && y == this.yChannel - 1)))) {
                        return false;
                    }
                }
                return true;
            case 1001:
                if (!(x == 0 && y == 0)) {
                    int i2 = this.xChannel;
                    if (!((x == i2 - 1 && y == 0) || ((x == 0 && y == this.yChannel - 2) || (x == i2 - 1 && y == this.yChannel - 2)))) {
                        return false;
                    }
                }
                return true;
            default:
                return false;
        }
    }
}
