package com.sec.factory.modules.vrr;

import android.app.Activity;
import android.view.Display;
import android.view.View;
import android.view.WindowManager;
import com.sec.factory.support.FtUtil;

public class DisplayModeSetting implements IRefreshRateSetting {
    private static final String CLASS_NAME = "DisplayModeSetting";
    private static Display.Mode mDefaultDisplayMode;
    private static final DisplayModeSetting uniqueInstance = new DisplayModeSetting();

    private DisplayModeSetting() {
    }

    public static DisplayModeSetting getInstance(Activity activityRef) {
        mDefaultDisplayMode = getDefaultDisplayMode(activityRef);
        return uniqueInstance;
    }

    private Display.Mode[] getSupportedDisplayMode(Activity activityRef) {
        try {
            FtUtil.log_d(CLASS_NAME, "getSupportedDisplayMode", "getSupportedDisplayMode");
            return ((WindowManager) activityRef.getSystemService("window")).getDefaultDisplay().getSupportedModes();
        } catch (Exception e) {
            e.printStackTrace();
        } catch (Throwable th) {
        }
        return null;
    }

    private static Display.Mode getCurrentDisplayMode(Activity activityRef) {
        Display.Mode currentMode = null;
        try {
            FtUtil.log_d(CLASS_NAME, "getCurrentDisplayMode", "getCurrentDisplayMode");
            currentMode = ((WindowManager) activityRef.getSystemService("window")).getDefaultDisplay().getMode();
            FtUtil.log_d(CLASS_NAME, "getCurrentDisplayMode", "width = " + currentMode.getPhysicalWidth() + " height = " + currentMode.getPhysicalHeight() + " rate = " + currentMode.getRefreshRate());
            return currentMode;
        } catch (Exception e) {
            e.printStackTrace();
            return currentMode;
        } catch (Throwable th) {
            return currentMode;
        }
    }

    private void setDisplayMode(Display.Mode displayMode, Activity activityRef) {
        try {
            FtUtil.log_d(CLASS_NAME, "setDisplayMode", "start");
            View decor = activityRef.getWindow().getDecorView();
            if (decor != null) {
                WindowManager.LayoutParams fl = activityRef.getWindow().getAttributes();
                fl.preferredDisplayModeId = displayMode.getModeId();
                activityRef.getWindowManager().updateViewLayout(decor, fl);
                FtUtil.log_d(CLASS_NAME, "setDisplayMode", "update view done");
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void setDisplayMode(int refreshRate, Activity activityRef) {
        try {
            FtUtil.log_d(CLASS_NAME, "setDisplayMode", "setDisplayMode");
            Display.Mode[] supportedModes = getSupportedDisplayMode(activityRef);
            for (Display.Mode mode : supportedModes) {
                FtUtil.log_d(CLASS_NAME, "setDisplayMode", "width = " + mode.getPhysicalWidth() + " height = " + mode.getPhysicalHeight() + " rate = " + mode.getRefreshRate());
                if (Math.round(mode.getRefreshRate()) == refreshRate) {
                    setDisplayMode(mode, activityRef);
                    return;
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private static Display.Mode getDefaultDisplayMode(Activity activityRef) {
        FtUtil.log_d(CLASS_NAME, "getDefaultDisplayMode", "getDefaultDisplayMode");
        return getCurrentDisplayMode(activityRef);
    }

    private void restoreDefaultDisplayMode(Activity activityRef) {
        FtUtil.log_d(CLASS_NAME, "restoreDefaultDisplayMode", "restoreDefaultDisplayMode");
        setDisplayMode(mDefaultDisplayMode, activityRef);
    }

    @Override // com.sec.factory.modules.vrr.IRefreshRateSetting
    public void setRate(int mode, int rate, Activity activityRef) {
        setDisplayMode(rate, activityRef);
    }

    @Override // com.sec.factory.modules.vrr.IRefreshRateSetting
    public void restoreDefault(Activity activityRef) {
        restoreDefaultDisplayMode(activityRef);
    }
}
