package com.sec.factory.modules.vrr;

import android.app.Activity;
import android.provider.Settings;
import com.sec.factory.support.FtUtil;

public class IntegerRefreshRateModeSetting implements IRefreshRateModeSetting<Integer> {
    private static final String CLASS_NAME = "IntegerRefreshRateModeSetting";
    private static int mDefaultRefreshRateMode;
    private static final String mRefreshRateMode = getRefreshRateModeStr();
    private static final IntegerRefreshRateModeSetting uniqueInstance = new IntegerRefreshRateModeSetting();

    private IntegerRefreshRateModeSetting() {
    }

    public static IntegerRefreshRateModeSetting getInstance(Activity activityRef) {
        mDefaultRefreshRateMode = getDefaultRefreshRateMode(activityRef).intValue();
        return uniqueInstance;
    }

    private static String getRefreshRateModeStr() {
        try {
            return (String) Settings.Secure.class.getDeclaredField("REFRESH_RATE_MODE").get(Settings.Secure.class);
        } catch (Exception e) {
            e.printStackTrace();
            return "refresh_rate_mode";
        } catch (Throwable th) {
            return "refresh_rate_mode";
        }
    }

    private static Integer getDefaultRefreshRateMode(Activity activityRef) {
        Integer result = Integer.valueOf(VRRcontants.REFRESH_RATE_MODE_ALWAYS);
        try {
            return getRefreshRateMode(activityRef);
        } catch (Exception e) {
            e.printStackTrace();
            return result;
        } catch (Throwable th) {
            return result;
        }
    }

    private static Integer getRefreshRateMode(Activity activityRef) {
        FtUtil.log_d(CLASS_NAME, "getRefreshRateMode", "start");
        return Integer.valueOf(Settings.Secure.getIntForUser(activityRef.getContentResolver(), mRefreshRateMode, VRRcontants.REFRESH_RATE_MODE_ALWAYS, 0));
    }

    private static void setRefreshRateMode(Integer refreshRateMode, Activity activityRef) {
        FtUtil.log_d(CLASS_NAME, "setRefreshRateMode", "refreshRateMode " + refreshRateMode);
        Settings.Secure.putIntForUser(activityRef.getContentResolver(), mRefreshRateMode, refreshRateMode.intValue(), 0);
    }

    public void setMode(Integer mode, Activity activityRef) {
        FtUtil.log_d(CLASS_NAME, "setMode", "mode : " + mode);
        setRefreshRateMode(mode, activityRef);
    }

    public boolean isSameWithCurrent(Integer mode, Activity activityRef) {
        FtUtil.log_d(CLASS_NAME, "isSameWithCurrent", "mode : " + mode);
        try {
            return getRefreshRateMode(activityRef) == mode;
        } catch (Exception e) {
            e.printStackTrace();
            return false;
        } catch (Throwable th) {
            return false;
        }
    }

    @Override // com.sec.factory.modules.vrr.IRefreshRateModeSetting
    public Integer getDefault() {
        FtUtil.log_d(CLASS_NAME, "getDefault", "getDefault");
        return Integer.valueOf(mDefaultRefreshRateMode);
    }

    @Override // com.sec.factory.modules.vrr.IRefreshRateModeSetting
    public void restoreDefault(Activity activityRef) {
        FtUtil.log_d(CLASS_NAME, "restoreDefault", "restoreDefault");
        setRefreshRateMode(Integer.valueOf(mDefaultRefreshRateMode), activityRef);
    }
}
