package com.sec.factory.modules.vrr;

import android.app.Activity;
import android.hardware.display.IDisplayManager;
import android.os.Binder;
import android.os.RemoteException;
import android.os.ServiceManager;
import com.samsung.android.hardware.display.ILowRefreshRateToken;
import com.sec.factory.support.FtUtil;

public class LowRefreshRateTokenHandle implements IRefreshRateSetting {
    private static final IDisplayManager mDisplayManager = IDisplayManager.Stub.asInterface(ServiceManager.getService("display"));
    private static ILowRefreshRateToken mLowRefreshRateToken;
    private static final LowRefreshRateTokenHandle uniqueInstance = new LowRefreshRateTokenHandle();
    private final String CLASS_NAME = "LowRefreshRateTokenHandle";

    private LowRefreshRateTokenHandle() {
    }

    public static LowRefreshRateTokenHandle getInstance() {
        return uniqueInstance;
    }

    private void acquireToken(String TAG) {
        try {
            mLowRefreshRateToken = mDisplayManager.acquireLowRefreshRateToken(new Binder(), TAG);
        } catch (RemoteException e) {
            e.printStackTrace();
        }
    }

    private void releaseToken() {
        try {
            ILowRefreshRateToken iLowRefreshRateToken = mLowRefreshRateToken;
            if (iLowRefreshRateToken != null) {
                iLowRefreshRateToken.release();
                mLowRefreshRateToken = null;
            }
        } catch (RemoteException e) {
            e.printStackTrace();
        }
    }

    @Override // com.sec.factory.modules.vrr.IRefreshRateSetting
    public void setRate(int mode, int rate, Activity activityRef) {
        FtUtil.log_d("LowRefreshRateTokenHandle", "setRate", "mode : " + mode + " rate : " + rate);
        if (rate == 60) {
            acquireToken(activityRef.getPackageName());
        }
    }

    @Override // com.sec.factory.modules.vrr.IRefreshRateSetting
    public void restoreDefault(Activity activityRef) {
        FtUtil.log_d("LowRefreshRateTokenHandle", "restoreDefault", "restoreDefault");
        releaseToken();
    }
}
