package com.sec.xmldata.support;

import android.content.Context;
import android.os.SystemProperties;
import android.util.Base64;
import android.widget.Toast;
import com.sec.xmldata.support.Support;
import java.io.BufferedReader;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.Locale;
import java.util.concurrent.ConcurrentHashMap;
import javax.xml.namespace.QName;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpressionException;
import javax.xml.xpath.XPathFactory;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

public class XMLDataStorage {
    public static final String CLASS_NAME = "XMLDataStorage";
    private static final int MAX_HWID = 255;
    private static XMLDataStorage mInstance = null;
    private ConcurrentHashMap<String, String> mAttrCache = new ConcurrentHashMap<>();
    private DocumentBuilder mDOMParser;
    private Document mDocument;
    private int mHwid;
    private boolean mInitFactoryTest = false;
    private boolean mInitFactoryTestSub = false;
    private boolean mInitHwTest = false;
    private boolean mInitSensorTest = false;
    private boolean mWasCompletedParsing = false;
    private XPath mXPath;

    public static synchronized XMLDataStorage instance() {
        XMLDataStorage xMLDataStorage;
        synchronized (XMLDataStorage.class) {
            if (mInstance == null) {
                mInstance = new XMLDataStorage();
            }
            xMLDataStorage = mInstance;
        }
        return xMLDataStorage;
    }

    private XMLDataStorage() {
        try {
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            factory.setIgnoringComments(true);
            factory.setIgnoringElementContentWhitespace(true);
            this.mDOMParser = factory.newDocumentBuilder();
            this.mXPath = XPathFactory.newInstance().newXPath();
        } catch (ParserConfigurationException e) {
            XmlUtil.log_e(e);
        }
    }

    private boolean setXmlUtilTag(Context context) {
        if (context != null) {
            String packageName = context.getPackageName();
            if ("com.sec.factory".equals(packageName)) {
                XmlUtil.setTagName("XmlData_FTA");
            } else if ("com.sec.android.app.factorykeystring".equals(packageName)) {
                XmlUtil.setTagName("XmlData_LTA");
            } else if ("com.sec.android.app.hwmoduletest".equals(packageName)) {
                XmlUtil.setTagName("XmlData_HMT");
            } else if ("com.sec.OneJigBinary".equals(packageName)) {
                XmlUtil.setTagName("XmlData_OJB");
            } else {
                XmlUtil.log_d(CLASS_NAME, "setXmlUtilTag", "UnKnown PackageName");
                return false;
            }
            XmlUtil.log_d(CLASS_NAME, "setXmlUtilTag", "packageName:" + XmlUtil.getTagName());
            return true;
        }
        XmlUtil.log_d(CLASS_NAME, "setXmlUtilTag", "context is null");
        return false;
    }

    public boolean parseXML(Context context) {
        if (!setXmlUtilTag(context)) {
            XmlUtil.log_d(CLASS_NAME, "parseXML", "false, unknown package name");
            return false;
        }
        this.mHwid = Integer.parseInt(SystemProperties.get("ro.revision", "0"));
        synchronized (XMLDataStorage.class) {
            if (!instance().wasCompletedParsing()) {
                String deviceXML = SystemProperties.get("ro.product.vendor.device", "base");
                String modelXML = SystemProperties.get("ro.product.model", "base");
                String deviceXML2 = deviceXML.trim().replace(" ", "").toLowerCase(Locale.ENGLISH) + ".dat";
                String modelXML2 = modelXML.trim().replace(" ", "").toLowerCase(Locale.ENGLISH) + ".dat";
                XmlUtil.log_d(CLASS_NAME, "parseXML", "deviceXML:" + deviceXML2 + ", modelXML:" + modelXML2);
                if (checkModelFileInAsset(context, deviceXML2, modelXML2)) {
                    if (!instance().parseAsset(context, deviceXML2)) {
                        XmlUtil.log_e(CLASS_NAME, "parseXML", "ro.product.vendor.device file not found: " + deviceXML2);
                    }
                    if (!instance().parseAsset(context, modelXML2)) {
                        XmlUtil.log_e(CLASS_NAME, "parseXML", "ro.product.model file not found: " + modelXML2);
                    }
                } else if (parseMergedDat(context)) {
                    this.mInitSensorTest = false;
                    this.mInitHwTest = false;
                    this.mInitFactoryTestSub = false;
                    this.mInitFactoryTest = false;
                    parseFromData(context, deviceXML2);
                    parseFromData(context, modelXML2);
                    XmlUtil.log_d(CLASS_NAME, "parseXML", "parse model file by vendor dat");
                } else {
                    XmlUtil.log_d(CLASS_NAME, "parseXML", "there are no model file");
                }
                if (this.mDocument == null) {
                    instance().parseAsset(context, "base.dat");
                    XmlUtil.log_e(CLASS_NAME, "parseXML", "Default file loaded => base.dat");
                }
                if (XmlUtil.isFactoryBinary()) {
                    replaceLineSpec();
                }
                XmlUtil.log_i(CLASS_NAME, "parseXML", "data parsing completed.");
                this.mWasCompletedParsing = true;
            } else {
                XmlUtil.log_i(CLASS_NAME, "parseXML", "data parsing was already completed.");
            }
        }
        return true;
    }

    private boolean checkModelFileInAsset(Context context, String deviceXML, String modelXML) {
        boolean isDeviceXMLExist = false;
        boolean isModelXMLExist = false;
        try {
            context.getResources().getAssets().open(deviceXML, 3);
            isDeviceXMLExist = true;
        } catch (IOException ie) {
            XmlUtil.log_e(ie);
            XmlUtil.log_i(CLASS_NAME, "checkModelFileInAsset", "no device xml");
        }
        try {
            context.getResources().getAssets().open(modelXML, 3);
            isModelXMLExist = true;
        } catch (IOException ie2) {
            XmlUtil.log_e(ie2);
            XmlUtil.log_i(CLASS_NAME, "checkModelFileInAsset", "no model xml");
        }
        StringBuilder sb = new StringBuilder();
        sb.append("");
        sb.append(isDeviceXMLExist || isModelXMLExist);
        XmlUtil.log_i(CLASS_NAME, "checkModelFileInAsset", sb.toString());
        return isDeviceXMLExist || isModelXMLExist;
    }

    private boolean parseFromData(Context context, String modelXML) {
        boolean result = false;
        String xmlAtData = "/sdcard/" + modelXML;
        if (!XmlUtil.isFactoryBinary() || !new File(xmlAtData).exists()) {
            return false;
        }
        try {
            this.mDocument = redefinitionXml(this.mDocument, this.mDOMParser.parse(convertBytesToIS(Base64.decode(readAllLine(xmlAtData), 0))));
            result = true;
            XmlUtil.log_i(CLASS_NAME, "parseFromData", "completed. " + xmlAtData);
            return true;
        } catch (SAXException e) {
            XmlUtil.log_e(e);
            return result;
        } catch (IOException e2) {
            XmlUtil.log_e(e2);
            return result;
        }
    }

    private boolean parseMergedDat(Context context) {
        XmlUtil.log_i(CLASS_NAME, "parseMergedDat", "");
        boolean result = false;
        try {
            Document parse = this.mDOMParser.parse(convertBytesToIS(Base64.decode(readAllLine(context.getResources().getAssets().open("fac_model.dat", 3)), 0)));
            this.mDocument = parse;
            redefinitionByHwid(parse);
            result = true;
            XmlUtil.log_i(CLASS_NAME, "parseMergedDat", "parse fac_model dat from asset");
            return true;
        } catch (IOException | XPathExpressionException | SAXException e) {
            XmlUtil.log_e(e);
            return result;
        }
    }

    private void redefinitionByHwid(Document doc) throws XPathExpressionException {
        NodeList nodelist = (NodeList) xpath(doc, "//*[@hwid]", XPathConstants.NODESET);
        for (int idx = 0; idx < nodelist.getLength(); idx++) {
            nodelist.item(idx).getParentNode().removeChild(nodelist.item(idx));
        }
        for (int idx2 = 0; idx2 < nodelist.getLength(); idx2++) {
            XmlUtil.log_i(CLASS_NAME, "redefinitionByHwid", "id : " + ((Element) nodelist.item(idx2)).getAttribute("id") + ", hwid : " + ((Element) nodelist.item(idx2)).getAttribute("hwid"));
            redefinitionById(doc, (Element) nodelist.item(idx2));
        }
    }

    private boolean parseAsset(Context context, String xml) {
        Document baseDocument;
        try {
            XmlUtil.log_d(CLASS_NAME, "parseAsset", "parseAsset Is Started");
            XmlUtil.log_i(CLASS_NAME, "parseAsset", "Convert dat file: " + xml);
            Document document = this.mDOMParser.parse(convertBytesToIS(Base64.decode(convertIStoString(context, xml), 0)));
            Document document2 = this.mDocument;
            if (document2 == null) {
                XmlUtil.log_d(CLASS_NAME, "parseAsset", "Decode base file: " + "base.dat");
                baseDocument = this.mDOMParser.parse(convertBytesToIS(Base64.decode(convertIStoString(context, "base.dat"), 0)));
                this.mDocument = baseDocument;
            } else {
                baseDocument = document2;
            }
            this.mDocument = redefinitionXml(baseDocument, document);
            XmlUtil.log_d(CLASS_NAME, "parseAsset", "completed redefinitionXml: " + xml);
            XmlUtil.log_d(CLASS_NAME, "parseAsset", "parseAsset Is Completed");
            return true;
        } catch (Exception e) {
            XmlUtil.log_e(e);
            return false;
        }
    }

    private Document redefinitionXml(Document base, Document sub) {
        redefinitionById(base, sub);
        if (sub.getElementsByTagName("FactoryTestMenu").item(0) != null) {
            if (!this.mInitFactoryTest) {
                XmlUtil.log_d(CLASS_NAME, "redefinitionXml", "Init FactoryTestMenu");
                swapNode(base, base.getElementsByTagName("FactoryTestMenu").item(0), sub.getElementsByTagName("FactoryTestMenu").item(0));
                this.mInitFactoryTest = true;
            } else {
                XmlUtil.log_d(CLASS_NAME, "redefinitionXml", "Override FactoryTestMenu");
                redefinitionByAction(getChildElementSet("FactoryTestMenu"), (Element) sub.getElementsByTagName("FactoryTestMenu").item(0));
            }
        }
        if (sub.getElementsByTagName("FactoryTestMenuSub").item(0) != null) {
            if (!this.mInitFactoryTestSub) {
                XmlUtil.log_d(CLASS_NAME, "redefinitionXml", "Init FactoryTestMenuSub");
                swapNode(base, base.getElementsByTagName("FactoryTestMenuSub").item(0), sub.getElementsByTagName("FactoryTestMenuSub").item(0));
                this.mInitFactoryTestSub = true;
            } else {
                XmlUtil.log_d(CLASS_NAME, "redefinitionXml", "Override FactoryTestMenuSub");
                redefinitionByAction(getChildElementSet("FactoryTestMenuSub"), (Element) sub.getElementsByTagName("FactoryTestMenuSub").item(0));
            }
        }
        if (sub.getElementsByTagName(Support.HwTestMenu.TAG).item(0) != null) {
            if (!this.mInitHwTest) {
                XmlUtil.log_d(CLASS_NAME, "redefinitionXml", "Init HwTestMenu");
                swapNode(base, base.getElementsByTagName(Support.HwTestMenu.TAG).item(0), sub.getElementsByTagName(Support.HwTestMenu.TAG).item(0));
                this.mInitHwTest = true;
            } else {
                XmlUtil.log_d(CLASS_NAME, "redefinitionXml", "Override HwTestMenu");
                redefinitionByAction(getChildElementSet(Support.HwTestMenu.TAG), (Element) sub.getElementsByTagName(Support.HwTestMenu.TAG).item(0));
            }
        }
        if (sub.getElementsByTagName(Support.SensorTestMenu.TAG).item(0) != null) {
            if (!this.mInitSensorTest) {
                XmlUtil.log_d(CLASS_NAME, "redefinitionXml", "Init SensorTestMenu");
                swapNode(base, base.getElementsByTagName(Support.SensorTestMenu.TAG).item(0), sub.getElementsByTagName(Support.SensorTestMenu.TAG).item(0));
                this.mInitSensorTest = true;
            } else {
                XmlUtil.log_d(CLASS_NAME, "redefinitionXml", "Override SensorTestMenu");
                redefinitionByAction(getChildElementSet(Support.SensorTestMenu.TAG), (Element) sub.getElementsByTagName(Support.SensorTestMenu.TAG).item(0));
            }
        }
        return base;
    }

    private String readAllLine(InputStream inputStream) {
        StringBuilder sb = new StringBuilder();
        BufferedReader buffreader = null;
        try {
            BufferedReader buffreader2 = new BufferedReader(new InputStreamReader(inputStream));
            while (true) {
                String line = buffreader2.readLine();
                if (line != null) {
                    sb.append(line);
                } else {
                    try {
                        break;
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }
            }
            buffreader2.close();
        } catch (IOException e2) {
            e2.printStackTrace();
            if (0 != 0) {
                buffreader.close();
            }
        } catch (Throwable th) {
            if (0 != 0) {
                try {
                    buffreader.close();
                } catch (IOException e3) {
                    e3.printStackTrace();
                }
            }
            throw th;
        }
        return sb.toString();
    }

    private String readAllLine(String xmlPath) {
        try {
            return readAllLine(new FileInputStream(new File(xmlPath)));
        } catch (FileNotFoundException e) {
            XmlUtil.log_e(e);
            return "";
        }
    }

    private String convertIStoString(Context context, String xmlFile) {
        InputStream inputstream;
        String mModelFileInSdcard = "/sdcard/" + xmlFile;
        StringBuilder stringbuilder = new StringBuilder();
        stringbuilder.setLength(0);
        InputStream inputstream2 = null;
        try {
            File file = new File(mModelFileInSdcard);
            if (!XmlUtil.isFactoryBinary() || !file.exists()) {
                inputstream = context.getResources().getAssets().open(xmlFile, 3);
            } else {
                inputstream = new FileInputStream(file);
                Toast.makeText(context, "Read " + xmlFile + " from sdcard", 1).show();
            }
            BufferedReader buffreader = new BufferedReader(new InputStreamReader(inputstream));
            while (true) {
                String line = buffreader.readLine();
                if (line == null) {
                    break;
                }
                stringbuilder.append(line);
            }
            if (inputstream != null) {
                try {
                    inputstream.close();
                } catch (IOException e) {
                    XmlUtil.log_e(e);
                }
            }
        } catch (FileNotFoundException e2) {
            XmlUtil.log_v(CLASS_NAME, "convertIStoString", xmlFile + " is not existed.");
            if (0 != 0) {
                inputstream2.close();
            }
        } catch (IOException e3) {
            XmlUtil.log_e(e3);
            if (0 != 0) {
                inputstream2.close();
            }
        } catch (Throwable th) {
            if (0 != 0) {
                try {
                    inputstream2.close();
                } catch (IOException e4) {
                    XmlUtil.log_e(e4);
                }
            }
            throw th;
        }
        return stringbuilder.toString();
    }

    private InputStream convertBytesToIS(byte[] bytes) {
        return new ByteArrayInputStream(bytes);
    }

    public boolean wasCompletedParsing() {
        return this.mWasCompletedParsing;
    }

    public Element getElementById(String id) {
        return this.mDocument.getElementById(id);
    }

    public Element getElementByName(String nodeName) {
        return (Element) xpath("//" + nodeName, XPathConstants.NODE);
    }

    public Element getElementByAttribute(String target, String attribute, String attributeValue) {
        return (Element) xpath("//" + target + "/*[@" + attribute + "='" + attributeValue + "']", XPathConstants.NODE);
    }

    public Element getElementByAttribute(String attribute, String attributeValue) {
        return (Element) xpath("//*[@" + attribute + "='" + attributeValue + "']", XPathConstants.NODE);
    }

    public Element[] getElementSetByName(String nodeName) {
        NodeList nodeList = (NodeList) xpath("//" + nodeName, XPathConstants.NODESET);
        if (nodeList != null) {
            return makeElementArray(nodeList);
        }
        return null;
    }

    public Element[] getChildElementSet(String parentNodeName) {
        NodeList nodeList = (NodeList) xpath("//" + parentNodeName + "/*", XPathConstants.NODESET);
        if (nodeList != null) {
            return makeElementArray(nodeList);
        }
        return null;
    }

    public String getAttributeValueById(String id, String resultAttr) {
        String cacheId = id + "$" + resultAttr;
        String attr = this.mAttrCache.get(cacheId);
        if (attr != null) {
            return attr;
        }
        String value = this.mDocument.getElementById(id).getAttribute(resultAttr);
        this.mAttrCache.putIfAbsent(cacheId, value);
        return value;
    }

    public String getAttributeValueByTag(String tag, String resultAttr) {
        return ((Element) this.mDocument.getElementsByTagName(tag).item(0)).getAttribute(resultAttr);
    }

    public String getAttributeValueByAttributeOnTarget(String target, String findAttr, String findAttrValue, String resultAttr) {
        Element element = getElementByAttribute(target, findAttr, findAttrValue);
        if (element != null) {
            return element.getAttribute(resultAttr);
        }
        return null;
    }

    public String getAttributeValueByAttribute(String finaAttr, String findAttrValue, String resultAttr) {
        Element element = getElementByAttribute(finaAttr, findAttrValue);
        if (element != null) {
            return element.getAttribute(resultAttr);
        }
        return null;
    }

    public String[] getAttributeNameSet(Element element) {
        String[] attributeSet = null;
        if (element.hasAttributes()) {
            NamedNodeMap map = element.getAttributes();
            attributeSet = new String[map.getLength()];
            for (int i = 0; i < map.getLength(); i++) {
                attributeSet[i] = map.item(i).getNodeName();
            }
        }
        return attributeSet;
    }

    public Document getDocument() {
        return this.mDocument;
    }

    private Object xpath(String expression, QName returnType) {
        return xpath(this.mDocument, expression, returnType);
    }

    private Object xpath(Document document, String expression, QName returnType) {
        try {
            return this.mXPath.compile(expression).evaluate(document, returnType);
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    private Element[] makeElementArray(NodeList nodeList) {
        Element[] elementSet = new Element[nodeList.getLength()];
        for (int i = 0; i < nodeList.getLength(); i++) {
            elementSet[i] = (Element) nodeList.item(i);
        }
        return elementSet;
    }

    private void redefinitionById(Document baseDocument, Document subDocument) {
        redefinitionById(baseDocument, subDocument.getDocumentElement());
    }

    private void redefinitionById(Document baseDocument, Element redefNode) {
        int redefHwid;
        String str;
        int baseHwid;
        if (redefNode.hasAttributes()) {
            String str2 = "id";
            String id = redefNode.getAttribute(str2);
            String tempStr = redefNode.getAttribute("hwid");
            if (tempStr == null || tempStr.isEmpty()) {
                redefHwid = 255;
            } else {
                redefHwid = Integer.parseInt(tempStr);
            }
            if (id != null && !id.isEmpty()) {
                Element element = baseDocument.getElementById(id);
                String[] attributes = getAttributeNameSet(redefNode);
                if (attributes != null) {
                    int length = attributes.length;
                    int i = 0;
                    while (true) {
                        if (i >= length) {
                            break;
                        }
                        String attr = attributes[i];
                        if (!str2.equals(attr)) {
                            if (element == null) {
                                XmlUtil.log_d(CLASS_NAME, "redefinitionById", "Element \"" + id + "\" does not exist in base document.");
                                break;
                            }
                            String tempStr2 = element.getAttribute("hwid");
                            if (tempStr2 == null || tempStr2.isEmpty()) {
                                baseHwid = 255;
                            } else {
                                baseHwid = Integer.parseInt(tempStr2);
                            }
                            str = str2;
                            if (this.mHwid > redefHwid || baseHwid < redefHwid) {
                                XmlUtil.log_d(CLASS_NAME, "redefinitionById", "Do not redefine because of Hwid");
                                XmlUtil.log_d(CLASS_NAME, "redefinitionById", "Hwid=" + this.mHwid + ", baseHwid=" + baseHwid + ", redefHwid=" + redefHwid);
                            } else {
                                element.setAttribute(attr, redefNode.getAttribute(attr));
                            }
                        } else {
                            str = str2;
                        }
                        i++;
                        str2 = str;
                    }
                }
            }
        }
        if (redefNode.hasChildNodes()) {
            NodeList childNodes = redefNode.getChildNodes();
            for (int i2 = 0; i2 < childNodes.getLength(); i2++) {
                if (childNodes.item(i2).getNodeType() == 1) {
                    redefinitionById(baseDocument, (Element) childNodes.item(i2));
                }
            }
        }
    }

    private void redefinitionByAction(Element[] baseNode, Element redefNode) {
        String action;
        String[] attributes;
        if (redefNode.hasAttributes() && (action = redefNode.getAttribute("action")) != null && !action.isEmpty() && (attributes = getAttributeNameSet(redefNode)) != null) {
            int length = baseNode.length;
            int i = 0;
            while (true) {
                if (i >= length) {
                    break;
                }
                Element element = baseNode[i];
                if (action.equals(element.getAttribute("action"))) {
                    for (String attr : attributes) {
                        if (!"action".equals(attr)) {
                            element.setAttribute(attr, redefNode.getAttribute(attr));
                        }
                    }
                    XmlUtil.log_d(CLASS_NAME, "redefinitionByAction", "action " + action + " Element have been override.");
                    if ("item-group".equals(redefNode.getTagName())) {
                        NodeList childNodes = redefNode.getChildNodes();
                        for (int i2 = 0; i2 < childNodes.getLength(); i2++) {
                            if (childNodes.item(i2).getNodeType() == 1) {
                                redefinitionByAction(makeElementArray(element.getChildNodes()), (Element) childNodes.item(i2));
                            }
                        }
                    }
                } else {
                    i++;
                }
            }
        }
        if (redefNode.hasChildNodes() && !"item-group".equals(redefNode.getTagName())) {
            NodeList childNodes2 = redefNode.getChildNodes();
            for (int i3 = 0; i3 < childNodes2.getLength(); i3++) {
                if (childNodes2.item(i3).getNodeType() == 1) {
                    redefinitionByAction(baseNode, (Element) childNodes2.item(i3));
                }
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:84:0x01f7  */
    /* JADX WARNING: Removed duplicated region for block: B:94:0x0220 A[SYNTHETIC, Splitter:B:94:0x0220] */
    public boolean replaceLineSpec() {
        Throwable th;
        Exception e;
        BufferedReader reader;
        String lineSpec;
        String lineSpecPath;
        String str;
        String[] specList;
        String str2 = " // ";
        String lineSpecPath2 = "/efs/FactoryApp/line_spec";
        String lineSpec2 = null;
        BufferedReader reader2 = null;
        boolean replaceStatus = false;
        File lineSpecFile = new File(lineSpecPath2);
        char c = 0;
        if (lineSpecFile.exists()) {
            XmlUtil.log_d(CLASS_NAME, "replaceLineSpec", "lineSpecPath exists");
            try {
                reader2 = new BufferedReader(new FileReader(lineSpecPath2));
                lineSpec2 = reader2.readLine();
                if (lineSpec2 != null) {
                    lineSpec2 = lineSpec2.trim();
                }
                try {
                    reader2.close();
                } catch (IOException e2) {
                    XmlUtil.log_e(e2);
                }
            } catch (Exception e3) {
                XmlUtil.log_e(e3);
                if (0 != 0) {
                    reader2.close();
                }
            } catch (Throwable th2) {
                th = th2;
                if (0 != 0) {
                }
                throw th;
            }
            if (lineSpec2 != null && !lineSpec2.isEmpty()) {
                try {
                    String[] specList2 = lineSpec2.split(":");
                    if (specList2 != null && specList2.length != 0) {
                        int length = specList2.length;
                        int i = 0;
                        while (i < length) {
                            String[] specItem = specList2[i].split("//");
                            if (specItem[c] == null || specItem[1] == null || specItem[2] == null) {
                                specList = specList2;
                                str = str2;
                                lineSpecPath = lineSpecPath2;
                                lineSpec = lineSpec2;
                                reader = reader2;
                            } else {
                                StringBuilder sb = new StringBuilder();
                                sb.append("spec : ");
                                specList = specList2;
                                sb.append(specItem[0]);
                                sb.append(str2);
                                sb.append(specItem[1]);
                                sb.append(str2);
                                sb.append(specItem[2]);
                                XmlUtil.log_d(CLASS_NAME, "replaceLineSpec", sb.toString());
                                Element element = this.mDocument.getElementById(specItem[1]);
                                if (element == null) {
                                    try {
                                        Element[] elements = getChildElementSet(specItem[0]);
                                        int i2 = 0;
                                        while (i2 < elements.length) {
                                            try {
                                                if (specItem[1].equals(elements[i2].getAttributes().getNamedItem("name").getNodeValue())) {
                                                    element = elements[i2];
                                                } else {
                                                    element = element;
                                                }
                                                i2++;
                                                str2 = str2;
                                                lineSpecPath2 = lineSpecPath2;
                                            } catch (Exception e4) {
                                                e = e4;
                                                XmlUtil.log_e(e);
                                                if (lineSpecFile.exists()) {
                                                }
                                                this.mAttrCache.clear();
                                                return replaceStatus;
                                            }
                                        }
                                        str = str2;
                                        lineSpecPath = lineSpecPath2;
                                        element = element;
                                    } catch (Exception e5) {
                                        e = e5;
                                        XmlUtil.log_e(e);
                                        if (lineSpecFile.exists()) {
                                        }
                                        this.mAttrCache.clear();
                                        return replaceStatus;
                                    }
                                } else {
                                    str = str2;
                                    lineSpecPath = lineSpecPath2;
                                }
                                if (element != null) {
                                    try {
                                        XmlUtil.log_d(CLASS_NAME, "replaceLineSpec", "specItem[2] =" + specItem[2]);
                                        String[] attrList = specItem[2].split("__");
                                        int length2 = attrList.length;
                                        int i3 = 0;
                                        while (i3 < length2) {
                                            String attr = attrList[i3];
                                            XmlUtil.log_d(CLASS_NAME, "replaceLineSpec", "attr = " + attr);
                                            String[] attrItem = attr.split("=");
                                            StringBuilder sb2 = new StringBuilder();
                                            try {
                                                sb2.append("attrItem[] = ");
                                                try {
                                                    sb2.append(attrItem[0]);
                                                    sb2.append(" = ");
                                                    sb2.append(attrItem[1]);
                                                    XmlUtil.log_d(CLASS_NAME, "replaceLineSpec", sb2.toString());
                                                    element.setAttribute(attrItem[0], attrItem[1]);
                                                    i3++;
                                                    attrList = attrList;
                                                    length2 = length2;
                                                    lineSpec2 = lineSpec2;
                                                    reader2 = reader2;
                                                } catch (Exception e6) {
                                                    e = e6;
                                                    XmlUtil.log_e(e);
                                                    if (lineSpecFile.exists()) {
                                                    }
                                                    this.mAttrCache.clear();
                                                    return replaceStatus;
                                                }
                                            } catch (Exception e7) {
                                                e = e7;
                                                XmlUtil.log_e(e);
                                                if (lineSpecFile.exists()) {
                                                }
                                                this.mAttrCache.clear();
                                                return replaceStatus;
                                            }
                                        }
                                        lineSpec = lineSpec2;
                                        reader = reader2;
                                    } catch (Exception e8) {
                                        e = e8;
                                        XmlUtil.log_e(e);
                                        if (lineSpecFile.exists()) {
                                            XmlUtil.log_d(CLASS_NAME, "replaceLineSpec", "delete lineSpecFile");
                                            if (lineSpecFile.delete()) {
                                                XmlUtil.log_d(CLASS_NAME, "replaceLineSpec", "delete lineSpecFile: success");
                                            } else {
                                                XmlUtil.log_d(CLASS_NAME, "replaceLineSpec", "delete lineSpecFile: failed");
                                            }
                                        }
                                        this.mAttrCache.clear();
                                        return replaceStatus;
                                    }
                                } else {
                                    lineSpec = lineSpec2;
                                    reader = reader2;
                                    XmlUtil.log_d(CLASS_NAME, "Element \"" + specItem[1] + "\" does not exist in base document.");
                                }
                            }
                            i++;
                            specList2 = specList;
                            str2 = str;
                            lineSpecPath2 = lineSpecPath;
                            lineSpec2 = lineSpec;
                            reader2 = reader;
                            c = 0;
                        }
                    }
                    replaceStatus = true;
                } catch (Exception e9) {
                    e = e9;
                    XmlUtil.log_e(e);
                    if (lineSpecFile.exists()) {
                    }
                    this.mAttrCache.clear();
                    return replaceStatus;
                }
                this.mAttrCache.clear();
            }
            return replaceStatus;
        }
        XmlUtil.log_d(CLASS_NAME, "replaceLineSpec", "lineSpecPath does not exist");
        return false;
    }

    private void swapNode(Document targetDocument, Node baseNode, Node subNode) {
        baseNode.getParentNode().replaceChild(cloneNode(targetDocument, (Element) subNode), baseNode);
    }

    private Node cloneNode(Document document, Element cloneTarget) {
        String[] attributes;
        Element newNode = document.createElement(cloneTarget.getNodeName());
        if (cloneTarget.hasAttributes() && (attributes = getAttributeNameSet(cloneTarget)) != null) {
            for (String attr : attributes) {
                newNode.setAttribute(attr, cloneTarget.getAttribute(attr));
            }
        }
        NodeList list = cloneTarget.getChildNodes();
        for (int i = 0; i < list.getLength(); i++) {
            if (list.item(i).getNodeType() == 1) {
                newNode.appendChild(cloneNode(document, (Element) list.item(i)));
            }
        }
        return newNode;
    }

    public static class ElementIdMismatchException extends RuntimeException {
        private static final long serialVersionUID = 5195850516633538384L;

        public ElementIdMismatchException() {
        }

        public ElementIdMismatchException(String detailMessage) {
            super(detailMessage);
        }
    }
}
