package egis.finger.host;

import android.util.Base64;
import android.util.Log;
import com.sec.factory.app.factorytest.FactoryTestManager;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.math.BigInteger;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.KeyFactory;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.spec.AlgorithmParameterSpec;
import java.security.spec.RSAPrivateKeySpec;
import java.security.spec.RSAPublicKeySpec;
import javax.crypto.BadPaddingException;
import javax.crypto.Cipher;
import javax.crypto.IllegalBlockSizeException;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;

public class CipherManager {
    private static final String PREFIX = "yu";
    private static final String TAG = "FpCsaClientLib_CipherManager";
    private CipherType cipherMode;
    private String mD;
    private String mE;
    private String mN;
    private SecretKeySpec mSecKey;
    private AlgorithmParameterSpec mSpec;

    public enum CipherType {
        AES,
        RSA
    }

    public CipherManager(CipherType cipherMode2) {
        this.cipherMode = cipherMode2;
    }

    public void init(byte[] keys, byte[] iv) {
        if (this.cipherMode == CipherType.AES) {
            this.mSecKey = new SecretKeySpec(keys, "AES");
            this.mSpec = new IvParameterSpec(iv);
        }
    }

    public void init(String mod, String pub, String sec2) {
        this.mN = mod;
        this.mE = pub;
        this.mD = sec2;
    }

    private byte[] extendKey(String key) {
        if (key == null) {
            Log.e(TAG, "extendKey key == null");
            FPNativeBase.lastErrCode = 2080;
            return null;
        }
        byte[] bKey = new byte[32];
        for (int i = 0; i < bKey.length; i++) {
            bKey[i] = FactoryTestManager.TEST_LOOPBACK_SPK;
        }
        byte[] bData = key.getBytes();
        int i2 = 0;
        while (i2 < key.length() && i2 < bKey.length) {
            bKey[i2] = bData[i2];
            i2++;
        }
        return bKey;
    }

    public boolean setKey(String key) {
        byte[] bKey = extendKey(key);
        if (bKey == null) {
            Log.e(TAG, "setKey bKey == null");
            FPNativeBase.lastErrCode = 2081;
            return false;
        }
        this.mSecKey = null;
        this.mSecKey = new SecretKeySpec(bKey, "AES");
        return true;
    }

    public byte[] encryption(String plaintext) {
        return encryption(plaintext.getBytes());
    }

    public byte[] encryption(byte[] plaintext) {
        if (plaintext == null) {
            Log.e(TAG, "encryption plaintext == null");
            FPNativeBase.lastErrCode = 2083;
            return null;
        }
        byte[] encryptedData = null;
        if (this.cipherMode == CipherType.AES) {
            try {
                Cipher cipher = Cipher.getInstance("AES/CBC/PKCS7Padding");
                cipher.init(1, this.mSecKey, this.mSpec);
                return cipher.doFinal(plaintext);
            } catch (NoSuchAlgorithmException e) {
                e.printStackTrace();
                return null;
            } catch (NoSuchPaddingException e2) {
                e2.printStackTrace();
                return null;
            } catch (InvalidKeyException e3) {
                e3.printStackTrace();
                return null;
            } catch (InvalidAlgorithmParameterException e4) {
                e4.printStackTrace();
                return null;
            } catch (IllegalBlockSizeException e5) {
                e5.printStackTrace();
                return null;
            } catch (BadPaddingException e6) {
                e6.printStackTrace();
                return null;
            }
        } else if (this.cipherMode != CipherType.RSA) {
            return null;
        } else {
            try {
                PublicKey pubKey = readPubKey();
                Cipher cipher2 = Cipher.getInstance("RSA");
                cipher2.init(1, pubKey);
                reverse(plaintext);
                encryptedData = cipher2.doFinal(plaintext);
                reverse(encryptedData);
                return encryptedData;
            } catch (IOException e7) {
                e7.printStackTrace();
                return encryptedData;
            } catch (NoSuchAlgorithmException e8) {
                e8.printStackTrace();
                return encryptedData;
            } catch (NoSuchPaddingException e9) {
                e9.printStackTrace();
                return encryptedData;
            } catch (InvalidKeyException e10) {
                e10.printStackTrace();
                return encryptedData;
            } catch (IllegalBlockSizeException e11) {
                e11.printStackTrace();
                return encryptedData;
            } catch (BadPaddingException e12) {
                e12.printStackTrace();
                return encryptedData;
            }
        }
    }

    public byte[] decryption(String ciphertext) {
        return decryption(ciphertext.getBytes());
    }

    public byte[] decryption(byte[] ciphertext) {
        if (ciphertext == null) {
            Log.e(TAG, "decryption data == null");
            FPNativeBase.lastErrCode = 2084;
            return null;
        }
        byte[] decryptedData = {FactoryTestManager.TEST_ID_DETECT_CHECK, FactoryTestManager.TEST_IDDETECT};
        if (this.cipherMode == CipherType.AES) {
            try {
                Cipher cipher = Cipher.getInstance("AES/CBC/PKCS7Padding");
                cipher.init(2, this.mSecKey, this.mSpec);
                return cipher.doFinal(ciphertext);
            } catch (NoSuchAlgorithmException e) {
                e.printStackTrace();
                return decryptedData;
            } catch (NoSuchPaddingException e2) {
                e2.printStackTrace();
                return decryptedData;
            } catch (InvalidKeyException e3) {
                e3.printStackTrace();
                return decryptedData;
            } catch (InvalidAlgorithmParameterException e4) {
                e4.printStackTrace();
                return decryptedData;
            } catch (IllegalBlockSizeException e5) {
                e5.printStackTrace();
                return decryptedData;
            } catch (BadPaddingException e6) {
                e6.printStackTrace();
                return decryptedData;
            }
        } else if (this.cipherMode != CipherType.RSA) {
            return decryptedData;
        } else {
            try {
                PrivateKey privKey = readPrivKey();
                Cipher cipher2 = Cipher.getInstance("RSA");
                cipher2.init(2, privKey);
                reverse(ciphertext);
                decryptedData = cipher2.doFinal(ciphertext);
                reverse(decryptedData);
                return decryptedData;
            } catch (IOException e7) {
                e7.printStackTrace();
                return decryptedData;
            } catch (NoSuchAlgorithmException e8) {
                e8.printStackTrace();
                return decryptedData;
            } catch (NoSuchPaddingException e9) {
                e9.printStackTrace();
                return decryptedData;
            } catch (InvalidKeyException e10) {
                e10.printStackTrace();
                return decryptedData;
            } catch (IllegalBlockSizeException e11) {
                e11.printStackTrace();
                return decryptedData;
            } catch (BadPaddingException e12) {
                e12.printStackTrace();
                return decryptedData;
            }
        }
    }

    private PublicKey readPubKey() throws IOException {
        try {
            return KeyFactory.getInstance("RSA").generatePublic(new RSAPublicKeySpec(new BigInteger(this.mN, 16), new BigInteger(this.mE, 16)));
        } catch (Exception e) {
            throw new RuntimeException("Spurious serialisation error", e);
        }
    }

    private PrivateKey readPrivKey() throws IOException {
        try {
            return KeyFactory.getInstance("RSA").generatePrivate(new RSAPrivateKeySpec(new BigInteger(this.mN, 16), new BigInteger(this.mD, 16)));
        } catch (Exception e) {
            throw new RuntimeException("Spurious serialisation error", e);
        }
    }

    private void reverse(byte[] array) {
        if (array != null) {
            int j = array.length - 1;
            for (int i = 0; j > i; i++) {
                byte tmp = array[j];
                array[j] = array[i];
                array[i] = tmp;
                j--;
            }
        }
    }

    public String packageData(String data) {
        return PREFIX + data;
    }

    public String unpackageData(String data) {
        if (!data.startsWith(PREFIX)) {
            return null;
        }
        return data.substring(PREFIX.length());
    }

    public String encryptData(String data) {
        if (data == null) {
            Log.e(TAG, "encryptData fail, data is null");
            FPNativeBase.lastErrCode = 2085;
            return null;
        }
        byte[] b = encryption(data);
        if (b != null) {
            return Base64.encodeToString(b, 0);
        }
        FPNativeBase.lastErrCode = 2086;
        return null;
    }

    public String decryptData(String data) {
        byte[] b = decryption(Base64.decode(data.getBytes(), 0));
        if (b == null) {
            FPNativeBase.lastErrCode = 2087;
            return null;
        }
        try {
            return new String(b, "UTF-8");
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
            return null;
        }
    }

    public boolean validateData(String data) {
        if (data == null || data.length() <= 0) {
            Log.e(TAG, "validateData invalid data");
            FPNativeBase.lastErrCode = 2088;
            return false;
        } else if (data.startsWith(PREFIX)) {
            return true;
        } else {
            return false;
        }
    }
}
