package egis.finger.host;

import android.util.Log;
import egis.finger.host.CipherManager;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectInputStream;
import java.io.ObjectOutput;
import java.io.ObjectOutputStream;
import java.io.StreamCorruptedException;
import java.util.ArrayList;
import java.util.List;

public class FileDB {
    private static final String TAG = "FpCsaClientLib_FileDB";
    private static final byte[] iv = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15};
    private static final byte[] key = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15};
    CipherManager cm;
    List<FingerData> mList = new ArrayList();

    public FileDB() {
        CipherManager cipherManager = new CipherManager(CipherManager.CipherType.AES);
        this.cm = cipherManager;
        cipherManager.init(key, iv);
    }

    public boolean add(String id, String feature) {
        if (id == null) {
            Log.e(TAG, "id == null");
            FPNativeBase.lastErrCode = 2013;
            return false;
        } else if (feature == null) {
            Log.e(TAG, "feature == null");
            FPNativeBase.lastErrCode = 2011;
            return false;
        } else if (id.length() <= 0) {
            Log.e(TAG, "id.length <= 0");
            FPNativeBase.lastErrCode = 2012;
            return false;
        } else if (feature.length() > 0) {
            return add(id, feature.getBytes());
        } else {
            Log.e(TAG, "feature.length <= 0");
            FPNativeBase.lastErrCode = 2010;
            return false;
        }
    }

    public boolean add(String id, byte[] feature) {
        if (feature == null) {
            Log.e(TAG, "feature == null");
            FPNativeBase.lastErrCode = 2011;
            return false;
        } else if (feature.length <= 0) {
            Log.e(TAG, "feature.length <= 0");
            FPNativeBase.lastErrCode = 2010;
            return false;
        } else {
            FingerData mFD = new FingerData(id, feature);
            int mRepIndex = this.mList.indexOf(mFD);
            if (mRepIndex == -1) {
                this.mList.add(mFD);
                return true;
            }
            this.mList.get(mRepIndex).setfeature(feature);
            return true;
        }
    }

    public boolean delete(String id) {
        if (id == null) {
            Log.e(TAG, "delete id == null");
            FPNativeBase.lastErrCode = 2013;
            return false;
        } else if (id.length() <= 0) {
            Log.e(TAG, "delete id length invalid");
            FPNativeBase.lastErrCode = 2012;
            return false;
        } else if (id.equals(new String("*"))) {
            this.mList.clear();
            return true;
        } else {
            int mDelIndex = this.mList.indexOf(new FingerData(id, null));
            if (mDelIndex == -1) {
                FPNativeBase.lastErrCode = 2014;
                return false;
            }
            this.mList.remove(mDelIndex);
            return true;
        }
    }

    public boolean update(String id, byte[] feature) {
        if (id == null) {
            Log.e(TAG, "id == null");
            FPNativeBase.lastErrCode = 2013;
            return false;
        } else if (feature == null) {
            Log.e(TAG, "feature == null");
            FPNativeBase.lastErrCode = 2011;
            return false;
        } else if (id.length() <= 0) {
            Log.e(TAG, "id.length <= 0");
            FPNativeBase.lastErrCode = 2012;
            return false;
        } else if (feature.length <= 0) {
            Log.e(TAG, "feature.length <= 0");
            FPNativeBase.lastErrCode = 2010;
            return false;
        } else {
            int mUpdateIndex = this.mList.indexOf(new FingerData(id, null));
            if (mUpdateIndex == -1) {
                FPNativeBase.lastErrCode = 2014;
                return false;
            }
            this.mList.get(mUpdateIndex).setfeature(feature);
            return true;
        }
    }

    private byte[] objtoByte(Object obj) {
        if (obj == null) {
            Log.e(TAG, "objtoByte obj == null");
            return null;
        }
        ByteArrayOutputStream bos = new ByteArrayOutputStream();
        ObjectOutput out = null;
        try {
            out = new ObjectOutputStream(bos);
            Log.e(TAG, "+++ before out.writeObject(obj) +++");
            out.writeObject(obj);
            Log.e(TAG, "+++ after out.writeObject(obj) +++");
            Log.e(TAG, "objtoByte obj == null");
            byte[] bytes = bos.toByteArray();
            try {
                out.close();
            } catch (IOException e) {
            }
            try {
                bos.close();
            } catch (IOException e2) {
            }
            return bytes;
        } catch (IOException e3) {
            e3.printStackTrace();
            if (out != null) {
                try {
                    out.close();
                } catch (IOException e4) {
                }
            }
            try {
                bos.close();
            } catch (IOException e5) {
            }
            return null;
        } catch (Throwable th) {
            if (out != null) {
                try {
                    out.close();
                } catch (IOException e6) {
                }
            }
            try {
                bos.close();
            } catch (IOException e7) {
            }
            throw th;
        }
    }

    private Object bytetoObj(byte[] data) {
        if (data == null) {
            Log.e(TAG, "delete data == null");
            FPNativeBase.lastErrCode = 2017;
            return false;
        } else if (data.length <= 0) {
            Log.e(TAG, "delete data length invalid");
            FPNativeBase.lastErrCode = 2016;
            return false;
        } else {
            ByteArrayInputStream bis = new ByteArrayInputStream(data);
            ObjectInput in = null;
            try {
                in = new ObjectInputStream(bis);
                Object o = in.readObject();
                try {
                    bis.close();
                } catch (IOException e) {
                }
                try {
                    in.close();
                } catch (IOException e2) {
                }
                return o;
            } catch (StreamCorruptedException e3) {
                e3.printStackTrace();
                try {
                    bis.close();
                } catch (IOException e4) {
                }
                if (in == null) {
                    return null;
                }
                in.close();
                return null;
            } catch (IOException e5) {
                e5.printStackTrace();
                try {
                    bis.close();
                } catch (IOException e6) {
                }
                if (in == null) {
                    return null;
                }
                in.close();
                return null;
            } catch (ClassNotFoundException e7) {
                e7.printStackTrace();
                try {
                    bis.close();
                } catch (IOException e8) {
                }
                if (in == null) {
                    return null;
                }
                try {
                    in.close();
                    return null;
                } catch (IOException e9) {
                    return null;
                }
            } catch (Throwable th) {
                try {
                    bis.close();
                } catch (IOException e10) {
                }
                if (in != null) {
                    try {
                        in.close();
                    } catch (IOException e11) {
                    }
                }
                throw th;
            }
        }
    }

    public boolean save(FileOutputStream fos) {
        Log.d(TAG, "save start");
        if (fos == null) {
            Log.e(TAG, "save file stream == null");
            FPNativeBase.lastErrCode = 2021;
            return false;
        }
        BufferedOutputStream oos = null;
        try {
            BufferedOutputStream oos2 = new BufferedOutputStream(fos);
            Log.d(TAG, "mList.size = " + this.mList.size());
            byte[] data = objtoByte(this.mList);
            if (data == null) {
                Log.e(TAG, "save data == null");
                FPNativeBase.lastErrCode = 2017;
                try {
                    oos2.close();
                    fos.close();
                } catch (IOException e1) {
                    e1.printStackTrace();
                }
                return false;
            }
            Log.d(TAG, "save data.length = " + data.length);
            byte[] outData = this.cm.encryption(data);
            if (outData == null) {
                Log.e(TAG, "save outData ==  null");
                FPNativeBase.lastErrCode = 2019;
                try {
                    oos2.close();
                    fos.close();
                } catch (IOException e12) {
                    e12.printStackTrace();
                }
                return false;
            }
            Log.d(TAG, "save outData.length = " + outData.length);
            oos2.write(outData);
            oos2.flush();
            fos.getFD().sync();
            oos2.close();
            fos.close();
            Log.d(TAG, "save success");
            try {
                oos2.close();
                fos.close();
            } catch (IOException e13) {
                e13.printStackTrace();
            }
            return true;
        } catch (IOException e) {
            e.printStackTrace();
            try {
                oos.close();
                fos.close();
            } catch (IOException e14) {
                e14.printStackTrace();
            }
            Log.d(TAG, "save fail");
            return false;
        } catch (Throwable th) {
            try {
                oos.close();
                fos.close();
            } catch (IOException e15) {
                e15.printStackTrace();
            }
            throw th;
        }
    }

    public boolean Load(FileInputStream fis) {
        Log.d(TAG, "Load start");
        if (fis == null) {
            Log.e(TAG, "Load file stream == null");
            FPNativeBase.lastErrCode = 2022;
            return false;
        }
        try {
            int mFisSize = fis.available();
            Log.d(TAG, "Load mFisSize = " + mFisSize);
            BufferedInputStream ois = null;
            if (mFisSize != 0) {
                try {
                    BufferedInputStream ois2 = new BufferedInputStream(fis);
                    Log.d(TAG, "Load ois.available() = " + ois2.available());
                    byte[] data = new byte[ois2.available()];
                    ois2.read(data);
                    byte[] inData = this.cm.decryption(data);
                    if (inData == null) {
                        Log.e(TAG, "Load inData == null");
                        FPNativeBase.lastErrCode = 2020;
                        try {
                            ois2.close();
                            fis.close();
                        } catch (IOException e1) {
                            e1.printStackTrace();
                        }
                        return false;
                    }
                    Log.d(TAG, "Load inData.length = " + inData.length);
                    this.mList = (ArrayList) bytetoObj(inData);
                    ois2.close();
                    fis.close();
                    Log.d(TAG, "Load succuess");
                    try {
                        ois2.close();
                        fis.close();
                    } catch (IOException e12) {
                        e12.printStackTrace();
                    }
                    return true;
                } catch (IOException e) {
                    e.printStackTrace();
                    try {
                        ois.close();
                        fis.close();
                    } catch (IOException e13) {
                        e13.printStackTrace();
                    }
                } catch (Throwable th) {
                    try {
                        ois.close();
                        fis.close();
                    } catch (IOException e14) {
                        e14.printStackTrace();
                    }
                    throw th;
                }
            }
            Log.d(TAG, "Load fail");
            return false;
        } catch (IOException e2) {
            e2.printStackTrace();
            FPNativeBase.lastErrCode = 2015;
            return false;
        }
    }

    public int size() {
        Log.d(TAG, "mFileDB.mList.size()");
        return this.mList.size();
    }

    public byte[] readFeature(int index) {
        return this.mList.get(index).mFeature;
    }

    public byte[] readFeature(String fid) {
        for (FingerData data : this.mList) {
            if (data.mID.equals(fid)) {
                return data.mFeature;
            }
        }
        return null;
    }

    public String readID(int index) {
        return this.mList.get(index).mID;
    }

    public int readID(String fid) {
        int idx = -1;
        for (FingerData f : this.mList) {
            idx++;
            if (f.getid().equals(fid)) {
                return idx;
            }
        }
        return idx;
    }

    public void clear() {
        this.mList.clear();
    }
}
