package egis.finger.host;

import android.content.Context;
import android.os.Handler;
import android.util.Log;
import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class FingerUtil {
    private static final String FEATURE_FILE = "Enroll_Data";
    private static final String FEATURE_FILE_BAK = "Enroll_Data_Bak";
    private static final String FEATURE_FILE_DEFAULT_ID = "Egistec_Company_Internal_Default_Data_1_id";
    private static final String FEATURE_FILE_DEFAULT_VAULE = "Egistec_Company_Internal_Default_Data_1_value";
    private static final String FEATURE_FILE_NEW = "Enroll_Data_New";
    protected static final String TAG = "FpCsaClientLib_FingerUtil";
    public static int[] fileDBMap;
    protected static Handler mApHandler;
    private static Context mContext;
    public byte[] mFeature = new byte[1024];
    public int mFeatureSize = 0;
    private FileDB mFileDB = null;

    public FingerUtil(Handler handle, Context context) {
        mApHandler = handle;
        mContext = context;
        this.mFileDB = new FileDB();
        if (!refreshList()) {
            Log.e(TAG, "onCreate load data from data fail, retry to use bak file");
            if (!recoveryDB()) {
                Log.e(TAG, "onCreate recoveryDB fail");
                if (!reInitDB()) {
                    Log.e(TAG, "reInitDB fail");
                    return;
                }
                return;
            }
            Log.d(TAG, "Try to refresh");
            if (!refreshList()) {
                Log.e(TAG, "onCreate still can not load data from DB");
            }
        }
    }

    public static void postFpResultStatus(int status) {
        Log.d(TAG, "postFpResultStatus status = " + status);
        mApHandler.obtainMessage(1000, status, -1).sendToTarget();
    }

    public boolean enrollToDB(String userID) {
        Log.d(TAG, "enrollToDB userID=" + userID);
        if (this.mFileDB == null) {
            Log.e(TAG, "enrollToDB FileDB==null");
            FPNativeBase.lastErrCode = 2030;
            return false;
        }
        byte[] bArr = this.mFeature;
        if (bArr == null) {
            Log.e(TAG, "mFeature == null");
            FPNativeBase.lastErrCode = 2034;
            return false;
        }
        if (!this.mFileDB.add(userID, (byte[]) bArr.clone())) {
            Log.e(TAG, "enrollToDB(): mFileDB.add() fail");
            postFpResultStatus(1002);
            return false;
        } else if (saveFeatureToFile()) {
            return true;
        } else {
            Log.e(TAG, "enrollToDB(): saveFeatureToFile() fail");
            postFpResultStatus(1002);
            return false;
        }
    }

    private boolean saveFeatureToFile() {
        Log.d(TAG, "svaeFeatureToFile");
        if (saveFeatureToFile(FEATURE_FILE_NEW)) {
            if (replaceDB()) {
                Log.d(TAG, "svaeFeatureToFile complete");
                return true;
            }
            Log.e(TAG, "svaeFeatureToFile replaceDB fail");
        }
        Log.e(TAG, "saveFeatureToFile fail, retry");
        if (saveFeatureToFile(FEATURE_FILE_NEW)) {
            if (replaceDB()) {
                Log.d(TAG, "svaeFeatureToFile complete");
                return true;
            }
            Log.e(TAG, "svaeFeatureToFile retry then replaceDB fail");
        }
        Log.e(TAG, "saveFeatureToFile still fail");
        return false;
    }

    private boolean saveFeatureToFile(String fileName) {
        checkFileLen(FEATURE_FILE);
        FileOutputStream fos = null;
        try {
            FileOutputStream fos2 = mContext.openFileOutput(fileName, 0);
            if (!this.mFileDB.save(fos2)) {
                Log.e(TAG, "saveFeature() mFileDB.Save() fail");
                if (fos2 != null) {
                    try {
                        fos2.close();
                    } catch (IOException e) {
                        Log.e(TAG, "saveFeature() fos.close() exception=" + e.getMessage());
                    }
                }
                Log.d(TAG, "svaeFeatureToFile end");
                return false;
            }
            Log.d(TAG, "svaeFeatureToFile success");
            if (fos2 != null) {
                try {
                    fos2.close();
                } catch (IOException e2) {
                    Log.e(TAG, "saveFeature() fos.close() exception=" + e2.getMessage());
                }
            }
            Log.d(TAG, "svaeFeatureToFile end");
            return true;
        } catch (FileNotFoundException e3) {
            Log.e(TAG, "saveFeature() exception=" + e3.getMessage());
            FPNativeBase.lastErrCode = 2044;
            if (0 != 0) {
                try {
                    fos.close();
                } catch (IOException e4) {
                    Log.e(TAG, "saveFeature() fos.close() exception=" + e4.getMessage());
                }
            }
            Log.d(TAG, "svaeFeatureToFile end");
            return false;
        } catch (Throwable th) {
            if (0 != 0) {
                try {
                    fos.close();
                } catch (IOException e5) {
                    Log.e(TAG, "saveFeature() fos.close() exception=" + e5.getMessage());
                }
            }
            Log.d(TAG, "svaeFeatureToFile end");
            throw th;
        }
    }

    private int checkFileLen(String fileName) {
        Log.d(TAG, "checkFileLen fileName = " + fileName);
        int len = 0;
        FileInputStream fis = null;
        BufferedInputStream ois = null;
        try {
            FileInputStream fis2 = mContext.openFileInput(fileName);
            if (fis2 != null) {
                Log.d(TAG, "checkDBLen fislen = " + fis2.available());
                ois = new BufferedInputStream(fis2);
                Log.d(TAG, "checkDBLen oislen = " + ois.available());
                len = ois.available();
            }
            if (fis2 != null) {
                try {
                    fis2.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            if (ois != null) {
                ois.close();
            }
        } catch (FileNotFoundException e2) {
            Log.e(TAG, "checkDBLen(): FileNotFoundException:" + e2.getMessage());
            e2.printStackTrace();
            if (0 != 0) {
                fis.close();
            }
            if (0 != 0) {
                ois.close();
            }
        } catch (IOException e3) {
            Log.e(TAG, "checkDBLen(): IOException:" + e3.getMessage());
            e3.printStackTrace();
            if (0 != 0) {
                fis.close();
            }
            if (0 != 0) {
                ois.close();
            }
        } catch (Throwable th) {
            if (0 != 0) {
                try {
                    fis.close();
                } catch (IOException e4) {
                    e4.printStackTrace();
                    throw th;
                }
            }
            if (0 != 0) {
                ois.close();
            }
            throw th;
        }
        Log.d(TAG, "checkFileLen len = " + len);
        return len;
    }

    private boolean replaceDB() {
        Log.d(TAG, "replaceDB");
        if (!checkFileState(FEATURE_FILE_NEW)) {
            Log.e(TAG, "replaceDB checkFileState fail Enroll_Data_New");
            return false;
        }
        File file_new = new File(getDBPath() + "/" + FEATURE_FILE_NEW);
        File file = new File(mContext.getFilesDir() + "/" + FEATURE_FILE);
        File file_bak = new File(getDBPath() + "/" + FEATURE_FILE_BAK);
        if (file_bak.exists() && !file_bak.delete()) {
            Log.e(TAG, "replaceDB delete file fail " + file_bak.getPath());
            FPNativeBase.lastErrCode = 2044;
        }
        if (!file.renameTo(file_bak)) {
            Log.e(TAG, "replaceDB rename file fail " + file.getPath() + " to " + file_bak.getPath());
        }
        if (file.exists() && !file.delete()) {
            Log.e(TAG, "replaceDB delete file fail " + file.getPath());
            FPNativeBase.lastErrCode = 2044;
        }
        if (file_new.renameTo(file)) {
            Log.d(TAG, "replaceDB complete");
            return true;
        }
        Log.e(TAG, "replaceDB rename file fail " + file_new.getPath() + " to " + file.getPath());
        FPNativeBase.lastErrCode = 2051;
        return false;
    }

    private boolean checkFileState(String fileName) {
        Log.d(TAG, "checkFileState fileName = " + fileName);
        if (checkFileLen(fileName) == 0) {
            Log.e(TAG, "   checkDBLen len == 0");
            FPNativeBase.lastErrCode = 2039;
            return false;
        } else if (getDBPath() == null) {
            Log.e(TAG, "checkDBState path == null");
            FPNativeBase.lastErrCode = 2040;
            return false;
        } else {
            String value = dataRead(FEATURE_FILE_DEFAULT_ID);
            if (value == null) {
                Log.e(TAG, "checkDBState dataRead error");
                return false;
            } else if (value.equals(FEATURE_FILE_DEFAULT_VAULE)) {
                Log.d(TAG, "checkDBState complete");
                return true;
            } else {
                Log.e(TAG, "checkDBState fail");
                FPNativeBase.lastErrCode = 2041;
                return false;
            }
        }
    }

    private String getDBPath() {
        if (mContext.getFilesDir() != null) {
            Log.d(TAG, "getDBPath()=" + mContext.getFilesDir().getAbsolutePath());
        } else {
            Log.e(TAG, "getDBPath()=null");
        }
        if (mContext.getFilesDir() != null) {
            return mContext.getFilesDir().getAbsolutePath();
        }
        return null;
    }

    public String dataRead(String id) {
        Log.d(TAG, "dataRead(): start, id=" + id);
        if (this.mFileDB == null) {
            Log.e(TAG, "dataRead(): FileDB is null");
            FPNativeBase.lastErrCode = 2030;
            return null;
        }
        int idx = -1;
        int i = 0;
        while (true) {
            try {
                if (i >= this.mFileDB.size()) {
                    break;
                } else if (this.mFileDB.readID(i).compareTo(id) == 0) {
                    idx = i;
                    break;
                } else {
                    i++;
                }
            } catch (Exception e) {
                Log.d(TAG, "search data from db file error");
                return null;
            }
        }
        if (idx != -1) {
            String data = new String(this.mFileDB.readFeature(idx), 0, this.mFileDB.readFeature(idx).length);
            Log.d(TAG, "data = " + data);
            return data;
        }
        Log.w(TAG, "data not found");
        FPNativeBase.lastErrCode = 2031;
        return null;
    }

    public boolean checkId(String id) {
        Log.d(TAG, "checkId(): start, id=" + id);
        if (this.mFileDB == null) {
            Log.e(TAG, "checkId(): FileDB is null");
            FPNativeBase.lastErrCode = 2030;
            return false;
        }
        int idx = -1;
        int i = 0;
        while (true) {
            try {
                if (i >= this.mFileDB.size()) {
                    break;
                }
                String temp = this.mFileDB.readID(i);
                int idLen = temp.indexOf(59);
                if (idLen != -1) {
                    if (temp.substring(0, idLen).compareTo(id.substring(0, id.indexOf(";"))) == 0) {
                        idx = i;
                        break;
                    }
                }
                i++;
            } catch (Exception e) {
                Log.d(TAG, "checkId search data from db file error");
                return false;
            }
        }
        if (idx != -1) {
            return true;
        }
        Log.w(TAG, "data not found");
        FPNativeBase.lastErrCode = 2031;
        return false;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:100:0x01da, code lost:
        r0 = th;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:63:0x015d, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:64:0x015e, code lost:
        r4 = "refreshList reInitDB fail";
        r3 = r9;
        r6 = "refreshList retry to load DB fail";
     */
    /* JADX WARNING: Code restructure failed: missing block: B:65:0x0165, code lost:
        r0 = th;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:66:0x0166, code lost:
        r4 = "refreshList reInitDB fail";
        r3 = r9;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:67:0x016c, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:68:0x016d, code lost:
        r4 = "refreshList reInitDB fail";
        r3 = r9;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:70:?, code lost:
        r0.printStackTrace();
        android.util.Log.e(egis.finger.host.FingerUtil.TAG, "refreshList retry to load DB fail");
        egis.finger.host.FPNativeBase.lastErrCode = 2052;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:71:0x017d, code lost:
        if (0 != 0) goto L_0x017f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:73:?, code lost:
        r2.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:74:0x0183, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:75:0x0184, code lost:
        r0.printStackTrace();
        android.util.Log.e(egis.finger.host.FingerUtil.TAG, "refreshList retry close DB fail");
        egis.finger.host.FPNativeBase.lastErrCode = 2052;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:76:0x018e, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:78:0x0193, code lost:
        if (checkFileState(egis.finger.host.FingerUtil.FEATURE_FILE) == false) goto L_0x0195;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:79:0x0195, code lost:
        android.util.Log.e(egis.finger.host.FingerUtil.TAG, r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:80:0x019c, code lost:
        if (reInitDB() == false) goto L_0x019e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:81:0x019e, code lost:
        android.util.Log.e(egis.finger.host.FingerUtil.TAG, r4);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:82:0x01a1, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:83:0x01a2, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:89:?, code lost:
        r2.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:90:0x01ba, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:91:0x01bb, code lost:
        r0.printStackTrace();
        android.util.Log.e(egis.finger.host.FingerUtil.TAG, "refreshList retry close DB fail");
        egis.finger.host.FPNativeBase.lastErrCode = 2052;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:92:0x01c5, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:95:0x01cc, code lost:
        android.util.Log.e(egis.finger.host.FingerUtil.TAG, r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:96:0x01d3, code lost:
        if (reInitDB() == false) goto L_0x01d5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:97:0x01d5, code lost:
        android.util.Log.e(egis.finger.host.FingerUtil.TAG, r4);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:98:0x01d8, code lost:
        return false;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:137:0x0283 A[SYNTHETIC, Splitter:B:137:0x0283] */
    /* JADX WARNING: Removed duplicated region for block: B:143:0x0295  */
    /* JADX WARNING: Removed duplicated region for block: B:226:0x03e7  */
    /* JADX WARNING: Removed duplicated region for block: B:228:0x03ed  */
    /* JADX WARNING: Removed duplicated region for block: B:552:0x08fa A[SYNTHETIC, Splitter:B:552:0x08fa] */
    /* JADX WARNING: Removed duplicated region for block: B:558:0x090e  */
    /* JADX WARNING: Removed duplicated region for block: B:641:0x0a59  */
    /* JADX WARNING: Removed duplicated region for block: B:643:0x0a5f  */
    /* JADX WARNING: Removed duplicated region for block: B:65:0x0165 A[ExcHandler: all (th java.lang.Throwable), Splitter:B:44:0x0120] */
    /* JADX WARNING: Removed duplicated region for block: B:67:0x016c A[ExcHandler: IOException (r0v210 'e' java.io.IOException A[CUSTOM_DECLARE]), Splitter:B:44:0x0120] */
    /* JADX WARNING: Removed duplicated region for block: B:88:0x01b6 A[SYNTHETIC, Splitter:B:88:0x01b6] */
    /* JADX WARNING: Removed duplicated region for block: B:95:0x01cc  */
    private boolean refreshList() {
        String str;
        String str2;
        String str3;
        String str4;
        Throwable th;
        FileInputStream fis2;
        String str5;
        Throwable th2;
        String str6;
        String str7;
        String str8;
        FileNotFoundException e;
        FileInputStream fis22;
        String str9;
        Throwable th3;
        FileInputStream fis23;
        String str10;
        Throwable th4;
        FileInputStream fis24;
        String str11;
        String str12;
        Throwable th5;
        String str13;
        String str14;
        String str15;
        String str16;
        IOException e2;
        FileInputStream fis25;
        String str17;
        String str18;
        Throwable th6;
        FileInputStream fis26;
        String str19;
        String str20;
        Throwable th7;
        String str21 = "refresshList bak file does not work, init all data";
        Log.d(TAG, "refreshList");
        if (!replaceNewDB()) {
            Log.e(TAG, "refreshList replaceNewDB fail");
            return false;
        }
        FileInputStream fis = null;
        try {
            FileInputStream fis3 = mContext.openFileInput(FEATURE_FILE);
            if (fis3 != null) {
                try {
                    this.mFileDB.Load(fis3);
                    Log.d(TAG, "refreshList mFileDB.Load(fis)");
                    fis3.close();
                } catch (FileNotFoundException e3) {
                    e = e3;
                    fis = fis3;
                    str6 = "refreshList saveFeatureToBakFile fail";
                    str7 = "refreshList retry to load DB fail";
                    str8 = "refreshList reInitDB fail";
                    str21 = str21;
                } catch (IOException e4) {
                    e2 = e4;
                    fis = fis3;
                    str14 = "refreshList saveFeatureToBakFile fail";
                    str13 = "refreshList saveFeatureToBakFile complete";
                    str15 = "refreshList retry to load DB fail";
                    str16 = "refreshList reInitDB fail";
                    str21 = str21;
                    try {
                        StringBuilder sb = new StringBuilder();
                        try {
                            sb.append("refreshList(): IOException:");
                            sb.append(e2.getMessage());
                            Log.e(TAG, sb.toString());
                            e2.printStackTrace();
                            FPNativeBase.lastErrCode = 2052;
                            if (fis != null) {
                            }
                            if (!checkFileState(FEATURE_FILE)) {
                            }
                            if (saveFeatureToBakFile()) {
                            }
                        } catch (Throwable th8) {
                            th = th8;
                            str21 = str21;
                        }
                    } catch (Throwable th9) {
                        th = th9;
                        str4 = str16;
                        str3 = str15;
                        str2 = str14;
                        str = str13;
                        if (fis != null) {
                        }
                        if (!checkFileState(FEATURE_FILE)) {
                        }
                        if (!saveFeatureToBakFile()) {
                        }
                    }
                } catch (Throwable th10) {
                    fis = fis3;
                    str2 = "refreshList saveFeatureToBakFile fail";
                    str = "refreshList saveFeatureToBakFile complete";
                    str3 = "refreshList retry to load DB fail";
                    str4 = "refreshList reInitDB fail";
                    str21 = str21;
                    th = th10;
                    if (fis != null) {
                    }
                    if (!checkFileState(FEATURE_FILE)) {
                    }
                    if (!saveFeatureToBakFile()) {
                    }
                }
            }
            try {
                Log.d(TAG, "refreshList load DB complete");
                if (fis3 != null) {
                    try {
                        fis3.close();
                    } catch (IOException e5) {
                        e5.printStackTrace();
                    }
                }
                if (!checkFileState(FEATURE_FILE)) {
                    File file = new File(FEATURE_FILE);
                    if (file.exists() && file.delete()) {
                        Log.e(TAG, "refreshList delete file fail " + file.getPath());
                    }
                    Log.e(TAG, "refreshList checkDBState fail, delete db and try to recovery");
                    if (!recoveryDB()) {
                        Log.e(TAG, "refreshList recoveryDB fail");
                        String path = getDBPath();
                        File file2 = new File(path + "/" + FEATURE_FILE);
                        if (file2.exists() && !file2.delete()) {
                            Log.e(TAG, "refreshList delete file error");
                        }
                        this.mFileDB.clear();
                        Log.e(TAG, "DB is cleared");
                        if (!dataSet(FEATURE_FILE_DEFAULT_ID, FEATURE_FILE_DEFAULT_VAULE)) {
                            Log.e(TAG, " Set default data fail");
                            return false;
                        }
                    } else {
                        fis26 = null;
                        try {
                            FileInputStream fis27 = mContext.openFileInput(FEATURE_FILE);
                            if (fis27 != null) {
                                this.mFileDB.Load(fis27);
                                Log.d(TAG, "refreshList mFileDB.Load(fis)");
                                fis27.close();
                            }
                            if (fis27 != null) {
                                try {
                                    fis27.close();
                                } catch (IOException e6) {
                                    e6.printStackTrace();
                                    Log.e(TAG, "refreshList retry close DB fail");
                                    FPNativeBase.lastErrCode = 2052;
                                    return false;
                                }
                            }
                            if (!checkFileState(FEATURE_FILE)) {
                                Log.e(TAG, str21);
                                if (!reInitDB()) {
                                    Log.e(TAG, "refreshList reInitDB fail");
                                    return false;
                                }
                            }
                        } catch (FileNotFoundException e7) {
                            FileNotFoundException e8 = e7;
                            String str22 = "refreshList retry to load DB fail";
                            String str23 = "refreshList reInitDB fail";
                            String str24 = str21;
                            e8.printStackTrace();
                            Log.e(TAG, str22);
                            FPNativeBase.lastErrCode = 2044;
                            if (0 != 0) {
                            }
                            if (!checkFileState(FEATURE_FILE)) {
                            }
                            return false;
                        } catch (IOException e9) {
                        } catch (Throwable th11) {
                        }
                    }
                }
                if (saveFeatureToBakFile()) {
                    Log.e(TAG, "refreshList saveFeatureToBakFile complete");
                    return true;
                }
                Log.e(TAG, "refreshList saveFeatureToBakFile fail");
                return true;
            } catch (FileNotFoundException e10) {
                e = e10;
                fis = fis3;
                str7 = "refreshList retry to load DB fail";
                str8 = "refreshList reInitDB fail";
                str21 = str21;
                str6 = "refreshList saveFeatureToBakFile fail";
            } catch (IOException e11) {
                e2 = e11;
                str14 = "refreshList saveFeatureToBakFile fail";
                str13 = "refreshList saveFeatureToBakFile complete";
                str15 = "refreshList retry to load DB fail";
                str16 = "refreshList reInitDB fail";
                str21 = str21;
                fis = fis3;
                StringBuilder sb2 = new StringBuilder();
                sb2.append("refreshList(): IOException:");
                sb2.append(e2.getMessage());
                Log.e(TAG, sb2.toString());
                e2.printStackTrace();
                FPNativeBase.lastErrCode = 2052;
                if (fis != null) {
                }
                if (!checkFileState(FEATURE_FILE)) {
                }
                if (saveFeatureToBakFile()) {
                }
            } catch (Throwable th12) {
                fis = fis3;
                str = "refreshList saveFeatureToBakFile complete";
                str3 = "refreshList retry to load DB fail";
                str4 = "refreshList reInitDB fail";
                str21 = str21;
                str2 = "refreshList saveFeatureToBakFile fail";
                th = th12;
                if (fis != null) {
                }
                if (!checkFileState(FEATURE_FILE)) {
                }
                if (!saveFeatureToBakFile()) {
                }
            }
        } catch (FileNotFoundException e12) {
            e = e12;
            str6 = "refreshList saveFeatureToBakFile fail";
            str7 = "refreshList retry to load DB fail";
            str8 = "refreshList reInitDB fail";
            try {
                StringBuilder sb3 = new StringBuilder();
                try {
                    sb3.append("refreshList(): FileNotFoundException:");
                    sb3.append(e.getMessage());
                    Log.e(TAG, sb3.toString());
                    e.printStackTrace();
                    if (recoveryDB()) {
                        try {
                            Log.d(TAG, " refreshList() recoveryDB  complete");
                            if (fis != null) {
                                try {
                                    fis.close();
                                } catch (IOException e13) {
                                    e13.printStackTrace();
                                }
                            }
                            if (!checkFileState(FEATURE_FILE)) {
                                File file3 = new File(FEATURE_FILE);
                                if (file3.exists() && file3.delete()) {
                                    Log.e(TAG, "refreshList delete file fail " + file3.getPath());
                                }
                                Log.e(TAG, "refreshList checkDBState fail, delete db and try to recovery");
                                if (!recoveryDB()) {
                                    Log.e(TAG, "refreshList recoveryDB fail");
                                    String path2 = getDBPath();
                                    File file22 = new File(path2 + "/" + FEATURE_FILE);
                                    if (file22.exists() && !file22.delete()) {
                                        Log.e(TAG, "refreshList delete file error");
                                    }
                                    this.mFileDB.clear();
                                    Log.e(TAG, "DB is cleared");
                                    if (!dataSet(FEATURE_FILE_DEFAULT_ID, FEATURE_FILE_DEFAULT_VAULE)) {
                                        Log.e(TAG, " Set default data fail");
                                        return false;
                                    }
                                } else {
                                    fis24 = null;
                                    try {
                                        FileInputStream fis28 = mContext.openFileInput(FEATURE_FILE);
                                        if (fis28 != null) {
                                            this.mFileDB.Load(fis28);
                                            Log.d(TAG, "refreshList mFileDB.Load(fis)");
                                            fis28.close();
                                        }
                                        if (fis28 != null) {
                                            try {
                                                fis28.close();
                                            } catch (IOException e14) {
                                                e14.printStackTrace();
                                                Log.e(TAG, "refreshList retry close DB fail");
                                                FPNativeBase.lastErrCode = 2052;
                                                return false;
                                            }
                                        }
                                        if (!checkFileState(FEATURE_FILE)) {
                                            Log.e(TAG, str21);
                                            if (!reInitDB()) {
                                                Log.e(TAG, str8);
                                                return false;
                                            }
                                        }
                                    } catch (FileNotFoundException e15) {
                                        e15.printStackTrace();
                                        Log.e(TAG, str7);
                                        FPNativeBase.lastErrCode = 2044;
                                        if (0 != 0) {
                                            try {
                                                fis24.close();
                                            } catch (IOException e16) {
                                                e16.printStackTrace();
                                                Log.e(TAG, "refreshList retry close DB fail");
                                                FPNativeBase.lastErrCode = 2052;
                                                return false;
                                            }
                                        }
                                        if (!checkFileState(FEATURE_FILE)) {
                                            Log.e(TAG, str21);
                                            if (!reInitDB()) {
                                                Log.e(TAG, str8);
                                                return false;
                                            }
                                        }
                                        return false;
                                    } catch (IOException e17) {
                                        str12 = str21;
                                        str11 = str8;
                                        e17.printStackTrace();
                                        Log.e(TAG, str7);
                                        FPNativeBase.lastErrCode = 2052;
                                        if (0 != 0) {
                                            try {
                                                fis24.close();
                                            } catch (IOException e18) {
                                                e18.printStackTrace();
                                                Log.e(TAG, "refreshList retry close DB fail");
                                                FPNativeBase.lastErrCode = 2052;
                                                return false;
                                            }
                                        }
                                        if (!checkFileState(FEATURE_FILE)) {
                                            Log.e(TAG, str12);
                                            if (!reInitDB()) {
                                                Log.e(TAG, str11);
                                                return false;
                                            }
                                        }
                                        return false;
                                    } catch (Throwable th13) {
                                        th5 = th13;
                                    }
                                }
                            }
                            if (saveFeatureToBakFile()) {
                                Log.e(TAG, "refreshList saveFeatureToBakFile complete");
                                return true;
                            }
                            Log.e(TAG, str6);
                            return true;
                        } catch (Throwable th14) {
                            str21 = str21;
                            th = th14;
                            str = "refreshList saveFeatureToBakFile complete";
                            str4 = str8;
                            str3 = str7;
                            str2 = str6;
                        }
                    } else {
                        str21 = str21;
                        try {
                            if (dataSet(FEATURE_FILE_DEFAULT_ID, FEATURE_FILE_DEFAULT_VAULE)) {
                                try {
                                    Log.d(TAG, "refreshList init default data complete");
                                    if (fis != null) {
                                        try {
                                            fis.close();
                                        } catch (IOException e19) {
                                            e19.printStackTrace();
                                        }
                                    }
                                    if (!checkFileState(FEATURE_FILE)) {
                                        File file4 = new File(FEATURE_FILE);
                                        if (file4.exists() && file4.delete()) {
                                            Log.e(TAG, "refreshList delete file fail " + file4.getPath());
                                        }
                                        Log.e(TAG, "refreshList checkDBState fail, delete db and try to recovery");
                                        if (!recoveryDB()) {
                                            Log.e(TAG, "refreshList recoveryDB fail");
                                            String path3 = getDBPath();
                                            File file23 = new File(path3 + "/" + FEATURE_FILE);
                                            if (file23.exists() && !file23.delete()) {
                                                Log.e(TAG, "refreshList delete file error");
                                            }
                                            this.mFileDB.clear();
                                            Log.e(TAG, "DB is cleared");
                                            if (!dataSet(FEATURE_FILE_DEFAULT_ID, FEATURE_FILE_DEFAULT_VAULE)) {
                                                Log.e(TAG, " Set default data fail");
                                                return false;
                                            }
                                        } else {
                                            fis23 = null;
                                            try {
                                                FileInputStream fis29 = mContext.openFileInput(FEATURE_FILE);
                                                if (fis29 != null) {
                                                    this.mFileDB.Load(fis29);
                                                    Log.d(TAG, "refreshList mFileDB.Load(fis)");
                                                    fis29.close();
                                                }
                                                if (fis29 != null) {
                                                    try {
                                                        fis29.close();
                                                    } catch (IOException e20) {
                                                        e20.printStackTrace();
                                                        Log.e(TAG, "refreshList retry close DB fail");
                                                        FPNativeBase.lastErrCode = 2052;
                                                        return false;
                                                    }
                                                }
                                                if (!checkFileState(FEATURE_FILE)) {
                                                    Log.e(TAG, str21);
                                                    if (!reInitDB()) {
                                                        Log.e(TAG, str8);
                                                        return false;
                                                    }
                                                }
                                            } catch (FileNotFoundException e21) {
                                                e21.printStackTrace();
                                                Log.e(TAG, str7);
                                                FPNativeBase.lastErrCode = 2044;
                                                if (0 != 0) {
                                                    try {
                                                        fis23.close();
                                                    } catch (IOException e22) {
                                                        e22.printStackTrace();
                                                        Log.e(TAG, "refreshList retry close DB fail");
                                                        FPNativeBase.lastErrCode = 2052;
                                                        return false;
                                                    }
                                                }
                                                if (!checkFileState(FEATURE_FILE)) {
                                                    Log.e(TAG, str21);
                                                    if (!reInitDB()) {
                                                        Log.e(TAG, str8);
                                                        return false;
                                                    }
                                                }
                                                return false;
                                            } catch (IOException e23) {
                                                str10 = str8;
                                                e23.printStackTrace();
                                                Log.e(TAG, str7);
                                                FPNativeBase.lastErrCode = 2052;
                                                if (0 != 0) {
                                                    try {
                                                        fis23.close();
                                                    } catch (IOException e24) {
                                                        e24.printStackTrace();
                                                        Log.e(TAG, "refreshList retry close DB fail");
                                                        FPNativeBase.lastErrCode = 2052;
                                                        return false;
                                                    }
                                                }
                                                if (!checkFileState(FEATURE_FILE)) {
                                                    Log.e(TAG, str21);
                                                    if (!reInitDB()) {
                                                        Log.e(TAG, str10);
                                                        return false;
                                                    }
                                                }
                                                return false;
                                            } catch (Throwable th15) {
                                                th4 = th15;
                                            }
                                        }
                                    }
                                    if (saveFeatureToBakFile()) {
                                        Log.e(TAG, "refreshList saveFeatureToBakFile complete");
                                        return true;
                                    }
                                    Log.e(TAG, str6);
                                    return true;
                                } catch (Throwable th16) {
                                    th = th16;
                                    str = "refreshList saveFeatureToBakFile complete";
                                    str4 = str8;
                                    str3 = str7;
                                    str2 = str6;
                                }
                            } else {
                                try {
                                    Log.e(TAG, "refreshList file not found, fail to recovertDB and dataSet");
                                    if (fis != null) {
                                        try {
                                            fis.close();
                                        } catch (IOException e25) {
                                            e25.printStackTrace();
                                        }
                                    }
                                    if (!checkFileState(FEATURE_FILE)) {
                                        File file5 = new File(FEATURE_FILE);
                                        if (file5.exists() && file5.delete()) {
                                            Log.e(TAG, "refreshList delete file fail " + file5.getPath());
                                        }
                                        Log.e(TAG, "refreshList checkDBState fail, delete db and try to recovery");
                                        if (!recoveryDB()) {
                                            Log.e(TAG, "refreshList recoveryDB fail");
                                            String path4 = getDBPath();
                                            File file24 = new File(path4 + "/" + FEATURE_FILE);
                                            if (file24.exists() && !file24.delete()) {
                                                Log.e(TAG, "refreshList delete file error");
                                            }
                                            this.mFileDB.clear();
                                            Log.e(TAG, "DB is cleared");
                                            if (!dataSet(FEATURE_FILE_DEFAULT_ID, FEATURE_FILE_DEFAULT_VAULE)) {
                                                Log.e(TAG, " Set default data fail");
                                                return false;
                                            }
                                        } else {
                                            fis22 = null;
                                            try {
                                                FileInputStream fis210 = mContext.openFileInput(FEATURE_FILE);
                                                if (fis210 != null) {
                                                    this.mFileDB.Load(fis210);
                                                    Log.d(TAG, "refreshList mFileDB.Load(fis)");
                                                    fis210.close();
                                                }
                                                if (fis210 != null) {
                                                    try {
                                                        fis210.close();
                                                    } catch (IOException e26) {
                                                        e26.printStackTrace();
                                                        Log.e(TAG, "refreshList retry close DB fail");
                                                        FPNativeBase.lastErrCode = 2052;
                                                        return false;
                                                    }
                                                }
                                                if (!checkFileState(FEATURE_FILE)) {
                                                    Log.e(TAG, str21);
                                                    if (!reInitDB()) {
                                                        Log.e(TAG, str8);
                                                        return false;
                                                    }
                                                }
                                            } catch (FileNotFoundException e27) {
                                                e27.printStackTrace();
                                                Log.e(TAG, str7);
                                                FPNativeBase.lastErrCode = 2044;
                                                if (0 != 0) {
                                                    try {
                                                        fis22.close();
                                                    } catch (IOException e28) {
                                                        e28.printStackTrace();
                                                        Log.e(TAG, "refreshList retry close DB fail");
                                                        FPNativeBase.lastErrCode = 2052;
                                                        return false;
                                                    }
                                                }
                                                if (!checkFileState(FEATURE_FILE)) {
                                                    Log.e(TAG, str21);
                                                    if (!reInitDB()) {
                                                        Log.e(TAG, str8);
                                                        return false;
                                                    }
                                                }
                                                return false;
                                            } catch (IOException e29) {
                                                str9 = str8;
                                                e29.printStackTrace();
                                                Log.e(TAG, str7);
                                                FPNativeBase.lastErrCode = 2052;
                                                if (0 != 0) {
                                                    try {
                                                        fis22.close();
                                                    } catch (IOException e30) {
                                                        e30.printStackTrace();
                                                        Log.e(TAG, "refreshList retry close DB fail");
                                                        FPNativeBase.lastErrCode = 2052;
                                                        return false;
                                                    }
                                                }
                                                if (!checkFileState(FEATURE_FILE)) {
                                                    Log.e(TAG, str21);
                                                    if (!reInitDB()) {
                                                        Log.e(TAG, str9);
                                                        return false;
                                                    }
                                                }
                                                return false;
                                            } catch (Throwable th17) {
                                                th3 = th17;
                                            }
                                        }
                                    }
                                    if (saveFeatureToBakFile()) {
                                        Log.e(TAG, "refreshList saveFeatureToBakFile complete");
                                        return true;
                                    }
                                    Log.e(TAG, str6);
                                    Log.e(TAG, "refreshList fail");
                                    return false;
                                } catch (Throwable th18) {
                                    str4 = str8;
                                    str3 = str7;
                                    str2 = str6;
                                    str = "refreshList saveFeatureToBakFile complete";
                                    th = th18;
                                    if (fis != null) {
                                    }
                                    if (!checkFileState(FEATURE_FILE)) {
                                    }
                                    if (!saveFeatureToBakFile()) {
                                    }
                                }
                            }
                        } catch (Throwable th19) {
                            str = "refreshList saveFeatureToBakFile complete";
                            str4 = str8;
                            str3 = str7;
                            str2 = str6;
                            th = th19;
                            if (fis != null) {
                            }
                            if (!checkFileState(FEATURE_FILE)) {
                            }
                            if (!saveFeatureToBakFile()) {
                            }
                        }
                    }
                } catch (Throwable th20) {
                    str = "refreshList saveFeatureToBakFile complete";
                    str21 = str21;
                    str4 = str8;
                    str3 = str7;
                    str2 = str6;
                    th = th20;
                    if (fis != null) {
                    }
                    if (!checkFileState(FEATURE_FILE)) {
                    }
                    if (!saveFeatureToBakFile()) {
                    }
                }
            } catch (Throwable th21) {
                str = "refreshList saveFeatureToBakFile complete";
                str4 = str8;
                str3 = str7;
                str2 = str6;
                th = th21;
                if (fis != null) {
                    try {
                        fis.close();
                    } catch (IOException e31) {
                        e31.printStackTrace();
                    }
                }
                if (!checkFileState(FEATURE_FILE)) {
                    File file6 = new File(FEATURE_FILE);
                    if (file6.exists() && file6.delete()) {
                        Log.e(TAG, "refreshList delete file fail " + file6.getPath());
                    }
                    Log.e(TAG, "refreshList checkDBState fail, delete db and try to recovery");
                    if (!recoveryDB()) {
                        Log.e(TAG, "refreshList recoveryDB fail");
                        String path5 = getDBPath();
                        File file25 = new File(path5 + "/" + FEATURE_FILE);
                        if (file25.exists() && !file25.delete()) {
                            Log.e(TAG, "refreshList delete file error");
                        }
                        this.mFileDB.clear();
                        Log.e(TAG, "DB is cleared");
                        if (!dataSet(FEATURE_FILE_DEFAULT_ID, FEATURE_FILE_DEFAULT_VAULE)) {
                            Log.e(TAG, " Set default data fail");
                            return false;
                        }
                    } else {
                        fis2 = null;
                        try {
                            FileInputStream fis211 = mContext.openFileInput(FEATURE_FILE);
                            if (fis211 != null) {
                                this.mFileDB.Load(fis211);
                                Log.d(TAG, "refreshList mFileDB.Load(fis)");
                                fis211.close();
                            }
                            if (fis211 != null) {
                                try {
                                    fis211.close();
                                } catch (IOException e32) {
                                    e32.printStackTrace();
                                    Log.e(TAG, "refreshList retry close DB fail");
                                    FPNativeBase.lastErrCode = 2052;
                                    return false;
                                }
                            }
                            if (!checkFileState(FEATURE_FILE)) {
                                Log.e(TAG, str21);
                                if (!reInitDB()) {
                                    Log.e(TAG, str4);
                                    return false;
                                }
                            }
                        } catch (FileNotFoundException e33) {
                            e33.printStackTrace();
                            Log.e(TAG, str3);
                            FPNativeBase.lastErrCode = 2044;
                            if (0 != 0) {
                                try {
                                    fis2.close();
                                } catch (IOException e34) {
                                    e34.printStackTrace();
                                    Log.e(TAG, "refreshList retry close DB fail");
                                    FPNativeBase.lastErrCode = 2052;
                                    return false;
                                }
                            }
                            if (!checkFileState(FEATURE_FILE)) {
                                Log.e(TAG, str21);
                                if (!reInitDB()) {
                                    Log.e(TAG, str4);
                                    return false;
                                }
                            }
                            return false;
                        } catch (IOException e35) {
                            str5 = str4;
                            e35.printStackTrace();
                            Log.e(TAG, str3);
                            FPNativeBase.lastErrCode = 2052;
                            if (0 != 0) {
                                try {
                                    fis2.close();
                                } catch (IOException e36) {
                                    e36.printStackTrace();
                                    Log.e(TAG, "refreshList retry close DB fail");
                                    FPNativeBase.lastErrCode = 2052;
                                    return false;
                                }
                            }
                            if (!checkFileState(FEATURE_FILE)) {
                                Log.e(TAG, str21);
                                if (!reInitDB()) {
                                    Log.e(TAG, str5);
                                    return false;
                                }
                            }
                            return false;
                        } catch (Throwable th22) {
                            th2 = th22;
                        }
                    }
                }
                if (!saveFeatureToBakFile()) {
                    Log.e(TAG, str);
                    return true;
                }
                Log.e(TAG, str2);
                throw th;
            }
        } catch (IOException e37) {
            e2 = e37;
            str14 = "refreshList saveFeatureToBakFile fail";
            str13 = "refreshList saveFeatureToBakFile complete";
            str15 = "refreshList retry to load DB fail";
            str16 = "refreshList reInitDB fail";
            StringBuilder sb22 = new StringBuilder();
            sb22.append("refreshList(): IOException:");
            sb22.append(e2.getMessage());
            Log.e(TAG, sb22.toString());
            e2.printStackTrace();
            FPNativeBase.lastErrCode = 2052;
            if (fis != null) {
                try {
                    fis.close();
                } catch (IOException e38) {
                    e38.printStackTrace();
                }
            }
            if (!checkFileState(FEATURE_FILE)) {
                File file7 = new File(FEATURE_FILE);
                if (file7.exists() && file7.delete()) {
                    Log.e(TAG, "refreshList delete file fail " + file7.getPath());
                }
                Log.e(TAG, "refreshList checkDBState fail, delete db and try to recovery");
                if (!recoveryDB()) {
                    Log.e(TAG, "refreshList recoveryDB fail");
                    String path6 = getDBPath();
                    File file26 = new File(path6 + "/" + FEATURE_FILE);
                    if (file26.exists() && !file26.delete()) {
                        Log.e(TAG, "refreshList delete file error");
                    }
                    this.mFileDB.clear();
                    Log.e(TAG, "DB is cleared");
                    if (!dataSet(FEATURE_FILE_DEFAULT_ID, FEATURE_FILE_DEFAULT_VAULE)) {
                        Log.e(TAG, " Set default data fail");
                        return false;
                    }
                } else {
                    fis25 = null;
                    try {
                        FileInputStream fis212 = mContext.openFileInput(FEATURE_FILE);
                        if (fis212 != null) {
                            this.mFileDB.Load(fis212);
                            Log.d(TAG, "refreshList mFileDB.Load(fis)");
                            fis212.close();
                        }
                        if (fis212 != null) {
                            try {
                                fis212.close();
                            } catch (IOException e39) {
                                e39.printStackTrace();
                                Log.e(TAG, "refreshList retry close DB fail");
                                FPNativeBase.lastErrCode = 2052;
                                return false;
                            }
                        }
                        if (!checkFileState(FEATURE_FILE)) {
                            Log.e(TAG, str21);
                            if (!reInitDB()) {
                                Log.e(TAG, str16);
                                return false;
                            }
                        }
                    } catch (FileNotFoundException e40) {
                        e40.printStackTrace();
                        Log.e(TAG, str15);
                        FPNativeBase.lastErrCode = 2044;
                        if (0 != 0) {
                            try {
                                fis25.close();
                            } catch (IOException e41) {
                                e41.printStackTrace();
                                Log.e(TAG, "refreshList retry close DB fail");
                                FPNativeBase.lastErrCode = 2052;
                                return false;
                            }
                        }
                        if (!checkFileState(FEATURE_FILE)) {
                            Log.e(TAG, str21);
                            if (!reInitDB()) {
                                Log.e(TAG, str16);
                                return false;
                            }
                        }
                        return false;
                    } catch (IOException e42) {
                        str18 = str21;
                        str17 = str16;
                        e42.printStackTrace();
                        Log.e(TAG, str15);
                        FPNativeBase.lastErrCode = 2052;
                        if (0 != 0) {
                            try {
                                fis25.close();
                            } catch (IOException e43) {
                                e43.printStackTrace();
                                Log.e(TAG, "refreshList retry close DB fail");
                                FPNativeBase.lastErrCode = 2052;
                                return false;
                            }
                        }
                        if (!checkFileState(FEATURE_FILE)) {
                            Log.e(TAG, str18);
                            if (!reInitDB()) {
                                Log.e(TAG, str17);
                                return false;
                            }
                        }
                        return false;
                    } catch (Throwable th23) {
                        th6 = th23;
                    }
                }
            }
            if (saveFeatureToBakFile()) {
                Log.e(TAG, str13);
                return true;
            }
            Log.e(TAG, str14);
            return false;
        } catch (Throwable th24) {
            str2 = "refreshList saveFeatureToBakFile fail";
            str = "refreshList saveFeatureToBakFile complete";
            str3 = "refreshList retry to load DB fail";
            str4 = "refreshList reInitDB fail";
            th = th24;
            if (fis != null) {
            }
            if (!checkFileState(FEATURE_FILE)) {
            }
            if (!saveFeatureToBakFile()) {
            }
        }
        if (0 != 0) {
            try {
                fis23.close();
            } catch (IOException e44) {
                e44.printStackTrace();
                Log.e(TAG, "refreshList retry close DB fail");
                FPNativeBase.lastErrCode = 2052;
                return false;
            }
        }
        if (!checkFileState(FEATURE_FILE)) {
            Log.e(TAG, str21);
            if (!reInitDB()) {
                Log.e(TAG, str10);
                return false;
            }
        }
        throw th4;
        if (0 != 0) {
            try {
                fis22.close();
            } catch (IOException e45) {
                e45.printStackTrace();
                Log.e(TAG, "refreshList retry close DB fail");
                FPNativeBase.lastErrCode = 2052;
                return false;
            }
        }
        if (!checkFileState(FEATURE_FILE)) {
            Log.e(TAG, str21);
            if (!reInitDB()) {
                Log.e(TAG, str9);
                return false;
            }
        }
        throw th3;
        if (0 != 0) {
            try {
                fis2.close();
            } catch (IOException e46) {
                e46.printStackTrace();
                Log.e(TAG, "refreshList retry close DB fail");
                FPNativeBase.lastErrCode = 2052;
                return false;
            }
        }
        if (!checkFileState(FEATURE_FILE)) {
            Log.e(TAG, str21);
            if (!reInitDB()) {
                Log.e(TAG, str5);
                return false;
            }
        }
        throw th2;
        if (0 != 0) {
            try {
                fis24.close();
            } catch (IOException e47) {
                e47.printStackTrace();
                Log.e(TAG, "refreshList retry close DB fail");
                FPNativeBase.lastErrCode = 2052;
                return false;
            }
        }
        if (!checkFileState(FEATURE_FILE)) {
            Log.e(TAG, str12);
            if (!reInitDB()) {
                Log.e(TAG, str11);
                return false;
            }
        }
        throw th5;
        if (0 != 0) {
            try {
                fis26.close();
            } catch (IOException e48) {
                e48.printStackTrace();
                Log.e(TAG, "refreshList retry close DB fail");
                FPNativeBase.lastErrCode = 2052;
                return false;
            }
        }
        if (!checkFileState(FEATURE_FILE)) {
            Log.e(TAG, str20);
            if (!reInitDB()) {
                Log.e(TAG, str19);
                return false;
            }
        }
        throw th7;
        if (0 != 0) {
            try {
                fis25.close();
            } catch (IOException e49) {
                e49.printStackTrace();
                Log.e(TAG, "refreshList retry close DB fail");
                FPNativeBase.lastErrCode = 2052;
                return false;
            }
        }
        if (!checkFileState(FEATURE_FILE)) {
            Log.e(TAG, str18);
            if (!reInitDB()) {
                Log.e(TAG, str17);
                return false;
            }
        }
        throw th6;
    }

    private boolean recoveryDB() {
        Log.d(TAG, "recoveryDB");
        File file = new File(getDBPath() + "/" + FEATURE_FILE);
        File file_bak = new File(getDBPath() + "/" + FEATURE_FILE_BAK);
        if (!file_bak.exists()) {
            Log.e(TAG, "Backup DB file does not exist");
            FPNativeBase.lastErrCode = 2048;
            return false;
        } else if (file_bak.renameTo(file)) {
            Log.d(TAG, "recoveryDB complete");
            return true;
        } else {
            Log.e(TAG, "rename file faile " + file.getPath() + " to " + file_bak.getPath());
            FPNativeBase.lastErrCode = 2051;
            return false;
        }
    }

    private boolean reInitDB() {
        Log.d(TAG, "reInitDB");
        File file_new = new File(getDBPath() + "/" + FEATURE_FILE_NEW);
        File file = new File(mContext.getFilesDir() + "/" + FEATURE_FILE);
        File file_bak = new File(getDBPath() + "/" + FEATURE_FILE_BAK);
        file_new.delete();
        file.delete();
        file_bak.delete();
        if (dataSet(FEATURE_FILE_DEFAULT_ID, FEATURE_FILE_DEFAULT_VAULE)) {
            Log.d(TAG, " onCreate init default data complete");
            return true;
        }
        Log.d(TAG, "reInitDB fail");
        return false;
    }

    private boolean replaceNewDB() {
        Log.d(TAG, "replaceNewDB");
        File file_new = new File(getDBPath() + "/" + FEATURE_FILE_NEW);
        if (file_new.exists()) {
            Log.e(TAG, "replaceNewDB DB new file exists, replace current DB");
            File file = new File(getDBPath() + "/" + FEATURE_FILE);
            if (file.exists() && !file.delete()) {
                Log.e(TAG, "replaceNewDB delete file fail " + file.getPath());
            }
            if (!file_new.renameTo(file)) {
                Log.e(TAG, "replaceNewDB rename fail " + file_new.getPath() + " to " + file.getPath());
                FPNativeBase.lastErrCode = 2051;
                return false;
            }
            Log.d(TAG, "replaceNewDB complete");
            return true;
        }
        Log.d(TAG, "replaceNewDB new file does not exist");
        return true;
    }

    public boolean dataSet(String id, String value) {
        Log.d(TAG, "dataSet id=" + id + "value=" + value);
        if (!this.mFileDB.add(id, value)) {
            Log.e(TAG, "dataSet(): mFileDB.add() fail");
            return false;
        } else if (saveFeatureToFile()) {
            return true;
        } else {
            Log.e(TAG, "dataSet(): saveFeatureToFile() fail");
            return false;
        }
    }

    private boolean saveFeatureToBakFile() {
        Log.d(TAG, "svaeFeatureToBakFile");
        if (saveFeatureToFile(FEATURE_FILE_BAK)) {
            Log.d(TAG, "svaeFeatureToBakFile complete");
            return true;
        }
        Log.e(TAG, "saveFeatureToBakFile fail, retry");
        if (saveFeatureToFile(FEATURE_FILE_BAK)) {
            Log.d(TAG, "svaeFeatureToBakFile complete");
            return true;
        }
        Log.e(TAG, "saveFeatureToBakFile still fail");
        return false;
    }

    public byte[][] getAllFeature(String IdentifyUserId) {
        int size = 0;
        for (int i = 0; i < this.mFileDB.size(); i++) {
            String fid = this.mFileDB.readID(i);
            if (fid.startsWith("*") && fid.substring(1, fid.indexOf(";")).equals(IdentifyUserId)) {
                size++;
            }
        }
        int index = 0;
        byte[][] allFeature = new byte[size][];
        fileDBMap = new int[size];
        for (int i2 = 0; i2 < this.mFileDB.size(); i2++) {
            String fid2 = this.mFileDB.readID(i2);
            if (fid2.startsWith("*") && fid2.substring(1, fid2.indexOf(";")).equals(IdentifyUserId)) {
                Log.d(TAG, "getAllFeature() fid=" + fid2);
                allFeature[index] = new byte[this.mFileDB.readFeature(i2).length];
                allFeature[index] = this.mFileDB.readFeature(i2);
                fileDBMap[index] = i2;
                index++;
            }
        }
        return allFeature;
    }

    public String getMatchedID(int matchIdx) {
        Log.d(TAG, "+++++ getMatchedID matchIdx = " + matchIdx + " +++++");
        String data = this.mFileDB.readID(matchIdx).substring(1);
        Log.d(TAG, "data = " + data);
        return data;
    }

    public String getEnrollListFromDB(String userID) {
        String fid;
        Log.d(TAG, "getEnrollListFromDB=" + userID);
        String enrollList = null;
        for (int i = 0; i < this.mFileDB.size(); i++) {
            String fid2 = this.mFileDB.readID(i);
            Log.d(TAG, "fid=" + fid2);
            if (!userID.equals(new String("*"))) {
                if (fid2.startsWith("*")) {
                    Log.d(TAG, "in startsWith() fid=" + fid2);
                    String dbUserId = fid2.substring(0, fid2.indexOf(";"));
                    Log.d(TAG, "dbUserId=" + dbUserId);
                    if (userID.equals(dbUserId)) {
                        fid = fid2.substring(fid2.length() - 2);
                    }
                }
            } else {
                Log.d(TAG, "userID=" + userID);
                if (fid2.startsWith("*")) {
                    fid = fid2.substring(1);
                }
            }
            enrollList = enrollList == null ? fid : enrollList + ";" + fid;
            Log.d(TAG, "-------------------------");
        }
        Log.d(TAG, "enrollList=" + enrollList);
        return enrollList;
    }

    public String[] getUserIdList() {
        Log.d(TAG, "+++++ getUserIdList+++++");
        List<String> enrollList = new ArrayList<>();
        for (int i = 0; i < this.mFileDB.size(); i++) {
            String fid = this.mFileDB.readID(i);
            if (fid.startsWith("*") && fid.indexOf(";") != -1) {
                String userName = fid.substring(1, fid.indexOf(";"));
                if (!enrollList.contains(userName)) {
                    enrollList.add(userName);
                }
            }
        }
        if (enrollList.size() == 0) {
            Log.d(TAG, "no user fingers in the fileDB");
            return null;
        }
        String[] s = (String[]) enrollList.toArray(new String[enrollList.size()]);
        Log.d(TAG, "s = " + s);
        return s;
    }

    public boolean deleteFromDB(String userID) {
        Log.d(TAG, "+++++ deleteFromDB  userID = " + userID + " +++++");
        if (!this.mFileDB.delete(userID)) {
            Log.e(TAG, "deleteFromDB(): mFileDB.delete() fail");
            return false;
        } else if (saveFeatureToFile()) {
            return true;
        } else {
            Log.e(TAG, "deleteFromDB(): saveFeature() fail");
            return false;
        }
    }

    public boolean dataDelete(String id) {
        if (!this.mFileDB.delete(id)) {
            Log.e(TAG, "dataDelete(): mFileDB.delete() fail");
            return false;
        } else if (saveFeatureToFile()) {
            return true;
        } else {
            Log.e(TAG, "dataDelete(): saveFeatureToFile() fail");
            return false;
        }
    }
}
