package egis.finger.service;

import android.content.Context;
import android.os.Handler;
import android.os.IBinder;
import android.os.RemoteException;
import android.util.Log;
import egis.finger.ICS1Native;
import egis.finger.host.CipherManager;
import egis.finger.host.FingerUtil;
import egis.finger.service.IEgisServiceNative;
import egis.finger.service.IEgisServiceNative_CB;
import java.util.Arrays;
import java.util.LinkedList;
import java.util.Queue;

public class FPCS1Native implements IBinder.DeathRecipient, ICS1Native {
    protected static final int EEPROM_STATUS_OPERATION_END = 101;
    protected static final int EVENT_ENROLL_CANDIDATE_COUNT = 9;
    protected static final int EVENT_ENROLL_LEARNING = 12;
    protected static final int EVENT_ENROLL_MAP_PROGRESS = 8;
    protected static final int EVENT_ENROLL_PROGRESS = 1;
    protected static final int EVENT_GET_BASE64_FEATURE = 5;
    protected static final int EVENT_GET_FEATURE = 4;
    protected static final int EVENT_GET_IMAGE = 3;
    protected static final int EVENT_GET_MATCHED_IMAGE = 10;
    protected static final int EVENT_GET_VERIFY_IMG = 7;
    protected static final int EVENT_GET_VERIFY_RESULT = 11;
    protected static final int EVENT_STATUS = 2;
    public static final int EVT_ERROR = 2020;
    public static final int FACTORY_TEST_EVT_SNSR_TEST_PUT = 285212677;
    public static final int FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_END = 285212676;
    public static final int FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_START = 285212675;
    public static final int FACTORY_WRITE_EEPROM_SCRIPT_END = 2032;
    public static final int FACTORY_WRITE_EEPROM_SCRIPT_START = 2031;
    private static final int NO_SERVICE = -1;
    public static final int OP_TYPE_ENROLL = 101;
    public static final int OP_TYPE_VERIFY = 102;
    public static final int PAUSE_ENROLL = 2010;
    public static final int RESUME_ENRORLL = 2011;
    private static final int RUN_ERROR = -2;
    public static final int SENSOR_TEST_NORMALSCAN_COMMAND = 100103;
    public static final int SENSOR_TEST_SNR_FINAL_COMMAND = 100107;
    public static final int SENSOR_TEST_SNR_ORG_COMMAND = 100106;
    private static final String SERVICE_NAME = "egistec.cs1.service.daemon";
    protected static final int STATUS_ADD_CANDIDATE = 41;
    protected static final int STATUS_BEFORE_GENERALIZE = 42;
    protected static final int STATUS_DELETED_CANDIDATE = 36;
    protected static final int STATUS_DIRTY_IMAGE = 31;
    protected static final int STATUS_DUPLICATED_CANDIDATE = 37;
    protected static final int STATUS_ENROLL_MAP = 34;
    protected static final int STATUS_FEATURE_LOW = 6;
    protected static final int STATUS_FINGER_DETECTED = 10;
    protected static final int STATUS_FINGER_REMOVE = 24;
    protected static final int STATUS_FINGER_REMOVED = 11;
    protected static final int STATUS_FINGER_TOUCH = 23;
    protected static final int STATUS_GET_IMAGE_FAIL = 29;
    protected static final int STATUS_IMAGE_BAD = 5;
    protected static final int STATUS_IMAGE_FETCH = 3;
    protected static final int STATUS_IMAGE_FETCHING = 9;
    protected static final int STATUS_IMAGE_PARTIAL = 46;
    protected static final int STATUS_IMAGE_READY = 4;
    protected static final int STATUS_IMAGE_SMALL = 33;
    protected static final int STATUS_IMAGE_WATER = 47;
    protected static final int STATUS_LUX_TOO_HIGHER = 22;
    protected static final int STATUS_LUX_TOO_LOWER = 21;
    protected static final int STATUS_MOVE_CANDIDATE = 39;
    protected static final int STATUS_OPERATION_BEGIN = 7;
    protected static final int STATUS_OPERATION_END = 8;
    protected static final int STATUS_REMOVE_CANDIDATE = 38;
    protected static final int STATUS_SELECT_CANDIDATE = 35;
    protected static final int STATUS_SELECT_IMAGE = 40;
    protected static final int STATUS_SENSOR_CLOSE = 2;
    protected static final int STATUS_SENSOR_OPEN = 1;
    protected static final int STATUS_SENSOR_TIMEOUT = 27;
    protected static final int STATUS_SENSOR_UNPLUG = 18;
    protected static final int STATUS_SWIPE_IMAGE_BAD = 30;
    protected static final int STATUS_SWIPE_TOO_DRY = 26;
    protected static final int STATUS_SWIPE_TOO_FAST = 12;
    protected static final int STATUS_SWIPE_TOO_LEFT = 16;
    protected static final int STATUS_SWIPE_TOO_RIGHT = 17;
    protected static final int STATUS_SWIPE_TOO_SHORT = 14;
    protected static final int STATUS_SWIPE_TOO_SKEWED = 15;
    protected static final int STATUS_SWIPE_TOO_SLOW = 13;
    protected static final int STATUS_SWIPE_TOO_WET = 25;
    protected static final int STATUS_TARGET_SENSOR_NOT_FOUND = 32;
    protected static final int STATUS_TEST_ENROLL_FAIL = 61;
    protected static final int STATUS_TEST_ENROLL_OK = 60;
    protected static final int STATUS_TEST_VERIFY_FAIL = 63;
    protected static final int STATUS_TEST_VERIFY_OK = 62;
    protected static final int STATUS_USER_ABORT = 28;
    protected static final int STATUS_USER_TOO_CLOSE = 20;
    protected static final int STATUS_USER_TOO_FAR = 19;
    protected static final int STATUS_WAIT_FPON = 44;
    private static final String TAG = "FPCS1Native";
    protected static final int VKX_RESULT_ENROLL_FAIL = -1001;
    protected static final int VKX_RESULT_SUCCESS = 0;
    private static boolean isSaveDataSet = false;
    protected static int lastErrCode;
    private static Handler mApHandler;
    private static int mBadTrial = 0;
    static IEgisServiceNative_CB mCallback = new IEgisServiceNative_CB.Stub() {
        /* class egis.finger.service.FPCS1Native.AnonymousClass1 */

        @Override // egis.finger.service.IEgisServiceNative_CB
        public void do_native_callback(int eventId, int value1, int value2, byte[] byteBuffer, int buffer_size) throws RemoteException {
            Log.d(FPCS1Native.TAG, "ICS1ServiceNative_CB mCallback enter");
            FPCS1Native.mApHandler.obtainMessage(eventId, value1, value2, byteBuffer).sendToTarget();
            Log.d(FPCS1Native.TAG, "NativeCallback(), event id = " + eventId + ", value1 = " + value1 + ", value2 = " + value2);
            switch (eventId) {
                case 1:
                    FPCS1Native.access$108();
                    FPCS1Native.mEnrollProgress = value1;
                    Log.d(FPCS1Native.TAG, "NativeCallback(), mSuccessTrial = " + FPCS1Native.mSuccessTrial);
                    FPCS1Native.postFpResultStatus(1011);
                    return;
                case 2:
                    FPCS1Native.doGetStatus(value1);
                    return;
                case 3:
                    FPCS1Native.doGetImage(byteBuffer, value1, value2);
                    return;
                case 4:
                    for (int i = 0; i < 10; i++) {
                        Log.d(FPCS1Native.TAG, "EVENT_GET_FEATURE, feature = " + ((int) byteBuffer[i]));
                    }
                    FPCS1Native.doGetFeature(byteBuffer, value1);
                    return;
                case 5:
                case 6:
                default:
                    Log.e(FPCS1Native.TAG, "NativeCallback(),  eventId = " + eventId);
                    return;
                case 7:
                    FPCS1Native.doGetVerifyImg(byteBuffer, value1, value2);
                    FPCS1Native.postFpResultStatus(1008);
                    return;
                case 8:
                case 9:
                    FPCS1Native.doEnrollProgress(value1);
                    return;
                case 10:
                    FPCS1Native.doGetMatchedImage(byteBuffer, value1, value2);
                    FPCS1Native.postFpResultStatus(1008);
                    return;
                case 11:
                    FPCS1Native.identify_result(value1, value2);
                    return;
                case 12:
                    FPCS1Native.doEnrollLearning(byteBuffer, value1);
                    return;
            }
        }
    };
    private static Context mContext;
    protected static String mEnrollListID;
    protected static int mEnrollProgress = 0;
    protected static String mEnrollUserID = "Empty@";
    protected static byte[] mFPMatchedImg;
    protected static Queue<byte[]> mFPMatchedImgQueue;
    protected static byte[] mFPVerifyImg;
    protected static FingerUtil mFingerUtil;
    protected static int mHeightImg;
    protected static byte[] mMap;
    protected static int mMapH;
    protected static int mMapIdx;
    protected static int mMapW;
    protected static int mMatchedHeightImg;
    protected static String mMatchedID;
    protected static int mMatchedWidthImg;
    protected static int mOperationType = 0;
    private static int mSuccessTrial = 0;
    protected static int mWidthImg;
    CipherManager cipherManager;
    private IEgisServiceNative mCS1Service;

    private enum AccuracyLevel {
        ACCURACY_LOW,
        ACCURACY_REGULAR,
        ACCURACY_HIGH,
        ACCURACY_VERY_HIGH
    }

    static /* synthetic */ int access$108() {
        int i = mSuccessTrial;
        mSuccessTrial = i + 1;
        return i;
    }

    public FPCS1Native(Handler handler, Context context) {
        Log.d(TAG, "FPCS1Native Constructor");
        mApHandler = handler;
        mContext = context;
        mFingerUtil = new FingerUtil(handler, context);
        CipherManager cipherManager2 = new CipherManager(CipherManager.CipherType.AES);
        this.cipherManager = cipherManager2;
        cipherManager2.init(new byte[]{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15}, new byte[]{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15});
        mFPMatchedImgQueue = new LinkedList();
        getService();
        setCallback();
    }

    public boolean getService() {
        Log.d(TAG, "getService enter");
        if (this.mCS1Service != null) {
            return true;
        }
        try {
            this.mCS1Service = IEgisServiceNative.Stub.asInterface((IBinder) Class.forName("android.os.ServiceManager").getMethod("getService", String.class).invoke(null, SERVICE_NAME));
        } catch (Exception e) {
            e.printStackTrace();
        }
        if (this.mCS1Service == null) {
            Log.e(TAG, "get service fail");
            return false;
        }
        Log.d(TAG, "get service success");
        try {
            this.mCS1Service.asBinder().linkToDeath(this, 0);
            return true;
        } catch (RemoteException e1) {
            e1.printStackTrace();
            this.mCS1Service = null;
            return false;
        }
    }

    public boolean Init() {
        Log.d(TAG, "Init() ");
        if (getService()) {
            try {
                if (this.mCS1Service.Init() == 0) {
                    return true;
                }
                return false;
            } catch (Exception e) {
                e.printStackTrace();
                return false;
            }
        } else {
            Log.d(TAG, "no service");
            return false;
        }
    }

    private static void resetEnrollStatus() {
        Log.d(TAG, "resetEnrollStatus()");
        mBadTrial = 0;
        mSuccessTrial = 0;
        mEnrollProgress = 0;
        mFingerUtil.mFeature = null;
    }

    @Override // egis.finger.ICS1Native
    public String getVersion() {
        String version = null;
        Log.d(TAG, "getVersion()");
        if (getService()) {
            try {
                version = this.mCS1Service.GetVersion();
                Log.d(TAG, "getVersion(), " + version);
                return version;
            } catch (RemoteException e) {
                e.printStackTrace();
                return version;
            }
        } else {
            Log.d(TAG, "no service");
            return null;
        }
    }

    @Override // egis.finger.ICS1Native
    public int getSensorStatus() {
        int data = -1;
        Log.d(TAG, "getSensorStatus()");
        if (getService()) {
            try {
                data = this.mCS1Service.GetSensorStatus();
                Log.d(TAG, "getSensorStatus(), " + data);
                return data;
            } catch (RemoteException e) {
                e.printStackTrace();
                return data;
            }
        } else {
            Log.d(TAG, "no service");
            return -1;
        }
    }

    @Override // egis.finger.ICS1Native
    public String getEnrollList(String userID) {
        String uid = "*";
        if (!userID.contentEquals(uid)) {
            uid = uid + userID;
        }
        mEnrollListID = mFingerUtil.getEnrollListFromDB(uid);
        mApHandler.obtainMessage(1000, 1025, -1).sendToTarget();
        Log.d(TAG, "getEnrollList(), userID = " + userID + ", mEnrollListID = " + mEnrollListID);
        return mEnrollListID;
    }

    @Override // egis.finger.ICS1Native
    public String dataRead(String id, String pwd) {
        Log.d(TAG, "dataRead(), id = " + id + ", pwd = " + pwd);
        if (this.cipherManager == null) {
            Log.e(TAG, "dataRead(), ciphermanager == null");
            lastErrCode = 2034;
            return null;
        } else if (id == null) {
            Log.e(TAG, "dataRead(), id == null");
            lastErrCode = 2035;
            return null;
        } else if (pwd == null) {
            Log.e(TAG, "dataRead(), pwd == null");
            lastErrCode = 2037;
            return null;
        } else if (mFingerUtil.dataRead(id) == null) {
            Log.e(TAG, "dataRead(), requested data does not exist");
            return null;
        } else if (!this.cipherManager.setKey(pwd)) {
            Log.e(TAG, "dataRead(),  setKey fail");
            return null;
        } else {
            String decryptionData = this.cipherManager.decryptData(mFingerUtil.dataRead(id));
            if (decryptionData == null) {
                Log.e(TAG, "dataRead(),  decryptData fail");
                return null;
            } else if (!this.cipherManager.validateData(decryptionData)) {
                Log.e(TAG, "dataRead(), password is incorrect !");
                lastErrCode = 2038;
                return null;
            } else {
                String decryptionData2 = this.cipherManager.unpackageData(decryptionData);
                Log.d(TAG, "dataRead(), data = " + decryptionData2);
                return decryptionData2;
            }
        }
    }

    @Override // egis.finger.ICS1Native
    public String[] getUserIdList() {
        String[] data = mFingerUtil.getUserIdList();
        Log.d(TAG, "getUserIdList(), " + Arrays.toString(data));
        return data;
    }

    @Override // egis.finger.ICS1Native
    public int[] getEnrollStatus() {
        int[] enrollStatus = {mSuccessTrial, mBadTrial, mEnrollProgress};
        Log.d(TAG, "getEnrollStatus() SuccessTrial = " + enrollStatus[0] + ", BadTrial=" + enrollStatus[1] + ", EnrollProgress = " + enrollStatus[2]);
        return enrollStatus;
    }

    @Override // egis.finger.ICS1Native
    public String getSensorInfo() {
        String data = null;
        Log.d(TAG, "getSensorInfo() ");
        if (getService()) {
            try {
                data = this.mCS1Service.GetSensorInfo();
                Log.d(TAG, "getSensorInfo(), " + data);
                return data;
            } catch (RemoteException e) {
                e.printStackTrace();
                return data;
            }
        } else {
            Log.d(TAG, "no service");
            return null;
        }
    }

    @Override // egis.finger.ICS1Native
    public int sensorDeviceEnable(boolean enable) {
        Log.d(TAG, "sensorDeviceEnable(): " + enable);
        if (getService()) {
            try {
                return this.mCS1Service.SensorDeviceEnable(enable);
            } catch (RemoteException e) {
                e.printStackTrace();
                return -1;
            }
        } else {
            Log.d(TAG, "no service");
            return -1;
        }
    }

    @Override // egis.finger.ICS1Native
    public int eepromTest(int cmd, int address, int value) {
        Log.d(TAG, "eepromTest(), cmd=" + cmd + ", value=" + value);
        if (getService()) {
            try {
                return this.mCS1Service.EepromTest(cmd, address, value);
            } catch (RemoteException e) {
                e.printStackTrace();
                return -1;
            }
        } else {
            Log.d(TAG, "no service");
            return -1;
        }
    }

    @Override // egis.finger.ICS1Native
    public int setAccuracyLevel(int accuracyLevel) {
        Log.d(TAG, "setAccuracyLevel(), " + accuracyLevel);
        if (accuracyLevel < 0) {
            accuracyLevel = 0;
        } else if (accuracyLevel > 3) {
            accuracyLevel = 3;
        }
        if (getService()) {
            try {
                return this.mCS1Service.SetAccuracyLevel(accuracyLevel);
            } catch (RemoteException e) {
                e.printStackTrace();
                return -1;
            }
        } else {
            Log.d(TAG, "no service");
            return -1;
        }
    }

    @Override // egis.finger.ICS1Native
    public boolean dataSet(String id, String value, String password) {
        Log.d(TAG, "dataSet(), id =  " + id + " value = " + value + " password = " + password);
        CipherManager cipherManager2 = this.cipherManager;
        if (cipherManager2 == null) {
            Log.e(TAG, "dataSet(), ciphermanager == null");
            lastErrCode = 2034;
            return false;
        } else if (id == null) {
            Log.e(TAG, "dataSet(), id == null");
            lastErrCode = 2035;
            return false;
        } else if (value == null) {
            Log.e(TAG, "dataSet(), value == null");
            lastErrCode = 2036;
            return false;
        } else if (password == null) {
            Log.e(TAG, "dataSet password == null");
            lastErrCode = 2037;
            return false;
        } else if (!cipherManager2.setKey(password)) {
            Log.e(TAG, "dataSet(), setKey fail");
            return false;
        } else {
            CipherManager cipherManager3 = this.cipherManager;
            String encryptionData = cipherManager3.encryptData(cipherManager3.packageData(value));
            if (encryptionData != null) {
                return mFingerUtil.dataSet(id, encryptionData);
            }
            Log.e(TAG, "dataSet(), encryptData fail");
            return false;
        }
    }

    @Override // egis.finger.ICS1Native
    public boolean identify(String userId) {
        try {
            mOperationType = 102;
            return verifyAll(mFingerUtil.getAllFeature(userId), new int[]{-1, 0});
        } catch (Exception e) {
            Log.e(TAG, "identify(), exception = " + e.getMessage());
            return false;
        }
    }

    public boolean verifyAll(byte[][] allEnrollTemplate, int[] matchRtn) {
        Log.d(TAG, "verifyAll() ");
        if (getService()) {
            try {
                if (this.mCS1Service.VerifyAllTemplate((byte[][]) allEnrollTemplate.clone(), matchRtn) == 0) {
                    return true;
                }
                return false;
            } catch (Exception e) {
                Log.e(TAG, "verifyAll() exception = " + e.getMessage());
                return false;
            }
        } else {
            Log.d(TAG, "no service");
            return false;
        }
    }

    @Override // egis.finger.ICS1Native
    public boolean enroll(String userID) {
        Log.d(TAG, "enroll(), " + userID);
        if (userID == null) {
            Log.e(TAG, "enroll(), userID == null");
            return false;
        }
        mEnrollUserID = "*" + userID;
        mOperationType = 101;
        Log.d(TAG, "mEnrollUserID = " + mEnrollUserID);
        if (getService()) {
            try {
                int ret = this.mCS1Service.EnrollFinger();
                if (ret == 0) {
                    resetEnrollStatus();
                    return true;
                }
                Log.e(TAG, "enroll(), fail " + ret);
                return false;
            } catch (Exception e) {
                Log.e(TAG, "enroll() exception = " + e.getMessage());
                return false;
            }
        } else {
            Log.d(TAG, "no service");
            return false;
        }
    }

    @Override // egis.finger.ICS1Native
    public boolean swipeEnroll(String userID) {
        Log.d(TAG, "swipeEnroll(), " + userID);
        if (userID == null) {
            Log.e(TAG, "swipeEnroll(), userID == null");
            return false;
        }
        mEnrollUserID = "*" + userID;
        mOperationType = 101;
        Log.d(TAG, "mEnrollUserID = " + mEnrollUserID);
        if (getService()) {
            try {
                int ret = this.mCS1Service.SwipeEnroll();
                if (ret == 0) {
                    resetEnrollStatus();
                    return true;
                }
                Log.e(TAG, "swipeEnroll(), fail " + ret);
                return false;
            } catch (Exception e) {
                Log.e(TAG, "swipeEnroll() exception = " + e.getMessage());
                return false;
            }
        } else {
            Log.d(TAG, "no service");
            return false;
        }
    }

    @Override // egis.finger.ICS1Native
    public boolean deleteFeature(String userID) {
        Log.d(TAG, "deleteFeature(), " + userID);
        if (mFingerUtil == null) {
            Log.d(TAG, "deleteFeature(), FingerUtil == null");
            lastErrCode = 2063;
            return false;
        } else if (userID == null) {
            Log.e(TAG, "deleteFeature(), userID == null");
            lastErrCode = 2064;
            return false;
        } else if (userID.length() == 0) {
            Log.d(TAG, "deleteFeature(), userID length==0");
            lastErrCode = 2065;
            return false;
        } else {
            String uid = "*";
            if (!userID.contentEquals(uid)) {
                uid = uid + userID;
            }
            boolean res = mFingerUtil.deleteFromDB(uid);
            if (res) {
                mApHandler.obtainMessage(1000, 1020, -1).sendToTarget();
            } else {
                mApHandler.obtainMessage(1000, 1021, -1).sendToTarget();
            }
            return res;
        }
    }

    @Override // egis.finger.ICS1Native
    public boolean dataDelete(String id, String password) {
        Log.d(TAG, "dataDelete(), id = " + id + " password = " + password);
        if (this.cipherManager == null) {
            Log.e(TAG, "dataDelete(), ciphermanager == null");
            lastErrCode = 2034;
            return false;
        } else if (id == null) {
            Log.e(TAG, "dataDelete(), id == null");
            lastErrCode = 2035;
            return false;
        } else if (password == null) {
            Log.e(TAG, "dataDelete(), password == null");
            lastErrCode = 2037;
            return false;
        } else if (mFingerUtil.dataRead(id) == null) {
            Log.e(TAG, "dataDelete(), requested data does not exist");
            return false;
        } else if (!this.cipherManager.setKey(password)) {
            Log.e(TAG, "dataDelete(), setKey fail");
            return false;
        } else {
            String decryptionData = this.cipherManager.decryptData(mFingerUtil.dataRead(id));
            if (decryptionData == null) {
                Log.e(TAG, "dataDelete(), decryptData fail");
                lastErrCode = 2036;
                return false;
            } else if (this.cipherManager.validateData(decryptionData)) {
                return mFingerUtil.dataDelete(id);
            } else {
                Log.e(TAG, "dataDelete(), password is incorrect");
                lastErrCode = 2036;
                return false;
            }
        }
    }

    @Override // egis.finger.ICS1Native
    public int sensorControl(int request, int interrupt_timeout) {
        Log.d(TAG, "sensorControl(), " + request + ", " + interrupt_timeout);
        if (getService()) {
            try {
                return this.mCS1Service.NativeSensorControl(request, interrupt_timeout);
            } catch (Exception e) {
                Log.e(TAG, "sensorControl(), exception = " + e.getMessage());
                return -1;
            }
        } else {
            Log.d(TAG, "no service");
            return -1;
        }
    }

    @Override // egis.finger.ICS1Native
    public boolean abort() {
        Log.d(TAG, "abort()");
        if (getService()) {
            try {
                int ret = this.mCS1Service.AbortOperation();
                if (ret == 0) {
                    resetEnrollStatus();
                    return true;
                }
                Log.e(TAG, "abort(),  fail " + ret);
                return false;
            } catch (Exception e) {
                return false;
            }
        } else {
            Log.d(TAG, "no service");
            return false;
        }
    }

    @Override // egis.finger.ICS1Native
    public int cleanup() {
        Log.d(TAG, "cleanup()");
        if (getService()) {
            try {
                return this.mCS1Service.Cleanup();
            } catch (Exception e) {
                Log.e(TAG, "cleanup(), exception = " + e.getMessage());
                return -1;
            }
        } else {
            Log.d(TAG, "no service");
            return -1;
        }
    }

    @Override // egis.finger.ICS1Native
    public boolean testEnrollmentAndVerification(boolean isEnroll) {
        int isEnrollTmp;
        Log.d(TAG, "testEnrollmentAndVerification(), " + isEnroll);
        if (isEnroll) {
            isEnrollTmp = 1;
            mOperationType = 101;
        } else {
            isEnrollTmp = 0;
            mOperationType = 102;
        }
        if (getService()) {
            try {
                int ret = this.mCS1Service.TestEnrollmentAndVerification(isEnrollTmp);
                if (ret != 0) {
                    Log.e(TAG, "testEnrollmentAndVerification(), " + ret);
                    return false;
                } else if (!isEnroll) {
                    return true;
                } else {
                    resetEnrollStatus();
                    return true;
                }
            } catch (Exception e) {
                return false;
            }
        } else {
            Log.d(TAG, "no service");
            return false;
        }
    }

    protected static void doGetEnrollStatus(int enrollStatus) {
        Log.d(TAG, "doGetEnrollStatus(), " + enrollStatus);
        mApHandler.obtainMessage(1200, enrollStatus + 1200, -1).sendToTarget();
    }

    @Override // egis.finger.ICS1Native
    public int[] getTinyMapInfo() {
        int[] info = {mMapIdx, mMapW, mMapH};
        Log.d(TAG, "getTinyMapInfo(), MapIdx = " + info[0] + ", MapW = " + info[1] + ", MapH = " + info[2]);
        return info;
    }

    @Override // egis.finger.ICS1Native
    public byte[] getTinyMap() {
        byte[] bArr = mMap;
        if (bArr != null) {
            return (byte[]) bArr.clone();
        }
        Log.e(TAG, "getTinyMap(), mMap == null");
        return null;
    }

    @Override // egis.finger.ICS1Native
    public byte[] getMatchedImg() {
        Queue<byte[]> queue = mFPMatchedImgQueue;
        if (queue == null) {
            Log.e(TAG, "getMatchedImg(), mFPMatchedImgQueue == null");
            return null;
        } else if (mFPMatchedImg == null) {
            Log.e(TAG, "getMatchedImg(), mFPMatchedImg == null");
            return null;
        } else if (queue.peek() != null) {
            return mFPMatchedImgQueue.poll();
        } else {
            return (byte[]) mFPMatchedImg.clone();
        }
    }

    @Override // egis.finger.ICS1Native
    public int[] getMatchedImgInfo() {
        int[] info = {mMatchedWidthImg, mMatchedHeightImg};
        Log.d(TAG, "getMatchedImgInfo() MatchedWidthImg = " + info[0] + " MatchedHeightImg = " + info[1]);
        return info;
    }

    @Override // egis.finger.ICS1Native
    public int getOperationType() {
        Log.d(TAG, "getOperationType(), " + mOperationType);
        return mOperationType;
    }

    @Override // egis.finger.ICS1Native
    public String getMatchedUserID() {
        Log.d(TAG, "getMatchedUserID(), " + mMatchedID);
        return mMatchedID;
    }

    public static boolean identify_result(int matchIdx, int maxScore) {
        Log.d(TAG, "identify_result(), matchIdx = " + matchIdx + ", maxScore = " + maxScore);
        if (matchIdx != -1) {
            mMatchedID = mFingerUtil.getMatchedID(FingerUtil.fileDBMap[matchIdx]);
            postFpResultStatus(1003);
            return true;
        }
        postFpResultStatus(1004);
        return true;
    }

    public static void postFpResultStatus(int status) {
        mApHandler.obtainMessage(1000, status, -1).sendToTarget();
    }

    protected static void doGetImage(byte[] image, int width, int height) {
        Log.d(TAG, "doGetImage(), donothing");
    }

    protected static void doGetMatchedImage(byte[] image, int width, int height) {
        Log.d(TAG, "doGetMatchedImage(), width =" + width + ", height = " + height);
        byte[] bArr = (byte[]) image.clone();
        mFPMatchedImg = bArr;
        mFPMatchedImgQueue.offer(bArr);
        mMatchedWidthImg = width;
        mMatchedHeightImg = height;
    }

    protected static void doGetStatus(int status) {
        Log.d(TAG, "doGetStatus status = " + status);
        switch (status) {
            case -1001:
                postFpResultStatus(1002);
                return;
            case 5:
            case 6:
            case 33:
                mBadTrial++;
                Log.d(TAG, "doGetStatus(), mBadTrial = " + mBadTrial);
                postFpResultStatus(1009);
                return;
            case 10:
                postFpResultStatus(1073);
                return;
            case 11:
                postFpResultStatus(1074);
                return;
            case 12:
                postFpResultStatus(1086);
                return;
            case 25:
                postFpResultStatus(1084);
                return;
            case 28:
                postFpResultStatus(1012);
                return;
            case 44:
                postFpResultStatus(1075);
                return;
            case 46:
                postFpResultStatus(1082);
                return;
            case 47:
                postFpResultStatus(1085);
                return;
            case 60:
                postFpResultStatus(1087);
                return;
            case 61:
                postFpResultStatus(1088);
                return;
            case 62:
                postFpResultStatus(1089);
                return;
            case 63:
                postFpResultStatus(1090);
                return;
            case 101:
                postFpResultStatus(101);
                return;
            case 2020:
                postFpResultStatus(2020);
                return;
            case 2031:
                postFpResultStatus(2031);
                return;
            case 2032:
                postFpResultStatus(2032);
                return;
            case 285212675:
                postFpResultStatus(285212675);
                return;
            case 285212676:
                postFpResultStatus(285212676);
                return;
            case 285212677:
                postFpResultStatus(285212677);
                return;
            default:
                return;
        }
    }

    @Override // egis.finger.ICS1Native
    public boolean getIsSaveDataSet() {
        return isSaveDataSet;
    }

    @Override // egis.finger.ICS1Native
    public void setIsSaveDataSet(boolean is_save_data_set) {
        isSaveDataSet = is_save_data_set;
    }

    protected static void doEnrollProgress(int progress) {
        Log.d(TAG, "doEnrollProgress(), " + progress);
        mEnrollProgress = progress;
        postFpResultStatus(1080);
    }

    protected static void doGetFeature(byte[] feature, int size) {
        Log.d(TAG, "doGetFeature(), size = " + size + ", mEnrollUserID = " + mEnrollUserID);
        if (feature == null) {
            Log.e(TAG, "doGetFeature(), feature = null");
        } else {
            Log.d(TAG, "doGetFeature(), feature[0] = " + ((int) feature[0]));
        }
        mFingerUtil.mFeature = feature;
        mFingerUtil.mFeatureSize = size;
        if (mOperationType == 101) {
            if (mFingerUtil.checkId(mEnrollUserID)) {
                mFingerUtil.enrollToDB(mEnrollUserID);
                isSaveDataSet = true;
            }
            postFpResultStatus(1001);
        }
    }

    @Override // egis.finger.ICS1Native
    public boolean doEnrollToDB(String userId) {
        Log.d(TAG, "doEnrollToDB(), " + userId);
        return mFingerUtil.enrollToDB(mEnrollUserID);
    }

    protected static void doGetVerifyImg(byte[] image, int width, int height) {
        Log.d(TAG, "doGetVerifyImg(), width = " + width + ", height = " + height);
        mFPVerifyImg = (byte[]) image.clone();
        mWidthImg = width;
        mHeightImg = height;
        postFpResultStatus(1078);
    }

    protected static void doEnrollLearning(byte[] EnrollTemplate, int len) {
        Log.d(TAG, "doEnrollLearning(), mMatchedID = " + mMatchedID + ", len = " + EnrollTemplate.length);
        mFingerUtil.mFeature = EnrollTemplate;
        mFingerUtil.mFeatureSize = len;
        if (mOperationType == 102) {
            FingerUtil fingerUtil = mFingerUtil;
            fingerUtil.enrollToDB("*" + mMatchedID);
        }
    }

    public int setCallback() {
        Log.d(TAG, "setCallback enter");
        if (!getService()) {
            return -1;
        }
        try {
            if (this.mCS1Service.set_on_callback_proc(mCallback) != 0) {
                return -2;
            }
            return -1;
        } catch (RemoteException e) {
            e.printStackTrace();
            return -1;
        }
    }

    public void binderDied() {
        Log.d(TAG, "CS1 Daemon binder Died");
        this.mCS1Service = null;
    }
}
