package egis.optical.client.api;

import android.content.Context;
import android.graphics.Bitmap;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.util.SparseArray;
import egis.optical.finger.host.FPNativeBase;
import egistec.optical.csa.client.api.Fingerprint;
import egistec.optical.csa.client.api.IFingerprint;
import java.io.UnsupportedEncodingException;
import java.nio.ByteBuffer;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

public class EgisFingerprint implements IFingerprint {
    public static final int ACCURACY_HIGH = 2;
    public static final int ACCURACY_LOW = 0;
    public static final int ACCURACY_REGULAR = 1;
    public static final int ACCURACY_VERY_HIGH = 3;
    public static final int CAPTURE_COMPLETED = 1042;
    public static final int CAPTURE_FAILED = 1045;
    public static final int CAPTURE_FINISHED = 1043;
    public static final int CAPTURE_RAW_DATA = 1046;
    public static final int CAPTURE_READY = 1040;
    public static final int CAPTURE_STARTED = 1041;
    public static final int CAPTURE_SUCCESS = 1044;
    public static final int ENROLL_BITMAP = 1005;
    public static final int ENROLL_FAILED = 1002;
    public static final int ENROLL_FAILURE_CANCELED = 1003;
    public static final int ENROLL_FAULURE_ENROLL_FAILURE_EXCEED_MAX_TRIAL = 1004;
    public static final int ENROLL_STATUS = 1000;
    public static final int ENROLL_SUCCESS = 1001;
    public static final int EVT_ERROR = 2020;
    public static final int FACTORY_TEST_EVT_SNSR_TEST_PUT_BKBOX = 285212679;
    public static final int FACTORY_TEST_EVT_SNSR_TEST_PUT_CHART = 285212680;
    public static final int FACTORY_TEST_EVT_SNSR_TEST_PUT_WKBOX = 285212678;
    public static final int FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_END = 285212676;
    public static final int FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_START = 285212675;
    public static final int FACTORY_TEST_EVT_SNSR_TEST_WAIT_COMMAND = 285212681;
    public static final int FACTORY_WRITE_EEPROM_SCRIPT_END = 2032;
    public static final int FACTORY_WRITE_EEPROM_SCRIPT_START = 2031;
    private static final String FPID_PREFIX = "EGISFPID";
    public static final int IDENTIFY_FAILED = 1021;
    public static final int IDENTIFY_FAILURE_BAD_QUALITY = 1025;
    public static final int IDENTIFY_FAILURE_CANCELED = 1022;
    public static final int IDENTIFY_FAILURE_NOT_MATCH = 1024;
    public static final int IDENTIFY_FAILURE_TIMEOUT = 1023;
    public static final int IDENTIFY_SUCCESS = 1020;
    public static final String JAR_VERSION = "9";
    public static final String MAJOR_VERSION = "3";
    private static final int MAP_H = 256;
    private static final int MAP_W = 256;
    public static final int MAX_ENROLL_FINGERS = 5;
    public static final int OP_TYPE_ENROLL = 101;
    public static final int OP_TYPE_VERIFY = 102;
    private static final String PASSOWORD_PREFIX = "EGISPWD";
    private static final String PASSWORD = "egistec";
    public static final int PAUSE_ENROLL = 2010;
    public static final int QUALITY_DUPLICATED_SCANNED_IMAGE = 256;
    public static final int QUALITY_EMPTY_TOUCH = 536870912;
    public static final int QUALITY_FAILED = 268435456;
    public static final int QUALITY_FINGER_TOO_THIN = 128;
    public static final int QUALITY_GOOD = 0;
    public static final int QUALITY_NOT_A_FINGER_SWIPE = 16;
    public static final int QUALITY_OFFSET_TOO_FAR_LEFT = 1;
    public static final int QUALITY_OFFSET_TOO_FAR_RIGHT = 2;
    public static final int QUALITY_ONE_HAND_SWIPE = 33554432;
    public static final int QUALITY_PARTIAL_TOUCH = Integer.MIN_VALUE;
    public static final int QUALITY_PRESSURE_TOO_HARD = 64;
    public static final int QUALITY_PRESSURE_TOO_LIGHT = 32;
    public static final int QUALITY_REVERSE_MOTION = 524288;
    public static final int QUALITY_SKEW_TOO_LARGE = 262144;
    public static final int QUALITY_SOMETHING_ON_THE_SENSOR = 4;
    public static final int QUALITY_STICTION = 16777216;
    public static final int QUALITY_TOO_FAST = 512;
    public static final int QUALITY_TOO_SHORT = 131072;
    public static final int QUALITY_TOO_SLOW = 65536;
    public static final int QUALITY_WATER = 4096;
    public static final int QUALITY_WET_FINGER = 8;
    public static final int RESULT_CANCELED = -2;
    public static final int RESULT_FAILED = -1;
    public static final int RESULT_NO_AUTHORITY = -4;
    public static final int RESULT_OK = 0;
    public static final int RESULT_TOO_MANY_FINGER = -5;
    public static final int RESUME_ENROLL = 2011;
    public static final int SENSOR_EEPROM_WRITE_COMMAND = 2030;
    public static final int SENSOR_OK = 2004;
    public static final int SENSOR_OUT_OF_ORDER = 2006;
    public static final int SENSOR_TEST_NORMALSCAN_COMMAND = 100103;
    public static final int SENSOR_TEST_SNR_FINAL_COMMAND = 100107;
    public static final int SENSOR_TEST_SNR_ORG_COMMAND = 100106;
    public static final int SENSOR_WORKING = 2005;
    public static final String TAG = "FpJar_EgisFingerprint";
    private static Context mContext;
    private static Fingerprint.FingerprintEventListener mFingerprintEventListener;
    private static EgisFingerprint mInstance;
    private Map<String, Integer> fingerIndexMap;
    private SparseArray<String> indexMapToFinger;
    private byte[] mBadImageData;
    private int[] mBadImageDataInfo;
    private int mEnrollIndex;
    private String mEnrollUserId;
    private FPNativeBase mFPNativeBase;
    private final Handler mHandler;
    private boolean mIsEnrollSessionOpen;
    private boolean mIsFilterOn;
    private boolean mIsFingerOrPWValidate;

    private EgisFingerprint() {
        AnonymousClass1 r1 = new Handler() {
            /* class egis.optical.client.api.EgisFingerprint.AnonymousClass1 */

            public void handleMessage(Message msg) {
                Log.d(EgisFingerprint.TAG, "mHandler(), meg.what = " + msg.what + ", msg.arg1 = " + msg.arg1);
                switch (msg.what) {
                    case 1000:
                        EgisFingerprint.this.handleFpResult(msg.arg1);
                        return;
                    default:
                        return;
                }
            }
        };
        this.mHandler = r1;
        HashMap hashMap = new HashMap();
        this.fingerIndexMap = hashMap;
        hashMap.put("R1", 1);
        this.fingerIndexMap.put("R2", 2);
        this.fingerIndexMap.put("R3", 3);
        this.fingerIndexMap.put("R4", 4);
        this.fingerIndexMap.put("R5", 5);
        this.fingerIndexMap.put("L1", 6);
        this.fingerIndexMap.put("L2", 7);
        this.fingerIndexMap.put("L3", 8);
        this.fingerIndexMap.put("L4", 9);
        this.fingerIndexMap.put("L5", 10);
        SparseArray<String> sparseArray = new SparseArray<>();
        this.indexMapToFinger = sparseArray;
        sparseArray.put(1, "R1");
        this.indexMapToFinger.put(2, "R2");
        this.indexMapToFinger.put(3, "R3");
        this.indexMapToFinger.put(4, "R4");
        this.indexMapToFinger.put(5, "R5");
        this.indexMapToFinger.put(6, "L1");
        this.indexMapToFinger.put(7, "L2");
        this.indexMapToFinger.put(8, "L3");
        this.indexMapToFinger.put(9, "L4");
        this.indexMapToFinger.put(10, "L5");
        this.mFPNativeBase = new FPNativeBase(r1, mContext);
        getVersion();
    }

    private String[] fpSplitor(String fpData) {
        String[] fingerArray;
        Log.d(TAG, "fpSplitor(), fpData = " + fpData);
        if (fpData.equals("")) {
            Log.e(TAG, "fpSplitor(), fpData is null");
            return null;
        }
        if (fpData.contains(";")) {
            fingerArray = fpData.split(";");
        } else {
            fingerArray = new String[]{fpData};
        }
        Log.d(TAG, "fpSplitor(), fingerArray = " + Arrays.toString(fingerArray));
        return fingerArray;
    }

    private void notifyOnEnrollStatus() {
        if (mFingerprintEventListener != null) {
            int[] enrollInfo = this.mFPNativeBase.getEnrollStatus();
            Fingerprint.EnrollStatus enrollStatus = new Fingerprint.EnrollStatus();
            enrollStatus.successTrial = enrollInfo[0];
            enrollStatus.badTrial = enrollInfo[1];
            enrollStatus.totalTrial = enrollInfo[0] + enrollInfo[1];
            enrollStatus.progress = enrollInfo[2];
            mFingerprintEventListener.onFingerprintEvent(1000, enrollStatus);
            return;
        }
        Log.e(TAG, "notifyOnEnrollStatus(), mFingerprintEventListener");
    }

    private void notifyOnBadImage(int quality, byte[] badImageData, int[] badImageDataInfo) {
        Log.d(TAG, "notifyOnBadImage(), quality = " + quality);
        if (mFingerprintEventListener != null) {
            Fingerprint.FingerprintBitmap fpBitmap = new Fingerprint.FingerprintBitmap();
            fpBitmap.width = badImageDataInfo[0];
            fpBitmap.height = badImageDataInfo[1];
            fpBitmap.quality = quality;
            if (!(badImageDataInfo[0] == 0 || badImageDataInfo[1] == 0)) {
                fpBitmap.bitmap = Bitmap.createBitmap(badImageDataInfo[0], badImageDataInfo[1], Bitmap.Config.ALPHA_8);
            }
            if (badImageData != null) {
                fpBitmap.bitmap.copyPixelsFromBuffer(ByteBuffer.wrap(badImageData));
                Log.d(TAG, "rawData len=" + badImageData.length);
            }
            mFingerprintEventListener.onFingerprintEvent(1045, fpBitmap);
            return;
        }
        Log.d(TAG, "notifyOnBadImage(), mFingerprintEventListener");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleFpResult(int result) {
        switch (result) {
            case 101:
                Log.d(TAG, "handleFpResult::EEPROM_STATUS_OPERATION_END");
                mFingerprintEventListener.onFingerprintEvent(101, null);
                return;
            case 1001:
                Log.d(TAG, "handleFpResult::FP_RES_ENROLL_OK");
                if (FPNativeBase.isSaveDataSet) {
                    FPNativeBase fPNativeBase = this.mFPNativeBase;
                    fPNativeBase.dataSet("EGISFPID;" + this.mEnrollUserId + ";" + this.indexMapToFinger.get(this.mEnrollIndex), UUID.randomUUID().toString(), PASSWORD);
                    FPNativeBase.isSaveDataSet = false;
                }
                Fingerprint.FingerprintEventListener fingerprintEventListener = mFingerprintEventListener;
                if (fingerprintEventListener != null) {
                    fingerprintEventListener.onFingerprintEvent(1001, null);
                    Log.i(TAG, "handleFpResult::ENROLL_SUCCESS");
                }
                this.mEnrollUserId = null;
                return;
            case 1002:
                Log.d(TAG, "handleFpResult::FP_RES_ENROLL_FAIL");
                Fingerprint.FingerprintEventListener fingerprintEventListener2 = mFingerprintEventListener;
                if (fingerprintEventListener2 != null) {
                    fingerprintEventListener2.onFingerprintEvent(1002, null);
                    Log.i(TAG, "handleFpResult::ENROLL_FAILED");
                }
                this.mEnrollUserId = null;
                this.mEnrollIndex = 0;
                return;
            case 1003:
                Log.d(TAG, "handleFpResult::FP_RES_MATCHED_OK");
                this.mIsFingerOrPWValidate = true;
                if (mFingerprintEventListener != null) {
                    Fingerprint.IdentifyResult identifyResult = new Fingerprint.IdentifyResult();
                    String egisId = this.mFPNativeBase.getMatchedUserID();
                    String[] idWithIndex = egisId.split(";");
                    if (idWithIndex.length < 2) {
                        Log.e(TAG, "handleFpResult::ERROR " + egisId);
                    }
                    Log.d(TAG, "handleFpResult::user=" + idWithIndex[0] + " index=" + idWithIndex[1]);
                    identifyResult.index = this.fingerIndexMap.get(idWithIndex[1]).intValue();
                    identifyResult.result = 1020;
                    mFingerprintEventListener.onFingerprintEvent(1020, identifyResult);
                    Log.i(TAG, "handleFpResult::IDENTIFY_SUCCESS");
                    return;
                }
                return;
            case 1004:
                Log.d(TAG, "handleFpResult::FP_RES_MATCHED_FAIL");
                if (mFingerprintEventListener != null) {
                    Fingerprint.IdentifyResult identifyResult2 = new Fingerprint.IdentifyResult();
                    identifyResult2.index = -1;
                    identifyResult2.result = 1024;
                    mFingerprintEventListener.onFingerprintEvent(1021, identifyResult2);
                    Log.i(TAG, "handleFpResult::IDENTIFY_FAILED");
                    return;
                }
                return;
            case 1006:
                Log.d(TAG, "handleFpResult::FP_RES_GETTED_RAW_DATA");
                if (mFingerprintEventListener != null) {
                    byte[] rawData = this.mFPNativeBase.getRawData();
                    int[] rawDataInfo = this.mFPNativeBase.getRawDataInfo();
                    Fingerprint.FingerprintRawData fpRawData = new Fingerprint.FingerprintRawData();
                    fpRawData.ImageInfoData = (byte[]) rawData.clone();
                    fpRawData.width = rawDataInfo[0];
                    fpRawData.height = rawDataInfo[1];
                    mFingerprintEventListener.onFingerprintEvent(1046, fpRawData);
                    return;
                }
                return;
            case 1008:
                Log.d(TAG, "handleFpResult::FP_RES_GETTED_GOOD_IMAGE");
                if (mFingerprintEventListener != null) {
                    byte[] rawData2 = this.mFPNativeBase.getGoodImg();
                    int[] rawDataInfo2 = this.mFPNativeBase.getGoodImgInfo();
                    Fingerprint.FingerprintBitmap fpBitmap = new Fingerprint.FingerprintBitmap();
                    fpBitmap.width = rawDataInfo2[0];
                    fpBitmap.height = rawDataInfo2[1];
                    fpBitmap.quality = 0;
                    if (!(rawDataInfo2[0] == 0 || rawDataInfo2[1] == 0)) {
                        fpBitmap.bitmap = Bitmap.createBitmap(rawDataInfo2[0], rawDataInfo2[1], Bitmap.Config.ALPHA_8);
                    }
                    if (rawData2 != null) {
                        Log.d(TAG, "handleFpResult::rawData len = " + rawData2.length);
                        for (int index = 0; index < rawData2.length; index++) {
                            rawData2[index] = (byte) (~rawData2[index]);
                        }
                        fpBitmap.bitmap.copyPixelsFromBuffer(ByteBuffer.wrap(rawData2));
                    }
                    mFingerprintEventListener.onFingerprintEvent(1044, fpBitmap);
                    return;
                }
                return;
            case 1009:
                Log.d(TAG, "handleFpResult::FP_RES_GETTED_BAD_IMAGE");
                if (mFingerprintEventListener != null) {
                    this.mBadImageData = this.mFPNativeBase.getBadImg();
                    this.mBadImageDataInfo = this.mFPNativeBase.getBadImgInfo();
                    Fingerprint.FingerprintBitmap fpBitmap2 = new Fingerprint.FingerprintBitmap();
                    fpBitmap2.width = this.mBadImageDataInfo[0];
                    fpBitmap2.height = this.mBadImageDataInfo[1];
                    fpBitmap2.quality = 268435456;
                    int[] iArr = this.mBadImageDataInfo;
                    if (!(iArr[0] == 0 || iArr[1] == 0)) {
                        fpBitmap2.bitmap = Bitmap.createBitmap(iArr[0], iArr[1], Bitmap.Config.ALPHA_8);
                    }
                    if (this.mBadImageData != null) {
                        Log.d(TAG, "handleFpResult::rawData len = " + this.mBadImageData.length);
                        int index2 = 0;
                        while (true) {
                            byte[] bArr = this.mBadImageData;
                            if (index2 < bArr.length) {
                                bArr[index2] = (byte) (~bArr[index2]);
                                index2++;
                            } else {
                                fpBitmap2.bitmap.copyPixelsFromBuffer(ByteBuffer.wrap(this.mBadImageData));
                            }
                        }
                    }
                    mFingerprintEventListener.onFingerprintEvent(1045, fpBitmap2);
                    return;
                }
                return;
            case 1011:
                Log.d(TAG, "handleFpResult::FP_RES_ENROLL_COUNT");
                notifyOnEnrollStatus();
                return;
            case 1012:
                Log.d(TAG, "handleFpResult::FP_RES_ABORT_OK");
                if (!this.mIsFilterOn) {
                    switch (this.mFPNativeBase.getOperationType()) {
                        case 101:
                            mFingerprintEventListener.onFingerprintEvent(1003, null);
                            return;
                        case 102:
                            Fingerprint.IdentifyResult identifyResult3 = new Fingerprint.IdentifyResult();
                            identifyResult3.result = 1022;
                            mFingerprintEventListener.onFingerprintEvent(1021, identifyResult3);
                            Log.i(TAG, "handleFpResult::IDENTIFY_FAILED");
                            return;
                        default:
                            return;
                    }
                } else {
                    return;
                }
            case 1073:
                Log.d(TAG, "handleFpResult::FP_RES_FINGER_DETECTED");
                Fingerprint.FingerprintEventListener fingerprintEventListener3 = mFingerprintEventListener;
                if (fingerprintEventListener3 != null) {
                    fingerprintEventListener3.onFingerprintEvent(1041, null);
                    Log.i(TAG, "handleFpResult::CAPTURE_STARTED");
                    return;
                }
                return;
            case 1074:
                Log.d(TAG, "handleFpResult::FP_RES_FINGER_REMOVED");
                if (!(mFingerprintEventListener == null || this.mIsFilterOn || Fingerprint.m_abort)) {
                    mFingerprintEventListener.onFingerprintEvent(1043, null);
                    Log.i(TAG, "handleFpResult::CAPTURE_FINISHED");
                    return;
                }
                return;
            case 1075:
                Log.d(TAG, "handleFpResult::FP_RES_FINGER_WAIT_FPON");
                Fingerprint.FingerprintEventListener fingerprintEventListener4 = mFingerprintEventListener;
                if (!(fingerprintEventListener4 == null || this.mIsFilterOn)) {
                    fingerprintEventListener4.onFingerprintEvent(1040, null);
                    Log.i(TAG, "handleFpResult::CAPTURE_READY");
                    return;
                }
                return;
            case 1082:
                Log.d(TAG, "handleFpResult::FP_RES_PARTIAL_IMG");
                notifyOnBadImage(Integer.MIN_VALUE, this.mBadImageData, this.mBadImageDataInfo);
                return;
            case FpResDef.FP_RES_REDUNDANT_IMG:
                Log.d(TAG, "handleFpResult::FP_RES_REDUNDANT_IMG");
                notifyOnBadImage(256, this.mBadImageData, this.mBadImageDataInfo);
                return;
            case 1084:
                Log.d(TAG, "handleFpResult::FP_RES_BAD_IMG");
                notifyOnBadImage(32, this.mBadImageData, this.mBadImageDataInfo);
                return;
            case 1085:
                Log.d(TAG, "handleFpResult::FP_RES_WATER_IMG");
                notifyOnBadImage(4096, this.mBadImageData, this.mBadImageDataInfo);
                return;
            case 1086:
                Log.d(TAG, "handleFpResult::FP_RES_FAST_IMG");
                notifyOnBadImage(512, this.mBadImageData, this.mBadImageDataInfo);
                return;
            case 1087:
                Log.d(TAG, "handleFpResult::FP_RES_TEST_ENROLL_OK");
                Fingerprint.FingerprintEventListener fingerprintEventListener5 = mFingerprintEventListener;
                if (fingerprintEventListener5 != null) {
                    fingerprintEventListener5.onFingerprintEvent(1001, null);
                    Log.i(TAG, "handleFpResult::ENROLL_SUCCESS");
                }
                this.mEnrollUserId = null;
                return;
            case 1088:
                Log.d(TAG, "handleFpResult::FP_RES_TEST_ENROLL_FAIL");
                Fingerprint.FingerprintEventListener fingerprintEventListener6 = mFingerprintEventListener;
                if (fingerprintEventListener6 != null) {
                    fingerprintEventListener6.onFingerprintEvent(1002, null);
                    Log.i(TAG, "handleFpResult::ENROLL_FAILED");
                }
                this.mEnrollUserId = null;
                this.mEnrollIndex = 0;
                return;
            case 1089:
                Log.d(TAG, "handleFpResult::FP_RES_TEST_MATCHED_OK");
                this.mIsFingerOrPWValidate = true;
                Fingerprint.FingerprintEventListener fingerprintEventListener7 = mFingerprintEventListener;
                if (fingerprintEventListener7 != null) {
                    fingerprintEventListener7.onFingerprintEvent(1020, null);
                    Log.i(TAG, "handleFpResult::IDENTIFY_SUCCESS");
                    return;
                }
                return;
            case 1090:
                Log.d(TAG, "handleFpResult::FP_RES_TEST_MATCHED_FAIL");
                Fingerprint.FingerprintEventListener fingerprintEventListener8 = mFingerprintEventListener;
                if (fingerprintEventListener8 != null) {
                    fingerprintEventListener8.onFingerprintEvent(1021, null);
                    Log.i(TAG, "handleFpResult::IDENTIFY_FAILED");
                    return;
                }
                return;
            case 2020:
                Log.d(TAG, "handleFpResult::EVT_ERROR");
                mFingerprintEventListener.onFingerprintEvent(2020, null);
                return;
            case 2031:
                Log.d(TAG, "handleFpResult::FACTORY_WRITE_EEPROM_SCRIPT_START");
                mFingerprintEventListener.onFingerprintEvent(2031, null);
                return;
            case 2032:
                Log.d(TAG, "handleFpResult::FACTORY_WRITE_EEPROM_SCRIPT_END");
                mFingerprintEventListener.onFingerprintEvent(2032, null);
                return;
            case 285212675:
                Log.d(TAG, "handleFpResult::FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_START");
                mFingerprintEventListener.onFingerprintEvent(285212675, null);
                return;
            case 285212676:
                Log.d(TAG, "handleFpResult::FACTORY_TEST_EVT_SNSR_TEST_SCRIPT_END");
                mFingerprintEventListener.onFingerprintEvent(285212676, null);
                return;
            case 285212678:
                Log.d(TAG, "handleFpResult::FACTORY_TEST_EVT_SNSR_TEST_PUT");
                mFingerprintEventListener.onFingerprintEvent(285212678, null);
                return;
            case 285212679:
                Log.d(TAG, "handleFpResult::FACTORY_TEST_EVT_SNSR_TEST_PUT2");
                mFingerprintEventListener.onFingerprintEvent(285212679, null);
                return;
            case 285212680:
                Log.d(TAG, "handleFpResult::FACTORY_TEST_EVT_SNSR_TEST_PUT3");
                mFingerprintEventListener.onFingerprintEvent(285212680, null);
                return;
            case 285212681:
                Log.d(TAG, "handleFpResult::FACTORY_TEST_EVT_SNSR_TEST_WAIT_COMMAND");
                mFingerprintEventListener.onFingerprintEvent(285212681, null);
                return;
            default:
                return;
        }
    }

    public static EgisFingerprint create(Context context) {
        Log.d(TAG, "create()");
        mContext = context;
        if (mInstance == null) {
            Log.d(TAG, "create(), new EgisFingerprint()");
            mInstance = new EgisFingerprint();
        }
        return mInstance;
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public void setEventListener(Fingerprint.FingerprintEventListener fingerprintEventListener) {
        Log.d(TAG, "setEventListener()");
        mFingerprintEventListener = fingerprintEventListener;
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public String getVersion() {
        String sdkVersion = this.mFPNativeBase.getVersion();
        String[] sdkVersionArray = sdkVersion.split("\\.");
        if (sdkVersionArray.length != 4) {
            Log.e(TAG, "getVersion(), SDK Version length = " + sdkVersionArray.length);
            return "UNKNOW_VERSION";
        }
        String outputVersion = "3.9." + sdkVersionArray[2] + "." + sdkVersionArray[3];
        Log.d(TAG, "getVersion(), SDK Version = " + sdkVersion + ", Output Version = " + outputVersion);
        return outputVersion;
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int getSensorStatus() {
        Log.d(TAG, "getSensorStatus()");
        return this.mFPNativeBase.getSensorStatus();
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int[] getFingerprintIndexList(String userId) {
        Log.d(TAG, "getFingerprintindexList(), userId = " + userId);
        String enrollList = this.mFPNativeBase.getEnrollList(userId);
        Log.d(TAG, "enrollList=" + enrollList);
        if (enrollList != null && !enrollList.equals("")) {
            String[] fingers = fpSplitor(enrollList);
            Arrays.sort(fingers);
            Log.d(TAG, "getFingerprintindexList(), fingers = " + Arrays.toString(fingers));
            int[] fingerIndex = new int[fingers.length];
            for (int i = 0; i < fingerIndex.length; i++) {
                fingerIndex[i] = this.fingerIndexMap.get(fingers[i]).intValue();
                Log.d(TAG, "getFingerprintindexList(), fingerIndex[" + i + "] = " + fingerIndex[i]);
            }
            return fingerIndex;
        } else if (enrollList == null) {
            Log.e(TAG, "getFingerprintindexList(),, enrollList == null");
            return null;
        } else {
            Log.e(TAG, "getFingerprintindexList(), enrollList.equals(\"\") == true");
            return null;
        }
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public byte[] getFingerprintId(String userId, int index) {
        Log.d(TAG, "getFingerprintId(), userId = " + userId + ", index = " + index);
        if (userId == null || userId.equals("") || this.indexMapToFinger.get(index) == null) {
            Log.e(TAG, "getFingerprintId(). input parameter error");
            return null;
        }
        FPNativeBase fPNativeBase = this.mFPNativeBase;
        String str = fPNativeBase.dataRead("EGISFPID;" + userId + ";" + this.indexMapToFinger.get(index), PASSWORD);
        if (str != null) {
            return str.getBytes();
        }
        Log.e(TAG, "getFingerprintId(), data read error");
        return null;
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public String[] getUserIdList() {
        Log.d(TAG, "getUserIdList()");
        return this.mFPNativeBase.getUserIdList();
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int getEnrollRepeatCount() {
        Log.d(TAG, "getEnrollRepeatCount()");
        int[] enrollStatus = this.mFPNativeBase.getEnrollStatus();
        if (enrollStatus[0] == 0 && enrollStatus[1] == 0 && enrollStatus[2] == 0) {
            Log.d(TAG, "getEnrollRepeatCount(), enrollStatus is null");
            return -1;
        }
        Log.d(TAG, "getEnrollRepeatCount(), " + enrollStatus[0] + ", " + enrollStatus[1] + ", " + enrollStatus[2]);
        return enrollStatus[0] + enrollStatus[1];
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public String getSensorInfo() {
        Log.d(TAG, "getSensorInfo()");
        return this.mFPNativeBase.getSensorInfo();
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int[] getTestItemNumber() {
        Log.d(TAG, "getTestItemNumber()");
        return this.mFPNativeBase.getTestItemNumber();
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int setAccuracyLevel(int level) {
        Log.d(TAG, "setAccuracyLevel(), level = " + level);
        return this.mFPNativeBase.setAccuracyLevel(level);
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int setEnrollSession(boolean flag) {
        Log.d(TAG, "setEnrollSession(), flag = " + flag);
        this.mIsEnrollSessionOpen = flag;
        this.mIsFingerOrPWValidate = false;
        return 0;
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int setPassword(String userId, byte[] pwdHash) throws UnsupportedEncodingException {
        Log.d(TAG, "setPassword(), userId = " + userId);
        if (!this.mIsEnrollSessionOpen) {
            Log.e(TAG, "setPassword(), mIsEnrollSessionOpen");
            return -4;
        } else if (userId.isEmpty()) {
            Log.e(TAG, "setPassword(), userId");
            return -4;
        } else {
            if (!hasFinger(userId) && !hasPasswd(userId)) {
                this.mIsFingerOrPWValidate = true;
            }
            if (!this.mIsFingerOrPWValidate) {
                Log.e(TAG, "setPassword(), no validate finger");
                return -4;
            }
            FPNativeBase fPNativeBase = this.mFPNativeBase;
            if (!fPNativeBase.dataSet("EGISPWD;" + userId, new String(pwdHash, "UTF-8"), PASSWORD)) {
                return -1;
            }
            if (!this.mFPNativeBase.doEnrollToDB(userId)) {
                return 0;
            }
            Log.d(TAG, "setPassword(), save dataSet = EGISFPID;" + userId + ";" + this.indexMapToFinger.get(this.mEnrollIndex));
            FPNativeBase fPNativeBase2 = this.mFPNativeBase;
            fPNativeBase2.dataSet("EGISFPID;" + userId + ";" + this.indexMapToFinger.get(this.mEnrollIndex), UUID.randomUUID().toString(), PASSWORD);
            return 0;
        }
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int verifyPassword(String userId, byte[] pwdHash) throws UnsupportedEncodingException {
        Log.d(TAG, "verifyPassword(), userId = " + userId);
        FPNativeBase fPNativeBase = this.mFPNativeBase;
        String dbPwd = fPNativeBase.dataRead("EGISPWD;" + userId, PASSWORD);
        if (dbPwd == null) {
            Log.e(TAG, "verifyPassword(), dbPwd");
            return -1;
        }
        String keyInPw = new String(pwdHash, "UTF-8");
        Log.d(TAG, "verifyPassword(), keyInPw = " + keyInPw + " dbPwd = " + dbPwd);
        if (!keyInPw.equals(dbPwd)) {
            return -1;
        }
        this.mIsFingerOrPWValidate = true;
        return 0;
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int identify(String userId) {
        Log.d(TAG, "identify(), userId = " + userId);
        if (userId == null || userId.equals("")) {
            Log.d(TAG, "identify(), Invalid userId");
            return -1;
        } else if (userId != "Test") {
            this.mIsFilterOn = false;
            if (this.mFPNativeBase.identify(userId)) {
                return 0;
            }
            return -1;
        } else if (this.mFPNativeBase.testEnrollmentAndVerification(false)) {
            return 0;
        } else {
            return -1;
        }
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int enroll(String userId, int index) {
        Log.d(TAG, "enroll(), userId = " + userId + ", index = " + index);
        if (userId == null || userId.equals("") || this.indexMapToFinger.get(index) == null) {
            Log.d(TAG, "enroll(), Invalid userId or index");
            return -1;
        } else if (userId == "Test") {
            if (this.mFPNativeBase.testEnrollmentAndVerification(true)) {
                return 0;
            }
            return -1;
        } else if (!this.mIsEnrollSessionOpen) {
            Log.e(TAG, "enroll(), no open enrollSession");
            return -4;
        } else {
            if (!hasFinger(userId) && !hasPasswd(userId)) {
                this.mIsFingerOrPWValidate = true;
            }
            if (!this.mIsFingerOrPWValidate) {
                Log.e(TAG, "enroll(), no validate finger or password");
                return -4;
            }
            int[] fingerList = getFingerprintIndexList(userId);
            boolean hasID = false;
            if (fingerList == null || fingerList.length < 5) {
                hasID = true;
            } else {
                for (int i : fingerList) {
                    if (i == index) {
                        hasID = true;
                    }
                }
            }
            if (!hasID) {
                Log.d(TAG, "enroll(), Too many");
                return -5;
            }
            this.mIsFilterOn = false;
            String egisId = userId + ";" + this.indexMapToFinger.get(index);
            Log.d(TAG, "enroll(), egisId = " + egisId);
            if (!this.mFPNativeBase.enroll(egisId)) {
                return -1;
            }
            this.mEnrollUserId = userId;
            this.mEnrollIndex = index;
            Log.d(TAG, "enroll(), mEnrollUserId = " + this.mEnrollUserId + ", mEnrollIndex = " + this.mEnrollIndex);
            return 0;
        }
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int swipeEnroll(String userId, int index) {
        Log.d(TAG, "swipeEnroll(), userId = " + userId + ", index = " + index);
        if (userId == null || userId.equals("") || this.indexMapToFinger.get(index) == null) {
            Log.d(TAG, "swipeEnroll(), Invalid userId or index");
            return -1;
        } else if (userId == "Test") {
            if (this.mFPNativeBase.testEnrollmentAndVerification(true)) {
                return 0;
            }
            return -1;
        } else if (!this.mIsEnrollSessionOpen) {
            Log.e(TAG, "swipeEnroll(), no open enrollSession");
            return -4;
        } else {
            if (!hasFinger(userId) && !hasPasswd(userId)) {
                this.mIsFingerOrPWValidate = true;
            }
            if (!this.mIsFingerOrPWValidate) {
                Log.e(TAG, "swipeEnroll(), no validate finger or password");
                return -4;
            }
            int[] fingerList = getFingerprintIndexList(userId);
            boolean hasID = false;
            if (fingerList == null || fingerList.length < 5) {
                hasID = true;
            } else {
                for (int i : fingerList) {
                    if (i == index) {
                        hasID = true;
                    }
                }
            }
            if (!hasID) {
                Log.d(TAG, "swipeEnroll(), Too many");
                return -5;
            }
            this.mIsFilterOn = false;
            String egisId = userId + ";" + this.indexMapToFinger.get(index);
            Log.d(TAG, "swipeEnroll(), egisId = " + egisId);
            if (!this.mFPNativeBase.swipeEnroll(egisId)) {
                return -1;
            }
            this.mEnrollUserId = userId;
            this.mEnrollIndex = index;
            Log.d(TAG, "swipeEnroll(), mEnrollUserId = " + this.mEnrollUserId + ", mEnrollIndex = " + this.mEnrollIndex);
            return 0;
        }
    }

    private boolean hasFinger(String userId) {
        Log.d(TAG, "hasFinger(), userId = " + userId);
        String enrollList = this.mFPNativeBase.getEnrollList(userId);
        Log.d(TAG, "hasFinger(), enrollList = " + enrollList);
        return enrollList != null && !enrollList.equals("");
    }

    private boolean hasPasswd(String userId) {
        Log.d(TAG, "hasPasswd(), userId = " + userId);
        FPNativeBase fPNativeBase = this.mFPNativeBase;
        if (fPNativeBase.dataRead("EGISPWD;" + userId, PASSWORD) != null) {
            return true;
        }
        Log.e(TAG, "hasPasswd(), dataRead false");
        return false;
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int remove(String userId, int index) {
        Log.d(TAG, "remove(), userId = " + userId + "index = " + index);
        if (userId == null || userId.equals("") || this.indexMapToFinger.get(index) == null) {
            Log.e(TAG, "remove(), Invalid userId");
            return -1;
        } else if (!this.mIsEnrollSessionOpen) {
            Log.e(TAG, "remove(), no open enrollSession");
            return -4;
        } else {
            if (!hasFinger(userId) && !hasPasswd(userId)) {
                this.mIsFingerOrPWValidate = true;
            }
            if (!this.mIsFingerOrPWValidate) {
                Log.e(TAG, "remove(), no validate finger or password");
                return -4;
            } else if (!hasFinger(userId)) {
                Log.e(TAG, "remove(), hasFinger()");
                return -1;
            } else {
                if (!this.mFPNativeBase.deleteFeature(userId + ";" + this.indexMapToFinger.get(index))) {
                    Log.e(TAG, "remove(), deleteFeature()");
                    return -1;
                }
                FPNativeBase fPNativeBase = this.mFPNativeBase;
                fPNativeBase.dataDelete("EGISFPID;" + userId + ";" + this.indexMapToFinger.get(index), PASSWORD);
                String enrollList = this.mFPNativeBase.getEnrollList(userId);
                StringBuilder sb = new StringBuilder();
                sb.append("remove(), enrollList = ");
                sb.append(enrollList);
                Log.d(TAG, sb.toString());
                if (enrollList != null && !enrollList.equals("")) {
                    return 0;
                }
                Log.d(TAG, "remove(), no finger, so delete password");
                FPNativeBase fPNativeBase2 = this.mFPNativeBase;
                fPNativeBase2.dataDelete("EGISPWD;" + userId, PASSWORD);
                return 0;
            }
        }
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int request(int status, Object obj) {
        Log.d(TAG, "request(), status = " + status);
        return this.mFPNativeBase.sensorControl(status, 0);
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int verifySensorState(int cmd, int sId, int opt, int logOpt, int uId) {
        Log.d(TAG, "verifySensorState(), cmd = " + cmd + ", opt = " + opt);
        return this.mFPNativeBase.sensorControl(cmd, opt);
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int cancel() {
        Log.d(TAG, "cancel()");
        if (this.mFPNativeBase.abort()) {
            return 0;
        }
        return -1;
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int cleanup() {
        Log.d(TAG, "cleanup()");
        mContext = null;
        mInstance = null;
        return this.mFPNativeBase.cleanup();
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int enableSensorDevice(boolean enable) {
        Log.d(TAG, "enableSensorDevice(), enable = " + enable);
        int ret = this.mFPNativeBase.sensorDeviceEnable(enable);
        Log.d(TAG, "enableSensorDevice(), ret = " + ret);
        return ret;
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public int eepromTest(int cmd, int address, int value) {
        Log.d(TAG, "eepromTest(), cmd = " + cmd + ", address = " + address + ", value = " + value);
        return this.mFPNativeBase.eepromTest(cmd, address, value);
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public void setForCaptureFrame(int expTime, int hwIntegrate, int pgaGain) {
        this.mFPNativeBase.setForCaptureFrame(expTime, hwIntegrate, pgaGain);
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public void triggerTouchEvent(int motionEventCase) {
        this.mFPNativeBase.triggerTouchEvent(motionEventCase);
    }

    @Override // egistec.optical.csa.client.api.IFingerprint
    public void calibration() {
        this.mFPNativeBase.calibration();
    }
}
