package hwbinder;

import android.os.IHwBinder;
import android.os.Process;
import android.os.RemoteException;
import android.util.Log;
import com.goodix.fingerprint.CmdResult;
import com.goodix.fingerprint.proxy.DaemonProxyBase;
import com.goodix.fingerprint.proxy.IDaemonDiedCallback;
import com.goodix.fingerprint.proxy.IGFDaemon;
import com.goodix.fingerprint.proxy.IGFDaemonCallback;
import com.goodix.fingerprint.proxy.IGFDaemonFido;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.NoSuchElementException;
import vendor.goodix.hardware.biometrics.fingerprint.V2_2.IGoodixFingerprintDaemon;
import vendor.goodix.hardware.biometrics.fingerprint.V2_2.IGoodixFingerprintDaemonCallback;

public class DaemonProxy extends DaemonProxyBase {
    private static final int CMD_ERROR = -1986;
    private static final String TAG = "HwBinderDaemonProxy";

    /* access modifiers changed from: protected */
    @Override // com.goodix.fingerprint.proxy.DaemonProxyBase
    public DaemonProxyBase.Daemon getGFDaemonImp(IGFDaemonCallback callback) {
        return new GFDaemonImp(callback);
    }

    /* access modifiers changed from: protected */
    @Override // com.goodix.fingerprint.proxy.DaemonProxyBase
    public DaemonProxyBase.Daemon getGFDaemonFidoImp(IGFDaemonCallback callback) {
        return new GFDaemonFidoImp(callback);
    }

    private abstract class HwBinderDaemon extends DaemonProxyBase.Daemon implements IHwBinder.DeathRecipient {
        IDaemonDiedCallback mDaemonCallback;

        /* access modifiers changed from: package-private */
        public abstract void handleServiceDied();

        private HwBinderDaemon() {
            super();
            this.mDaemonCallback = null;
        }

        public void serviceDied(long cookie) {
            handleServiceDied();
            IDaemonDiedCallback iDaemonDiedCallback = this.mDaemonCallback;
            if (iDaemonDiedCallback != null) {
                iDaemonDiedCallback.onDaemonDied();
            }
        }

        /* access modifiers changed from: package-private */
        public ArrayList<Byte> toArrayList(byte[] param) {
            if (param == null || param.length == 0) {
                return new ArrayList<>();
            }
            Byte[] p = new Byte[param.length];
            for (int i = 0; i < param.length; i++) {
                p[i] = Byte.valueOf(param[i]);
            }
            return new ArrayList<>(Arrays.asList(p));
        }

        /* access modifiers changed from: package-private */
        public byte[] toByteArray(ArrayList<Byte> list) {
            if (list == null || list.size() == 0) {
                return null;
            }
            Byte[] tmp = new Byte[list.size()];
            list.toArray(tmp);
            byte[] ret = new byte[tmp.length];
            for (int i = 0; i < tmp.length; i++) {
                ret[i] = tmp[i].byteValue();
            }
            return ret;
        }

        /* access modifiers changed from: package-private */
        public int[] toIntArray(ArrayList<Integer> list) {
            if (list == null || list.size() == 0) {
                return null;
            }
            Integer[] tmp = new Integer[list.size()];
            list.toArray(tmp);
            int[] ret = new int[tmp.length];
            for (int i = 0; i < tmp.length; i++) {
                ret[i] = tmp[i].byteValue();
            }
            return ret;
        }
    }

    private class GFDaemonImp extends HwBinderDaemon implements IGFDaemon {
        private IGoodixFingerprintDaemon mDaemon = null;
        private IGoodixFingerprintDaemonCallback mGFDaemonCallback = new IGoodixFingerprintDaemonCallback.Stub() {
            /* class hwbinder.DaemonProxy.GFDaemonImp.AnonymousClass2 */

            @Override // vendor.goodix.hardware.biometrics.fingerprint.V2_2.IGoodixFingerprintDaemonCallback
            public void onDaemonMessage(long devId, int msgId, int cmdId, ArrayList<Byte> data) {
                Log.d(DaemonProxy.TAG, "onDaemonMessage current PID : " + Process.myPid());
                Log.d(DaemonProxy.TAG, "onDaemonMessage cmdId : " + cmdId);
                if (GFDaemonImp.this.mDaemonCallback != null) {
                    ((IGFDaemonCallback) GFDaemonImp.this.mDaemonCallback).onDaemonMessage(devId, msgId, cmdId, GFDaemonImp.this.toByteArray(data));
                }
            }
        };

        public GFDaemonImp(IGFDaemonCallback callback) {
            super();
            this.mDaemonCallback = callback;
        }

        @Override // com.goodix.fingerprint.proxy.DaemonProxyBase.Daemon
        public Object getService() {
            try {
                Log.d(DaemonProxy.TAG, "getService begin");
                IGoodixFingerprintDaemon service = IGoodixFingerprintDaemon.getService();
                this.mDaemon = service;
                if (service != null) {
                    service.asBinder().linkToDeath(this, 0);
                    Log.d(DaemonProxy.TAG, "getService mDaemon.setNotify : " + this.mGFDaemonCallback);
                    this.mDaemon.setNotify(this.mGFDaemonCallback);
                }
            } catch (NoSuchElementException e) {
            } catch (RemoteException e2) {
                this.mDaemon = null;
            }
            return this.mDaemon;
        }

        /* access modifiers changed from: package-private */
        @Override // hwbinder.DaemonProxy.HwBinderDaemon
        public void handleServiceDied() {
            this.mDaemon = null;
        }

        @Override // com.goodix.fingerprint.proxy.IGFDaemon
        public void setNotify(IGFDaemonCallback callback) {
            this.mDaemonCallback = callback;
        }

        @Override // com.goodix.fingerprint.proxy.IGFDaemon
        public CmdResult sendCommand(int cmdId, byte[] param) throws RemoteException {
            final CmdResult ret = new CmdResult();
            IGoodixFingerprintDaemon daemon = (IGoodixFingerprintDaemon) getService();
            Log.d(DaemonProxy.TAG, "sendCommand current PID : " + Process.myPid());
            Log.d(DaemonProxy.TAG, "sendCommand cmdId : " + cmdId);
            if (this.mDaemon != null) {
                daemon.sendCommand(cmdId, toArrayList(param), new IGoodixFingerprintDaemon.sendCommandCallback() {
                    /* class hwbinder.DaemonProxy.GFDaemonImp.AnonymousClass1 */

                    @Override // vendor.goodix.hardware.biometrics.fingerprint.V2_2.IGoodixFingerprintDaemon.sendCommandCallback
                    public void onValues(int resultCode, ArrayList<Byte> out_buf) {
                        ret.mResultCode = resultCode;
                        ret.mResultData = GFDaemonImp.this.toByteArray(out_buf);
                    }
                });
            }
            return ret;
        }
    }

    private class GFDaemonFidoImp extends HwBinderDaemon implements IGFDaemonFido {
        private byte[] mCmdOutBuf = null;
        private int mCmdRet = 0;
        private int[] mIdList = null;

        public GFDaemonFidoImp(IGFDaemonCallback callback) {
            super();
            this.mDaemonCallback = callback;
        }

        @Override // com.goodix.fingerprint.proxy.DaemonProxyBase.Daemon
        public Object getService() {
            return null;
        }

        /* access modifiers changed from: package-private */
        @Override // hwbinder.DaemonProxy.HwBinderDaemon
        public void handleServiceDied() {
        }

        @Override // com.goodix.fingerprint.proxy.IGFDaemonFido
        public int authenticateFido(int groupId, byte[] aaid, byte[] finalChallenge) throws RemoteException {
            return 0;
        }

        @Override // com.goodix.fingerprint.proxy.IGFDaemonFido
        public int stopAuthenticateFido() throws RemoteException {
            return 0;
        }

        @Override // com.goodix.fingerprint.proxy.IGFDaemonFido
        public int isIdValid(int groupId, int fingerId) throws RemoteException {
            return 0;
        }

        @Override // com.goodix.fingerprint.proxy.IGFDaemonFido
        public synchronized int[] getIdList(int groupId) throws RemoteException {
            return null;
        }

        @Override // com.goodix.fingerprint.proxy.IGFDaemonFido
        public synchronized int invokeFidoCommand(byte[] inBuf, byte[] outBuf) throws RemoteException {
            this.mCmdRet = 0;
            return 0;
        }
    }
}
