package org.apache.poi.ddf;

import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndian;

public class EscherBlipRecord extends EscherRecord {
    private static final int HEADER_SIZE = 8;
    public static final String RECORD_DESCRIPTION = "msofbtBlip";
    public static final short RECORD_ID_END = -3817;
    public static final short RECORD_ID_START = -4072;
    protected byte[] field_pictureData;

    @Override // org.apache.poi.ddf.EscherRecord
    public int fillFields(byte[] data, int offset, EscherRecordFactory recordFactory) {
        int bytesAfterHeader = readHeader(data, offset);
        byte[] bArr = new byte[bytesAfterHeader];
        this.field_pictureData = bArr;
        System.arraycopy(data, offset + 8, bArr, 0, bytesAfterHeader);
        return bytesAfterHeader + 8;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int serialize(int offset, byte[] data, EscherSerializationListener listener) {
        listener.beforeRecordSerialize(offset, getRecordId(), this);
        LittleEndian.putShort(data, offset, getOptions());
        LittleEndian.putShort(data, offset + 2, getRecordId());
        byte[] bArr = this.field_pictureData;
        System.arraycopy(bArr, 0, data, offset + 4, bArr.length);
        listener.afterRecordSerialize(offset + 4 + this.field_pictureData.length, getRecordId(), this.field_pictureData.length + 4, this);
        return this.field_pictureData.length + 4;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int getRecordSize() {
        return this.field_pictureData.length + 8;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public String getRecordName() {
        return "Blip";
    }

    public byte[] getPicturedata() {
        return this.field_pictureData;
    }

    public void setPictureData(byte[] pictureData) {
        if (pictureData != null) {
            this.field_pictureData = (byte[]) pictureData.clone();
            return;
        }
        throw new IllegalArgumentException("picture data can't be null");
    }

    public String toString() {
        String extraData = HexDump.toHex(this.field_pictureData, 32);
        return getClass().getName() + ":" + '\n' + "  RecordId: 0x" + HexDump.toHex(getRecordId()) + '\n' + "  Version: 0x" + HexDump.toHex(getVersion()) + '\n' + "  Instance: 0x" + HexDump.toHex(getInstance()) + '\n' + "  Extra Data:" + '\n' + extraData;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public String toXml(String tab) {
        String extraData = HexDump.toHex(this.field_pictureData, 32);
        return tab + formatXmlRecordHeader(getClass().getSimpleName(), HexDump.toHex(getRecordId()), HexDump.toHex(getVersion()), HexDump.toHex(getInstance())) + tab + "\t" + "<ExtraData>" + extraData + "</ExtraData>\n" + tab + "</" + getClass().getSimpleName() + ">\n";
    }
}
