package org.apache.poi.ddf;

import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndian;

public class EscherClientDataRecord extends EscherRecord {
    public static final String RECORD_DESCRIPTION = "MsofbtClientData";
    public static final short RECORD_ID = -4079;
    private byte[] remainingData;

    @Override // org.apache.poi.ddf.EscherRecord
    public int fillFields(byte[] data, int offset, EscherRecordFactory recordFactory) {
        int bytesRemaining = readHeader(data, offset);
        byte[] bArr = new byte[bytesRemaining];
        this.remainingData = bArr;
        System.arraycopy(data, offset + 8, bArr, 0, bytesRemaining);
        return bytesRemaining + 8;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int serialize(int offset, byte[] data, EscherSerializationListener listener) {
        listener.beforeRecordSerialize(offset, getRecordId(), this);
        if (this.remainingData == null) {
            this.remainingData = new byte[0];
        }
        LittleEndian.putShort(data, offset, getOptions());
        LittleEndian.putShort(data, offset + 2, getRecordId());
        LittleEndian.putInt(data, offset + 4, this.remainingData.length);
        byte[] bArr = this.remainingData;
        System.arraycopy(bArr, 0, data, offset + 8, bArr.length);
        int pos = offset + 8 + this.remainingData.length;
        listener.afterRecordSerialize(pos, getRecordId(), pos - offset, this);
        return pos - offset;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public int getRecordSize() {
        byte[] bArr = this.remainingData;
        return (bArr == null ? 0 : bArr.length) + 8;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public short getRecordId() {
        return RECORD_ID;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public String getRecordName() {
        return "ClientData";
    }

    public String toString() {
        String nl = System.getProperty("line.separator");
        String extraData = HexDump.dump(getRemainingData(), 0, 0);
        return getClass().getName() + ":" + nl + "  RecordId: 0x" + HexDump.toHex((short) RECORD_ID) + nl + "  Version: 0x" + HexDump.toHex(getVersion()) + nl + "  Instance: 0x" + HexDump.toHex(getInstance()) + nl + "  Extra Data:" + nl + extraData;
    }

    @Override // org.apache.poi.ddf.EscherRecord
    public String toXml(String tab) {
        String extraData = HexDump.dump(getRemainingData(), 0, 0).trim();
        return tab + formatXmlRecordHeader(getClass().getSimpleName(), HexDump.toHex(getRecordId()), HexDump.toHex(getVersion()), HexDump.toHex(getInstance())) + tab + "\t" + "<ExtraData>" + extraData + "</ExtraData>\n" + tab + "</" + getClass().getSimpleName() + ">\n";
    }

    public byte[] getRemainingData() {
        return this.remainingData;
    }

    public void setRemainingData(byte[] remainingData2) {
        this.remainingData = remainingData2 == null ? new byte[0] : (byte[]) remainingData2.clone();
    }
}
