package org.apache.poi.ddf;

import android.support.v4.os.EnvironmentCompat;
import com.goodix.cap.fingerprint.utils.TestResultParser;
import com.goodix.display.fingerprint.insystem.InSystemTest;
import com.goodix.fingerprint.ShenzhenConstants;
import com.goodix.fingerprint.utils.ShenzhenTestResultParser;
import com.sec.factory.aporiented.athandler.AtTspptestStandard;
import com.sec.factory.app.factorytest.FactoryTestManager;
import java.util.HashMap;
import java.util.Map;
import org.apache.poi.util.Units;

public final class EscherProperties {
    public static final short BLIP__BLIPFILENAME = 261;
    public static final short BLIP__BLIPFLAGS = 262;
    public static final short BLIP__BLIPTODISPLAY = 260;
    public static final short BLIP__BRIGHTNESSSETTING = 265;
    public static final short BLIP__CONTRASTSETTING = 264;
    public static final short BLIP__CROPFROMBOTTOM = 257;
    public static final short BLIP__CROPFROMLEFT = 258;
    public static final short BLIP__CROPFROMRIGHT = 259;
    public static final short BLIP__CROPFROMTOP = 256;
    public static final short BLIP__DOUBLEMOD = 268;
    public static final short BLIP__GAMMA = 266;
    public static final short BLIP__NOHITTESTPICTURE = 316;
    public static final short BLIP__PICTUREACTIVE = 319;
    public static final short BLIP__PICTUREBILEVEL = 318;
    public static final short BLIP__PICTUREFILLMOD = 269;
    public static final short BLIP__PICTUREGRAY = 317;
    public static final short BLIP__PICTUREID = 267;
    public static final short BLIP__PICTURELINE = 270;
    public static final short BLIP__PRINTBLIP = 271;
    public static final short BLIP__PRINTBLIPFILENAME = 272;
    public static final short BLIP__PRINTFLAGS = 273;
    public static final short BLIP__TRANSPARENTCOLOR = 263;
    public static final short CALLOUT__CALLOUTACCENTBAR = 890;
    public static final short CALLOUT__CALLOUTANGLE = 834;
    public static final short CALLOUT__CALLOUTDROPSPECIFIED = 836;
    public static final short CALLOUT__CALLOUTDROPTYPE = 835;
    public static final short CALLOUT__CALLOUTLENGTHSPECIFIED = 837;
    public static final short CALLOUT__CALLOUTMINUSX = 892;
    public static final short CALLOUT__CALLOUTMINUSY = 893;
    public static final short CALLOUT__CALLOUTTEXTBORDER = 891;
    public static final short CALLOUT__CALLOUTTYPE = 832;
    public static final short CALLOUT__DROPAUTO = 894;
    public static final short CALLOUT__ISCALLOUT = 889;
    public static final short CALLOUT__LENGTHSPECIFIED = 895;
    public static final short CALLOUT__XYCALLOUTGAP = 833;
    public static final short FILL__ANGLE = 395;
    public static final short FILL__BACKOPACITY = 388;
    public static final short FILL__BLIPFILENAME = 391;
    public static final short FILL__BLIPFLAGS = 392;
    public static final short FILL__CRMOD = 389;
    public static final short FILL__DZTYPE = 405;
    public static final short FILL__FILLBACKCOLOR = 387;
    public static final short FILL__FILLCOLOR = 385;
    public static final short FILL__FILLED = 443;
    public static final short FILL__FILLOPACITY = 386;
    public static final short FILL__FILLTYPE = 384;
    public static final short FILL__FOCUS = 396;
    public static final short FILL__HEIGHT = 394;
    public static final short FILL__HITTESTFILL = 444;
    public static final short FILL__NOFILLHITTEST = 447;
    public static final short FILL__ORIGINX = 408;
    public static final short FILL__ORIGINY = 409;
    public static final short FILL__PATTERNTEXTURE = 390;
    public static final short FILL__RECTBOTTOM = 404;
    public static final short FILL__RECTLEFT = 401;
    public static final short FILL__RECTRIGHT = 403;
    public static final short FILL__RECTTOP = 402;
    public static final short FILL__SHADECOLORS = 407;
    public static final short FILL__SHADEPRESET = 406;
    public static final short FILL__SHADETYPE = 412;
    public static final short FILL__SHAPE = 445;
    public static final short FILL__SHAPEORIGINX = 410;
    public static final short FILL__SHAPEORIGINY = 411;
    public static final short FILL__TOBOTTOM = 400;
    public static final short FILL__TOLEFT = 397;
    public static final short FILL__TORIGHT = 399;
    public static final short FILL__TOTOP = 398;
    public static final short FILL__USERECT = 446;
    public static final short FILL__WIDTH = 393;
    public static final short GEOMETRY__3DOK = 379;
    public static final short GEOMETRY__ADJUST10VALUE = 336;
    public static final short GEOMETRY__ADJUST2VALUE = 328;
    public static final short GEOMETRY__ADJUST3VALUE = 329;
    public static final short GEOMETRY__ADJUST4VALUE = 330;
    public static final short GEOMETRY__ADJUST5VALUE = 331;
    public static final short GEOMETRY__ADJUST6VALUE = 332;
    public static final short GEOMETRY__ADJUST7VALUE = 333;
    public static final short GEOMETRY__ADJUST8VALUE = 334;
    public static final short GEOMETRY__ADJUST9VALUE = 335;
    public static final short GEOMETRY__ADJUSTVALUE = 327;
    public static final short GEOMETRY__BOTTOM = 323;
    public static final short GEOMETRY__FILLOK = 383;
    public static final short GEOMETRY__FILLSHADESHAPEOK = 382;
    public static final short GEOMETRY__GEOTEXTOK = 381;
    public static final short GEOMETRY__LEFT = 320;
    public static final short GEOMETRY__LINEOK = 380;
    public static final short GEOMETRY__RIGHT = 322;
    public static final short GEOMETRY__SEGMENTINFO = 326;
    public static final short GEOMETRY__SHADOWok = 378;
    public static final short GEOMETRY__SHAPEPATH = 324;
    public static final short GEOMETRY__TOP = 321;
    public static final short GEOMETRY__VERTICES = 325;
    public static final short GEOTEXT__ALIGNMENTONCURVE = 194;
    public static final short GEOTEXT__BOLDFONT = 250;
    public static final short GEOTEXT__CHARBOUNDINGBOX = 246;
    public static final short GEOTEXT__DEFAULTPOINTSIZE = 195;
    public static final short GEOTEXT__FONTFAMILYNAME = 197;
    public static final short GEOTEXT__HASTEXTEFFECT = 241;
    public static final short GEOTEXT__ITALICFONT = 251;
    public static final short GEOTEXT__KERNCHARACTERS = 243;
    public static final short GEOTEXT__NOMEASUREALONGPATH = 249;
    public static final short GEOTEXT__REVERSEROWORDER = 240;
    public static final short GEOTEXT__ROTATECHARACTERS = 242;
    public static final short GEOTEXT__RTFTEXT = 193;
    public static final short GEOTEXT__SCALETEXTONPATH = 247;
    public static final short GEOTEXT__SHADOWFONT = 253;
    public static final short GEOTEXT__SMALLCAPSFONT = 254;
    public static final short GEOTEXT__STRETCHCHARHEIGHT = 248;
    public static final short GEOTEXT__STRETCHTOFITSHAPE = 245;
    public static final short GEOTEXT__STRIKETHROUGHFONT = 255;
    public static final short GEOTEXT__TEXTSPACING = 196;
    public static final short GEOTEXT__TIGHTORTRACK = 244;
    public static final short GEOTEXT__UNDERLINEFONT = 252;
    public static final short GEOTEXT__UNICODE = 192;
    public static final short GROUPSHAPE__1DADJUSTMENT = 957;
    public static final short GROUPSHAPE__BEHINDDOCUMENT = 954;
    public static final short GROUPSHAPE__BORDERBOTTOMCOLOR = 925;
    public static final short GROUPSHAPE__BORDERLEFTCOLOR = 924;
    public static final short GROUPSHAPE__BORDERRIGHTCOLOR = 926;
    public static final short GROUPSHAPE__BORDERTOPCOLOR = 923;
    public static final short GROUPSHAPE__DESCRIPTION = 897;
    public static final short GROUPSHAPE__EDITEDWRAP = 953;
    public static final short GROUPSHAPE__FLAGS = 959;
    public static final short GROUPSHAPE__HIDDEN = 958;
    public static final short GROUPSHAPE__HR_ALIGN = 916;
    public static final short GROUPSHAPE__HR_HEIGHT = 917;
    public static final short GROUPSHAPE__HR_PCT = 915;
    public static final short GROUPSHAPE__HR_WIDTH = 918;
    public static final short GROUPSHAPE__HYPERLINK = 898;
    public static final short GROUPSHAPE__ISBUTTON = 956;
    public static final short GROUPSHAPE__METROBLOB = 937;
    public static final short GROUPSHAPE__ONDBLCLICKNOTIFY = 955;
    public static final short GROUPSHAPE__POSH = 911;
    public static final short GROUPSHAPE__POSRELH = 912;
    public static final short GROUPSHAPE__POSRELV = 914;
    public static final short GROUPSHAPE__POSV = 913;
    public static final short GROUPSHAPE__PRINT = 959;
    public static final short GROUPSHAPE__REGROUPID = 904;
    public static final short GROUPSHAPE__SCRIPT = 910;
    public static final short GROUPSHAPE__SCRIPTEXT = 919;
    public static final short GROUPSHAPE__SCRIPTLANG = 920;
    public static final short GROUPSHAPE__SHAPENAME = 896;
    public static final short GROUPSHAPE__TABLEPROPERTIES = 927;
    public static final short GROUPSHAPE__TABLEROWPROPERTIES = 928;
    public static final short GROUPSHAPE__TOOLTIP = 909;
    public static final short GROUPSHAPE__UNUSED906 = 906;
    public static final short GROUPSHAPE__WEBBOT = 933;
    public static final short GROUPSHAPE__WRAPDISTBOTTOM = 903;
    public static final short GROUPSHAPE__WRAPDISTLEFT = 900;
    public static final short GROUPSHAPE__WRAPDISTRIGHT = 902;
    public static final short GROUPSHAPE__WRAPDISTTOP = 901;
    public static final short GROUPSHAPE__WRAPPOLYGONVERTICES = 899;
    public static final short GROUPSHAPE__ZORDER = 938;
    public static final short LINESTYLE__ANYLINE = 508;
    public static final short LINESTYLE__ARROWHEADSOK = 507;
    public static final short LINESTYLE__BACKCOLOR = 450;
    public static final short LINESTYLE__COLOR = 448;
    public static final short LINESTYLE__CRMOD = 451;
    public static final short LINESTYLE__FILLBLIP = 453;
    public static final short LINESTYLE__FILLBLIPFLAGS = 455;
    public static final short LINESTYLE__FILLBLIPNAME = 454;
    public static final short LINESTYLE__FILLDZTYPE = 458;
    public static final short LINESTYLE__FILLHEIGHT = 457;
    public static final short LINESTYLE__FILLWIDTH = 456;
    public static final short LINESTYLE__HITLINETEST = 509;
    public static final short LINESTYLE__LINEDASHING = 462;
    public static final short LINESTYLE__LINEDASHSTYLE = 463;
    public static final short LINESTYLE__LINEENDARROWHEAD = 465;
    public static final short LINESTYLE__LINEENDARROWLENGTH = 469;
    public static final short LINESTYLE__LINEENDARROWWIDTH = 468;
    public static final short LINESTYLE__LINEENDCAPSTYLE = 471;
    public static final short LINESTYLE__LINEFILLSHAPE = 510;
    public static final short LINESTYLE__LINEJOINSTYLE = 470;
    public static final short LINESTYLE__LINEMITERLIMIT = 460;
    public static final short LINESTYLE__LINESTARTARROWHEAD = 464;
    public static final short LINESTYLE__LINESTARTARROWLENGTH = 467;
    public static final short LINESTYLE__LINESTARTARROWWIDTH = 466;
    public static final short LINESTYLE__LINESTYLE = 461;
    public static final short LINESTYLE__LINETYPE = 452;
    public static final short LINESTYLE__LINEWIDTH = 459;
    public static final short LINESTYLE__NOLINEDRAWDASH = 511;
    public static final short LINESTYLE__NOLINEDRAWDASH_BOTTOM = 1599;
    public static final short LINESTYLE__NOLINEDRAWDASH_LEFT = 1407;
    public static final short LINESTYLE__NOLINEDRAWDASH_RIGHT = 1535;
    public static final short LINESTYLE__NOLINEDRAWDASH_TOP = 1471;
    public static final short LINESTYLE__OPACITY = 449;
    public static final short PERSPECTIVE__OFFSETX = 577;
    public static final short PERSPECTIVE__OFFSETY = 578;
    public static final short PERSPECTIVE__ORIGINX = 586;
    public static final short PERSPECTIVE__ORIGINY = 587;
    public static final short PERSPECTIVE__PERSPECTIVEON = 639;
    public static final short PERSPECTIVE__PERSPECTIVEX = 583;
    public static final short PERSPECTIVE__PERSPECTIVEY = 584;
    public static final short PERSPECTIVE__SCALEXTOX = 579;
    public static final short PERSPECTIVE__SCALEXTOY = 581;
    public static final short PERSPECTIVE__SCALEYTOX = 580;
    public static final short PERSPECTIVE__SCALEYTOY = 582;
    public static final short PERSPECTIVE__TYPE = 576;
    public static final short PERSPECTIVE__WEIGHT = 585;
    public static final short PROTECTION__LOCKADJUSTHANDLES = 126;
    public static final short PROTECTION__LOCKAGAINSTGROUPING = 127;
    public static final short PROTECTION__LOCKAGAINSTSELECT = 122;
    public static final short PROTECTION__LOCKASPECTRATIO = 120;
    public static final short PROTECTION__LOCKCROPPING = 123;
    public static final short PROTECTION__LOCKPOSITION = 121;
    public static final short PROTECTION__LOCKROTATION = 119;
    public static final short PROTECTION__LOCKTEXT = 125;
    public static final short PROTECTION__LOCKVERTICES = 124;
    public static final short SHADOWSTYLE__COLOR = 513;
    public static final short SHADOWSTYLE__CRMOD = 515;
    public static final short SHADOWSTYLE__HIGHLIGHT = 514;
    public static final short SHADOWSTYLE__OFFSETX = 517;
    public static final short SHADOWSTYLE__OFFSETY = 518;
    public static final short SHADOWSTYLE__OPACITY = 516;
    public static final short SHADOWSTYLE__ORIGINX = 528;
    public static final short SHADOWSTYLE__ORIGINY = 529;
    public static final short SHADOWSTYLE__PERSPECTIVEX = 525;
    public static final short SHADOWSTYLE__PERSPECTIVEY = 526;
    public static final short SHADOWSTYLE__SCALEXTOX = 521;
    public static final short SHADOWSTYLE__SCALEXTOY = 523;
    public static final short SHADOWSTYLE__SCALEYTOX = 522;
    public static final short SHADOWSTYLE__SCALEYTOY = 524;
    public static final short SHADOWSTYLE__SECONDOFFSETX = 519;
    public static final short SHADOWSTYLE__SECONDOFFSETY = 520;
    public static final short SHADOWSTYLE__SHADOW = 574;
    public static final short SHADOWSTYLE__SHADOWOBSURED = 575;
    public static final short SHADOWSTYLE__TYPE = 512;
    public static final short SHADOWSTYLE__WEIGHT = 527;
    public static final short SHAPE__BACKGROUNDSHAPE = 831;
    public static final short SHAPE__BLACKANDWHITESETTINGS = 772;
    public static final short SHAPE__CONNECTORSTYLE = 771;
    public static final short SHAPE__DELETEATTACHEDOBJECT = 830;
    public static final short SHAPE__LOCKSHAPETYPE = 828;
    public static final short SHAPE__MASTER = 769;
    public static final short SHAPE__OLEICON = 826;
    public static final short SHAPE__PREFERRELATIVERESIZE = 827;
    public static final short SHAPE__WMODEBW = 774;
    public static final short SHAPE__WMODEPUREBW = 773;
    public static final short TEXT__ANCHORTEXT = 135;
    public static final short TEXT__BIDIR = 139;
    public static final short TEXT__FONTROTATION = 137;
    public static final short TEXT__IDOFNEXTSHAPE = 138;
    public static final short TEXT__ROTATETEXTWITHSHAPE = 189;
    public static final short TEXT__SCALETEXT = 134;
    public static final short TEXT__SINGLECLICKSELECTS = 187;
    public static final short TEXT__SIZESHAPETOFITTEXT = 190;
    public static final short TEXT__SIZE_TEXT_TO_FIT_SHAPE = 191;
    public static final short TEXT__TEXTBOTTOM = 132;
    public static final short TEXT__TEXTFLOW = 136;
    public static final short TEXT__TEXTID = 128;
    public static final short TEXT__TEXTLEFT = 129;
    public static final short TEXT__TEXTRIGHT = 131;
    public static final short TEXT__TEXTTOP = 130;
    public static final short TEXT__USEHOSTMARGINS = 188;
    public static final short TEXT__WRAPTEXT = 133;
    public static final short THREEDSTYLE__AMBIENTINTENSITY = 722;
    public static final short THREEDSTYLE__CONSTRAINROTATION = 763;
    public static final short THREEDSTYLE__FILLHARSH = 767;
    public static final short THREEDSTYLE__FILLINTENSITY = 730;
    public static final short THREEDSTYLE__FILLX = 727;
    public static final short THREEDSTYLE__FILLY = 728;
    public static final short THREEDSTYLE__FILLZ = 729;
    public static final short THREEDSTYLE__KEYHARSH = 766;
    public static final short THREEDSTYLE__KEYINTENSITY = 726;
    public static final short THREEDSTYLE__KEYX = 723;
    public static final short THREEDSTYLE__KEYY = 724;
    public static final short THREEDSTYLE__KEYZ = 725;
    public static final short THREEDSTYLE__ORIGINX = 718;
    public static final short THREEDSTYLE__ORIGINY = 719;
    public static final short THREEDSTYLE__PARALLEL = 765;
    public static final short THREEDSTYLE__RENDERMODE = 713;
    public static final short THREEDSTYLE__ROTATIONANGLE = 709;
    public static final short THREEDSTYLE__ROTATIONAXISX = 706;
    public static final short THREEDSTYLE__ROTATIONAXISY = 707;
    public static final short THREEDSTYLE__ROTATIONAXISZ = 708;
    public static final short THREEDSTYLE__ROTATIONCENTERAUTO = 764;
    public static final short THREEDSTYLE__ROTATIONCENTERX = 710;
    public static final short THREEDSTYLE__ROTATIONCENTERY = 711;
    public static final short THREEDSTYLE__ROTATIONCENTERZ = 712;
    public static final short THREEDSTYLE__SKEWAMOUNT = 721;
    public static final short THREEDSTYLE__SKEWANGLE = 720;
    public static final short THREEDSTYLE__TOLERANCE = 714;
    public static final short THREEDSTYLE__XROTATIONANGLE = 705;
    public static final short THREEDSTYLE__XVIEWPOINT = 715;
    public static final short THREEDSTYLE__YROTATIONANGLE = 704;
    public static final short THREEDSTYLE__YVIEWPOINT = 716;
    public static final short THREEDSTYLE__ZVIEWPOINT = 717;
    public static final short THREED__3DEFFECT = 700;
    public static final short THREED__CRMOD = 648;
    public static final short THREED__DIFFUSEAMOUNT = 661;
    public static final short THREED__EDGETHICKNESS = 663;
    public static final short THREED__EXTRUDEBACKWARD = 665;
    public static final short THREED__EXTRUDEFORWARD = 664;
    public static final short THREED__EXTRUDEPLANE = 666;
    public static final short THREED__EXTRUSIONCOLOR = 667;
    public static final short THREED__LIGHTFACE = 703;
    public static final short THREED__METALLIC = 701;
    public static final short THREED__SHININESS = 662;
    public static final short THREED__SPECULARAMOUNT = 640;
    public static final short THREED__USEEXTRUSIONCOLOR = 702;
    public static final short TRANSFORM__ROTATION = 4;
    private static final Map<Short, EscherPropertyMetaData> properties = initProps();

    private static Map<Short, EscherPropertyMetaData> initProps() {
        Map<Short, EscherPropertyMetaData> m = new HashMap<>();
        addProp(m, 4, "transform.rotation");
        addProp(m, 119, "protection.lockrotation");
        addProp(m, 120, "protection.lockaspectratio");
        addProp(m, 121, "protection.lockposition");
        addProp(m, 122, "protection.lockagainstselect");
        addProp(m, 123, "protection.lockcropping");
        addProp(m, 124, "protection.lockvertices");
        addProp(m, 125, "protection.locktext");
        addProp(m, 126, "protection.lockadjusthandles");
        addProp(m, 127, "protection.lockagainstgrouping", (byte) 1);
        addProp(m, 128, "text.textid");
        addProp(m, 129, "text.textleft");
        addProp(m, 130, "text.texttop");
        addProp(m, 131, "text.textright");
        addProp(m, 132, "text.textbottom");
        addProp(m, 133, "text.wraptext");
        addProp(m, 134, "text.scaletext");
        addProp(m, 135, "text.anchortext");
        addProp(m, 136, "text.textflow");
        addProp(m, 137, "text.fontrotation");
        addProp(m, 138, "text.idofnextshape");
        addProp(m, 139, "text.bidir");
        addProp(m, 187, "text.singleclickselects");
        addProp(m, 188, "text.usehostmargins");
        addProp(m, 189, "text.rotatetextwithshape");
        addProp(m, 190, "text.sizeshapetofittext");
        addProp(m, 191, "text.sizetexttofitshape", (byte) 1);
        addProp(m, 192, "geotext.unicode");
        addProp(m, 193, "geotext.rtftext");
        addProp(m, 194, "geotext.alignmentoncurve");
        addProp(m, 195, "geotext.defaultpointsize");
        addProp(m, 196, "geotext.textspacing");
        addProp(m, 197, "geotext.fontfamilyname");
        addProp(m, 240, "geotext.reverseroworder");
        addProp(m, 241, "geotext.hastexteffect");
        addProp(m, 242, "geotext.rotatecharacters");
        addProp(m, 243, "geotext.kerncharacters");
        addProp(m, 244, "geotext.tightortrack");
        addProp(m, 245, "geotext.stretchtofitshape");
        addProp(m, 246, "geotext.charboundingbox");
        addProp(m, 247, "geotext.scaletextonpath");
        addProp(m, 248, "geotext.stretchcharheight");
        addProp(m, 249, "geotext.nomeasurealongpath");
        addProp(m, 250, "geotext.boldfont");
        addProp(m, 251, "geotext.italicfont");
        addProp(m, 252, "geotext.underlinefont");
        addProp(m, 253, "geotext.shadowfont");
        addProp(m, 254, "geotext.smallcapsfont");
        addProp(m, 255, "geotext.strikethroughfont");
        addProp(m, 256, "blip.cropfromtop");
        addProp(m, 257, "blip.cropfrombottom");
        addProp(m, InSystemTest.GET_SENSOR_INFO, "blip.cropfromleft");
        addProp(m, InSystemTest.SUBLINE, "blip.cropfromright");
        addProp(m, 260, "blip.bliptodisplay");
        addProp(m, InSystemTest.SYSTEM_SPEC, "blip.blipfilename");
        addProp(m, 262, "blip.blipflags");
        addProp(m, 263, "blip.transparentcolor");
        addProp(m, 264, "blip.contrastsetting");
        addProp(m, 265, "blip.brightnesssetting");
        addProp(m, 266, "blip.gamma");
        addProp(m, 267, "blip.pictureid");
        addProp(m, 268, "blip.doublemod");
        addProp(m, 269, "blip.picturefillmod");
        addProp(m, 270, "blip.pictureline");
        addProp(m, 271, "blip.printblip");
        addProp(m, AtTspptestStandard.NV_TSPCAL2, "blip.printblipfilename");
        addProp(m, 273, "blip.printflags");
        addProp(m, 316, "blip.nohittestpicture");
        addProp(m, 317, "blip.picturegray");
        addProp(m, 318, "blip.picturebilevel");
        addProp(m, TestResultParser.TEST_TOKEN_LOCAL_BIG_BAD_PIXEL_NUM, "blip.pictureactive");
        addProp(m, 320, "geometry.left");
        addProp(m, TestResultParser.TEST_TOKEN_IS_BAD_LINE, "geometry.top");
        addProp(m, 322, "geometry.right");
        addProp(m, 323, "geometry.bottom");
        addProp(m, 324, "geometry.shapepath", (byte) 3);
        addProp(m, 325, "geometry.vertices", (byte) 5);
        addProp(m, 326, "geometry.segmentinfo", (byte) 5);
        addProp(m, 327, "geometry.adjustvalue");
        addProp(m, FactoryTestManager.TEST_3D_DIGITAL_HALL_IC_CAL_TEST, "geometry.adjust2value");
        addProp(m, FactoryTestManager.TEST_3D_DIGITAL_HALL_IC_TEST, "geometry.adjust3value");
        addProp(m, FactoryTestManager.TEST_LCD_GRADATION_120HZ_TEST, "geometry.adjust4value");
        addProp(m, FactoryTestManager.TEST_SUB_MCD_PRESENTATION, "geometry.adjust5value");
        addProp(m, FactoryTestManager.TEST_SUB_TSP_SELF_PRESENTATION, "geometry.adjust6value");
        addProp(m, FactoryTestManager.TEST_SUB_TSP_OPEN_SHORT_PRESENTATION, "geometry.adjust7value");
        addProp(m, 334, "geometry.adjust8value");
        addProp(m, 335, "geometry.adjust9value");
        addProp(m, 336, "geometry.adjust10value");
        addProp(m, FactoryTestManager.TEST_ACH_MOTOR_SOUND, "geometry.shadowOK");
        addProp(m, 379, "geometry.3dok");
        addProp(m, 380, "geometry.lineok");
        addProp(m, 381, "geometry.geotextok");
        addProp(m, 382, "geometry.fillshadeshapeok");
        addProp(m, 383, "geometry.fillok", (byte) 1);
        addProp(m, 384, "fill.filltype");
        addProp(m, 385, "fill.fillcolor", (byte) 2);
        addProp(m, 386, "fill.fillopacity");
        addProp(m, 387, "fill.fillbackcolor", (byte) 2);
        addProp(m, 388, "fill.backopacity");
        addProp(m, 389, "fill.crmod");
        addProp(m, 390, "fill.patterntexture");
        addProp(m, 391, "fill.blipfilename");
        addProp(m, 392, "fill.blipflags");
        addProp(m, 393, "fill.width");
        addProp(m, 394, "fill.height");
        addProp(m, 395, "fill.angle");
        addProp(m, 396, "fill.focus");
        addProp(m, 397, "fill.toleft");
        addProp(m, 398, "fill.totop");
        addProp(m, 399, "fill.toright");
        addProp(m, 400, "fill.tobottom");
        addProp(m, 401, "fill.rectleft");
        addProp(m, 402, "fill.recttop");
        addProp(m, 403, "fill.rectright");
        addProp(m, 404, "fill.rectbottom");
        addProp(m, 405, "fill.dztype");
        addProp(m, 406, "fill.shadepreset");
        addProp(m, 407, "fill.shadecolors", (byte) 5);
        addProp(m, 408, "fill.originx");
        addProp(m, 409, "fill.originy");
        addProp(m, 410, "fill.shapeoriginx");
        addProp(m, 411, "fill.shapeoriginy");
        addProp(m, 412, "fill.shadetype");
        addProp(m, 443, "fill.filled");
        addProp(m, 444, "fill.hittestfill");
        addProp(m, 445, "fill.shape");
        addProp(m, 446, "fill.userect");
        addProp(m, 447, "fill.nofillhittest", (byte) 1);
        addProp(m, 448, "linestyle.color", (byte) 2);
        addProp(m, 449, "linestyle.opacity");
        addProp(m, 450, "linestyle.backcolor", (byte) 2);
        addProp(m, 451, "linestyle.crmod");
        addProp(m, 452, "linestyle.linetype");
        addProp(m, ShenzhenConstants.DEFAULT_SENSOR_X, "linestyle.fillblip");
        addProp(m, 454, "linestyle.fillblipname");
        addProp(m, 455, "linestyle.fillblipflags");
        addProp(m, 456, "linestyle.fillwidth");
        addProp(m, 457, "linestyle.fillheight");
        addProp(m, 458, "linestyle.filldztype");
        addProp(m, 459, "linestyle.linewidth");
        addProp(m, 460, "linestyle.linemiterlimit");
        addProp(m, 461, "linestyle.linestyle");
        addProp(m, 462, "linestyle.linedashing");
        addProp(m, 463, "linestyle.linedashstyle", (byte) 5);
        addProp(m, 464, "linestyle.linestartarrowhead");
        addProp(m, 465, "linestyle.lineendarrowhead");
        addProp(m, 466, "linestyle.linestartarrowwidth");
        addProp(m, 467, "linestyle.linestartarrowlength");
        addProp(m, 468, "linestyle.lineendarrowwidth");
        addProp(m, 469, "linestyle.lineendarrowlength");
        addProp(m, 470, "linestyle.linejoinstyle");
        addProp(m, 471, "linestyle.lineendcapstyle");
        addProp(m, 507, "linestyle.arrowheadsok");
        addProp(m, 508, "linestyle.anyline");
        addProp(m, 509, "linestyle.hitlinetest");
        addProp(m, 510, "linestyle.linefillshape");
        addProp(m, 511, "linestyle.nolinedrawdash", (byte) 1);
        addProp(m, 1407, "linestyle.nolinedrawdash.left", (byte) 1);
        addProp(m, ShenzhenTestResultParser.TEST_TOKEN_MAX_SUBLINE_BUBBLE_NUM, "linestyle.nolinedrawdash.top", (byte) 1);
        addProp(m, ShenzhenConstants.CMD_TEST_SZ_SET_HIGH_BRIGHTNESS, "linestyle.nolinedrawdash.bottom", (byte) 1);
        addProp(m, 1535, "linestyle.nolinedrawdash.right", (byte) 1);
        addProp(m, 512, "shadowstyle.type");
        addProp(m, 513, "shadowstyle.color", (byte) 2);
        addProp(m, 514, "shadowstyle.highlight");
        addProp(m, 515, "shadowstyle.crmod");
        addProp(m, 516, "shadowstyle.opacity");
        addProp(m, 517, "shadowstyle.offsetx");
        addProp(m, 518, "shadowstyle.offsety");
        addProp(m, 519, "shadowstyle.secondoffsetx");
        addProp(m, 520, "shadowstyle.secondoffsety");
        addProp(m, 521, "shadowstyle.scalextox");
        addProp(m, 522, "shadowstyle.scaleytox");
        addProp(m, 523, "shadowstyle.scalextoy");
        addProp(m, 524, "shadowstyle.scaleytoy");
        addProp(m, 525, "shadowstyle.perspectivex");
        addProp(m, 526, "shadowstyle.perspectivey");
        addProp(m, 527, "shadowstyle.weight");
        addProp(m, 528, "shadowstyle.originx");
        addProp(m, 529, "shadowstyle.originy");
        addProp(m, 574, "shadowstyle.shadow");
        addProp(m, 575, "shadowstyle.shadowobscured");
        addProp(m, Units.MASTER_DPI, "perspective.type");
        addProp(m, 577, "perspective.offsetx");
        addProp(m, 578, "perspective.offsety");
        addProp(m, 579, "perspective.scalextox");
        addProp(m, 580, "perspective.scaleytox");
        addProp(m, 581, "perspective.scalextoy");
        addProp(m, 582, "perspective.scaleytoy");
        addProp(m, 583, "perspective.perspectivex");
        addProp(m, 584, "perspective.perspectivey");
        addProp(m, 585, "perspective.weight");
        addProp(m, 586, "perspective.originx");
        addProp(m, 587, "perspective.originy");
        addProp(m, 639, "perspective.perspectiveon");
        addProp(m, 640, "3d.specularamount");
        addProp(m, 661, "3d.diffuseamount");
        addProp(m, 662, "3d.shininess");
        addProp(m, 663, "3d.edgethickness");
        addProp(m, 664, "3d.extrudeforward");
        addProp(m, 665, "3d.extrudebackward");
        addProp(m, 666, "3d.extrudeplane");
        addProp(m, 667, "3d.extrusioncolor", (byte) 2);
        addProp(m, 648, "3d.crmod");
        addProp(m, 700, "3d.3deffect");
        addProp(m, 701, "3d.metallic");
        addProp(m, 702, "3d.useextrusioncolor", (byte) 2);
        addProp(m, 703, "3d.lightface");
        addProp(m, 704, "3dstyle.yrotationangle");
        addProp(m, 705, "3dstyle.xrotationangle");
        addProp(m, 706, "3dstyle.rotationaxisx");
        addProp(m, 707, "3dstyle.rotationaxisy");
        addProp(m, 708, "3dstyle.rotationaxisz");
        addProp(m, 709, "3dstyle.rotationangle");
        addProp(m, 710, "3dstyle.rotationcenterx");
        addProp(m, 711, "3dstyle.rotationcentery");
        addProp(m, 712, "3dstyle.rotationcenterz");
        addProp(m, 713, "3dstyle.rendermode");
        addProp(m, 714, "3dstyle.tolerance");
        addProp(m, 715, "3dstyle.xviewpoint");
        addProp(m, 716, "3dstyle.yviewpoint");
        addProp(m, 717, "3dstyle.zviewpoint");
        addProp(m, 718, "3dstyle.originx");
        addProp(m, 719, "3dstyle.originy");
        addProp(m, 720, "3dstyle.skewangle");
        addProp(m, 721, "3dstyle.skewamount");
        addProp(m, 722, "3dstyle.ambientintensity");
        addProp(m, 723, "3dstyle.keyx");
        addProp(m, 724, "3dstyle.keyy");
        addProp(m, 725, "3dstyle.keyz");
        addProp(m, 726, "3dstyle.keyintensity");
        addProp(m, 727, "3dstyle.fillx");
        addProp(m, 728, "3dstyle.filly");
        addProp(m, 729, "3dstyle.fillz");
        addProp(m, 730, "3dstyle.fillintensity");
        addProp(m, 763, "3dstyle.constrainrotation");
        addProp(m, 764, "3dstyle.rotationcenterauto");
        addProp(m, 765, "3dstyle.parallel");
        addProp(m, 766, "3dstyle.keyharsh");
        addProp(m, 767, "3dstyle.fillharsh");
        addProp(m, 769, "shape.master");
        addProp(m, 771, "shape.connectorstyle");
        addProp(m, 772, "shape.blackandwhitesettings");
        addProp(m, 773, "shape.wmodepurebw");
        addProp(m, 774, "shape.wmodebw");
        addProp(m, 826, "shape.oleicon");
        addProp(m, 827, "shape.preferrelativeresize");
        addProp(m, 828, "shape.lockshapetype");
        addProp(m, 830, "shape.deleteattachedobject");
        addProp(m, 831, "shape.backgroundshape");
        addProp(m, 832, "callout.callouttype");
        addProp(m, 833, "callout.xycalloutgap");
        addProp(m, 834, "callout.calloutangle");
        addProp(m, 835, "callout.calloutdroptype");
        addProp(m, 836, "callout.calloutdropspecified");
        addProp(m, 837, "callout.calloutlengthspecified");
        addProp(m, 889, "callout.iscallout");
        addProp(m, 890, "callout.calloutaccentbar");
        addProp(m, 891, "callout.callouttextborder");
        addProp(m, 892, "callout.calloutminusx");
        addProp(m, 893, "callout.calloutminusy");
        addProp(m, 894, "callout.dropauto");
        addProp(m, 895, "callout.lengthspecified");
        addProp(m, 896, "groupshape.shapename");
        addProp(m, 897, "groupshape.description");
        addProp(m, 898, "groupshape.hyperlink");
        addProp(m, 899, "groupshape.wrappolygonvertices", (byte) 5);
        addProp(m, 900, "groupshape.wrapdistleft");
        addProp(m, 901, "groupshape.wrapdisttop");
        addProp(m, 902, "groupshape.wrapdistright");
        addProp(m, 903, "groupshape.wrapdistbottom");
        addProp(m, 904, "groupshape.regroupid");
        addProp(m, 906, "unused906");
        addProp(m, 909, "groupshape.wzTooltip");
        addProp(m, 910, "groupshape.wzScript");
        addProp(m, 911, "groupshape.posh");
        addProp(m, 912, "groupshape.posrelh");
        addProp(m, 913, "groupshape.posv");
        addProp(m, 914, "groupshape.posrelv");
        addProp(m, 915, "groupshape.pctHR");
        addProp(m, 916, "groupshape.alignHR");
        addProp(m, 917, "groupshape.dxHeightHR");
        addProp(m, 918, "groupshape.dxWidthHR");
        addProp(m, 919, "groupshape.wzScriptExtAttr");
        addProp(m, 920, "groupshape.scriptLang");
        addProp(m, 923, "groupshape.borderTopColor");
        addProp(m, 924, "groupshape.borderLeftColor");
        addProp(m, 925, "groupshape.borderBottomColor");
        addProp(m, 926, "groupshape.borderRightColor");
        addProp(m, 927, "groupshape.tableProperties");
        addProp(m, 928, "groupshape.tableRowProperties");
        addProp(m, 933, "groupshape.wzWebBot");
        addProp(m, 937, "groupshape.metroBlob");
        addProp(m, 938, "groupshape.dhgt");
        addProp(m, 959, "groupshape.GroupShapeBooleanProperties");
        addProp(m, 953, "groupshape.editedwrap");
        addProp(m, 954, "groupshape.behinddocument");
        addProp(m, 955, "groupshape.ondblclicknotify");
        addProp(m, 956, "groupshape.isbutton");
        addProp(m, 957, "groupshape.1dadjustment");
        addProp(m, 958, "groupshape.hidden");
        addProp(m, 959, "groupshape.print", (byte) 1);
        return m;
    }

    private static void addProp(Map<Short, EscherPropertyMetaData> m, int s, String propName) {
        m.put(Short.valueOf((short) s), new EscherPropertyMetaData(propName));
    }

    private static void addProp(Map<Short, EscherPropertyMetaData> m, int s, String propName, byte type) {
        m.put(Short.valueOf((short) s), new EscherPropertyMetaData(propName, type));
    }

    public static String getPropertyName(short propertyId) {
        EscherPropertyMetaData o = properties.get(Short.valueOf(propertyId));
        return o == null ? EnvironmentCompat.MEDIA_UNKNOWN : o.getDescription();
    }

    public static byte getPropertyType(short propertyId) {
        EscherPropertyMetaData escherPropertyMetaData = properties.get(Short.valueOf(propertyId));
        if (escherPropertyMetaData == null) {
            return 0;
        }
        return escherPropertyMetaData.getType();
    }
}
