package org.apache.poi.dev;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.PrintStream;
import java.util.Locale;
import java.util.Properties;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import org.apache.poi.util.XMLHelper;
import org.w3c.dom.Element;

public class RecordGenerator {
    public static void main(String[] args) throws Exception {
        Class.forName("org.apache.poi.generator.FieldIterator");
        if (args.length != 4) {
            System.out.println("Usage:");
            System.out.println("  java org.apache.poi.hssf.util.RecordGenerator RECORD_DEFINTIONS RECORD_STYLES DEST_SRC_PATH TEST_SRC_PATH");
            return;
        }
        generateRecords(args[0], args[1], args[2], args[3]);
    }

    private static void generateRecords(String defintionsDir, String recordStyleDir, String destSrcPathDir, String testSrcPathDir) throws Exception {
        int i$;
        int len$;
        File[] arr$;
        File[] definitionsFiles;
        File[] definitionsFiles2 = new File(defintionsDir).listFiles();
        if (definitionsFiles2 == null) {
            System.err.println(defintionsDir + " is not a directory.");
            return;
        }
        File[] arr$2 = definitionsFiles2;
        int len$2 = arr$2.length;
        int i$2 = 0;
        while (i$2 < len$2) {
            File file = arr$2[i$2];
            if (!file.isFile()) {
                definitionsFiles = definitionsFiles2;
                arr$ = arr$2;
                len$ = len$2;
                i$ = i$2;
            } else if (file.getName().endsWith("_record.xml") || file.getName().endsWith("_type.xml")) {
                Element record = XMLHelper.getDocumentBuilderFactory().newDocumentBuilder().parse(file).getDocumentElement();
                String extendstg = record.getElementsByTagName("extends").item(0).getFirstChild().getNodeValue();
                String suffix = record.getElementsByTagName("suffix").item(0).getFirstChild().getNodeValue();
                String recordName = record.getAttributes().getNamedItem("name").getNodeValue();
                String packageName = record.getAttributes().getNamedItem("package").getNodeValue().replace('.', '/');
                StringBuilder sb = new StringBuilder();
                sb.append(destSrcPathDir);
                definitionsFiles = definitionsFiles2;
                sb.append("/");
                sb.append(packageName);
                String destinationPath = sb.toString();
                arr$ = arr$2;
                File destinationPathFile = new File(destinationPath);
                len$ = len$2;
                if (destinationPathFile.mkdirs()) {
                    System.out.println("Created destination directory: " + destinationPath);
                    String destinationFilepath = destinationPath + "/" + recordName + suffix + ".java";
                    File file2 = new File(destinationFilepath);
                    StringBuilder sb2 = new StringBuilder();
                    sb2.append(recordStyleDir);
                    sb2.append("/");
                    i$ = i$2;
                    sb2.append(extendstg.toLowerCase(Locale.ROOT));
                    sb2.append(".xsl");
                    transform(file, file2, new File(sb2.toString()));
                    System.out.println("Generated " + suffix + ": " + destinationFilepath);
                    StringBuilder sb3 = new StringBuilder();
                    sb3.append(testSrcPathDir);
                    sb3.append("/");
                    sb3.append(packageName);
                    String destinationPath2 = sb3.toString();
                    File destinationPathFile2 = new File(destinationPath2);
                    if (destinationPathFile2.mkdirs()) {
                        System.out.println("Created destination directory: " + destinationPath2);
                        String destinationFilepath2 = destinationPath2 + "/Test" + recordName + suffix + ".java";
                        if (!new File(destinationFilepath2).exists()) {
                            transform(file, new File(destinationFilepath2), new File(recordStyleDir + "/" + extendstg.toLowerCase(Locale.ROOT) + "_test.xsl"));
                            PrintStream printStream = System.out;
                            StringBuilder sb4 = new StringBuilder();
                            sb4.append("Generated test: ");
                            sb4.append(destinationFilepath2);
                            printStream.println(sb4.toString());
                        } else {
                            System.out.println("Skipped test generation: " + destinationFilepath2);
                        }
                    } else {
                        throw new IOException("Could not create directory " + destinationPathFile2);
                    }
                } else {
                    throw new IOException("Could not create directory " + destinationPathFile);
                }
            } else {
                definitionsFiles = definitionsFiles2;
                arr$ = arr$2;
                len$ = len$2;
                i$ = i$2;
            }
            i$2 = i$ + 1;
            definitionsFiles2 = definitionsFiles;
            arr$2 = arr$;
            len$2 = len$;
        }
    }

    private static void transform(File in, File out, File xslt) throws FileNotFoundException, TransformerException {
        try {
            Transformer t = TransformerFactory.newInstance().newTransformer(new StreamSource(xslt));
            Properties p = new Properties();
            p.setProperty("method", "text");
            t.setOutputProperties(p);
            t.transform(new StreamSource(in), new StreamResult(out));
        } catch (TransformerException ex) {
            PrintStream printStream = System.err;
            printStream.println("Error compiling XSL style sheet " + xslt);
            throw ex;
        }
    }
}
