package org.apache.poi.hpsf;

import com.sec.factory.modules.ModuleDevice;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;

/* access modifiers changed from: package-private */
@Internal
public class Array {
    private ArrayHeader _header;
    private TypedPropertyValue[] _values;

    /* access modifiers changed from: package-private */
    public static class ArrayDimension {
        static final int SIZE = 8;
        private int _indexOffset;
        private long _size;

        ArrayDimension(byte[] data, int offset) {
            this._size = LittleEndian.getUInt(data, offset);
            this._indexOffset = LittleEndian.getInt(data, offset + 4);
        }
    }

    /* access modifiers changed from: package-private */
    public static class ArrayHeader {
        private ArrayDimension[] _dimensions;
        private int _type;

        ArrayHeader(byte[] data, int startOffset) {
            this._type = LittleEndian.getInt(data, startOffset);
            int offset = startOffset + 4;
            long numDimensionsUnsigned = LittleEndian.getUInt(data, offset);
            int offset2 = offset + 4;
            if (1 > numDimensionsUnsigned || numDimensionsUnsigned > 31) {
                throw new IllegalPropertySetDataException("Array dimension number " + numDimensionsUnsigned + " is not in [1; 31] range");
            }
            int numDimensions = (int) numDimensionsUnsigned;
            this._dimensions = new ArrayDimension[numDimensions];
            for (int i = 0; i < numDimensions; i++) {
                this._dimensions[i] = new ArrayDimension(data, offset2);
                offset2 += 8;
            }
        }

        /* access modifiers changed from: package-private */
        public long getNumberOfScalarValues() {
            long result = 1;
            for (ArrayDimension dimension : this._dimensions) {
                result *= dimension._size;
            }
            return result;
        }

        /* access modifiers changed from: package-private */
        public int getSize() {
            return (this._dimensions.length * 8) + 8;
        }

        /* access modifiers changed from: package-private */
        public int getType() {
            return this._type;
        }
    }

    Array() {
    }

    Array(byte[] data, int offset) {
        read(data, offset);
    }

    /* access modifiers changed from: package-private */
    public int read(byte[] data, int startOffset) {
        ArrayHeader arrayHeader = new ArrayHeader(data, startOffset);
        this._header = arrayHeader;
        int offset = startOffset + arrayHeader.getSize();
        long numberOfScalarsLong = this._header.getNumberOfScalarValues();
        if (numberOfScalarsLong <= ModuleDevice.TIMELESS_VIBRATOR) {
            int numberOfScalars = (int) numberOfScalarsLong;
            this._values = new TypedPropertyValue[numberOfScalars];
            int type = this._header._type;
            if (type == 12) {
                for (int i = 0; i < numberOfScalars; i++) {
                    offset += new TypedPropertyValue().read(data, offset);
                }
            } else {
                for (int i2 = 0; i2 < numberOfScalars; i2++) {
                    offset += new TypedPropertyValue(type, (Object) null).readValuePadded(data, offset);
                }
            }
            return offset - startOffset;
        }
        throw new UnsupportedOperationException("Sorry, but POI can't store array of properties with size of " + numberOfScalarsLong + " in memory");
    }
}
