package org.apache.poi.hpsf;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.charset.Charset;
import java.util.List;
import org.apache.poi.hpsf.wellknown.PropertyIDMap;
import org.apache.poi.poifs.filesystem.DirectoryEntry;
import org.apache.poi.util.LittleEndian;

public abstract class SpecialPropertySet extends MutablePropertySet {
    private final MutablePropertySet delegate;

    public abstract PropertyIDMap getPropertySetIDMap();

    public SpecialPropertySet(PropertySet ps) {
        this.delegate = new MutablePropertySet(ps);
    }

    public SpecialPropertySet(MutablePropertySet ps) {
        this.delegate = ps;
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public int getByteOrder() {
        return this.delegate.getByteOrder();
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public int getFormat() {
        return this.delegate.getFormat();
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public int getOSVersion() {
        return this.delegate.getOSVersion();
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public ClassID getClassID() {
        return this.delegate.getClassID();
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public int getSectionCount() {
        return this.delegate.getSectionCount();
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public List<Section> getSections() {
        return this.delegate.getSections();
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public boolean isSummaryInformation() {
        return this.delegate.isSummaryInformation();
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public boolean isDocumentSummaryInformation() {
        return this.delegate.isDocumentSummaryInformation();
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public Section getFirstSection() {
        return this.delegate.getFirstSection();
    }

    @Override // org.apache.poi.hpsf.MutablePropertySet
    public void addSection(Section section) {
        this.delegate.addSection(section);
    }

    @Override // org.apache.poi.hpsf.MutablePropertySet
    public void clearSections() {
        this.delegate.clearSections();
    }

    @Override // org.apache.poi.hpsf.MutablePropertySet
    public void setByteOrder(int byteOrder) {
        this.delegate.setByteOrder(byteOrder);
    }

    @Override // org.apache.poi.hpsf.MutablePropertySet
    public void setClassID(ClassID classID) {
        this.delegate.setClassID(classID);
    }

    @Override // org.apache.poi.hpsf.MutablePropertySet
    public void setFormat(int format) {
        this.delegate.setFormat(format);
    }

    @Override // org.apache.poi.hpsf.MutablePropertySet
    public void setOSVersion(int osVersion) {
        this.delegate.setOSVersion(osVersion);
    }

    @Override // org.apache.poi.hpsf.MutablePropertySet
    public InputStream toInputStream() throws IOException, WritingNotSupportedException {
        return this.delegate.toInputStream();
    }

    @Override // org.apache.poi.hpsf.MutablePropertySet
    public void write(DirectoryEntry dir, String name) throws WritingNotSupportedException, IOException {
        this.delegate.write(dir, name);
    }

    @Override // org.apache.poi.hpsf.MutablePropertySet
    public void write(OutputStream out) throws WritingNotSupportedException, IOException {
        this.delegate.write(out);
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public boolean equals(Object o) {
        return this.delegate.equals(o);
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public Property[] getProperties() throws NoSingleSectionException {
        return this.delegate.getProperties();
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.poi.hpsf.PropertySet
    public Object getProperty(int id) throws NoSingleSectionException {
        return this.delegate.getProperty(id);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.poi.hpsf.PropertySet
    public boolean getPropertyBooleanValue(int id) throws NoSingleSectionException {
        return this.delegate.getPropertyBooleanValue(id);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.poi.hpsf.PropertySet
    public int getPropertyIntValue(int id) throws NoSingleSectionException {
        return this.delegate.getPropertyIntValue(id);
    }

    /* access modifiers changed from: protected */
    public String getPropertyStringValue(int propertyId) {
        return getPropertyStringValue(getProperty(propertyId));
    }

    protected static String getPropertyStringValue(Object propertyValue) {
        if (propertyValue == null) {
            return null;
        }
        if (propertyValue instanceof String) {
            return (String) propertyValue;
        }
        if (!(propertyValue instanceof byte[])) {
            return propertyValue.toString();
        }
        byte[] b = (byte[]) propertyValue;
        if (b.length == 0) {
            return "";
        }
        if (b.length == 1) {
            return Byte.toString(b[0]);
        }
        if (b.length == 2) {
            return Integer.toString(LittleEndian.getUShort(b));
        }
        if (b.length == 4) {
            return Long.toString(LittleEndian.getUInt(b));
        }
        return new String(b, Charset.forName("ASCII"));
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public int hashCode() {
        return this.delegate.hashCode();
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public String toString() {
        return this.delegate.toString();
    }

    @Override // org.apache.poi.hpsf.PropertySet
    public boolean wasNull() throws NoSingleSectionException {
        return this.delegate.wasNull();
    }
}
