package org.apache.poi.hpsf;

import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.StringUtil;

/* access modifiers changed from: package-private */
@Internal
public class UnicodeString {
    private static final POILogger logger = POILogFactory.getLogger(UnicodeString.class);
    private byte[] _value;

    UnicodeString(byte[] data, int offset) {
        int length = LittleEndian.getInt(data, offset);
        int dataOffset = offset + 4;
        if (!validLength(length, data, dataOffset)) {
            boolean valid = false;
            int past4byte = offset % 4;
            if (past4byte != 0) {
                offset += past4byte;
                length = LittleEndian.getInt(data, offset);
                dataOffset = offset + 4;
                valid = validLength(length, data, dataOffset);
            }
            if (!valid) {
                throw new IllegalPropertySetDataException("UnicodeString started at offset #" + offset + " is not NULL-terminated");
            }
        }
        if (length == 0) {
            this._value = new byte[0];
        } else {
            this._value = LittleEndian.getByteArray(data, dataOffset, length * 2);
        }
    }

    /* access modifiers changed from: package-private */
    public boolean validLength(int length, byte[] data, int offset) {
        if (length == 0) {
            return true;
        }
        int endOffset = (length * 2) + offset;
        if (endOffset <= data.length && data[endOffset - 1] == 0 && data[endOffset - 2] == 0) {
            return true;
        }
        return false;
    }

    /* access modifiers changed from: package-private */
    public int getSize() {
        return this._value.length + 4;
    }

    /* access modifiers changed from: package-private */
    public byte[] getValue() {
        return this._value;
    }

    /* access modifiers changed from: package-private */
    public String toJavaString() {
        byte[] bArr = this._value;
        if (bArr.length == 0) {
            return null;
        }
        String result = StringUtil.getFromUnicodeLE(bArr, 0, bArr.length >> 1);
        int terminator = result.indexOf(0);
        if (terminator == -1) {
            logger.log(5, "String terminator (\\0) for UnicodeString property value not found.Continue without trimming and hope for the best.");
            return result;
        }
        if (terminator != result.length() - 1) {
            logger.log(5, "String terminator (\\0) for UnicodeString property value occured before the end of string. Trimming and hope for the best.");
        }
        return result.substring(0, terminator);
    }
}
