package org.apache.poi.hssf.record;

import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;

public final class FtCfSubRecord extends SubRecord implements Cloneable {
    public static final short BITMAP_BIT = 9;
    public static final short METAFILE_BIT = 2;
    public static final short UNSPECIFIED_BIT = -1;
    public static final short length = 2;
    public static final short sid = 7;
    private short flags = 0;

    public FtCfSubRecord() {
    }

    public FtCfSubRecord(LittleEndianInput in, int size) {
        if (size == 2) {
            this.flags = in.readShort();
            return;
        }
        throw new RecordFormatException("Unexpected size (" + size + ")");
    }

    public String toString() {
        StringBuffer buffer = new StringBuffer();
        buffer.append("[FtCf ]\n");
        buffer.append("  size     = ");
        buffer.append(2);
        buffer.append("\n");
        buffer.append("  flags    = ");
        buffer.append(HexDump.toHex(this.flags));
        buffer.append("\n");
        buffer.append("[/FtCf ]\n");
        return buffer.toString();
    }

    @Override // org.apache.poi.hssf.record.SubRecord
    public void serialize(LittleEndianOutput out) {
        out.writeShort(7);
        out.writeShort(2);
        out.writeShort(this.flags);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.poi.hssf.record.SubRecord
    public int getDataSize() {
        return 2;
    }

    public short getSid() {
        return 7;
    }

    @Override // org.apache.poi.hssf.record.SubRecord, java.lang.Object
    public FtCfSubRecord clone() {
        FtCfSubRecord rec = new FtCfSubRecord();
        rec.flags = this.flags;
        return rec;
    }

    public short getFlags() {
        return this.flags;
    }

    public void setFlags(short flags2) {
        this.flags = flags2;
    }
}
