package org.apache.poi.hssf.record;

import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;

public final class FtPioGrbitSubRecord extends SubRecord implements Cloneable {
    public static final int AUTO_LOAD_BIT = 512;
    public static final int AUTO_PICT_BIT = 1;
    public static final int CAMERA_BIT = 128;
    public static final int CTL_BIT = 16;
    public static final int DDE_BIT = 2;
    public static final int DEFAULT_SIZE_BIT = 256;
    public static final int ICON_BIT = 8;
    public static final int PRINT_CALC_BIT = 4;
    public static final int PRSTM_BIT = 32;
    public static final short length = 2;
    public static final short sid = 8;
    private short flags = 0;

    public FtPioGrbitSubRecord() {
    }

    public FtPioGrbitSubRecord(LittleEndianInput in, int size) {
        if (size == 2) {
            this.flags = in.readShort();
            return;
        }
        throw new RecordFormatException("Unexpected size (" + size + ")");
    }

    public void setFlagByBit(int bitmask, boolean enabled) {
        if (enabled) {
            this.flags = (short) (this.flags | bitmask);
        } else {
            this.flags = (short) (this.flags & (65535 ^ bitmask));
        }
    }

    public boolean getFlagByBit(int bitmask) {
        return (this.flags & bitmask) != 0;
    }

    public String toString() {
        StringBuffer buffer = new StringBuffer();
        buffer.append("[FtPioGrbit ]\n");
        buffer.append("  size     = ");
        buffer.append(2);
        buffer.append("\n");
        buffer.append("  flags    = ");
        buffer.append(HexDump.toHex(this.flags));
        buffer.append("\n");
        buffer.append("[/FtPioGrbit ]\n");
        return buffer.toString();
    }

    @Override // org.apache.poi.hssf.record.SubRecord
    public void serialize(LittleEndianOutput out) {
        out.writeShort(8);
        out.writeShort(2);
        out.writeShort(this.flags);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.poi.hssf.record.SubRecord
    public int getDataSize() {
        return 2;
    }

    public short getSid() {
        return 8;
    }

    @Override // org.apache.poi.hssf.record.SubRecord, java.lang.Object
    public FtPioGrbitSubRecord clone() {
        FtPioGrbitSubRecord rec = new FtPioGrbitSubRecord();
        rec.flags = this.flags;
        return rec;
    }

    public short getFlags() {
        return this.flags;
    }

    public void setFlags(short flags2) {
        this.flags = flags2;
    }
}
