package org.apache.poi.hssf.record;

import org.apache.poi.util.HexDump;

public abstract class OldCellRecord {
    private final int field_1_row;
    private final short field_2_column;
    private int field_3_cell_attrs;
    private short field_3_xf_index;
    private final boolean isBiff2;
    private final short sid;

    /* access modifiers changed from: protected */
    public abstract void appendValueText(StringBuilder sb);

    /* access modifiers changed from: protected */
    public abstract String getRecordName();

    protected OldCellRecord(RecordInputStream in, boolean isBiff22) {
        this.sid = in.getSid();
        this.isBiff2 = isBiff22;
        this.field_1_row = in.readUShort();
        this.field_2_column = in.readShort();
        if (isBiff22) {
            int readUShort = in.readUShort() << 8;
            this.field_3_cell_attrs = readUShort;
            this.field_3_cell_attrs = readUShort + in.readUByte();
            return;
        }
        this.field_3_xf_index = in.readShort();
    }

    public final int getRow() {
        return this.field_1_row;
    }

    public final short getColumn() {
        return this.field_2_column;
    }

    public final short getXFIndex() {
        return this.field_3_xf_index;
    }

    public int getCellAttrs() {
        return this.field_3_cell_attrs;
    }

    public boolean isBiff2() {
        return this.isBiff2;
    }

    public short getSid() {
        return this.sid;
    }

    public final String toString() {
        StringBuilder sb = new StringBuilder();
        String recordName = getRecordName();
        sb.append("[");
        sb.append(recordName);
        sb.append("]\n");
        sb.append("    .row    = ");
        sb.append(HexDump.shortToHex(getRow()));
        sb.append("\n");
        sb.append("    .col    = ");
        sb.append(HexDump.shortToHex(getColumn()));
        sb.append("\n");
        if (isBiff2()) {
            sb.append("    .cellattrs = ");
            sb.append(HexDump.shortToHex(getCellAttrs()));
            sb.append("\n");
        } else {
            sb.append("    .xfindex   = ");
            sb.append(HexDump.shortToHex(getXFIndex()));
            sb.append("\n");
        }
        appendValueText(sb);
        sb.append("\n");
        sb.append("[/");
        sb.append(recordName);
        sb.append("]\n");
        return sb.toString();
    }
}
