package org.apache.poi.hssf.record;

import org.apache.poi.util.LittleEndianOutput;

public final class TabIdRecord extends StandardRecord {
    private static final short[] EMPTY_SHORT_ARRAY = new short[0];
    public static final short sid = 317;
    public short[] _tabids;

    public TabIdRecord() {
        this._tabids = EMPTY_SHORT_ARRAY;
    }

    public TabIdRecord(RecordInputStream in) {
        this._tabids = new short[(in.remaining() / 2)];
        int i = 0;
        while (true) {
            short[] sArr = this._tabids;
            if (i < sArr.length) {
                sArr[i] = in.readShort();
                i++;
            } else {
                return;
            }
        }
    }

    public void setTabIdArray(short[] array) {
        this._tabids = (short[]) array.clone();
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer buffer = new StringBuffer();
        buffer.append("[TABID]\n");
        buffer.append("    .elements        = ");
        buffer.append(this._tabids.length);
        buffer.append("\n");
        for (int i = 0; i < this._tabids.length; i++) {
            buffer.append("    .element_");
            buffer.append(i);
            buffer.append(" = ");
            buffer.append((int) this._tabids[i]);
            buffer.append("\n");
        }
        buffer.append("[/TABID]\n");
        return buffer.toString();
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput out) {
        short[] tabids;
        for (short s : this._tabids) {
            out.writeShort(s);
        }
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return this._tabids.length * 2;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return 317;
    }
}
