package org.apache.poi.hssf.record.aggregates;

import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hssf.model.RecordStream;
import org.apache.poi.hssf.record.CFHeader12Record;
import org.apache.poi.hssf.record.CFHeaderRecord;
import org.apache.poi.hssf.record.aggregates.RecordAggregate;
import org.apache.poi.ss.formula.FormulaShifter;

public final class ConditionalFormattingTable extends RecordAggregate {
    private final List<CFRecordsAggregate> _cfHeaders;

    public ConditionalFormattingTable() {
        this._cfHeaders = new ArrayList();
    }

    public ConditionalFormattingTable(RecordStream rs) {
        List<CFRecordsAggregate> temp = new ArrayList<>();
        while (true) {
            if (rs.peekNextClass() == CFHeaderRecord.class || rs.peekNextClass() == CFHeader12Record.class) {
                temp.add(CFRecordsAggregate.createCFAggregate(rs));
            } else {
                this._cfHeaders = temp;
                return;
            }
        }
    }

    @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate
    public void visitContainedRecords(RecordAggregate.RecordVisitor rv) {
        for (CFRecordsAggregate subAgg : this._cfHeaders) {
            subAgg.visitContainedRecords(rv);
        }
    }

    public int add(CFRecordsAggregate cfAggregate) {
        cfAggregate.getHeader().setID(this._cfHeaders.size());
        this._cfHeaders.add(cfAggregate);
        return this._cfHeaders.size() - 1;
    }

    public int size() {
        return this._cfHeaders.size();
    }

    public CFRecordsAggregate get(int index) {
        checkIndex(index);
        return this._cfHeaders.get(index);
    }

    public void remove(int index) {
        checkIndex(index);
        this._cfHeaders.remove(index);
    }

    private void checkIndex(int index) {
        if (index < 0 || index >= this._cfHeaders.size()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Specified CF index ");
            sb.append(index);
            sb.append(" is outside the allowable range (0..");
            sb.append(this._cfHeaders.size() - 1);
            sb.append(")");
            throw new IllegalArgumentException(sb.toString());
        }
    }

    public void updateFormulasAfterCellShift(FormulaShifter shifter, int externSheetIndex) {
        int i = 0;
        while (i < this._cfHeaders.size()) {
            if (!this._cfHeaders.get(i).updateFormulasAfterCellShift(shifter, externSheetIndex)) {
                this._cfHeaders.remove(i);
                i--;
            }
            i++;
        }
    }
}
