package org.apache.poi.hssf.record.cf;

import org.apache.poi.hssf.record.common.ExtendedColor;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class DataBarFormatting implements Cloneable {
    private static BitField iconOnly = BitFieldFactory.getInstance(1);
    private static POILogger log = POILogFactory.getLogger(DataBarFormatting.class);
    private static BitField reversed = BitFieldFactory.getInstance(4);
    private ExtendedColor color;
    private byte options;
    private byte percentMax;
    private byte percentMin;
    private DataBarThreshold thresholdMax;
    private DataBarThreshold thresholdMin;

    public DataBarFormatting() {
        this.options = 0;
        this.percentMin = 0;
        this.percentMax = 0;
        this.options = 2;
    }

    public DataBarFormatting(LittleEndianInput in) {
        this.options = 0;
        this.percentMin = 0;
        this.percentMax = 0;
        in.readShort();
        in.readByte();
        this.options = in.readByte();
        this.percentMin = in.readByte();
        this.percentMax = in.readByte();
        byte b = this.percentMin;
        if (b < 0 || b > 100) {
            POILogger pOILogger = log;
            pOILogger.log(5, "Inconsistent Minimum Percentage found " + ((int) this.percentMin));
        }
        byte b2 = this.percentMax;
        if (b2 < 0 || b2 > 100) {
            POILogger pOILogger2 = log;
            pOILogger2.log(5, "Inconsistent Minimum Percentage found " + ((int) this.percentMin));
        }
        this.color = new ExtendedColor(in);
        this.thresholdMin = new DataBarThreshold(in);
        this.thresholdMax = new DataBarThreshold(in);
    }

    public boolean isIconOnly() {
        return getOptionFlag(iconOnly);
    }

    public void setIconOnly(boolean only) {
        setOptionFlag(only, iconOnly);
    }

    public boolean isReversed() {
        return getOptionFlag(reversed);
    }

    public void setReversed(boolean rev) {
        setOptionFlag(rev, reversed);
    }

    private boolean getOptionFlag(BitField field) {
        return field.getValue(this.options) != 0;
    }

    private void setOptionFlag(boolean option, BitField field) {
        this.options = field.setByteBoolean(this.options, option);
    }

    public byte getPercentMin() {
        return this.percentMin;
    }

    public void setPercentMin(byte percentMin2) {
        this.percentMin = percentMin2;
    }

    public byte getPercentMax() {
        return this.percentMax;
    }

    public void setPercentMax(byte percentMax2) {
        this.percentMax = percentMax2;
    }

    public ExtendedColor getColor() {
        return this.color;
    }

    public void setColor(ExtendedColor color2) {
        this.color = color2;
    }

    public DataBarThreshold getThresholdMin() {
        return this.thresholdMin;
    }

    public void setThresholdMin(DataBarThreshold thresholdMin2) {
        this.thresholdMin = thresholdMin2;
    }

    public DataBarThreshold getThresholdMax() {
        return this.thresholdMax;
    }

    public void setThresholdMax(DataBarThreshold thresholdMax2) {
        this.thresholdMax = thresholdMax2;
    }

    public String toString() {
        StringBuffer buffer = new StringBuffer();
        buffer.append("    [Data Bar Formatting]\n");
        buffer.append("          .icon_only= ");
        buffer.append(isIconOnly());
        buffer.append("\n");
        buffer.append("          .reversed = ");
        buffer.append(isReversed());
        buffer.append("\n");
        buffer.append(this.color);
        buffer.append(this.thresholdMin);
        buffer.append(this.thresholdMax);
        buffer.append("    [/Data Bar Formatting]\n");
        return buffer.toString();
    }

    @Override // java.lang.Object
    public Object clone() {
        DataBarFormatting rec = new DataBarFormatting();
        rec.options = this.options;
        rec.percentMin = this.percentMin;
        rec.percentMax = this.percentMax;
        rec.color = this.color.clone();
        rec.thresholdMin = this.thresholdMin.clone();
        rec.thresholdMax = this.thresholdMax.clone();
        return rec;
    }

    public int getDataLength() {
        return this.color.getDataLength() + 6 + this.thresholdMin.getDataLength() + this.thresholdMax.getDataLength();
    }

    public void serialize(LittleEndianOutput out) {
        out.writeShort(0);
        out.writeByte(0);
        out.writeByte(this.options);
        out.writeByte(this.percentMin);
        out.writeByte(this.percentMax);
        this.color.serialize(out);
        this.thresholdMin.serialize(out);
        this.thresholdMax.serialize(out);
    }
}
