package org.apache.poi.hssf.record.cf;

import java.util.Arrays;
import org.apache.poi.ss.formula.Formula;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.usermodel.ConditionalFormattingThreshold;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;

public abstract class Threshold {
    private Formula formula;
    private byte type;
    private Double value;

    protected Threshold() {
        this.type = (byte) ConditionalFormattingThreshold.RangeType.NUMBER.id;
        this.formula = Formula.create(null);
        this.value = Double.valueOf(0.0d);
    }

    protected Threshold(LittleEndianInput in) {
        this.type = in.readByte();
        short formulaLen = in.readShort();
        if (formulaLen > 0) {
            this.formula = Formula.read(formulaLen, in);
        } else {
            this.formula = Formula.create(null);
        }
        if (formulaLen == 0 && this.type != ConditionalFormattingThreshold.RangeType.MIN.id && this.type != ConditionalFormattingThreshold.RangeType.MAX.id) {
            this.value = Double.valueOf(in.readDouble());
        }
    }

    public byte getType() {
        return this.type;
    }

    public void setType(byte type2) {
        this.type = type2;
        if (type2 == ConditionalFormattingThreshold.RangeType.MIN.id || type2 == ConditionalFormattingThreshold.RangeType.MAX.id || type2 == ConditionalFormattingThreshold.RangeType.FORMULA.id) {
            this.value = null;
        } else if (this.value == null) {
            this.value = Double.valueOf(0.0d);
        }
    }

    public void setType(int type2) {
        this.type = (byte) type2;
    }

    /* access modifiers changed from: protected */
    public Formula getFormula() {
        return this.formula;
    }

    public Ptg[] getParsedExpression() {
        return this.formula.getTokens();
    }

    public void setParsedExpression(Ptg[] ptgs) {
        this.formula = Formula.create(ptgs);
        if (ptgs.length > 0) {
            this.value = null;
        }
    }

    public Double getValue() {
        return this.value;
    }

    public void setValue(Double value2) {
        this.value = value2;
    }

    public int getDataLength() {
        int len = this.formula.getEncodedSize() + 1;
        if (this.value != null) {
            return len + 8;
        }
        return len;
    }

    public String toString() {
        StringBuffer buffer = new StringBuffer();
        buffer.append("    [CF Threshold]\n");
        buffer.append("          .type    = ");
        buffer.append(Integer.toHexString(this.type));
        buffer.append("\n");
        buffer.append("          .formula = ");
        buffer.append(Arrays.toString(this.formula.getTokens()));
        buffer.append("\n");
        buffer.append("          .value   = ");
        buffer.append(this.value);
        buffer.append("\n");
        buffer.append("    [/CF Threshold]\n");
        return buffer.toString();
    }

    public void copyTo(Threshold rec) {
        rec.type = this.type;
        rec.formula = this.formula;
        rec.value = this.value;
    }

    public void serialize(LittleEndianOutput out) {
        out.writeByte(this.type);
        if (this.formula.getTokens().length == 0) {
            out.writeShort(0);
        } else {
            this.formula.serialize(out);
        }
        Double d = this.value;
        if (d != null) {
            out.writeDouble(d.doubleValue());
        }
    }
}
