package org.apache.poi.hssf.record.chart;

import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class ChartEndObjectRecord extends StandardRecord {
    public static final short sid = 2133;
    private short grbitFrt;
    private short iObjectKind;
    private byte[] reserved = new byte[6];
    private short rt;

    public ChartEndObjectRecord(RecordInputStream in) {
        this.rt = in.readShort();
        this.grbitFrt = in.readShort();
        this.iObjectKind = in.readShort();
        if (in.available() != 0) {
            in.readFully(this.reserved);
        }
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 12;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput out) {
        out.writeShort(this.rt);
        out.writeShort(this.grbitFrt);
        out.writeShort(this.iObjectKind);
        out.write(this.reserved);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer buffer = new StringBuffer();
        buffer.append("[ENDOBJECT]\n");
        buffer.append("    .rt         =");
        buffer.append(HexDump.shortToHex(this.rt));
        buffer.append('\n');
        buffer.append("    .grbitFrt   =");
        buffer.append(HexDump.shortToHex(this.grbitFrt));
        buffer.append('\n');
        buffer.append("    .iObjectKind=");
        buffer.append(HexDump.shortToHex(this.iObjectKind));
        buffer.append('\n');
        buffer.append("    .reserved   =");
        buffer.append(HexDump.toHex(this.reserved));
        buffer.append('\n');
        buffer.append("[/ENDOBJECT]\n");
        return buffer.toString();
    }
}
