package org.apache.poi.hssf.record.chart;

import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.hssf.record.StandardRecord;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianOutput;

public final class ChartStartObjectRecord extends StandardRecord {
    public static final short sid = 2132;
    private short grbitFrt;
    private short iObjectContext;
    private short iObjectInstance1;
    private short iObjectInstance2;
    private short iObjectKind;
    private short rt;

    public ChartStartObjectRecord(RecordInputStream in) {
        this.rt = in.readShort();
        this.grbitFrt = in.readShort();
        this.iObjectKind = in.readShort();
        this.iObjectContext = in.readShort();
        this.iObjectInstance1 = in.readShort();
        this.iObjectInstance2 = in.readShort();
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.poi.hssf.record.StandardRecord
    public int getDataSize() {
        return 12;
    }

    @Override // org.apache.poi.hssf.record.Record
    public short getSid() {
        return sid;
    }

    @Override // org.apache.poi.hssf.record.StandardRecord
    public void serialize(LittleEndianOutput out) {
        out.writeShort(this.rt);
        out.writeShort(this.grbitFrt);
        out.writeShort(this.iObjectKind);
        out.writeShort(this.iObjectContext);
        out.writeShort(this.iObjectInstance1);
        out.writeShort(this.iObjectInstance2);
    }

    @Override // org.apache.poi.hssf.record.Record
    public String toString() {
        StringBuffer buffer = new StringBuffer();
        buffer.append("[STARTOBJECT]\n");
        buffer.append("    .rt              =");
        buffer.append(HexDump.shortToHex(this.rt));
        buffer.append('\n');
        buffer.append("    .grbitFrt        =");
        buffer.append(HexDump.shortToHex(this.grbitFrt));
        buffer.append('\n');
        buffer.append("    .iObjectKind     =");
        buffer.append(HexDump.shortToHex(this.iObjectKind));
        buffer.append('\n');
        buffer.append("    .iObjectContext  =");
        buffer.append(HexDump.shortToHex(this.iObjectContext));
        buffer.append('\n');
        buffer.append("    .iObjectInstance1=");
        buffer.append(HexDump.shortToHex(this.iObjectInstance1));
        buffer.append('\n');
        buffer.append("    .iObjectInstance2=");
        buffer.append(HexDump.shortToHex(this.iObjectInstance2));
        buffer.append('\n');
        buffer.append("[/STARTOBJECT]\n");
        return buffer.toString();
    }
}
