package org.apache.poi.hssf.record.crypto;

import com.sec.factory.app.factorytest.FactoryTestManager;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;

public class Biff8XOR implements Biff8Cipher {
    private ByteBuffer _buffer = ByteBuffer.allocate(8).order(ByteOrder.LITTLE_ENDIAN);
    private int _dataLength = 0;
    private final int _initialOffset;
    private final Biff8XORKey _key;
    private boolean _shouldSkipEncryptionOnCurrentRecord;
    private int _xorArrayIndex = 0;

    public Biff8XOR(int initialOffset, Biff8XORKey key) {
        this._key = key;
        this._initialOffset = initialOffset;
    }

    @Override // org.apache.poi.hssf.record.crypto.Biff8Cipher
    public void startRecord(int currentSid) {
        this._shouldSkipEncryptionOnCurrentRecord = isNeverEncryptedRecord(currentSid);
    }

    @Override // org.apache.poi.hssf.record.crypto.Biff8Cipher
    public void setNextRecordSize(int recordSize) {
        this._xorArrayIndex = ((this._initialOffset + this._dataLength) + recordSize) % 16;
    }

    private static boolean isNeverEncryptedRecord(int sid) {
        switch (sid) {
            case 47:
            case FactoryTestManager.TEST_ECHO_PARALLEL:
            case 2057:
                return true;
            default:
                return false;
        }
    }

    @Override // org.apache.poi.hssf.record.crypto.Biff8Cipher
    public void skipTwoBytes() {
        this._dataLength += 2;
    }

    @Override // org.apache.poi.hssf.record.crypto.Biff8Cipher
    public void xor(byte[] buf, int pOffset, int pLen) {
        if (this._shouldSkipEncryptionOnCurrentRecord) {
            this._dataLength += pLen;
            return;
        }
        byte[] xorArray = this._key._secretKey.getEncoded();
        for (int i = 0; i < pLen; i++) {
            byte value = rotateLeft(buf[pOffset + i], 3);
            int i2 = this._xorArrayIndex;
            buf[pOffset + i] = (byte) (xorArray[i2] ^ value);
            this._xorArrayIndex = (i2 + 1) % 16;
            this._dataLength++;
        }
    }

    private static byte rotateLeft(byte bits, int shift) {
        return (byte) (((bits & 255) << shift) | ((bits & 255) >>> (8 - shift)));
    }

    @Override // org.apache.poi.hssf.record.crypto.Biff8Cipher
    public int xorByte(int rawVal) {
        this._buffer.put(0, (byte) rawVal);
        xor(this._buffer.array(), 0, 1);
        return this._buffer.get(0);
    }

    @Override // org.apache.poi.hssf.record.crypto.Biff8Cipher
    public int xorShort(int rawVal) {
        this._buffer.putShort(0, (short) rawVal);
        xor(this._buffer.array(), 0, 2);
        return this._buffer.getShort(0);
    }

    @Override // org.apache.poi.hssf.record.crypto.Biff8Cipher
    public int xorInt(int rawVal) {
        this._buffer.putInt(0, rawVal);
        xor(this._buffer.array(), 0, 4);
        return this._buffer.getInt(0);
    }

    @Override // org.apache.poi.hssf.record.crypto.Biff8Cipher
    public long xorLong(long rawVal) {
        this._buffer.putLong(0, rawVal);
        xor(this._buffer.array(), 0, 8);
        return this._buffer.getLong(0);
    }
}
