package org.apache.poi.hssf.usermodel;

import org.apache.poi.hssf.record.CFRule12Record;
import org.apache.poi.hssf.record.cf.ColorGradientFormatting;
import org.apache.poi.hssf.record.cf.ColorGradientThreshold;
import org.apache.poi.hssf.record.cf.Threshold;
import org.apache.poi.hssf.record.common.ExtendedColor;
import org.apache.poi.ss.usermodel.Color;
import org.apache.poi.ss.usermodel.ColorScaleFormatting;
import org.apache.poi.ss.usermodel.ConditionalFormattingThreshold;

public final class HSSFColorScaleFormatting implements ColorScaleFormatting {
    private final CFRule12Record cfRule12Record;
    private final ColorGradientFormatting colorFormatting;
    private final HSSFSheet sheet;

    protected HSSFColorScaleFormatting(CFRule12Record cfRule12Record2, HSSFSheet sheet2) {
        this.sheet = sheet2;
        this.cfRule12Record = cfRule12Record2;
        this.colorFormatting = cfRule12Record2.getColorGradientFormatting();
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public int getNumControlPoints() {
        return this.colorFormatting.getNumControlPoints();
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public void setNumControlPoints(int num) {
        this.colorFormatting.setNumControlPoints(num);
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public HSSFExtendedColor[] getColors() {
        ExtendedColor[] colors = this.colorFormatting.getColors();
        HSSFExtendedColor[] hcolors = new HSSFExtendedColor[colors.length];
        for (int i = 0; i < colors.length; i++) {
            hcolors[i] = new HSSFExtendedColor(colors[i]);
        }
        return hcolors;
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public void setColors(Color[] colors) {
        ExtendedColor[] cr = new ExtendedColor[colors.length];
        for (int i = 0; i < colors.length; i++) {
            cr[i] = ((HSSFExtendedColor) colors[i]).getExtendedColor();
        }
        this.colorFormatting.setColors(cr);
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public HSSFConditionalFormattingThreshold[] getThresholds() {
        Threshold[] t = this.colorFormatting.getThresholds();
        HSSFConditionalFormattingThreshold[] ht = new HSSFConditionalFormattingThreshold[t.length];
        for (int i = 0; i < t.length; i++) {
            ht[i] = new HSSFConditionalFormattingThreshold(t[i], this.sheet);
        }
        return ht;
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public void setThresholds(ConditionalFormattingThreshold[] thresholds) {
        ColorGradientThreshold[] t = new ColorGradientThreshold[thresholds.length];
        for (int i = 0; i < t.length; i++) {
            t[i] = (ColorGradientThreshold) ((HSSFConditionalFormattingThreshold) thresholds[i]).getThreshold();
        }
        this.colorFormatting.setThresholds(t);
    }

    @Override // org.apache.poi.ss.usermodel.ColorScaleFormatting
    public HSSFConditionalFormattingThreshold createThreshold() {
        return new HSSFConditionalFormattingThreshold(new ColorGradientThreshold(), this.sheet);
    }
}
