package org.apache.poi.poifs.crypt;

import org.apache.poi.EncryptedDocumentException;

public enum CipherAlgorithm {
    rc4(CipherProvider.rc4, "RC4", 26625, 64, new int[]{40, 48, 56, 64, 72, 80, 88, 96, 104, 112, 120, 128}, -1, 20, "RC4", false),
    aes128(CipherProvider.aes, "AES", 26126, 128, new int[]{128}, 16, 32, "AES", false),
    aes192(CipherProvider.aes, "AES", 26127, 192, new int[]{192}, 16, 32, "AES", false),
    aes256(CipherProvider.aes, "AES", 26128, 256, new int[]{256}, 16, 32, "AES", false),
    rc2(null, "RC2", -1, 128, new int[]{40, 48, 56, 64, 72, 80, 88, 96, 104, 112, 120, 128}, 8, 20, "RC2", false),
    des(null, "DES", -1, 64, new int[]{64}, 8, 32, "DES", false),
    des3(null, "DESede", -1, 192, new int[]{192}, 8, 32, "3DES", false),
    des3_112(null, "DESede", -1, 128, new int[]{128}, 8, 32, "3DES_112", true),
    rsa(null, "RSA", -1, 1024, new int[]{1024, 2048, 3072, 4096}, -1, -1, "", false);
    
    public final int[] allowedKeySize;
    public final int blockSize;
    public final int defaultKeySize;
    public final int ecmaId;
    public final int encryptedVerifierHashLength;
    public final String jceId;
    public final boolean needsBouncyCastle;
    public final CipherProvider provider;
    public final String xmlId;

    private CipherAlgorithm(CipherProvider provider2, String jceId2, int ecmaId2, int defaultKeySize2, int[] allowedKeySize2, int blockSize2, int encryptedVerifierHashLength2, String xmlId2, boolean needsBouncyCastle2) {
        this.provider = provider2;
        this.jceId = jceId2;
        this.ecmaId = ecmaId2;
        this.defaultKeySize = defaultKeySize2;
        this.allowedKeySize = (int[]) allowedKeySize2.clone();
        this.blockSize = blockSize2;
        this.encryptedVerifierHashLength = encryptedVerifierHashLength2;
        this.xmlId = xmlId2;
        this.needsBouncyCastle = needsBouncyCastle2;
    }

    public static CipherAlgorithm fromEcmaId(int ecmaId2) {
        CipherAlgorithm[] arr$ = values();
        for (CipherAlgorithm ca : arr$) {
            if (ca.ecmaId == ecmaId2) {
                return ca;
            }
        }
        throw new EncryptedDocumentException("cipher algorithm " + ecmaId2 + " not found");
    }

    public static CipherAlgorithm fromXmlId(String xmlId2, int keySize) {
        CipherAlgorithm[] arr$ = values();
        for (CipherAlgorithm ca : arr$) {
            if (ca.xmlId.equals(xmlId2)) {
                for (int ks : ca.allowedKeySize) {
                    if (ks == keySize) {
                        return ca;
                    }
                }
                continue;
            }
        }
        throw new EncryptedDocumentException("cipher algorithm " + xmlId2 + "/" + keySize + " not found");
    }
}
