package org.apache.poi.poifs.crypt;

import java.io.IOException;
import java.io.InputStream;
import java.security.GeneralSecurityException;
import javax.crypto.SecretKey;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.OPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

public abstract class Decryptor {
    public static final String DEFAULT_PASSWORD = "VelvetSweatshop";
    public static final String DEFAULT_POIFS_ENTRY = "EncryptedPackage";
    protected final EncryptionInfoBuilder builder;
    private byte[] integrityHmacKey;
    private byte[] integrityHmacValue;
    private SecretKey secretKey;
    private byte[] verifier;

    public abstract InputStream getDataStream(DirectoryNode directoryNode) throws IOException, GeneralSecurityException;

    public abstract long getLength();

    public abstract boolean verifyPassword(String str) throws GeneralSecurityException;

    protected Decryptor(EncryptionInfoBuilder builder2) {
        this.builder = builder2;
    }

    public static Decryptor getInstance(EncryptionInfo info) {
        Decryptor d = info.getDecryptor();
        if (d != null) {
            return d;
        }
        throw new EncryptedDocumentException("Unsupported version");
    }

    public InputStream getDataStream(NPOIFSFileSystem fs) throws IOException, GeneralSecurityException {
        return getDataStream(fs.getRoot());
    }

    public InputStream getDataStream(OPOIFSFileSystem fs) throws IOException, GeneralSecurityException {
        return getDataStream(fs.getRoot());
    }

    public InputStream getDataStream(POIFSFileSystem fs) throws IOException, GeneralSecurityException {
        return getDataStream(fs.getRoot());
    }

    public byte[] getVerifier() {
        return this.verifier;
    }

    public SecretKey getSecretKey() {
        return this.secretKey;
    }

    public byte[] getIntegrityHmacKey() {
        return this.integrityHmacKey;
    }

    public byte[] getIntegrityHmacValue() {
        return this.integrityHmacValue;
    }

    /* access modifiers changed from: protected */
    public void setSecretKey(SecretKey secretKey2) {
        this.secretKey = secretKey2;
    }

    /* access modifiers changed from: protected */
    public void setVerifier(byte[] verifier2) {
        this.verifier = verifier2 == null ? null : (byte[]) verifier2.clone();
    }

    /* access modifiers changed from: protected */
    public void setIntegrityHmacKey(byte[] integrityHmacKey2) {
        this.integrityHmacKey = integrityHmacKey2 == null ? null : (byte[]) integrityHmacKey2.clone();
    }

    /* access modifiers changed from: protected */
    public void setIntegrityHmacValue(byte[] integrityHmacValue2) {
        this.integrityHmacValue = integrityHmacValue2 == null ? null : (byte[]) integrityHmacValue2.clone();
    }

    /* access modifiers changed from: protected */
    public int getBlockSizeInBytes() {
        return this.builder.getHeader().getBlockSize();
    }

    /* access modifiers changed from: protected */
    public int getKeySizeInBytes() {
        return this.builder.getHeader().getKeySize() / 8;
    }
}
