package org.apache.poi.poifs.crypt;

public abstract class EncryptionHeader {
    public static final int ALGORITHM_AES_128 = CipherAlgorithm.aes128.ecmaId;
    public static final int ALGORITHM_AES_192 = CipherAlgorithm.aes192.ecmaId;
    public static final int ALGORITHM_AES_256 = CipherAlgorithm.aes256.ecmaId;
    public static final int ALGORITHM_RC4 = CipherAlgorithm.rc4.ecmaId;
    public static final int HASH_NONE = HashAlgorithm.none.ecmaId;
    public static final int HASH_SHA1 = HashAlgorithm.sha1.ecmaId;
    public static final int HASH_SHA256 = HashAlgorithm.sha256.ecmaId;
    public static final int HASH_SHA384 = HashAlgorithm.sha384.ecmaId;
    public static final int HASH_SHA512 = HashAlgorithm.sha512.ecmaId;
    public static final int MODE_CBC = ChainingMode.cbc.ecmaId;
    public static final int MODE_CFB = ChainingMode.cfb.ecmaId;
    public static final int MODE_ECB = ChainingMode.ecb.ecmaId;
    public static final int PROVIDER_AES = CipherProvider.aes.ecmaId;
    public static final int PROVIDER_RC4 = CipherProvider.rc4.ecmaId;
    private int blockSize;
    private ChainingMode chainingMode;
    private CipherAlgorithm cipherAlgorithm;
    private String cspName;
    private int flags;
    private HashAlgorithm hashAlgorithm;
    private int keyBits;
    private byte[] keySalt;
    private CipherProvider providerType;
    private int sizeExtra;

    protected EncryptionHeader() {
    }

    public ChainingMode getChainingMode() {
        return this.chainingMode;
    }

    /* access modifiers changed from: protected */
    public void setChainingMode(ChainingMode chainingMode2) {
        this.chainingMode = chainingMode2;
    }

    public int getFlags() {
        return this.flags;
    }

    /* access modifiers changed from: protected */
    public void setFlags(int flags2) {
        this.flags = flags2;
    }

    public int getSizeExtra() {
        return this.sizeExtra;
    }

    /* access modifiers changed from: protected */
    public void setSizeExtra(int sizeExtra2) {
        this.sizeExtra = sizeExtra2;
    }

    public CipherAlgorithm getCipherAlgorithm() {
        return this.cipherAlgorithm;
    }

    /* access modifiers changed from: protected */
    public void setCipherAlgorithm(CipherAlgorithm cipherAlgorithm2) {
        this.cipherAlgorithm = cipherAlgorithm2;
    }

    public HashAlgorithm getHashAlgorithmEx() {
        return this.hashAlgorithm;
    }

    /* access modifiers changed from: protected */
    public void setHashAlgorithm(HashAlgorithm hashAlgorithm2) {
        this.hashAlgorithm = hashAlgorithm2;
    }

    public int getKeySize() {
        return this.keyBits;
    }

    /* access modifiers changed from: protected */
    public void setKeySize(int keyBits2) {
        this.keyBits = keyBits2;
    }

    public int getBlockSize() {
        return this.blockSize;
    }

    /* access modifiers changed from: protected */
    public void setBlockSize(int blockSize2) {
        this.blockSize = blockSize2;
    }

    public byte[] getKeySalt() {
        return this.keySalt;
    }

    /* access modifiers changed from: protected */
    public void setKeySalt(byte[] salt) {
        this.keySalt = salt == null ? null : (byte[]) salt.clone();
    }

    public CipherProvider getCipherProvider() {
        return this.providerType;
    }

    /* access modifiers changed from: protected */
    public void setCipherProvider(CipherProvider providerType2) {
        this.providerType = providerType2;
    }

    public String getCspName() {
        return this.cspName;
    }

    /* access modifiers changed from: protected */
    public void setCspName(String cspName2) {
        this.cspName = cspName2;
    }
}
