package org.apache.poi.poifs.crypt;

public abstract class EncryptionVerifier {
    private ChainingMode chainingMode;
    private CipherAlgorithm cipherAlgorithm;
    private byte[] encryptedKey;
    private byte[] encryptedVerifier;
    private byte[] encryptedVerifierHash;
    private HashAlgorithm hashAlgorithm;
    private byte[] salt;
    private int spinCount;

    protected EncryptionVerifier() {
    }

    public byte[] getSalt() {
        return this.salt;
    }

    public byte[] getEncryptedVerifier() {
        return this.encryptedVerifier;
    }

    public byte[] getEncryptedVerifierHash() {
        return this.encryptedVerifierHash;
    }

    public int getSpinCount() {
        return this.spinCount;
    }

    public int getCipherMode() {
        return this.chainingMode.ecmaId;
    }

    public int getAlgorithm() {
        return this.cipherAlgorithm.ecmaId;
    }

    public byte[] getEncryptedKey() {
        return this.encryptedKey;
    }

    public CipherAlgorithm getCipherAlgorithm() {
        return this.cipherAlgorithm;
    }

    public HashAlgorithm getHashAlgorithm() {
        return this.hashAlgorithm;
    }

    public ChainingMode getChainingMode() {
        return this.chainingMode;
    }

    /* access modifiers changed from: protected */
    public void setSalt(byte[] salt2) {
        this.salt = salt2 == null ? null : (byte[]) salt2.clone();
    }

    /* access modifiers changed from: protected */
    public void setEncryptedVerifier(byte[] encryptedVerifier2) {
        this.encryptedVerifier = encryptedVerifier2 == null ? null : (byte[]) encryptedVerifier2.clone();
    }

    /* access modifiers changed from: protected */
    public void setEncryptedVerifierHash(byte[] encryptedVerifierHash2) {
        this.encryptedVerifierHash = encryptedVerifierHash2 == null ? null : (byte[]) encryptedVerifierHash2.clone();
    }

    /* access modifiers changed from: protected */
    public void setEncryptedKey(byte[] encryptedKey2) {
        this.encryptedKey = encryptedKey2 == null ? null : (byte[]) encryptedKey2.clone();
    }

    /* access modifiers changed from: protected */
    public void setSpinCount(int spinCount2) {
        this.spinCount = spinCount2;
    }

    /* access modifiers changed from: protected */
    public void setCipherAlgorithm(CipherAlgorithm cipherAlgorithm2) {
        this.cipherAlgorithm = cipherAlgorithm2;
    }

    /* access modifiers changed from: protected */
    public void setChainingMode(ChainingMode chainingMode2) {
        this.chainingMode = chainingMode2;
    }

    /* access modifiers changed from: protected */
    public void setHashAlgorithm(HashAlgorithm hashAlgorithm2) {
        this.hashAlgorithm = hashAlgorithm2;
    }
}
