package org.apache.poi.poifs.crypt.standard;

import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.poifs.crypt.ChainingMode;
import org.apache.poi.poifs.crypt.CipherAlgorithm;
import org.apache.poi.poifs.crypt.EncryptionVerifier;
import org.apache.poi.poifs.crypt.HashAlgorithm;
import org.apache.poi.util.LittleEndianByteArrayOutputStream;
import org.apache.poi.util.LittleEndianInput;

public class StandardEncryptionVerifier extends EncryptionVerifier implements EncryptionRecord {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final int SPIN_COUNT = 50000;
    private final int verifierHashSize;

    protected StandardEncryptionVerifier(LittleEndianInput is, StandardEncryptionHeader header) {
        if (is.readInt() == 16) {
            byte[] salt = new byte[16];
            is.readFully(salt);
            setSalt(salt);
            byte[] encryptedVerifier = new byte[16];
            is.readFully(encryptedVerifier);
            setEncryptedVerifier(encryptedVerifier);
            this.verifierHashSize = is.readInt();
            byte[] encryptedVerifierHash = new byte[header.getCipherAlgorithm().encryptedVerifierHashLength];
            is.readFully(encryptedVerifierHash);
            setEncryptedVerifierHash(encryptedVerifierHash);
            setSpinCount(50000);
            setCipherAlgorithm(header.getCipherAlgorithm());
            setChainingMode(header.getChainingMode());
            setEncryptedKey(null);
            setHashAlgorithm(header.getHashAlgorithmEx());
            return;
        }
        throw new RuntimeException("Salt size != 16 !?");
    }

    protected StandardEncryptionVerifier(CipherAlgorithm cipherAlgorithm, HashAlgorithm hashAlgorithm, int keyBits, int blockSize, ChainingMode chainingMode) {
        setCipherAlgorithm(cipherAlgorithm);
        setHashAlgorithm(hashAlgorithm);
        setChainingMode(chainingMode);
        setSpinCount(50000);
        this.verifierHashSize = hashAlgorithm.hashSize;
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.poi.poifs.crypt.EncryptionVerifier
    public void setSalt(byte[] salt) {
        if (salt == null || salt.length != 16) {
            throw new EncryptedDocumentException("invalid verifier salt");
        }
        super.setSalt(salt);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.poi.poifs.crypt.EncryptionVerifier
    public void setEncryptedVerifier(byte[] encryptedVerifier) {
        super.setEncryptedVerifier(encryptedVerifier);
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.poi.poifs.crypt.EncryptionVerifier
    public void setEncryptedVerifierHash(byte[] encryptedVerifierHash) {
        super.setEncryptedVerifierHash(encryptedVerifierHash);
    }

    @Override // org.apache.poi.poifs.crypt.standard.EncryptionRecord
    public void write(LittleEndianByteArrayOutputStream bos) {
        byte[] salt = getSalt();
        bos.writeInt(salt.length);
        bos.write(salt);
        bos.write(getEncryptedVerifier());
        bos.writeInt(20);
        bos.write(getEncryptedVerifierHash());
    }

    /* access modifiers changed from: protected */
    public int getVerifierHashSize() {
        return this.verifierHashSize;
    }
}
