package org.apache.poi.poifs.filesystem;

import java.io.IOException;
import java.nio.ByteBuffer;
import org.apache.poi.poifs.storage.BATBlock;

public abstract class BlockStore {
    /* access modifiers changed from: protected */
    public abstract ByteBuffer createBlockIfNeeded(int i) throws IOException;

    /* access modifiers changed from: protected */
    public abstract BATBlock.BATBlockAndIndex getBATBlockAndIndex(int i);

    /* access modifiers changed from: protected */
    public abstract ByteBuffer getBlockAt(int i) throws IOException;

    /* access modifiers changed from: protected */
    public abstract int getBlockStoreBlockSize();

    /* access modifiers changed from: protected */
    public abstract ChainLoopDetector getChainLoopDetector() throws IOException;

    /* access modifiers changed from: protected */
    public abstract int getFreeBlock() throws IOException;

    /* access modifiers changed from: protected */
    public abstract int getNextBlock(int i);

    /* access modifiers changed from: protected */
    public abstract void setNextBlock(int i, int i2);

    /* access modifiers changed from: protected */
    public class ChainLoopDetector {
        private boolean[] used_blocks;

        protected ChainLoopDetector(long rawSize) {
            int blkSize = BlockStore.this.getBlockStoreBlockSize();
            int numBlocks = (int) (rawSize / ((long) blkSize));
            this.used_blocks = new boolean[(rawSize % ((long) blkSize) != 0 ? numBlocks + 1 : numBlocks)];
        }

        /* access modifiers changed from: protected */
        public void claim(int offset) {
            boolean[] zArr = this.used_blocks;
            if (offset < zArr.length) {
                if (!zArr[offset]) {
                    zArr[offset] = true;
                    return;
                }
                throw new IllegalStateException("Potential loop detected - Block " + offset + " was already claimed but was just requested again");
            }
        }
    }
}
