package org.apache.poi.poifs.nio;

import android.support.v4.media.session.PlaybackStateCompat;
import java.io.IOException;
import java.io.OutputStream;
import java.nio.ByteBuffer;

public class ByteArrayBackedDataSource extends DataSource {
    private byte[] buffer;
    private long size;

    public ByteArrayBackedDataSource(byte[] data, int size2) {
        this.buffer = data;
        this.size = (long) size2;
    }

    public ByteArrayBackedDataSource(byte[] data) {
        this(data, data.length);
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public ByteBuffer read(int length, long position) {
        long j = this.size;
        if (position < j) {
            return ByteBuffer.wrap(this.buffer, (int) position, (int) Math.min((long) length, j - position));
        }
        throw new IndexOutOfBoundsException("Unable to read " + length + " bytes from " + position + " in stream of length " + this.size);
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public void write(ByteBuffer src, long position) {
        long endPosition = ((long) src.capacity()) + position;
        if (endPosition > ((long) this.buffer.length)) {
            extend(endPosition);
        }
        src.get(this.buffer, (int) position, src.capacity());
        if (endPosition > this.size) {
            this.size = endPosition;
        }
    }

    private void extend(long length) {
        byte[] bArr = this.buffer;
        long difference = length - ((long) bArr.length);
        if (((double) difference) < ((double) bArr.length) * 0.25d) {
            difference = (long) (((double) bArr.length) * 0.25d);
        }
        if (difference < PlaybackStateCompat.ACTION_SKIP_TO_QUEUE_ITEM) {
            difference = PlaybackStateCompat.ACTION_SKIP_TO_QUEUE_ITEM;
        }
        byte[] nb = new byte[((int) (((long) bArr.length) + difference))];
        System.arraycopy(bArr, 0, nb, 0, (int) this.size);
        this.buffer = nb;
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public void copyTo(OutputStream stream) throws IOException {
        stream.write(this.buffer, 0, (int) this.size);
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public long size() {
        return this.size;
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public void close() {
        this.buffer = null;
        this.size = -1;
    }
}
