package org.apache.poi.sl.draw;

import java.awt.BasicStroke;
import java.awt.Graphics2D;
import java.awt.geom.AffineTransform;
import java.awt.geom.Rectangle2D;
import java.util.Locale;
import org.apache.poi.sl.usermodel.PlaceableShape;
import org.apache.poi.sl.usermodel.Shape;
import org.apache.poi.sl.usermodel.StrokeStyle;

public class DrawShape implements Drawable {
    protected final Shape<?, ?> shape;

    public DrawShape(Shape<?, ?> shape2) {
        this.shape = shape2;
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void applyTransform(Graphics2D graphics) {
        double rotation;
        int quadrant;
        double rotation2;
        AffineTransform txs;
        Shape<?, ?> shape2 = this.shape;
        if (shape2 instanceof PlaceableShape) {
            PlaceableShape<?, ?> ps = (PlaceableShape) shape2;
            AffineTransform tx = (AffineTransform) graphics.getRenderingHint(Drawable.GROUP_TRANSFORM);
            if (tx == null) {
                tx = new AffineTransform();
            }
            Rectangle2D anchor = tx.createTransformedShape(ps.getAnchor()).getBounds2D();
            double rotation3 = ps.getRotation();
            if (rotation3 != 0.0d) {
                double centerX = anchor.getCenterX();
                double centerY = anchor.getCenterY();
                double rotation4 = rotation3 % 360.0d;
                if (rotation4 < 0.0d) {
                    rotation4 += 360.0d;
                }
                int quadrant2 = ((((int) rotation4) + 45) / 90) % 4;
                double scaleX = 1.0d;
                if (quadrant2 == 1 || quadrant2 == 3) {
                    if (ps.getClass().getCanonicalName().toLowerCase(Locale.ROOT).contains("hslf")) {
                        txs = new AffineTransform(tx);
                        rotation = rotation4;
                    } else {
                        txs = new AffineTransform();
                        txs.translate(centerX, centerY);
                        txs.rotate(1.5707963267948966d);
                        rotation = rotation4;
                        txs.translate(-centerX, -centerY);
                        txs.concatenate(tx);
                    }
                    txs.translate(centerX, centerY);
                    txs.rotate(1.5707963267948966d);
                    txs.translate(-centerX, -centerY);
                    Rectangle2D anchor2 = txs.createTransformedShape(ps.getAnchor()).getBounds2D();
                    double scaleX2 = safeScale(anchor.getWidth(), anchor2.getWidth());
                    quadrant = quadrant2;
                    rotation2 = safeScale(anchor.getHeight(), anchor2.getHeight());
                    scaleX = scaleX2;
                } else {
                    quadrant = 0;
                    rotation = rotation4;
                    rotation2 = 1.0d;
                }
                graphics.translate(centerX, centerY);
                double rot = Math.toRadians(rotation - (((double) quadrant) * 90.0d));
                if (rot != 0.0d) {
                    graphics.rotate(rot);
                }
                graphics.scale(scaleX, rotation2);
                double rot2 = Math.toRadians((double) (quadrant * 90));
                if (rot2 != 0.0d) {
                    graphics.rotate(rot2);
                }
                graphics.translate(-centerX, -centerY);
            }
            if (ps.getFlipHorizontal()) {
                graphics.translate(anchor.getX() + anchor.getWidth(), anchor.getY());
                graphics.scale(-1.0d, 1.0d);
                graphics.translate(-anchor.getX(), -anchor.getY());
            }
            if (ps.getFlipVertical()) {
                graphics.translate(anchor.getX(), anchor.getY() + anchor.getHeight());
                graphics.scale(1.0d, -1.0d);
                graphics.translate(-anchor.getX(), -anchor.getY());
            }
        }
    }

    private static double safeScale(double dim1, double dim2) {
        if (dim1 == 0.0d || dim2 == 0.0d) {
            return 1.0d;
        }
        return dim1 / dim2;
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void draw(Graphics2D graphics) {
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void drawContent(Graphics2D graphics) {
    }

    public static Rectangle2D getAnchor(Graphics2D graphics, PlaceableShape<?, ?> shape2) {
        return getAnchor(graphics, shape2.getAnchor());
    }

    public static Rectangle2D getAnchor(Graphics2D graphics, Rectangle2D anchor) {
        AffineTransform tx;
        if (graphics == null || (tx = (AffineTransform) graphics.getRenderingHint(Drawable.GROUP_TRANSFORM)) == null) {
            return anchor;
        }
        return tx.createTransformedShape(anchor).getBounds2D();
    }

    /* access modifiers changed from: protected */
    public Shape<?, ?> getShape() {
        return this.shape;
    }

    protected static BasicStroke getStroke(StrokeStyle strokeStyle) {
        StrokeStyle.LineDash lineDash;
        float[] dashPatF;
        int lineCap;
        float lineWidth = (float) strokeStyle.getLineWidth();
        if (lineWidth == 0.0f) {
            lineWidth = 0.25f;
        }
        StrokeStyle.LineDash lineDash2 = strokeStyle.getLineDash();
        if (lineDash2 == null) {
            lineDash = StrokeStyle.LineDash.SOLID;
        } else {
            lineDash = lineDash2;
        }
        int[] dashPatI = lineDash.pattern;
        if (dashPatI != null) {
            float[] dashPatF2 = new float[dashPatI.length];
            for (int i = 0; i < dashPatI.length; i++) {
                dashPatF2[i] = ((float) dashPatI[i]) * Math.max(1.0f, lineWidth);
            }
            dashPatF = dashPatF2;
        } else {
            dashPatF = null;
        }
        StrokeStyle.LineCap lineCapE = strokeStyle.getLineCap();
        if (lineCapE == null) {
            lineCapE = StrokeStyle.LineCap.FLAT;
        }
        switch (AnonymousClass1.$SwitchMap$org$apache$poi$sl$usermodel$StrokeStyle$LineCap[lineCapE.ordinal()]) {
            case 1:
                lineCap = 1;
                break;
            case 2:
                lineCap = 2;
                break;
            default:
                lineCap = 0;
                break;
        }
        return new BasicStroke(lineWidth, lineCap, 1, lineWidth, dashPatF, 0.0f);
    }

    /* renamed from: org.apache.poi.sl.draw.DrawShape$1  reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$StrokeStyle$LineCap;

        static {
            int[] iArr = new int[StrokeStyle.LineCap.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$StrokeStyle$LineCap = iArr;
            try {
                iArr[StrokeStyle.LineCap.ROUND.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$org$apache$poi$sl$usermodel$StrokeStyle$LineCap[StrokeStyle.LineCap.SQUARE.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$org$apache$poi$sl$usermodel$StrokeStyle$LineCap[StrokeStyle.LineCap.FLAT.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
        }
    }
}
