package org.apache.poi.sl.draw;

import java.awt.Graphics2D;
import java.awt.font.TextLayout;
import java.text.AttributedCharacterIterator;
import java.text.AttributedString;

public class DrawTextFragment implements Drawable {
    final TextLayout layout;
    final AttributedString str;
    double x;
    double y;

    public DrawTextFragment(TextLayout layout2, AttributedString str2) {
        this.layout = layout2;
        this.str = str2;
    }

    public void setPosition(double x2, double y2) {
        this.x = x2;
        this.y = y2;
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void draw(Graphics2D graphics) {
        if (this.str != null) {
            double yBaseline = this.y + ((double) this.layout.getAscent());
            Integer textMode = (Integer) graphics.getRenderingHint(Drawable.TEXT_RENDERING_MODE);
            if (textMode == null || textMode.intValue() != 2) {
                graphics.drawString(this.str.getIterator(), (float) this.x, (float) yBaseline);
            } else {
                this.layout.draw(graphics, (float) this.x, (float) yBaseline);
            }
        }
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void applyTransform(Graphics2D graphics) {
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void drawContent(Graphics2D graphics) {
    }

    public TextLayout getLayout() {
        return this.layout;
    }

    public AttributedString getAttributedString() {
        return this.str;
    }

    public float getHeight() {
        return (float) (Math.ceil((double) this.layout.getAscent()) + Math.ceil((double) this.layout.getDescent()) + ((double) this.layout.getLeading()));
    }

    public float getWidth() {
        return this.layout.getAdvance();
    }

    public String getString() {
        AttributedString attributedString = this.str;
        if (attributedString == null) {
            return "";
        }
        AttributedCharacterIterator it = attributedString.getIterator();
        StringBuilder buf = new StringBuilder();
        for (char c = it.first(); c != 65535; c = it.next()) {
            buf.append(c);
        }
        return buf.toString();
    }

    public String toString() {
        return "[" + getClass().getSimpleName() + "] " + getString();
    }
}
