package org.apache.poi.sl.draw;

import java.awt.Dimension;
import java.awt.Graphics2D;
import java.awt.Paint;
import java.awt.font.FontRenderContext;
import java.awt.font.LineBreakMeasurer;
import java.awt.font.TextAttribute;
import java.awt.font.TextLayout;
import java.awt.geom.AffineTransform;
import java.awt.geom.Rectangle2D;
import java.io.InvalidObjectException;
import java.text.AttributedCharacterIterator;
import java.text.AttributedString;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.poi.sl.usermodel.AutoNumberingScheme;
import org.apache.poi.sl.usermodel.Hyperlink;
import org.apache.poi.sl.usermodel.Insets2D;
import org.apache.poi.sl.usermodel.PaintStyle;
import org.apache.poi.sl.usermodel.PlaceableShape;
import org.apache.poi.sl.usermodel.ShapeContainer;
import org.apache.poi.sl.usermodel.Sheet;
import org.apache.poi.sl.usermodel.TextParagraph;
import org.apache.poi.sl.usermodel.TextRun;
import org.apache.poi.sl.usermodel.TextShape;
import org.apache.poi.util.Units;

public class DrawTextParagraph implements Drawable {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final XlinkAttribute HYPERLINK_HREF = new XlinkAttribute("href");
    public static final XlinkAttribute HYPERLINK_LABEL = new XlinkAttribute("label");
    protected int autoNbrIdx = 0;
    protected DrawTextFragment bullet;
    protected List<DrawTextFragment> lines = new ArrayList();
    protected double maxLineHeight;
    protected TextParagraph<?, ?, ?> paragraph;
    protected String rawText;
    double x;
    double y;

    /* access modifiers changed from: private */
    public static class XlinkAttribute extends AttributedCharacterIterator.Attribute {
        XlinkAttribute(String name) {
            super(name);
        }

        /* access modifiers changed from: protected */
        @Override // java.text.AttributedCharacterIterator.Attribute
        public Object readResolve() throws InvalidObjectException {
            if (DrawTextParagraph.HYPERLINK_HREF.getName().equals(getName())) {
                return DrawTextParagraph.HYPERLINK_HREF;
            }
            if (DrawTextParagraph.HYPERLINK_LABEL.getName().equals(getName())) {
                return DrawTextParagraph.HYPERLINK_LABEL;
            }
            throw new InvalidObjectException("unknown attribute name");
        }
    }

    public DrawTextParagraph(TextParagraph<?, ?, ?> paragraph2) {
        this.paragraph = paragraph2;
    }

    public void setPosition(double x2, double y2) {
        this.x = x2;
        this.y = y2;
    }

    public double getY() {
        return this.y;
    }

    public void setAutoNumberingIdx(int index) {
        this.autoNbrIdx = index;
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void draw(Graphics2D graphics) {
        Iterator i$;
        Double indent;
        int indentLevel;
        double penX;
        DrawTextParagraph drawTextParagraph = this;
        Graphics2D graphics2D = graphics;
        if (!drawTextParagraph.lines.isEmpty()) {
            double penY = drawTextParagraph.y;
            boolean firstLine = true;
            int indentLevel2 = drawTextParagraph.paragraph.getIndentLevel();
            Double leftMargin = drawTextParagraph.paragraph.getLeftMargin();
            if (leftMargin == null) {
                leftMargin = Double.valueOf(Units.toPoints(((long) indentLevel2) * 347663));
            }
            Double indent2 = drawTextParagraph.paragraph.getIndent();
            if (indent2 == null) {
                indent2 = Double.valueOf(Units.toPoints(((long) indentLevel2) * 347663));
            }
            if (isHSLF()) {
                indent2 = Double.valueOf(indent2.doubleValue() - leftMargin.doubleValue());
            }
            Double spacing = drawTextParagraph.paragraph.getLineSpacing();
            if (spacing == null) {
                spacing = Double.valueOf(100.0d);
            }
            Iterator i$2 = drawTextParagraph.lines.iterator();
            while (i$2.hasNext()) {
                DrawTextFragment line = i$2.next();
                if (firstLine) {
                    if (!isEmptyParagraph()) {
                        drawTextParagraph.bullet = drawTextParagraph.getBullet(graphics2D, line.getAttributedString().getIterator());
                    }
                    DrawTextFragment drawTextFragment = drawTextParagraph.bullet;
                    if (drawTextFragment != null) {
                        drawTextFragment.setPosition(drawTextParagraph.x + leftMargin.doubleValue() + indent2.doubleValue(), penY);
                        drawTextParagraph.bullet.draw(graphics2D);
                        indentLevel = indentLevel2;
                        i$ = i$2;
                        indent = indent2;
                        penX = drawTextParagraph.x + Math.max(leftMargin.doubleValue(), leftMargin.doubleValue() + indent2.doubleValue() + ((double) (drawTextParagraph.bullet.getLayout().getAdvance() + 1.0f)));
                    } else {
                        indentLevel = indentLevel2;
                        i$ = i$2;
                        indent = indent2;
                        penX = drawTextParagraph.x + leftMargin.doubleValue();
                    }
                } else {
                    indentLevel = indentLevel2;
                    i$ = i$2;
                    indent = indent2;
                    penX = drawTextParagraph.x + leftMargin.doubleValue();
                }
                Rectangle2D anchor = DrawShape.getAnchor(graphics2D, drawTextParagraph.paragraph.getParentShape());
                Insets2D insets = drawTextParagraph.paragraph.getParentShape().getInsets();
                double leftInset = insets.left;
                double rightInset = insets.right;
                TextParagraph.TextAlign ta = drawTextParagraph.paragraph.getTextAlign();
                if (ta == null) {
                    ta = TextParagraph.TextAlign.LEFT;
                }
                switch (AnonymousClass2.$SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign[ta.ordinal()]) {
                    case 1:
                        penX += ((((anchor.getWidth() - ((double) line.getWidth())) - leftInset) - rightInset) - leftMargin.doubleValue()) / 2.0d;
                        break;
                    case 2:
                        penX += ((anchor.getWidth() - ((double) line.getWidth())) - leftInset) - rightInset;
                        break;
                }
                line.setPosition(penX, penY);
                line.draw(graphics);
                if (spacing.doubleValue() > 0.0d) {
                    penY += spacing.doubleValue() * 0.01d * ((double) line.getHeight());
                } else {
                    penY += -spacing.doubleValue();
                }
                firstLine = false;
                drawTextParagraph = this;
                graphics2D = graphics;
                indentLevel2 = indentLevel;
                indent2 = indent;
                i$2 = i$;
            }
            this.y = penY - this.y;
        }
    }

    public float getFirstLineHeight() {
        if (this.lines.isEmpty()) {
            return 0.0f;
        }
        return this.lines.get(0).getHeight();
    }

    public float getLastLineHeight() {
        if (this.lines.isEmpty()) {
            return 0.0f;
        }
        List<DrawTextFragment> list = this.lines;
        return list.get(list.size() - 1).getHeight();
    }

    public boolean isEmptyParagraph() {
        return this.lines.isEmpty() || this.rawText.trim().isEmpty();
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void applyTransform(Graphics2D graphics) {
    }

    @Override // org.apache.poi.sl.draw.Drawable
    public void drawContent(Graphics2D graphics) {
    }

    /* access modifiers changed from: protected */
    public void breakText(Graphics2D graphics) {
        Graphics2D graphics2D = graphics;
        this.lines.clear();
        DrawFactory fact = DrawFactory.getInstance(graphics);
        StringBuilder text = new StringBuilder();
        AttributedString at = getAttributedString(graphics2D, text);
        boolean emptyParagraph = "".equals(text.toString().trim());
        AttributedCharacterIterator it = at.getIterator();
        LineBreakMeasurer measurer = new LineBreakMeasurer(it, graphics.getFontRenderContext());
        while (true) {
            int startIndex = measurer.getPosition();
            double wrappingWidth = getWrappingWidth(this.lines.size() == 0, graphics2D) + 1.0d;
            if (wrappingWidth < 0.0d) {
                wrappingWidth = 1.0d;
            }
            int nextBreak = text.indexOf("\n", startIndex + 1);
            if (nextBreak == -1) {
                nextBreak = it.getEndIndex();
            }
            TextLayout layout = measurer.nextLayout((float) wrappingWidth, nextBreak, true);
            if (layout == null) {
                layout = measurer.nextLayout((float) wrappingWidth, nextBreak, false);
            }
            if (layout == null) {
                break;
            }
            int endIndex = measurer.getPosition();
            if (endIndex < it.getEndIndex() && text.charAt(endIndex) == '\n') {
                measurer.setPosition(endIndex + 1);
            }
            TextParagraph.TextAlign hAlign = this.paragraph.getTextAlign();
            if (hAlign == TextParagraph.TextAlign.JUSTIFY || hAlign == TextParagraph.TextAlign.JUSTIFY_LOW) {
                layout = layout.getJustifiedLayout((float) wrappingWidth);
            }
            DrawTextFragment line = fact.getTextFragment(layout, emptyParagraph ? null : new AttributedString(it, startIndex, endIndex));
            this.lines.add(line);
            this.maxLineHeight = Math.max(this.maxLineHeight, (double) line.getHeight());
            if (endIndex == it.getEndIndex()) {
                break;
            }
            graphics2D = graphics;
            fact = fact;
            emptyParagraph = emptyParagraph;
            at = at;
        }
        this.rawText = text.toString();
    }

    /* access modifiers changed from: protected */
    public DrawTextFragment getBullet(Graphics2D graphics, AttributedCharacterIterator firstLineAttr) {
        String buCharacter;
        Paint fgPaint;
        float fontSize;
        TextParagraph.BulletStyle bulletStyle = this.paragraph.getBulletStyle();
        if (bulletStyle == null) {
            return null;
        }
        AutoNumberingScheme ans = bulletStyle.getAutoNumberingScheme();
        if (ans != null) {
            buCharacter = ans.format(this.autoNbrIdx);
        } else {
            buCharacter = bulletStyle.getBulletCharacter();
        }
        if (buCharacter == null) {
            return null;
        }
        String buFont = bulletStyle.getBulletFont();
        if (buFont == null) {
            buFont = this.paragraph.getDefaultFontFamily();
        }
        PlaceableShape<?, ?> ps = getParagraphShape();
        PaintStyle fgPaintStyle = bulletStyle.getBulletFontColor();
        if (fgPaintStyle == null) {
            fgPaint = (Paint) firstLineAttr.getAttribute(TextAttribute.FOREGROUND);
        } else {
            fgPaint = new DrawPaint(ps).getPaint(graphics, fgPaintStyle);
        }
        float fontSize2 = ((Float) firstLineAttr.getAttribute(TextAttribute.SIZE)).floatValue();
        Double buSz = bulletStyle.getBulletFontSize();
        if (buSz == null) {
            buSz = Double.valueOf(100.0d);
        }
        if (buSz.doubleValue() > 0.0d) {
            fontSize = (float) (((double) fontSize2) * buSz.doubleValue() * 0.01d);
        } else {
            fontSize = (float) (-buSz.doubleValue());
        }
        AttributedString str = new AttributedString(mapFontCharset(buCharacter, buFont));
        str.addAttribute(TextAttribute.FOREGROUND, fgPaint);
        str.addAttribute(TextAttribute.FAMILY, buFont);
        str.addAttribute(TextAttribute.SIZE, Float.valueOf(fontSize));
        return DrawFactory.getInstance(graphics).getTextFragment(new TextLayout(str.getIterator(), graphics.getFontRenderContext()), str);
    }

    /* access modifiers changed from: protected */
    public String getRenderableText(TextRun tr) {
        StringBuilder buf = new StringBuilder();
        TextRun.TextCap cap = tr.getTextCap();
        String tabs = null;
        char[] arr$ = tr.getRawText().toCharArray();
        for (char c : arr$) {
            switch (c) {
                case '\t':
                    if (tabs == null) {
                        tabs = tab2space(tr);
                    }
                    buf.append(tabs);
                    break;
                case '\n':
                default:
                    switch (AnonymousClass2.$SwitchMap$org$apache$poi$sl$usermodel$TextRun$TextCap[cap.ordinal()]) {
                        case 1:
                            c = Character.toUpperCase(c);
                            break;
                        case 2:
                            c = Character.toLowerCase(c);
                            break;
                    }
                    buf.append(c);
                    break;
                case 11:
                    buf.append('\n');
                    break;
            }
        }
        return buf.toString();
    }

    private String tab2space(TextRun tr) {
        AttributedString string = new AttributedString(" ");
        String fontFamily = tr.getFontFamily();
        if (fontFamily == null) {
            fontFamily = "Lucida Sans";
        }
        string.addAttribute(TextAttribute.FAMILY, fontFamily);
        Double fs = tr.getFontSize();
        if (fs == null) {
            fs = Double.valueOf(12.0d);
        }
        string.addAttribute(TextAttribute.SIZE, Float.valueOf(fs.floatValue()));
        double wspace = (double) new TextLayout(string.getIterator(), new FontRenderContext((AffineTransform) null, true, true)).getAdvance();
        Double tabSz = this.paragraph.getDefaultTabSize();
        if (tabSz == null) {
            tabSz = Double.valueOf(4.0d * wspace);
        }
        int numSpaces = (int) Math.ceil(tabSz.doubleValue() / wspace);
        StringBuilder buf = new StringBuilder();
        for (int i = 0; i < numSpaces; i++) {
            buf.append(' ');
        }
        return buf.toString();
    }

    /* access modifiers changed from: protected */
    public double getWrappingWidth(boolean firstLine, Graphics2D graphics) {
        double width;
        TextShape<?, ?> ts = this.paragraph.getParentShape();
        Insets2D insets = ts.getInsets();
        double leftInset = insets.left;
        double rightInset = insets.right;
        int indentLevel = this.paragraph.getIndentLevel();
        if (indentLevel == -1) {
            indentLevel = 0;
        }
        Double leftMargin = this.paragraph.getLeftMargin();
        if (leftMargin == null) {
            leftMargin = Double.valueOf(Units.toPoints(((long) (indentLevel + 1)) * 347663));
        }
        Double indent = this.paragraph.getIndent();
        if (indent == null) {
            indent = Double.valueOf(Units.toPoints(((long) indentLevel) * 347663));
        }
        Double rightMargin = this.paragraph.getRightMargin();
        if (rightMargin == null) {
            rightMargin = Double.valueOf(0.0d);
        }
        Rectangle2D anchor = DrawShape.getAnchor(graphics, ts);
        TextShape.TextDirection textDir = ts.getTextDirection();
        if (!ts.getWordWrap()) {
            Dimension pageDim = ts.getSheet().getSlideShow().getPageSize();
            switch (AnonymousClass2.$SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextDirection[textDir.ordinal()]) {
                case 1:
                    return pageDim.getHeight() - anchor.getX();
                case 2:
                    return anchor.getX();
                default:
                    return pageDim.getWidth() - anchor.getX();
            }
        } else {
            switch (AnonymousClass2.$SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextDirection[textDir.ordinal()]) {
                case 1:
                case 2:
                    width = (((anchor.getHeight() - leftInset) - rightInset) - leftMargin.doubleValue()) - rightMargin.doubleValue();
                    break;
                default:
                    width = (((anchor.getWidth() - leftInset) - rightInset) - leftMargin.doubleValue()) - rightMargin.doubleValue();
                    break;
            }
            if (!firstLine || isHSLF()) {
                return width;
            }
            if (this.bullet != null) {
                if (indent.doubleValue() > 0.0d) {
                    return width - indent.doubleValue();
                }
                return width;
            } else if (indent.doubleValue() > 0.0d) {
                return width - indent.doubleValue();
            } else {
                if (indent.doubleValue() < 0.0d) {
                    return width + leftMargin.doubleValue();
                }
                return width;
            }
        }
    }

    /* access modifiers changed from: package-private */
    /* renamed from: org.apache.poi.sl.draw.DrawTextParagraph$2  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass2 {
        static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign;
        static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$TextRun$TextCap;
        static final /* synthetic */ int[] $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextDirection;

        static {
            int[] iArr = new int[TextShape.TextDirection.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextDirection = iArr;
            try {
                iArr[TextShape.TextDirection.VERTICAL.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$org$apache$poi$sl$usermodel$TextShape$TextDirection[TextShape.TextDirection.VERTICAL_270.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            int[] iArr2 = new int[TextRun.TextCap.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$TextRun$TextCap = iArr2;
            try {
                iArr2[TextRun.TextCap.ALL.ordinal()] = 1;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$org$apache$poi$sl$usermodel$TextRun$TextCap[TextRun.TextCap.SMALL.ordinal()] = 2;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$org$apache$poi$sl$usermodel$TextRun$TextCap[TextRun.TextCap.NONE.ordinal()] = 3;
            } catch (NoSuchFieldError e5) {
            }
            int[] iArr3 = new int[TextParagraph.TextAlign.values().length];
            $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign = iArr3;
            try {
                iArr3[TextParagraph.TextAlign.CENTER.ordinal()] = 1;
            } catch (NoSuchFieldError e6) {
            }
            try {
                $SwitchMap$org$apache$poi$sl$usermodel$TextParagraph$TextAlign[TextParagraph.TextAlign.RIGHT.ordinal()] = 2;
            } catch (NoSuchFieldError e7) {
            }
        }
    }

    /* access modifiers changed from: private */
    public static class AttributedStringData {
        AttributedCharacterIterator.Attribute attribute;
        int beginIndex;
        int endIndex;
        Object value;

        AttributedStringData(AttributedCharacterIterator.Attribute attribute2, Object value2, int beginIndex2, int endIndex2) {
            this.attribute = attribute2;
            this.value = value2;
            this.beginIndex = beginIndex2;
            this.endIndex = endIndex2;
        }
    }

    private PlaceableShape<?, ?> getParagraphShape() {
        return new PlaceableShape() {
            /* class org.apache.poi.sl.draw.DrawTextParagraph.AnonymousClass1 */

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public ShapeContainer<?, ?> getParent() {
                return null;
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public Rectangle2D getAnchor() {
                return DrawTextParagraph.this.paragraph.getParentShape().getAnchor();
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public void setAnchor(Rectangle2D anchor) {
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public double getRotation() {
                return 0.0d;
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public void setRotation(double theta) {
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public void setFlipHorizontal(boolean flip) {
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public void setFlipVertical(boolean flip) {
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public boolean getFlipHorizontal() {
                return false;
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public boolean getFlipVertical() {
                return false;
            }

            @Override // org.apache.poi.sl.usermodel.PlaceableShape
            public Sheet<?, ?> getSheet() {
                return DrawTextParagraph.this.paragraph.getParentShape().getSheet();
            }
        };
    }

    /* access modifiers changed from: protected */
    public AttributedString getAttributedString(Graphics2D graphics, StringBuilder text) {
        DrawFontManager fontHandler;
        Graphics2D graphics2D = graphics;
        List<AttributedStringData> attList = new ArrayList<>();
        StringBuilder text2 = text == null ? new StringBuilder() : text;
        PlaceableShape<?, ?> ps = getParagraphShape();
        DrawFontManager fontHandler2 = (DrawFontManager) graphics2D.getRenderingHint(Drawable.FONT_HANDLER);
        for (T run : this.paragraph) {
            String runText = getRenderableText(run);
            if (!runText.isEmpty()) {
                String fontFamily = run.getFontFamily();
                Map<String, String> fontMap = (Map) graphics2D.getRenderingHint(Drawable.FONT_MAP);
                if (fontMap != null && fontMap.containsKey(fontFamily)) {
                    fontFamily = fontMap.get(fontFamily);
                }
                if (fontHandler2 != null) {
                    fontFamily = fontHandler2.getRendererableFont(fontFamily, run.getPitchAndFamily());
                }
                if (fontFamily == null) {
                    fontFamily = this.paragraph.getDefaultFontFamily();
                }
                int beginIndex = text2.length();
                text2.append(mapFontCharset(runText, fontFamily));
                int endIndex = text2.length();
                attList.add(new AttributedStringData(TextAttribute.FAMILY, fontFamily, beginIndex, endIndex));
                attList.add(new AttributedStringData(TextAttribute.FOREGROUND, new DrawPaint(ps).getPaint(graphics2D, run.getFontColor()), beginIndex, endIndex));
                Double fontSz = run.getFontSize();
                if (fontSz == null) {
                    fontSz = this.paragraph.getDefaultFontSize();
                }
                attList.add(new AttributedStringData(TextAttribute.SIZE, Float.valueOf(fontSz.floatValue()), beginIndex, endIndex));
                if (run.isBold()) {
                    attList.add(new AttributedStringData(TextAttribute.WEIGHT, TextAttribute.WEIGHT_BOLD, beginIndex, endIndex));
                }
                if (run.isItalic()) {
                    attList.add(new AttributedStringData(TextAttribute.POSTURE, TextAttribute.POSTURE_OBLIQUE, beginIndex, endIndex));
                }
                if (run.isUnderlined()) {
                    attList.add(new AttributedStringData(TextAttribute.UNDERLINE, TextAttribute.UNDERLINE_ON, beginIndex, endIndex));
                    attList.add(new AttributedStringData(TextAttribute.INPUT_METHOD_UNDERLINE, TextAttribute.UNDERLINE_LOW_TWO_PIXEL, beginIndex, endIndex));
                }
                if (run.isStrikethrough()) {
                    attList.add(new AttributedStringData(TextAttribute.STRIKETHROUGH, TextAttribute.STRIKETHROUGH_ON, beginIndex, endIndex));
                }
                if (run.isSubscript()) {
                    attList.add(new AttributedStringData(TextAttribute.SUPERSCRIPT, TextAttribute.SUPERSCRIPT_SUB, beginIndex, endIndex));
                }
                if (run.isSuperscript()) {
                    attList.add(new AttributedStringData(TextAttribute.SUPERSCRIPT, TextAttribute.SUPERSCRIPT_SUPER, beginIndex, endIndex));
                }
                Hyperlink<?, ?> hl = run.getHyperlink();
                if (hl != null) {
                    fontHandler = fontHandler2;
                    attList.add(new AttributedStringData(HYPERLINK_HREF, hl.getAddress(), beginIndex, endIndex));
                    attList.add(new AttributedStringData(HYPERLINK_LABEL, hl.getLabel(), beginIndex, endIndex));
                } else {
                    fontHandler = fontHandler2;
                }
                graphics2D = graphics;
                ps = ps;
                fontHandler2 = fontHandler;
            }
        }
        if (text2.length() == 0) {
            Double fontSz2 = this.paragraph.getDefaultFontSize();
            text2.append(" ");
            attList.add(new AttributedStringData(TextAttribute.SIZE, Float.valueOf(fontSz2.floatValue()), 0, 1));
        }
        AttributedString string = new AttributedString(text2.toString());
        for (AttributedStringData asd : attList) {
            string.addAttribute(asd.attribute, asd.value, asd.beginIndex, asd.endIndex);
        }
        return string;
    }

    /* access modifiers changed from: protected */
    public boolean isHSLF() {
        return this.paragraph.getClass().getName().contains("HSLF");
    }

    /* access modifiers changed from: protected */
    public String mapFontCharset(String text, String fontFamily) {
        if (!"Wingdings".equalsIgnoreCase(fontFamily)) {
            return text;
        }
        boolean changed = false;
        char[] chrs = text.toCharArray();
        for (int i = 0; i < chrs.length; i++) {
            if ((' ' <= chrs[i] && chrs[i] <= 127) || (160 <= chrs[i] && chrs[i] <= 255)) {
                chrs[i] = (char) (chrs[i] | 61440);
                changed = true;
            }
        }
        if (changed) {
            return new String(chrs);
        }
        return text;
    }
}
