package org.apache.poi.sl.draw.geom;

import java.lang.reflect.Constructor;
import java.util.HashMap;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class ExpressionParser {
    private static final Map<String, ExpressionEntry> impls = new HashMap();

    static {
        try {
            new ExpressionEntry("\\*/ +([\\-\\w]+) +([\\-\\w]+) +([\\-\\w]+)", MultiplyDivideExpression.class);
            new ExpressionEntry("\\+- +([\\-\\w]+) +([\\-\\w]+) +([\\-\\w]+)( 0)?", AddSubtractExpression.class);
            new ExpressionEntry("\\+/ +([\\-\\w]+) +([\\-\\w]+) +([\\-\\w]+)", AddDivideExpression.class);
            new ExpressionEntry("\\?: +([\\-\\w]+) +([\\-\\w]+) +([\\-\\w]+)", IfElseExpression.class);
            new ExpressionEntry("val +([\\-\\w]+)", LiteralValueExpression.class);
            new ExpressionEntry("abs +([\\-\\w]+)", AbsExpression.class);
            new ExpressionEntry("sqrt +([\\-\\w]+)", SqrtExpression.class);
            new ExpressionEntry("max +([\\-\\w]+) +([\\-\\w]+)", MaxExpression.class);
            new ExpressionEntry("min +([\\-\\w]+) +([\\-\\w]+)", MinExpression.class);
            new ExpressionEntry("at2 +([\\-\\w]+) +([\\-\\w]+)", ArcTanExpression.class);
            new ExpressionEntry("sin +([\\-\\w]+) +([\\-\\w]+)", SinExpression.class);
            new ExpressionEntry("cos +([\\-\\w]+) +([\\-\\w]+)", CosExpression.class);
            new ExpressionEntry("tan +([\\-\\w]+) +([\\-\\w]+)", TanExpression.class);
            new ExpressionEntry("cat2 +([\\-\\w]+) +([\\-\\w]+) +([\\-\\w]+)", CosineArcTanExpression.class);
            new ExpressionEntry("sat2 +([\\-\\w]+) +([\\-\\w]+) +([\\-\\w]+)", SinArcTanExpression.class);
            new ExpressionEntry("pin +([\\-\\w]+) +([\\-\\w]+) +([\\-\\w]+)", PinExpression.class);
            new ExpressionEntry("mod +([\\-\\w]+) +([\\-\\w]+) +([\\-\\w]+)", ModExpression.class);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    /* access modifiers changed from: private */
    public static class ExpressionEntry {
        final Constructor<? extends Expression> con;
        final Pattern regex;

        ExpressionEntry(String regex2, Class<? extends Expression> cls) throws SecurityException, NoSuchMethodException {
            this.regex = Pattern.compile(regex2);
            this.con = cls.getDeclaredConstructor(Matcher.class);
            ExpressionParser.impls.put(ExpressionParser.op(regex2), this);
        }
    }

    /* access modifiers changed from: private */
    public static String op(String str) {
        return (str == null || !str.contains(" ")) ? "" : str.substring(0, str.indexOf(" ")).replace("\\", "");
    }

    public static Expression parse(String str) {
        ExpressionEntry ee = impls.get(op(str));
        Matcher m = ee == null ? null : ee.regex.matcher(str);
        if (m == null || !m.matches()) {
            throw new RuntimeException("Unsupported formula: " + str);
        }
        try {
            return (Expression) ee.con.newInstance(m);
        } catch (Exception e) {
            throw new RuntimeException("Unsupported formula: " + str, e);
        }
    }
}
