package org.apache.poi.sl.draw.geom;

import java.awt.geom.Rectangle2D;
import java.util.HashMap;
import java.util.Map;

public abstract class Formula {
    static Map<String, Formula> builtInFormulas;

    /* access modifiers changed from: package-private */
    public abstract double evaluate(Context context);

    /* access modifiers changed from: package-private */
    public String getName() {
        return null;
    }

    static {
        HashMap hashMap = new HashMap();
        builtInFormulas = hashMap;
        hashMap.put("3cd4", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass1 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return 1.62E7d;
            }
        });
        builtInFormulas.put("3cd8", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass2 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return 8100000.0d;
            }
        });
        builtInFormulas.put("5cd8", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass3 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return 1.62E7d;
            }
        });
        builtInFormulas.put("7cd8", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass4 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return 1.62E7d;
            }
        });
        builtInFormulas.put("b", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass5 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                Rectangle2D anchor = ctx.getShapeAnchor();
                return anchor.getY() + anchor.getHeight();
            }
        });
        builtInFormulas.put("cd2", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass6 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return 1.08E7d;
            }
        });
        builtInFormulas.put("cd4", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass7 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return 5400000.0d;
            }
        });
        builtInFormulas.put("cd8", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass8 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return 2700000.0d;
            }
        });
        builtInFormulas.put("hc", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass9 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                Rectangle2D anchor = ctx.getShapeAnchor();
                return anchor.getX() + (anchor.getWidth() / 2.0d);
            }
        });
        builtInFormulas.put("h", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass10 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getHeight();
            }
        });
        builtInFormulas.put("hd2", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass11 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getHeight() / 2.0d;
            }
        });
        builtInFormulas.put("hd3", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass12 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getHeight() / 3.0d;
            }
        });
        builtInFormulas.put("hd4", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass13 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getHeight() / 4.0d;
            }
        });
        builtInFormulas.put("hd5", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass14 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getHeight() / 5.0d;
            }
        });
        builtInFormulas.put("hd6", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass15 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getHeight() / 6.0d;
            }
        });
        builtInFormulas.put("hd8", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass16 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getHeight() / 8.0d;
            }
        });
        builtInFormulas.put("l", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass17 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getX();
            }
        });
        builtInFormulas.put("ls", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass18 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                Rectangle2D anchor = ctx.getShapeAnchor();
                return Math.max(anchor.getWidth(), anchor.getHeight());
            }
        });
        builtInFormulas.put("r", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass19 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                Rectangle2D anchor = ctx.getShapeAnchor();
                return anchor.getX() + anchor.getWidth();
            }
        });
        builtInFormulas.put("ss", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass20 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                Rectangle2D anchor = ctx.getShapeAnchor();
                return Math.min(anchor.getWidth(), anchor.getHeight());
            }
        });
        builtInFormulas.put("ssd2", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass21 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                Rectangle2D anchor = ctx.getShapeAnchor();
                return Math.min(anchor.getWidth(), anchor.getHeight()) / 2.0d;
            }
        });
        builtInFormulas.put("ssd4", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass22 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                Rectangle2D anchor = ctx.getShapeAnchor();
                return Math.min(anchor.getWidth(), anchor.getHeight()) / 4.0d;
            }
        });
        builtInFormulas.put("ssd6", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass23 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                Rectangle2D anchor = ctx.getShapeAnchor();
                return Math.min(anchor.getWidth(), anchor.getHeight()) / 6.0d;
            }
        });
        builtInFormulas.put("ssd8", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass24 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                Rectangle2D anchor = ctx.getShapeAnchor();
                return Math.min(anchor.getWidth(), anchor.getHeight()) / 8.0d;
            }
        });
        builtInFormulas.put("ssd16", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass25 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                Rectangle2D anchor = ctx.getShapeAnchor();
                return Math.min(anchor.getWidth(), anchor.getHeight()) / 16.0d;
            }
        });
        builtInFormulas.put("ssd32", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass26 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                Rectangle2D anchor = ctx.getShapeAnchor();
                return Math.min(anchor.getWidth(), anchor.getHeight()) / 32.0d;
            }
        });
        builtInFormulas.put("t", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass27 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getY();
            }
        });
        builtInFormulas.put("vc", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass28 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                Rectangle2D anchor = ctx.getShapeAnchor();
                return anchor.getY() + (anchor.getHeight() / 2.0d);
            }
        });
        builtInFormulas.put("w", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass29 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getWidth();
            }
        });
        builtInFormulas.put("wd2", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass30 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getWidth() / 2.0d;
            }
        });
        builtInFormulas.put("wd3", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass31 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getWidth() / 3.0d;
            }
        });
        builtInFormulas.put("wd4", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass32 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getWidth() / 4.0d;
            }
        });
        builtInFormulas.put("wd5", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass33 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getWidth() / 5.0d;
            }
        });
        builtInFormulas.put("wd6", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass34 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getWidth() / 6.0d;
            }
        });
        builtInFormulas.put("wd8", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass35 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getWidth() / 8.0d;
            }
        });
        builtInFormulas.put("wd10", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass36 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getWidth() / 10.0d;
            }
        });
        builtInFormulas.put("wd32", new Formula() {
            /* class org.apache.poi.sl.draw.geom.Formula.AnonymousClass37 */

            /* access modifiers changed from: package-private */
            @Override // org.apache.poi.sl.draw.geom.Formula
            public double evaluate(Context ctx) {
                return ctx.getShapeAnchor().getWidth() / 32.0d;
            }
        });
    }
}
