package org.apache.poi.sl.usermodel;

import java.awt.Dimension;
import java.io.IOException;

public interface PictureData {
    byte[] getChecksum();

    String getContentType();

    byte[] getData();

    Dimension getImageDimension();

    Dimension getImageDimensionInPixels();

    PictureType getType();

    void setData(byte[] bArr) throws IOException;

    public enum PictureType {
        EMF(2, 2, "image/x-emf", ".emf"),
        WMF(3, 3, "image/x-wmf", ".wmf"),
        PICT(4, 4, "image/pict", ".pict"),
        JPEG(5, 5, "image/jpeg", ".jpg"),
        PNG(6, 6, "image/png", ".png"),
        DIB(7, 7, "image/dib", ".dib"),
        GIF(-1, 8, "image/gif", ".gif"),
        TIFF(-1, 9, "image/tiff", ".tif"),
        EPS(-1, 10, "image/x-eps", ".eps"),
        BMP(-1, 11, "image/x-ms-bmp", ".bmp"),
        WPG(-1, 12, "image/x-wpg", ".wpg"),
        WDP(-1, 13, "image/vnd.ms-photo", ".wdp");
        
        public final String contentType;
        public final String extension;
        public final int nativeId;
        public final int ooxmlId;

        private PictureType(int nativeId2, int ooxmlId2, String contentType2, String extension2) {
            this.nativeId = nativeId2;
            this.ooxmlId = ooxmlId2;
            this.contentType = contentType2;
            this.extension = extension2;
        }

        public static PictureType forNativeID(int nativeId2) {
            PictureType[] arr$ = values();
            for (PictureType ans : arr$) {
                if (ans.nativeId == nativeId2) {
                    return ans;
                }
            }
            return null;
        }

        public static PictureType forOoxmlID(int ooxmlId2) {
            PictureType[] arr$ = values();
            for (PictureType ans : arr$) {
                if (ans.ooxmlId == ooxmlId2) {
                    return ans;
                }
            }
            return null;
        }
    }
}
