package org.apache.poi.ss.format;

import java.util.HashMap;
import java.util.Map;

public abstract class CellFormatCondition {
    private static final int EQ = 4;
    private static final int GE = 3;
    private static final int GT = 2;
    private static final int LE = 1;
    private static final int LT = 0;
    private static final int NE = 5;
    private static final Map<String, Integer> TESTS;

    public abstract boolean pass(double d);

    static {
        HashMap hashMap = new HashMap();
        TESTS = hashMap;
        hashMap.put("<", 0);
        hashMap.put("<=", 1);
        hashMap.put(">", 2);
        hashMap.put(">=", 3);
        hashMap.put("=", 4);
        hashMap.put("==", 4);
        hashMap.put("!=", 5);
        hashMap.put("<>", 5);
    }

    public static CellFormatCondition getInstance(String opString, String constStr) {
        Map<String, Integer> map = TESTS;
        if (map.containsKey(opString)) {
            int test = map.get(opString).intValue();
            final double c = Double.parseDouble(constStr);
            switch (test) {
                case 0:
                    return new CellFormatCondition() {
                        /* class org.apache.poi.ss.format.CellFormatCondition.AnonymousClass1 */

                        @Override // org.apache.poi.ss.format.CellFormatCondition
                        public boolean pass(double value) {
                            return value < c;
                        }
                    };
                case 1:
                    return new CellFormatCondition() {
                        /* class org.apache.poi.ss.format.CellFormatCondition.AnonymousClass2 */

                        @Override // org.apache.poi.ss.format.CellFormatCondition
                        public boolean pass(double value) {
                            return value <= c;
                        }
                    };
                case 2:
                    return new CellFormatCondition() {
                        /* class org.apache.poi.ss.format.CellFormatCondition.AnonymousClass3 */

                        @Override // org.apache.poi.ss.format.CellFormatCondition
                        public boolean pass(double value) {
                            return value > c;
                        }
                    };
                case 3:
                    return new CellFormatCondition() {
                        /* class org.apache.poi.ss.format.CellFormatCondition.AnonymousClass4 */

                        @Override // org.apache.poi.ss.format.CellFormatCondition
                        public boolean pass(double value) {
                            return value >= c;
                        }
                    };
                case 4:
                    return new CellFormatCondition() {
                        /* class org.apache.poi.ss.format.CellFormatCondition.AnonymousClass5 */

                        @Override // org.apache.poi.ss.format.CellFormatCondition
                        public boolean pass(double value) {
                            return value == c;
                        }
                    };
                case 5:
                    return new CellFormatCondition() {
                        /* class org.apache.poi.ss.format.CellFormatCondition.AnonymousClass6 */

                        @Override // org.apache.poi.ss.format.CellFormatCondition
                        public boolean pass(double value) {
                            return value != c;
                        }
                    };
                default:
                    throw new IllegalArgumentException("Cannot create for test number " + test + "(\"" + opString + "\")");
            }
        } else {
            throw new IllegalArgumentException("Unknown test: " + opString);
        }
    }
}
