package org.apache.poi.ss.format;

import java.util.LinkedList;
import java.util.List;
import java.util.ListIterator;
import java.util.regex.Matcher;
import org.apache.poi.ss.format.CellFormatPart;
import org.apache.poi.ss.format.CellNumberFormatter;
import org.apache.poi.util.Internal;

@Internal
public class CellNumberPartHandler implements CellFormatPart.PartHandler {
    private CellNumberFormatter.Special decimalPoint;
    private CellNumberFormatter.Special exponent;
    private boolean improperFraction;
    private char insertSignForExponent;
    private CellNumberFormatter.Special numerator;
    private double scale = 1.0d;
    private CellNumberFormatter.Special slash;
    private final List<CellNumberFormatter.Special> specials = new LinkedList();

    @Override // org.apache.poi.ss.format.CellFormatPart.PartHandler
    public String handlePart(Matcher m, String part, CellFormatType type, StringBuffer descBuf) {
        int pos = descBuf.length();
        boolean z = false;
        switch (part.charAt(0)) {
            case '#':
            case '0':
            case '?':
                char c = this.insertSignForExponent;
                if (c != 0) {
                    this.specials.add(new CellNumberFormatter.Special(c, pos));
                    descBuf.append(this.insertSignForExponent);
                    this.insertSignForExponent = 0;
                    pos++;
                }
                for (int i = 0; i < part.length(); i++) {
                    this.specials.add(new CellNumberFormatter.Special(part.charAt(i), pos + i));
                }
                break;
            case '%':
                this.scale *= 100.0d;
                break;
            case '.':
                if (this.decimalPoint == null && this.specials.size() > 0) {
                    CellNumberFormatter.Special special = new CellNumberFormatter.Special('.', pos);
                    this.decimalPoint = special;
                    this.specials.add(special);
                    break;
                }
            case '/':
                if (this.slash == null && this.specials.size() > 0) {
                    CellNumberFormatter.Special previousNumber = previousNumber();
                    this.numerator = previousNumber;
                    boolean z2 = this.improperFraction;
                    if (previousNumber == firstDigit(this.specials)) {
                        z = true;
                    }
                    this.improperFraction = z | z2;
                    CellNumberFormatter.Special special2 = new CellNumberFormatter.Special('.', pos);
                    this.slash = special2;
                    this.specials.add(special2);
                    break;
                }
            case 'E':
            case 'e':
                if (this.exponent == null && this.specials.size() > 0) {
                    CellNumberFormatter.Special special3 = new CellNumberFormatter.Special('.', pos);
                    this.exponent = special3;
                    this.specials.add(special3);
                    this.insertSignForExponent = part.charAt(1);
                    return part.substring(0, 1);
                }
            default:
                return null;
        }
        return part;
    }

    public double getScale() {
        return this.scale;
    }

    public CellNumberFormatter.Special getDecimalPoint() {
        return this.decimalPoint;
    }

    public CellNumberFormatter.Special getSlash() {
        return this.slash;
    }

    public CellNumberFormatter.Special getExponent() {
        return this.exponent;
    }

    public CellNumberFormatter.Special getNumerator() {
        return this.numerator;
    }

    public List<CellNumberFormatter.Special> getSpecials() {
        return this.specials;
    }

    public boolean isImproperFraction() {
        return this.improperFraction;
    }

    private CellNumberFormatter.Special previousNumber() {
        List<CellNumberFormatter.Special> list = this.specials;
        ListIterator<CellNumberFormatter.Special> it = list.listIterator(list.size());
        while (it.hasPrevious()) {
            CellNumberFormatter.Special s = it.previous();
            if (isDigitFmt(s)) {
                while (it.hasPrevious()) {
                    s = it.previous();
                    if (s.pos - s.pos > 1 || !isDigitFmt(s)) {
                        break;
                    }
                }
                return s;
            }
        }
        return null;
    }

    private static boolean isDigitFmt(CellNumberFormatter.Special s) {
        return s.ch == '0' || s.ch == '?' || s.ch == '#';
    }

    private static CellNumberFormatter.Special firstDigit(List<CellNumberFormatter.Special> specials2) {
        for (CellNumberFormatter.Special s : specials2) {
            if (isDigitFmt(s)) {
                return s;
            }
        }
        return null;
    }
}
