package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.ValueEval;

public abstract class AggregateFunction extends MultiOperandNumericFunction {
    public static final Function AVEDEV = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass2 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] values) {
            return StatsLib.avedev(values);
        }
    };
    public static final Function AVERAGE = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass3 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] values) throws EvaluationException {
            if (values.length >= 1) {
                return MathX.average(values);
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };
    public static final Function DEVSQ = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass4 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] values) {
            return StatsLib.devsq(values);
        }
    };
    public static final Function LARGE = new LargeSmall(true);
    public static final Function MAX = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass5 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] values) {
            if (values.length > 0) {
                return MathX.max(values);
            }
            return 0.0d;
        }
    };
    public static final Function MEDIAN = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass6 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] values) {
            return StatsLib.median(values);
        }
    };
    public static final Function MIN = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass7 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] values) {
            if (values.length > 0) {
                return MathX.min(values);
            }
            return 0.0d;
        }
    };
    public static final Function PERCENTILE = new Percentile();
    public static final Function PRODUCT = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass8 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] values) {
            return MathX.product(values);
        }
    };
    public static final Function SMALL = new LargeSmall(false);
    public static final Function STDEV = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass9 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] values) throws EvaluationException {
            if (values.length >= 1) {
                return StatsLib.stdev(values);
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };
    public static final Function SUM = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass10 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] values) {
            return MathX.sum(values);
        }
    };
    public static final Function SUMSQ = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass11 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] values) {
            return MathX.sumsq(values);
        }
    };
    public static final Function VAR = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass12 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] values) throws EvaluationException {
            if (values.length >= 1) {
                return StatsLib.var(values);
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };
    public static final Function VARP = new AggregateFunction() {
        /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass13 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] values) throws EvaluationException {
            if (values.length >= 1) {
                return StatsLib.varp(values);
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };

    private static final class LargeSmall extends Fixed2ArgFunction {
        private final boolean _isLarge;

        protected LargeSmall(boolean isLarge) {
            this._isLarge = isLarge;
        }

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0, ValueEval arg1) {
            try {
                double dn = OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(arg1, srcRowIndex, srcColumnIndex));
                if (dn < 1.0d) {
                    return ErrorEval.NUM_ERROR;
                }
                int k = (int) Math.ceil(dn);
                try {
                    double[] ds = ValueCollector.collectValues(arg0);
                    if (k > ds.length) {
                        return ErrorEval.NUM_ERROR;
                    }
                    double result = this._isLarge ? StatsLib.kthLargest(ds, k) : StatsLib.kthSmallest(ds, k);
                    NumericFunction.checkValue(result);
                    return new NumberEval(result);
                } catch (EvaluationException e) {
                    return e.getErrorEval();
                }
            } catch (EvaluationException e2) {
                return ErrorEval.VALUE_INVALID;
            }
        }
    }

    private static final class Percentile extends Fixed2ArgFunction {
        protected Percentile() {
        }

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0, ValueEval arg1) {
            double d;
            try {
                double dn = OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(arg1, srcRowIndex, srcColumnIndex));
                if (dn < 0.0d || dn > 1.0d) {
                    return ErrorEval.NUM_ERROR;
                }
                try {
                    double[] ds = ValueCollector.collectValues(arg0);
                    int N = ds.length;
                    if (N != 0) {
                        if (N <= 8191) {
                            double n = (((double) (N - 1)) * dn) + 1.0d;
                            if (n == 1.0d) {
                                d = StatsLib.kthSmallest(ds, 1);
                            } else if (Double.compare(n, (double) N) == 0) {
                                d = StatsLib.kthLargest(ds, 1);
                            } else {
                                int k = (int) n;
                                d = StatsLib.kthSmallest(ds, k) + ((StatsLib.kthSmallest(ds, k + 1) - StatsLib.kthSmallest(ds, k)) * (n - ((double) k)));
                            }
                            NumericFunction.checkValue(d);
                            return new NumberEval(d);
                        }
                    }
                    return ErrorEval.NUM_ERROR;
                } catch (EvaluationException e) {
                    return e.getErrorEval();
                }
            } catch (EvaluationException e2) {
                return ErrorEval.VALUE_INVALID;
            }
        }
    }

    static final class ValueCollector extends MultiOperandNumericFunction {
        private static final ValueCollector instance = new ValueCollector();

        public ValueCollector() {
            super(false, false);
        }

        public static double[] collectValues(ValueEval... operands) throws EvaluationException {
            return instance.getNumberArray(operands);
        }

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
        public double evaluate(double[] values) {
            throw new IllegalStateException("should not be called");
        }
    }

    protected AggregateFunction() {
        super(false, false);
    }

    static Function subtotalInstance(Function func) {
        return new AggregateFunction((AggregateFunction) func) {
            /* class org.apache.poi.ss.formula.functions.AggregateFunction.AnonymousClass1 */
            final /* synthetic */ AggregateFunction val$arg;

            {
                this.val$arg = r1;
            }

            /* access modifiers changed from: protected */
            @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
            public double evaluate(double[] values) throws EvaluationException {
                return this.val$arg.evaluate(values);
            }

            @Override // org.apache.poi.ss.formula.functions.MultiOperandNumericFunction
            public boolean isSubtotalCounted() {
                return false;
            }
        };
    }
}
