package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.AggregateFunction;

public final class Irr implements Function {
    @Override // org.apache.poi.ss.formula.functions.Function
    public ValueEval evaluate(ValueEval[] args, int srcRowIndex, int srcColumnIndex) {
        double guess;
        if (args.length == 0 || args.length > 2) {
            return ErrorEval.VALUE_INVALID;
        }
        try {
            double[] values = AggregateFunction.ValueCollector.collectValues(args[0]);
            if (args.length == 2) {
                guess = NumericFunction.singleOperandEvaluate(args[1], srcRowIndex, srcColumnIndex);
            } else {
                guess = 0.1d;
            }
            double result = irr(values, guess);
            NumericFunction.checkValue(result);
            return new NumberEval(result);
        } catch (EvaluationException e) {
            return e.getErrorEval();
        }
    }

    public static double irr(double[] income) {
        return irr(income, 0.1d);
    }

    public static double irr(double[] values, double guess) {
        int maxIterationCount = 20;
        double absoluteAccuracy = 1.0E-7d;
        double x0 = guess;
        int i = 0;
        while (i < maxIterationCount) {
            double fValue = 0.0d;
            double fDerivative = 0.0d;
            int k = 0;
            while (k < values.length) {
                fValue += values[k] / Math.pow(x0 + 1.0d, (double) k);
                fDerivative += (((double) (-k)) * values[k]) / Math.pow(x0 + 1.0d, (double) (k + 1));
                k++;
                maxIterationCount = maxIterationCount;
                absoluteAccuracy = absoluteAccuracy;
            }
            double x1 = x0 - (fValue / fDerivative);
            if (Math.abs(x1 - x0) <= absoluteAccuracy) {
                return x1;
            }
            x0 = x1;
            i++;
            maxIterationCount = maxIterationCount;
            absoluteAccuracy = absoluteAccuracy;
        }
        return Double.NaN;
    }
}
