package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.eval.AreaEval;
import org.apache.poi.ss.formula.eval.BlankEval;
import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;

public abstract class LogicalFunction extends Fixed1ArgFunction {
    public static final Function ISBLANK = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass5 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval arg) {
            return arg instanceof BlankEval;
        }
    };
    public static final Function ISERR = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass7 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval arg) {
            if (!(arg instanceof ErrorEval) || arg == ErrorEval.NA) {
                return false;
            }
            return true;
        }
    };
    public static final Function ISERROR = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass6 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval arg) {
            return arg instanceof ErrorEval;
        }
    };
    public static final Function ISLOGICAL = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass1 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval arg) {
            return arg instanceof BoolEval;
        }
    };
    public static final Function ISNA = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass8 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval arg) {
            return arg == ErrorEval.NA;
        }
    };
    public static final Function ISNONTEXT = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass2 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval arg) {
            return !(arg instanceof StringEval);
        }
    };
    public static final Function ISNUMBER = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass3 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval arg) {
            return arg instanceof NumberEval;
        }
    };
    public static final Function ISREF = new Fixed1ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass9 */

        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0) {
            if ((arg0 instanceof RefEval) || (arg0 instanceof AreaEval)) {
                return BoolEval.TRUE;
            }
            return BoolEval.FALSE;
        }
    };
    public static final Function ISTEXT = new LogicalFunction() {
        /* class org.apache.poi.ss.formula.functions.LogicalFunction.AnonymousClass4 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.LogicalFunction
        public boolean evaluate(ValueEval arg) {
            return arg instanceof StringEval;
        }
    };

    /* access modifiers changed from: protected */
    public abstract boolean evaluate(ValueEval valueEval);

    @Override // org.apache.poi.ss.formula.functions.Function1Arg
    public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0) {
        ValueEval ve;
        try {
            ve = OperandResolver.getSingleValue(arg0, srcRowIndex, srcColumnIndex);
        } catch (EvaluationException e) {
            ve = e.getErrorEval();
        }
        return BoolEval.valueOf(evaluate(ve));
    }
}
