package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.ValueEval;

public abstract class NumericFunction implements Function {
    public static final Function ABS = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass1 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return Math.abs(d);
        }
    };
    public static final Function ACOS = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass2 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return Math.acos(d);
        }
    };
    public static final Function ACOSH = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass3 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return MathX.acosh(d);
        }
    };
    public static final Function ASIN = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass4 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return Math.asin(d);
        }
    };
    public static final Function ASINH = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass5 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return MathX.asinh(d);
        }
    };
    public static final Function ATAN = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass6 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return Math.atan(d);
        }
    };
    public static final Function ATAN2 = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass24 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d0, double d1) throws EvaluationException {
            if (d0 != NumericFunction.LOG_10_TO_BASE_e || d1 != NumericFunction.LOG_10_TO_BASE_e) {
                return Math.atan2(d1, d0);
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };
    public static final Function ATANH = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass7 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return MathX.atanh(d);
        }
    };
    public static final Function CEILING = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass25 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d0, double d1) {
            return MathX.ceiling(d0, d1);
        }
    };
    public static final Function COMBIN = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass26 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d0, double d1) throws EvaluationException {
            if (d0 <= 2.147483647E9d && d1 <= 2.147483647E9d) {
                return MathX.nChooseK((int) d0, (int) d1);
            }
            throw new EvaluationException(ErrorEval.NUM_ERROR);
        }
    };
    public static final Function COS = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass8 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return Math.cos(d);
        }
    };
    public static final Function COSH = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass9 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return MathX.cosh(d);
        }
    };
    public static final Function DEGREES = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass10 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return Math.toDegrees(d);
        }
    };
    public static final Function DOLLAR = new Var1or2ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass11 */

        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0) {
            return evaluate(srcRowIndex, srcColumnIndex, arg0, NumericFunction.DOLLAR_ARG2_DEFAULT);
        }

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0, ValueEval arg1) {
            try {
                double val = NumericFunction.singleOperandEvaluate(arg0, srcRowIndex, srcColumnIndex);
                if (((int) NumericFunction.singleOperandEvaluate(arg1, srcRowIndex, srcColumnIndex)) > 127) {
                    return ErrorEval.VALUE_INVALID;
                }
                return new NumberEval(val);
            } catch (EvaluationException e) {
                return e.getErrorEval();
            }
        }
    };
    static final NumberEval DOLLAR_ARG2_DEFAULT = new NumberEval(2.0d);
    public static final Function EXP = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass12 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return Math.pow(2.718281828459045d, d);
        }
    };
    public static final Function FACT = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass13 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return MathX.factorial((int) d);
        }
    };
    public static final Function FLOOR = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass27 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d0, double d1) throws EvaluationException {
            if (d1 != NumericFunction.LOG_10_TO_BASE_e) {
                return MathX.floor(d0, d1);
            }
            if (d0 == NumericFunction.LOG_10_TO_BASE_e) {
                return NumericFunction.LOG_10_TO_BASE_e;
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };
    public static final Function INT = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass14 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return (double) Math.round(d - 0.5d);
        }
    };
    public static final Function LN = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass15 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return Math.log(d);
        }
    };
    public static final Function LOG = new Log();
    public static final Function LOG10 = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass16 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return Math.log(d) / NumericFunction.LOG_10_TO_BASE_e;
        }
    };
    static final double LOG_10_TO_BASE_e = Math.log(TEN);
    public static final Function MOD = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass28 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d0, double d1) throws EvaluationException {
            if (d1 != NumericFunction.LOG_10_TO_BASE_e) {
                return MathX.mod(d0, d1);
            }
            throw new EvaluationException(ErrorEval.DIV_ZERO);
        }
    };
    public static final Function PI = new Fixed0ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass34 */

        @Override // org.apache.poi.ss.formula.functions.Function0Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex) {
            return NumericFunction.PI_EVAL;
        }
    };
    static final NumberEval PI_EVAL = new NumberEval(3.141592653589793d);
    public static final Function POISSON = new Fixed3ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass36 */
        private static final double DEFAULT_RETURN_RESULT = 1.0d;
        private final long[] FACTORIALS = {1, 1, 2, 6, 24, 120, 720, 5040, 40320, 362880, 3628800, 39916800, 479001600, 6227020800L, 87178291200L, 1307674368000L, 20922789888000L, 355687428096000L, 6402373705728000L, 121645100408832000L, 2432902008176640000L};

        private boolean isDefaultResult(double x, double mean) {
            if (x == NumericFunction.LOG_10_TO_BASE_e && mean == NumericFunction.LOG_10_TO_BASE_e) {
                return true;
            }
            return false;
        }

        private boolean checkArgument(double aDouble) throws EvaluationException {
            NumericFunction.checkValue(aDouble);
            if (aDouble >= NumericFunction.LOG_10_TO_BASE_e) {
                return true;
            }
            throw new EvaluationException(ErrorEval.NUM_ERROR);
        }

        private double probability(int k, double lambda) {
            return (Math.pow(lambda, (double) k) * Math.exp(-lambda)) / ((double) factorial(k));
        }

        private double cumulativeProbability(int x, double lambda) {
            double result = NumericFunction.LOG_10_TO_BASE_e;
            for (int k = 0; k <= x; k++) {
                result += probability(k, lambda);
            }
            return result;
        }

        public long factorial(int n) {
            if (n >= 0 && n <= 20) {
                return this.FACTORIALS[n];
            }
            throw new IllegalArgumentException("Valid argument should be in the range [0..20]");
        }

        @Override // org.apache.poi.ss.formula.functions.Function3Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0, ValueEval arg1, ValueEval arg2) {
            double result;
            boolean cumulative = ((BoolEval) arg2).getBooleanValue();
            try {
                double x = NumericFunction.singleOperandEvaluate(arg0, srcRowIndex, srcColumnIndex);
                double mean = NumericFunction.singleOperandEvaluate(arg1, srcRowIndex, srcColumnIndex);
                if (isDefaultResult(x, mean)) {
                    return new NumberEval((double) DEFAULT_RETURN_RESULT);
                }
                checkArgument(x);
                checkArgument(mean);
                if (cumulative) {
                    result = cumulativeProbability((int) x, mean);
                } else {
                    result = probability((int) x, mean);
                }
                NumericFunction.checkValue(result);
                return new NumberEval(result);
            } catch (EvaluationException e) {
                return e.getErrorEval();
            }
        }
    };
    public static final Function POWER = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass29 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d0, double d1) {
            return Math.pow(d0, d1);
        }
    };
    public static final Function RADIANS = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass17 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return Math.toRadians(d);
        }
    };
    public static final Function RAND = new Fixed0ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass35 */

        @Override // org.apache.poi.ss.formula.functions.Function0Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex) {
            return new NumberEval(Math.random());
        }
    };
    public static final Function ROUND = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass30 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d0, double d1) {
            return MathX.round(d0, (int) d1);
        }
    };
    public static final Function ROUNDDOWN = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass31 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d0, double d1) {
            return MathX.roundDown(d0, (int) d1);
        }
    };
    public static final Function ROUNDUP = new TwoArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass32 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.TwoArg
        public double evaluate(double d0, double d1) {
            return MathX.roundUp(d0, (int) d1);
        }
    };
    public static final Function SIGN = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass18 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return (double) MathX.sign(d);
        }
    };
    public static final Function SIN = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass19 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return Math.sin(d);
        }
    };
    public static final Function SINH = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass20 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return MathX.sinh(d);
        }
    };
    public static final Function SQRT = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass21 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return Math.sqrt(d);
        }
    };
    public static final Function TAN = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass22 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return Math.tan(d);
        }
    };
    public static final Function TANH = new OneArg() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass23 */

        /* access modifiers changed from: protected */
        @Override // org.apache.poi.ss.formula.functions.NumericFunction.OneArg
        public double evaluate(double d) {
            return MathX.tanh(d);
        }
    };
    static final double TEN = 10.0d;
    public static final Function TRUNC = new Var1or2ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.NumericFunction.AnonymousClass33 */

        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0) {
            return evaluate(srcRowIndex, srcColumnIndex, arg0, NumericFunction.TRUNC_ARG2_DEFAULT);
        }

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0, ValueEval arg1) {
            double result;
            try {
                double d0 = NumericFunction.singleOperandEvaluate(arg0, srcRowIndex, srcColumnIndex);
                double multi = Math.pow(NumericFunction.TEN, NumericFunction.singleOperandEvaluate(arg1, srcRowIndex, srcColumnIndex));
                if (d0 < NumericFunction.LOG_10_TO_BASE_e) {
                    result = (-Math.floor((-d0) * multi)) / multi;
                } else {
                    result = Math.floor(d0 * multi) / multi;
                }
                NumericFunction.checkValue(result);
                return new NumberEval(result);
            } catch (EvaluationException e) {
                return e.getErrorEval();
            }
        }
    };
    static final NumberEval TRUNC_ARG2_DEFAULT = new NumberEval((double) LOG_10_TO_BASE_e);
    static final double ZERO = 0.0d;

    /* access modifiers changed from: protected */
    public abstract double eval(ValueEval[] valueEvalArr, int i, int i2) throws EvaluationException;

    protected static final double singleOperandEvaluate(ValueEval arg, int srcRowIndex, int srcColumnIndex) throws EvaluationException {
        if (arg != null) {
            double result = OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(arg, srcRowIndex, srcColumnIndex));
            checkValue(result);
            return result;
        }
        throw new IllegalArgumentException("arg must not be null");
    }

    public static final void checkValue(double result) throws EvaluationException {
        if (Double.isNaN(result) || Double.isInfinite(result)) {
            throw new EvaluationException(ErrorEval.NUM_ERROR);
        }
    }

    @Override // org.apache.poi.ss.formula.functions.Function
    public final ValueEval evaluate(ValueEval[] args, int srcCellRow, int srcCellCol) {
        try {
            double result = eval(args, srcCellRow, srcCellCol);
            checkValue(result);
            return new NumberEval(result);
        } catch (EvaluationException e) {
            return e.getErrorEval();
        }
    }

    public static abstract class OneArg extends Fixed1ArgFunction {
        /* access modifiers changed from: protected */
        public abstract double evaluate(double d) throws EvaluationException;

        protected OneArg() {
        }

        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0) {
            try {
                double result = evaluate(NumericFunction.singleOperandEvaluate(arg0, srcRowIndex, srcColumnIndex));
                NumericFunction.checkValue(result);
                return new NumberEval(result);
            } catch (EvaluationException e) {
                return e.getErrorEval();
            }
        }

        /* access modifiers changed from: protected */
        public final double eval(ValueEval[] args, int srcCellRow, int srcCellCol) throws EvaluationException {
            if (args.length == 1) {
                return evaluate(NumericFunction.singleOperandEvaluate(args[0], srcCellRow, srcCellCol));
            }
            throw new EvaluationException(ErrorEval.VALUE_INVALID);
        }
    }

    public static abstract class TwoArg extends Fixed2ArgFunction {
        /* access modifiers changed from: protected */
        public abstract double evaluate(double d, double d2) throws EvaluationException;

        protected TwoArg() {
        }

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0, ValueEval arg1) {
            try {
                double result = evaluate(NumericFunction.singleOperandEvaluate(arg0, srcRowIndex, srcColumnIndex), NumericFunction.singleOperandEvaluate(arg1, srcRowIndex, srcColumnIndex));
                NumericFunction.checkValue(result);
                return new NumberEval(result);
            } catch (EvaluationException e) {
                return e.getErrorEval();
            }
        }
    }

    private static final class Log extends Var1or2ArgFunction {
        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0) {
            try {
                double result = Math.log(NumericFunction.singleOperandEvaluate(arg0, srcRowIndex, srcColumnIndex)) / NumericFunction.LOG_10_TO_BASE_e;
                NumericFunction.checkValue(result);
                return new NumberEval(result);
            } catch (EvaluationException e) {
                return e.getErrorEval();
            }
        }

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0, ValueEval arg1) {
            double result;
            try {
                double d0 = NumericFunction.singleOperandEvaluate(arg0, srcRowIndex, srcColumnIndex);
                double d1 = NumericFunction.singleOperandEvaluate(arg1, srcRowIndex, srcColumnIndex);
                double logE = Math.log(d0);
                if (Double.compare(d1, 2.718281828459045d) == 0) {
                    result = logE;
                } else {
                    result = logE / Math.log(d1);
                }
                NumericFunction.checkValue(result);
                return new NumberEval(result);
            } catch (EvaluationException e) {
                return e.getErrorEval();
            }
        }
    }
}
