package org.apache.poi.ss.formula.udf;

import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import org.apache.poi.ss.formula.functions.FreeRefFunction;

public final class DefaultUDFFinder implements UDFFinder {
    private final Map<String, FreeRefFunction> _functionsByName;

    public DefaultUDFFinder(String[] functionNames, FreeRefFunction[] functionImpls) {
        int nFuncs = functionNames.length;
        if (functionImpls.length == nFuncs) {
            HashMap<String, FreeRefFunction> m = new HashMap<>((nFuncs * 3) / 2);
            for (int i = 0; i < functionImpls.length; i++) {
                m.put(functionNames[i].toUpperCase(Locale.ROOT), functionImpls[i]);
            }
            this._functionsByName = m;
            return;
        }
        throw new IllegalArgumentException("Mismatch in number of function names and implementations");
    }

    @Override // org.apache.poi.ss.formula.udf.UDFFinder
    public FreeRefFunction findFunction(String name) {
        return this._functionsByName.get(name.toUpperCase(Locale.ROOT));
    }
}
