package org.apache.poi.ss.usermodel;

public class CellCopyPolicy {
    public static final boolean DEFAULT_CONDENSE_ROWS_POLICY = false;
    public static final boolean DEFAULT_COPY_CELL_FORMULA_POLICY = true;
    public static final boolean DEFAULT_COPY_CELL_STYLE_POLICY = true;
    public static final boolean DEFAULT_COPY_CELL_VALUE_POLICY = true;
    public static final boolean DEFAULT_COPY_HYPERLINK_POLICY = true;
    public static final boolean DEFAULT_COPY_MERGED_REGIONS_POLICY = true;
    public static final boolean DEFAULT_COPY_ROW_HEIGHT_POLICY = true;
    public static final boolean DEFAULT_MERGE_HYPERLINK_POLICY = false;
    private boolean condenseRows;
    private boolean copyCellFormula;
    private boolean copyCellStyle;
    private boolean copyCellValue;
    private boolean copyHyperlink;
    private boolean copyMergedRegions;
    private boolean copyRowHeight;
    private boolean mergeHyperlink;

    public CellCopyPolicy() {
        this.copyCellValue = true;
        this.copyCellStyle = true;
        this.copyCellFormula = true;
        this.copyHyperlink = true;
        this.mergeHyperlink = false;
        this.copyRowHeight = true;
        this.condenseRows = false;
        this.copyMergedRegions = true;
    }

    public CellCopyPolicy(CellCopyPolicy other) {
        this.copyCellValue = true;
        this.copyCellStyle = true;
        this.copyCellFormula = true;
        this.copyHyperlink = true;
        this.mergeHyperlink = false;
        this.copyRowHeight = true;
        this.condenseRows = false;
        this.copyMergedRegions = true;
        this.copyCellValue = other.isCopyCellValue();
        this.copyCellStyle = other.isCopyCellStyle();
        this.copyCellFormula = other.isCopyCellFormula();
        this.copyHyperlink = other.isCopyHyperlink();
        this.mergeHyperlink = other.isMergeHyperlink();
        this.copyRowHeight = other.isCopyRowHeight();
        this.condenseRows = other.isCondenseRows();
        this.copyMergedRegions = other.isCopyMergedRegions();
    }

    private CellCopyPolicy(Builder builder) {
        this.copyCellValue = true;
        this.copyCellStyle = true;
        this.copyCellFormula = true;
        this.copyHyperlink = true;
        this.mergeHyperlink = false;
        this.copyRowHeight = true;
        this.condenseRows = false;
        this.copyMergedRegions = true;
        this.copyCellValue = builder.copyCellValue;
        this.copyCellStyle = builder.copyCellStyle;
        this.copyCellFormula = builder.copyCellFormula;
        this.copyHyperlink = builder.copyHyperlink;
        this.mergeHyperlink = builder.mergeHyperlink;
        this.copyRowHeight = builder.copyRowHeight;
        this.condenseRows = builder.condenseRows;
        this.copyMergedRegions = builder.copyMergedRegions;
    }

    public static class Builder {
        private boolean condenseRows = false;
        private boolean copyCellFormula = true;
        private boolean copyCellStyle = true;
        private boolean copyCellValue = true;
        private boolean copyHyperlink = true;
        private boolean copyMergedRegions = true;
        private boolean copyRowHeight = true;
        private boolean mergeHyperlink = false;

        public Builder cellValue(boolean copyCellValue2) {
            this.copyCellValue = copyCellValue2;
            return this;
        }

        public Builder cellStyle(boolean copyCellStyle2) {
            this.copyCellStyle = copyCellStyle2;
            return this;
        }

        public Builder cellFormula(boolean copyCellFormula2) {
            this.copyCellFormula = copyCellFormula2;
            return this;
        }

        public Builder copyHyperlink(boolean copyHyperlink2) {
            this.copyHyperlink = copyHyperlink2;
            return this;
        }

        public Builder mergeHyperlink(boolean mergeHyperlink2) {
            this.mergeHyperlink = mergeHyperlink2;
            return this;
        }

        public Builder rowHeight(boolean copyRowHeight2) {
            this.copyRowHeight = copyRowHeight2;
            return this;
        }

        public Builder condenseRows(boolean condenseRows2) {
            this.condenseRows = condenseRows2;
            return this;
        }

        public Builder mergedRegions(boolean copyMergedRegions2) {
            this.copyMergedRegions = copyMergedRegions2;
            return this;
        }

        public CellCopyPolicy build() {
            return new CellCopyPolicy(this);
        }
    }

    public Builder createBuilder() {
        return new Builder().cellValue(this.copyCellValue).cellStyle(this.copyCellStyle).cellFormula(this.copyCellFormula).copyHyperlink(this.copyHyperlink).mergeHyperlink(this.mergeHyperlink).rowHeight(this.copyRowHeight).condenseRows(this.condenseRows).mergedRegions(this.copyMergedRegions);
    }

    public boolean isCopyCellValue() {
        return this.copyCellValue;
    }

    public void setCopyCellValue(boolean copyCellValue2) {
        this.copyCellValue = copyCellValue2;
    }

    public boolean isCopyCellStyle() {
        return this.copyCellStyle;
    }

    public void setCopyCellStyle(boolean copyCellStyle2) {
        this.copyCellStyle = copyCellStyle2;
    }

    public boolean isCopyCellFormula() {
        return this.copyCellFormula;
    }

    public void setCopyCellFormula(boolean copyCellFormula2) {
        this.copyCellFormula = copyCellFormula2;
    }

    public boolean isCopyHyperlink() {
        return this.copyHyperlink;
    }

    public void setCopyHyperlink(boolean copyHyperlink2) {
        this.copyHyperlink = copyHyperlink2;
    }

    public boolean isMergeHyperlink() {
        return this.mergeHyperlink;
    }

    public void setMergeHyperlink(boolean mergeHyperlink2) {
        this.mergeHyperlink = mergeHyperlink2;
    }

    public boolean isCopyRowHeight() {
        return this.copyRowHeight;
    }

    public void setCopyRowHeight(boolean copyRowHeight2) {
        this.copyRowHeight = copyRowHeight2;
    }

    public boolean isCondenseRows() {
        return this.condenseRows;
    }

    public void setCondenseRows(boolean condenseRows2) {
        this.condenseRows = condenseRows2;
    }

    public boolean isCopyMergedRegions() {
        return this.copyMergedRegions;
    }

    public void setCopyMergedRegions(boolean copyMergedRegions2) {
        this.copyMergedRegions = copyMergedRegions2;
    }
}
