package org.apache.poi.ss.util;

import java.util.Calendar;
import java.util.Date;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;

public class SheetBuilder {
    private final Object[][] cells;
    private String sheetName = null;
    private boolean shouldCreateEmptyCells = false;
    private final Workbook workbook;

    public SheetBuilder(Workbook workbook2, Object[][] cells2) {
        this.workbook = workbook2;
        this.cells = (Object[][]) cells2.clone();
    }

    public boolean getCreateEmptyCells() {
        return this.shouldCreateEmptyCells;
    }

    public SheetBuilder setCreateEmptyCells(boolean shouldCreateEmptyCells2) {
        this.shouldCreateEmptyCells = shouldCreateEmptyCells2;
        return this;
    }

    public SheetBuilder setSheetName(String sheetName2) {
        this.sheetName = sheetName2;
        return this;
    }

    public Sheet build() {
        String str = this.sheetName;
        Sheet sheet = str == null ? this.workbook.createSheet() : this.workbook.createSheet(str);
        int rowIndex = 0;
        while (true) {
            Object[][] objArr = this.cells;
            if (rowIndex >= objArr.length) {
                return sheet;
            }
            Object[] rowArray = objArr[rowIndex];
            Row currentRow = sheet.createRow(rowIndex);
            for (int cellIndex = 0; cellIndex < rowArray.length; cellIndex++) {
                Object cellValue = rowArray[cellIndex];
                if (cellValue != null || this.shouldCreateEmptyCells) {
                    setCellValue(currentRow.createCell(cellIndex), cellValue);
                }
            }
            rowIndex++;
        }
    }

    private void setCellValue(Cell cell, Object value) {
        if (value != null && cell != null) {
            if (value instanceof Number) {
                cell.setCellValue(((Number) value).doubleValue());
            } else if (value instanceof Date) {
                cell.setCellValue((Date) value);
            } else if (value instanceof Calendar) {
                cell.setCellValue((Calendar) value);
            } else if (isFormulaDefinition(value)) {
                cell.setCellFormula(getFormula(value));
            } else {
                cell.setCellValue(value.toString());
            }
        }
    }

    private boolean isFormulaDefinition(Object obj) {
        if (!(obj instanceof String) || ((String) obj).length() < 2 || ((String) obj).charAt(0) != '=') {
            return false;
        }
        return true;
    }

    private String getFormula(Object obj) {
        return ((String) obj).substring(1);
    }
}
