package org.apache.poi.util;

import java.io.IOException;
import java.io.InputStream;

public class BlockingInputStream extends InputStream {
    protected InputStream is;

    public BlockingInputStream(InputStream is2) {
        this.is = is2;
    }

    @Override // java.io.InputStream
    public int available() throws IOException {
        return this.is.available();
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable, java.io.InputStream
    public void close() throws IOException {
        this.is.close();
    }

    public void mark(int readLimit) {
        this.is.mark(readLimit);
    }

    public boolean markSupported() {
        return this.is.markSupported();
    }

    @Override // java.io.InputStream
    public int read() throws IOException {
        return this.is.read();
    }

    @Override // java.io.InputStream
    public int read(byte[] bf) throws IOException {
        int i = 0;
        int b = 4611;
        while (i < bf.length && (b = this.is.read()) != -1) {
            bf[i] = (byte) b;
            i++;
        }
        if (i == 0 && b == -1) {
            return -1;
        }
        return i;
    }

    @Override // java.io.InputStream
    public int read(byte[] bf, int s, int l) throws IOException {
        return this.is.read(bf, s, l);
    }

    @Override // java.io.InputStream
    public void reset() throws IOException {
        this.is.reset();
    }

    @Override // java.io.InputStream
    public long skip(long n) throws IOException {
        return this.is.skip(n);
    }
}
