package org.apache.poi.util;

import com.google.common.primitives.UnsignedBytes;

public final class LittleEndianByteArrayInputStream implements LittleEndianInput {
    private final byte[] _buf;
    private final int _endIndex;
    private int _readIndex;

    public LittleEndianByteArrayInputStream(byte[] buf, int startOffset, int maxReadLen) {
        this._buf = buf;
        this._readIndex = startOffset;
        this._endIndex = startOffset + maxReadLen;
    }

    public LittleEndianByteArrayInputStream(byte[] buf, int startOffset) {
        this(buf, startOffset, buf.length - startOffset);
    }

    public LittleEndianByteArrayInputStream(byte[] buf) {
        this(buf, 0, buf.length);
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public int available() {
        return this._endIndex - this._readIndex;
    }

    private void checkPosition(int i) {
        if (i > this._endIndex - this._readIndex) {
            throw new RuntimeException("Buffer overrun");
        }
    }

    public int getReadIndex() {
        return this._readIndex;
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public byte readByte() {
        checkPosition(1);
        byte[] bArr = this._buf;
        int i = this._readIndex;
        this._readIndex = i + 1;
        return bArr[i];
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public int readInt() {
        checkPosition(4);
        int i = this._readIndex;
        byte[] bArr = this._buf;
        int i2 = i + 1;
        int b0 = bArr[i] & UnsignedBytes.MAX_VALUE;
        int i3 = i2 + 1;
        int b1 = bArr[i2] & UnsignedBytes.MAX_VALUE;
        int i4 = i3 + 1;
        int b2 = bArr[i3] & UnsignedBytes.MAX_VALUE;
        int b3 = bArr[i4] & UnsignedBytes.MAX_VALUE;
        this._readIndex = i4 + 1;
        return (b3 << 24) + (b2 << 16) + (b1 << 8) + (b0 << 0);
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public long readLong() {
        checkPosition(8);
        int i = this._readIndex;
        byte[] bArr = this._buf;
        int i2 = i + 1;
        int b0 = bArr[i] & UnsignedBytes.MAX_VALUE;
        int i3 = i2 + 1;
        int b1 = bArr[i2] & UnsignedBytes.MAX_VALUE;
        int i4 = i3 + 1;
        int b2 = bArr[i3] & UnsignedBytes.MAX_VALUE;
        int i5 = i4 + 1;
        int b3 = bArr[i4] & UnsignedBytes.MAX_VALUE;
        int i6 = i5 + 1;
        int b4 = bArr[i5] & UnsignedBytes.MAX_VALUE;
        int i7 = i6 + 1;
        int b5 = bArr[i6] & UnsignedBytes.MAX_VALUE;
        int i8 = i7 + 1;
        int b6 = bArr[i7] & UnsignedBytes.MAX_VALUE;
        int b7 = bArr[i8] & UnsignedBytes.MAX_VALUE;
        this._readIndex = i8 + 1;
        return (((long) b7) << 56) + (((long) b6) << 48) + (((long) b5) << 40) + (((long) b4) << 32) + (((long) b3) << 24) + ((long) (b2 << 16)) + ((long) (b1 << 8)) + ((long) (b0 << 0));
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public short readShort() {
        return (short) readUShort();
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public int readUByte() {
        checkPosition(1);
        byte[] bArr = this._buf;
        int i = this._readIndex;
        this._readIndex = i + 1;
        return bArr[i] & UnsignedBytes.MAX_VALUE;
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public int readUShort() {
        checkPosition(2);
        int i = this._readIndex;
        byte[] bArr = this._buf;
        int i2 = i + 1;
        int b0 = bArr[i] & UnsignedBytes.MAX_VALUE;
        int b1 = bArr[i2] & UnsignedBytes.MAX_VALUE;
        this._readIndex = i2 + 1;
        return (b1 << 8) + (b0 << 0);
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public void readFully(byte[] buf, int off, int len) {
        checkPosition(len);
        System.arraycopy(this._buf, this._readIndex, buf, off, len);
        this._readIndex += len;
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public void readFully(byte[] buf) {
        readFully(buf, 0, buf.length);
    }

    @Override // org.apache.poi.util.LittleEndianInput
    public double readDouble() {
        return Double.longBitsToDouble(readLong());
    }
}
