package org.apache.poi.util;

@Internal
public abstract class POILogger {
    public static final int DEBUG = 1;
    public static final int ERROR = 7;
    public static final int FATAL = 9;
    public static final int INFO = 3;
    protected static final String[] LEVEL_STRINGS = {"?0?", "DEBUG", "?2?", "INFO", "?4?", "WARN", "?6?", "ERROR", "?8?", "FATAL", "?10+?"};
    protected static final String[] LEVEL_STRINGS_SHORT = {"?", "D", "?", "I", "?", "W", "?", "E", "?", "F", "?"};
    public static final int WARN = 5;

    public abstract boolean check(int i);

    public abstract void initialize(String str);

    /* access modifiers changed from: protected */
    public abstract void log(int i, Object obj);

    /* access modifiers changed from: protected */
    public abstract void log(int i, Object obj, Throwable th);

    POILogger() {
    }

    public void log(int level, Object... objs) {
        if (check(level)) {
            StringBuilder sb = new StringBuilder(32);
            Throwable lastEx = null;
            for (int i = 0; i < objs.length; i++) {
                if (i != objs.length - 1 || !(objs[i] instanceof Throwable)) {
                    sb.append(objs[i]);
                } else {
                    lastEx = (Throwable) objs[i];
                }
            }
            String msg = sb.toString().replaceAll("[\r\n]+", " ");
            if (lastEx == null) {
                log(level, msg);
            } else {
                log(level, msg, lastEx);
            }
        }
    }
}
