package vigis.client.api;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.graphics.Bitmap;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.os.RemoteException;
import android.util.Log;
import android.util.SparseArray;
import egistec.csa.client.api.Fingerprint;
import egistec.csa.client.api.IFPAuthService;
import egistec.csa.client.api.IFPAuthServiceCallback;
import egistec.csa.client.api.IFingerprint;
import java.nio.ByteBuffer;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

public class VigisFingerprint implements IFingerprint {
    public static final int ACCURACY_HIGH = 2002;
    public static final int ACCURACY_LOW = 2000;
    public static final int ACCURACY_REGULAR = 2001;
    public static final int ACCURACY_VERY_HIGH = 2003;
    public static final int CAPTURE_COMPLETED = 1042;
    public static final int CAPTURE_FAILED = 1045;
    public static final int CAPTURE_FINISHED = 1043;
    public static final int CAPTURE_READY = 1040;
    public static final int CAPTURE_STARTED = 1041;
    public static final int CAPTURE_SUCCESS = 1044;
    public static final int ENROLL_BITMAP = 1005;
    public static final int ENROLL_FAILED = 1002;
    public static final int ENROLL_FAILURE_CANCELED = 1003;
    public static final int ENROLL_FAULURE_ENROLL_FAILURE_EXCEED_MAX_TRIAL = 1004;
    public static final int ENROLL_STATUS = 1000;
    public static final int ENROLL_SUCCESS = 1001;
    private static final String FPID_PREFIX = "EGISFPID";
    public static final int IDENTIFY_FAILED = 1021;
    public static final int IDENTIFY_FAILURE_BAD_QUALITY = 1025;
    public static final int IDENTIFY_FAILURE_CANCELED = 1022;
    public static final int IDENTIFY_FAILURE_NOT_MATCH = 1024;
    public static final int IDENTIFY_SUCCESS = 1020;
    private static final int MAP_H = 256;
    private static final int MAP_W = 256;
    public static final int OP_TYPE_ENROLL = 101;
    public static final int OP_TYPE_VERIFY = 102;
    private static final String PASSOWORD_PREFIX = "EGISPWD";
    private static final String PASSWORD = "egistec";
    public static final int PAUSE_ENROLL = 2010;
    public static final int QUALITY_DUPLICATED_SCANNED_IMAGE = 256;
    public static final int QUALITY_EMPTY_TOUCH = 536870912;
    public static final int QUALITY_FAILED = 268435456;
    public static final int QUALITY_FINGER_TOO_THIN = 128;
    public static final int QUALITY_GOOD = 0;
    public static final int QUALITY_NOT_A_FINGER_SWIPE = 16;
    public static final int QUALITY_OFFSET_TOO_FAR_LEFT = 1;
    public static final int QUALITY_OFFSET_TOO_FAR_RIGHT = 2;
    public static final int QUALITY_ONE_HAND_SWIPE = 33554432;
    public static final int QUALITY_PARTIAL_TOUCH = 268435456;
    public static final int QUALITY_PRESSURE_TOO_HARD = 64;
    public static final int QUALITY_PRESSURE_TOO_LIGHT = 32;
    public static final int QUALITY_REVERSE_MOTION = 524288;
    public static final int QUALITY_SKEW_TOO_LARGE = 262144;
    public static final int QUALITY_SOMETHING_ON_THE_SENSOR = 4;
    public static final int QUALITY_STICTION = 16777216;
    public static final int QUALITY_TOO_FAST = 512;
    public static final int QUALITY_TOO_SHORT = 131072;
    public static final int QUALITY_TOO_SLOW = 65536;
    public static final int QUALITY_WET_FINGER = 8;
    public static final int RESULT_CANCELED = -2;
    public static final int RESULT_FAILED = -1;
    public static final int RESULT_NO_AUTHORITY = -4;
    public static final int RESULT_OK = 0;
    public static final int RESUME_ENRORLL = 2011;
    public static final int SENSOR_OK = 2004;
    public static final int SENSOR_OUT_OF_ORDER = 2006;
    public static final int SENSOR_WORKING = 2005;
    public static final String TAG = "FpCsaClientLib_VigisFingerprint";
    private static Context mContext;
    private static VigisFingerprint mInstance;
    private Map<String, Integer> fingerIndexMap;
    private SparseArray<String> indexMapToFinger;
    private int mEnrollIndex;
    private String mEnrollUserId;
    protected ServiceConnection mFPAuthConnection = new ServiceConnection() {
        /* class vigis.client.api.VigisFingerprint.AnonymousClass1 */

        public void onServiceConnected(ComponentName className, IBinder service) {
            Log.d(VigisFingerprint.TAG, "onServiceConnected()");
            VigisFingerprint.this.mFPAuthService = IFPAuthService.Stub.asInterface(service);
            try {
                VigisFingerprint.this.mFPAuthService.registerCallback(VigisFingerprint.this.mFPAuthServiceCallback);
            } catch (RemoteException e) {
                Log.d(VigisFingerprint.TAG, "registerCallback fail, e =" + e.toString());
            }
        }

        public void onServiceDisconnected(ComponentName className) {
            Log.d(VigisFingerprint.TAG, "onServiceDisConnected()");
            VigisFingerprint.this.mFPAuthService = null;
        }
    };
    private IFPAuthService mFPAuthService;
    protected IFPAuthServiceCallback mFPAuthServiceCallback = new IFPAuthServiceCallback.Stub() {
        /* class vigis.client.api.VigisFingerprint.AnonymousClass2 */

        @Override // egistec.csa.client.api.IFPAuthServiceCallback
        public void postMessage(int what, int arg1, int arg2) {
            VigisFingerprint.this.mHandler.obtainMessage(what, arg1, arg2).sendToTarget();
        }
    };
    private Fingerprint.FingerprintEventListener mFingerprintEventListener;
    private final Handler mHandler = new Handler() {
        /* class vigis.client.api.VigisFingerprint.AnonymousClass4 */

        /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1000:
                    switch (msg.arg1) {
                        case 1001:
                            Log.d(VigisFingerprint.TAG, "FpResDef.FP_RES_ENROLL_OK");
                            try {
                                IFPAuthService iFPAuthService = VigisFingerprint.this.mFPAuthService;
                                iFPAuthService.DataSet("EGISFPID;" + VigisFingerprint.this.mEnrollUserId + ";" + ((String) VigisFingerprint.this.indexMapToFinger.get(VigisFingerprint.this.mEnrollIndex)), UUID.randomUUID().toString(), VigisFingerprint.PASSWORD);
                            } catch (RemoteException e1) {
                                e1.printStackTrace();
                            }
                            if (VigisFingerprint.this.mFingerprintEventListener != null) {
                                VigisFingerprint.this.mFingerprintEventListener.onFingerprintEvent(1001, null);
                            }
                            VigisFingerprint.this.mEnrollIndex = 0;
                            break;
                        case 1002:
                            Log.d(VigisFingerprint.TAG, "FpResDef.FP_RES_ENROLL_FAIL");
                            if (VigisFingerprint.this.mFingerprintEventListener != null) {
                                VigisFingerprint.this.mFingerprintEventListener.onFingerprintEvent(1002, null);
                            }
                            VigisFingerprint.this.mEnrollIndex = 0;
                            break;
                        case 1003:
                            Log.d(VigisFingerprint.TAG, "FpResDef.FP_RES_MATCHED_OK");
                            VigisFingerprint.this.mIsFingerOrPWValidate = true;
                            if (VigisFingerprint.this.mFingerprintEventListener != null) {
                                Fingerprint.IdentifyResult identifyResult = new Fingerprint.IdentifyResult();
                                try {
                                    String[] idWithIndex = VigisFingerprint.this.mFPAuthService.getMatchedUserID().split(";");
                                    Log.d(VigisFingerprint.TAG, "user=" + idWithIndex[0] + " index=" + idWithIndex[1]);
                                    identifyResult.index = ((Integer) VigisFingerprint.this.fingerIndexMap.get(idWithIndex[1])).intValue();
                                    identifyResult.result = 1020;
                                    VigisFingerprint.this.mFingerprintEventListener.onFingerprintEvent(1020, identifyResult);
                                    break;
                                } catch (RemoteException e) {
                                    e.printStackTrace();
                                    break;
                                }
                            }
                            break;
                        case 1004:
                            Log.d(VigisFingerprint.TAG, "FpResDef.FP_RES_MATCHED_FAIL");
                            if (VigisFingerprint.this.mFingerprintEventListener != null) {
                                Fingerprint.IdentifyResult identifyResult2 = new Fingerprint.IdentifyResult();
                                identifyResult2.index = -1;
                                identifyResult2.result = 1024;
                                VigisFingerprint.this.mFingerprintEventListener.onFingerprintEvent(1021, identifyResult2);
                                break;
                            }
                            break;
                        case 1008:
                            Log.d(VigisFingerprint.TAG, "FpResDef.FP_RES_GETTED_GOOD_IMAGE");
                            if (VigisFingerprint.this.mFingerprintEventListener != null) {
                                try {
                                    byte[] rawData = VigisFingerprint.this.mFPAuthService.getMatchedImg();
                                    Log.d(VigisFingerprint.TAG, "rawData len=" + rawData.length);
                                    int[] rawDataInfo = VigisFingerprint.this.mFPAuthService.getMatchedImgInfo();
                                    Fingerprint.FingerprintBitmap fpBitmap = new Fingerprint.FingerprintBitmap();
                                    fpBitmap.width = rawDataInfo[0];
                                    fpBitmap.height = rawDataInfo[1];
                                    fpBitmap.quality = 0;
                                    fpBitmap.bitmap = Bitmap.createBitmap(rawDataInfo[0], rawDataInfo[1], Bitmap.Config.ALPHA_8);
                                    for (int index = 0; index < rawData.length; index++) {
                                        rawData[index] = (byte) (~rawData[index]);
                                    }
                                    fpBitmap.bitmap.copyPixelsFromBuffer(ByteBuffer.wrap(rawData));
                                    VigisFingerprint.this.mFingerprintEventListener.onFingerprintEvent(1044, fpBitmap);
                                    break;
                                } catch (RemoteException e2) {
                                    e2.printStackTrace();
                                    break;
                                } catch (NullPointerException e3) {
                                    Log.e(VigisFingerprint.TAG, "doOnGetRawData get null pointer");
                                    e3.printStackTrace();
                                    break;
                                }
                            }
                            break;
                        case 1009:
                            Log.d(VigisFingerprint.TAG, "FpResDef.FP_RES_GETTED_BAD_IMAGE");
                            VigisFingerprint.this.notifyOnBadImage(268435456);
                            break;
                        case 1011:
                            Log.d(VigisFingerprint.TAG, "FpResDef.FP_RES_ENROLL_COUNT");
                            VigisFingerprint.this.notifyOnEnrollStatus();
                            break;
                        case 1012:
                            Log.d(VigisFingerprint.TAG, "FpResDef.FP_RES_ABORT_OK");
                            try {
                                if (VigisFingerprint.this.mIsFilterOn) {
                                    break;
                                } else {
                                    switch (VigisFingerprint.this.mFPAuthService.getOperationType()) {
                                        case 101:
                                            VigisFingerprint.this.mFingerprintEventListener.onFingerprintEvent(1003, null);
                                            break;
                                        case 102:
                                            Fingerprint.IdentifyResult identifyResult3 = new Fingerprint.IdentifyResult();
                                            identifyResult3.result = 1022;
                                            VigisFingerprint.this.mFingerprintEventListener.onFingerprintEvent(1021, identifyResult3);
                                            break;
                                    }
                                }
                            } catch (RemoteException e4) {
                                e4.printStackTrace();
                                break;
                            }
                            break;
                        case 1073:
                            Log.d(VigisFingerprint.TAG, "FpResDef.FP_RES_FINGER_DETECTED");
                            if (VigisFingerprint.this.mFingerprintEventListener != null) {
                                VigisFingerprint.this.mFingerprintEventListener.onFingerprintEvent(1041, null);
                                break;
                            }
                            break;
                        case 1074:
                            Log.d(VigisFingerprint.TAG, "FpResDef.FP_RES_FINGER_REMOVED");
                            if (VigisFingerprint.this.mFingerprintEventListener != null && !VigisFingerprint.this.mIsFilterOn && !Fingerprint.m_abort) {
                                VigisFingerprint.this.mFingerprintEventListener.onFingerprintEvent(1043, null);
                                break;
                            }
                        case 1075:
                            Log.d(VigisFingerprint.TAG, "FpResDef.FP_RES_FINGER_WAIT_FPON");
                            if (VigisFingerprint.this.mFingerprintEventListener != null && !VigisFingerprint.this.mIsFilterOn) {
                                VigisFingerprint.this.mFingerprintEventListener.onFingerprintEvent(1040, null);
                                break;
                            }
                        case 1082:
                            Log.d(VigisFingerprint.TAG, "FpResDef.FP_RES_PARTIAL_IMG");
                            VigisFingerprint.this.notifyOnBadImage(268435456);
                            break;
                    }
                    break;
                case 1200:
                    break;
                default:
                    return;
            }
            switch (msg.arg1) {
                case 1234:
                    Log.d(VigisFingerprint.TAG, "FpResDef.TINY_STATUS_ENROLL_MAP");
                    VigisFingerprint.this.notifyOnEnrollMap();
                    return;
                case 1245:
                    Log.d(VigisFingerprint.TAG, "FpResDef.TINY_STATUS_HIGHLY_SIMILAR");
                    return;
                default:
                    return;
            }
        }
    };
    private boolean mIsEnrollSessionOpen;
    private boolean mIsFilterOn;
    private boolean mIsFingerOrPWValidate;

    public static VigisFingerprint create(Context context) {
        Log.d(TAG, "create()");
        mContext = context;
        if (mInstance == null) {
            Log.d(TAG, "new VigisFingerprint()");
            mInstance = new VigisFingerprint();
        }
        return mInstance;
    }

    private VigisFingerprint() {
        unbind();
        bind();
        HashMap hashMap = new HashMap();
        this.fingerIndexMap = hashMap;
        hashMap.put("R1", 1);
        this.fingerIndexMap.put("R2", 2);
        this.fingerIndexMap.put("R3", 3);
        this.fingerIndexMap.put("R4", 4);
        this.fingerIndexMap.put("R5", 5);
        this.fingerIndexMap.put("L1", 6);
        this.fingerIndexMap.put("L2", 7);
        this.fingerIndexMap.put("L3", 8);
        this.fingerIndexMap.put("L4", 9);
        this.fingerIndexMap.put("L5", 10);
        SparseArray<String> sparseArray = new SparseArray<>();
        this.indexMapToFinger = sparseArray;
        sparseArray.put(1, "R1");
        this.indexMapToFinger.put(2, "R2");
        this.indexMapToFinger.put(3, "R3");
        this.indexMapToFinger.put(4, "R4");
        this.indexMapToFinger.put(5, "R5");
        this.indexMapToFinger.put(6, "L1");
        this.indexMapToFinger.put(7, "L2");
        this.indexMapToFinger.put(8, "L3");
        this.indexMapToFinger.put(9, "L4");
        this.indexMapToFinger.put(10, "L5");
    }

    public void bind() {
        Log.d(TAG, "bind()");
        new Thread() {
            /* class vigis.client.api.VigisFingerprint.AnonymousClass3 */

            public void run() {
                if (!VigisFingerprint.mContext.bindService(new Intent(IFPAuthService.class.getName()), VigisFingerprint.this.mFPAuthConnection, 1)) {
                    Log.e(VigisFingerprint.TAG, "bindService fail");
                }
            }
        }.start();
    }

    private void unbind() {
        Log.d(TAG, "unbind()");
        IFPAuthService iFPAuthService = this.mFPAuthService;
        if (iFPAuthService != null) {
            try {
                iFPAuthService.unregisterCallback(this.mFPAuthServiceCallback);
            } catch (RemoteException e) {
                e.printStackTrace();
            }
            mContext.unbindService(this.mFPAuthConnection);
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public void setEventListener(Fingerprint.FingerprintEventListener l) {
        Log.d(TAG, "setEventListener()");
        this.mFingerprintEventListener = l;
    }

    @Override // egistec.csa.client.api.IFingerprint
    public String getVersion() {
        Log.d(TAG, "getVersion()");
        checkServiceConnected();
        try {
            return this.mFPAuthService.getVersion();
        } catch (RemoteException e) {
            Log.e(TAG, "getVersion() RemoteException:" + e.getMessage());
            return "RESULT_CANCELED";
        } catch (Exception e2) {
            Log.e(TAG, "getVersion() Exception:" + e2.getMessage());
            return "RESULT_CANCELED";
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int getSensorStatus() {
        Log.d(TAG, "getSensorStatus()");
        checkServiceConnected();
        try {
            if (this.mFPAuthService.IsSensorWorking()) {
                return 2005;
            }
            if (this.mFPAuthService.connectDevice()) {
                return 2004;
            }
            return 2006;
        } catch (RemoteException e) {
            Log.e(TAG, "getSensorStatus() RemoteException:" + e.getMessage());
            return -2;
        } catch (Exception e2) {
            Log.e(TAG, "getSensorStatus() Exception:" + e2.getMessage());
            return -2;
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int[] getFingerprintIndexList(String userId) {
        Log.d(TAG, "getFingerprintindexList() userId = " + userId);
        checkServiceConnected();
        try {
            String enrollList = this.mFPAuthService.getEnrollList(userId);
            Log.d(TAG, "enrollList=" + enrollList);
            if (enrollList != null) {
                if (!enrollList.equals("")) {
                    String[] fingers = fpSplitor(enrollList);
                    Arrays.sort(fingers);
                    Log.d(TAG, "fingers=" + Arrays.toString(fingers));
                    int[] fingerIndex = new int[fingers.length];
                    for (int i = 0; i < fingerIndex.length; i++) {
                        fingerIndex[i] = this.fingerIndexMap.get(fingers[i]).intValue();
                    }
                    return fingerIndex;
                }
            }
            return null;
        } catch (RemoteException e) {
            Log.e(TAG, "getFingerprintindexList() RemoteException:" + e.getMessage());
            return null;
        } catch (Exception e2) {
            Log.e(TAG, "getFingerprintindexList() Exception:" + e2.getMessage());
            return null;
        }
    }

    private String[] fpSplitor(String fpData) {
        Log.d(TAG, "fpSplitor fpData = " + fpData);
        if (fpData.equals("")) {
            return null;
        }
        if (fpData.contains(";")) {
            return fpData.split(";");
        }
        return new String[]{fpData};
    }

    @Override // egistec.csa.client.api.IFingerprint
    public byte[] getFingerprintId(String userId, int index) {
        Log.d(TAG, "getFingerprintId() userId = " + userId + ", index = " + index);
        checkServiceConnected();
        if (userId != null) {
            try {
                if (!userId.equals("")) {
                    if (this.indexMapToFinger.get(index) != null) {
                        IFPAuthService iFPAuthService = this.mFPAuthService;
                        return iFPAuthService.DataRead("EGISFPID;" + userId + ";" + this.indexMapToFinger.get(index), PASSWORD).getBytes();
                    }
                }
            } catch (RemoteException e) {
                Log.e(TAG, "getFingerprintId() RemoteException:" + e.getMessage());
                return null;
            } catch (Exception e2) {
                Log.e(TAG, "getFingerprintId() Exception:" + e2.getMessage());
                return null;
            }
        }
        Log.e(TAG, "input parameter error");
        return null;
    }

    @Override // egistec.csa.client.api.IFingerprint
    public String[] getUserIdList() {
        Log.d(TAG, "getUserIdList()");
        checkServiceConnected();
        try {
            return this.mFPAuthService.getUserIdList();
        } catch (RemoteException e) {
            Log.e(TAG, "getUserIdList() RemoteException:" + e.getMessage());
            return null;
        } catch (Exception e2) {
            Log.e(TAG, "getUserIdList() Exception:" + e2.getMessage());
            return null;
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int getEnrollRepeatCount() {
        Log.d(TAG, "getEnrollRepeatCount()");
        checkServiceConnected();
        try {
            int[] enrollStatus = this.mFPAuthService.getEnrollStatus();
            if (enrollStatus[0] == 0 && enrollStatus[1] == 0 && enrollStatus[2] == 0) {
                return -1;
            }
            return enrollStatus[0] + enrollStatus[1];
        } catch (RemoteException e) {
            Log.e(TAG, "getEnrollRepeatCount() RemoteException:" + e.getMessage());
            return -2;
        } catch (Exception e2) {
            Log.e(TAG, "getEnrollRepeatCount() Exception:" + e2.getMessage());
            return -2;
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public String getSensorInfo() {
        Log.d(TAG, "getSensorInfo()");
        checkServiceConnected();
        try {
            return this.mFPAuthService.getSensorInfo();
        } catch (RemoteException e) {
            Log.e(TAG, "getSensorInfo() RemoteException:" + e.getMessage());
            e.printStackTrace();
            return "RESULT_CANCELED";
        } catch (Exception e2) {
            Log.e(TAG, "getSensorInfo() Exception:" + e2.getMessage());
            e2.printStackTrace();
            return "RESULT_CANCELED";
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int setAccuracyLevel(int level) {
        Log.d(TAG, "setAccuracyLevel() level = " + level);
        checkServiceConnected();
        try {
            return this.mFPAuthService.setAccuracyLevel(level);
        } catch (RemoteException e) {
            Log.e(TAG, "setAccuracyLevel() RemoteException:" + e.getMessage());
            e.printStackTrace();
            return -2;
        } catch (Exception e2) {
            Log.e(TAG, "setAccuracyLevel() Exception:" + e2.getMessage());
            e2.printStackTrace();
            return -2;
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int setEnrollSession(boolean flag) {
        Log.d(TAG, "setEnrollSession() flag = " + flag);
        this.mIsEnrollSessionOpen = flag;
        this.mIsFingerOrPWValidate = false;
        if (!flag) {
            if (!hasPasswd(this.mEnrollUserId) && hasFinger(this.mEnrollUserId)) {
                try {
                    int[] fIdxList = getFingerprintIndexList(this.mEnrollUserId);
                    for (int idx : fIdxList) {
                        if (!this.mFPAuthService.deleteFeature(this.mEnrollUserId + ";" + this.indexMapToFinger.get(idx))) {
                            Log.e(TAG, "deleteFeature error, idx=" + idx);
                        }
                        this.mFPAuthService.DataDelete("EGISFPID;" + this.mEnrollUserId + ";" + this.indexMapToFinger.get(idx), PASSWORD);
                    }
                } catch (RemoteException e) {
                    e.printStackTrace();
                }
            }
            this.mEnrollUserId = null;
        }
        return 0;
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int setPassword(String userId, byte[] pwdHash) {
        Log.d(TAG, "setPassword() userId = " + userId);
        if (!this.mIsEnrollSessionOpen) {
            Log.e(TAG, "no open enrollSession");
            return -4;
        }
        checkServiceConnected();
        if (!hasFinger(userId) && !hasPasswd(userId)) {
            this.mIsFingerOrPWValidate = true;
        }
        if (!this.mIsFingerOrPWValidate) {
            Log.e(TAG, "no validate finger");
            return -4;
        }
        try {
            IFPAuthService iFPAuthService = this.mFPAuthService;
            if (iFPAuthService.DataSet("EGISPWD;" + userId, new String(pwdHash, "UTF-8"), PASSWORD)) {
                return 0;
            }
            return -1;
        } catch (RemoteException e) {
            Log.e(TAG, "setPassword() RemoteException:" + e.getMessage());
            return -2;
        } catch (Exception e2) {
            Log.e(TAG, "setPassword() Exception:" + e2.getMessage());
            return -2;
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int verifyPassword(String userId, byte[] pwdHash) {
        Log.d(TAG, "verifyPassword() userId = " + userId);
        checkServiceConnected();
        try {
            IFPAuthService iFPAuthService = this.mFPAuthService;
            String dbPwd = iFPAuthService.DataRead("EGISPWD;" + userId, PASSWORD);
            if (dbPwd == null || !new String(pwdHash, "UTF-8").equals(dbPwd)) {
                return -1;
            }
            this.mIsFingerOrPWValidate = true;
            return 0;
        } catch (RemoteException e) {
            Log.e(TAG, "verifyPassword() RemoteException:" + e.getMessage());
            e.printStackTrace();
            return -2;
        } catch (Exception e2) {
            Log.e(TAG, "verifyPassword() Exception:" + e2.getMessage());
            e2.printStackTrace();
            return -2;
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int identify(String userId) {
        Log.d(TAG, "identify() userId = " + userId);
        if (userId == null || userId.equals("")) {
            return -1;
        }
        checkServiceConnected();
        this.mIsFilterOn = false;
        try {
            if (this.mFPAuthService.identify(userId)) {
                return 0;
            }
            return -1;
        } catch (RemoteException e) {
            Log.e(TAG, "identify() RemoteException:" + e.getMessage());
            return -2;
        } catch (Exception e2) {
            Log.e(TAG, "identify() Exception:" + e2.getMessage());
            return -2;
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int enroll(String userId, int index) {
        Log.d(TAG, "enroll() userId = " + userId + ", index = " + index);
        if (userId == null || userId.equals("") || this.indexMapToFinger.get(index) == null) {
            Log.e(TAG, "user input error");
            return -1;
        } else if (!this.mIsEnrollSessionOpen) {
            Log.e(TAG, "no open enrollSession");
            return -4;
        } else {
            checkServiceConnected();
            if (!hasFinger(userId) && !hasPasswd(userId)) {
                this.mIsFingerOrPWValidate = true;
            }
            if (!this.mIsFingerOrPWValidate) {
                Log.e(TAG, "no validate finger or password");
                return -4;
            }
            this.mIsFilterOn = false;
            String egisId = userId + ";" + this.indexMapToFinger.get(index);
            Log.d(TAG, "egisId=" + egisId);
            try {
                if (!this.mFPAuthService.enroll(egisId)) {
                    return -1;
                }
                this.mEnrollUserId = userId;
                this.mEnrollIndex = index;
                return 0;
            } catch (RemoteException e) {
                Log.e(TAG, "enroll() RemoteException:" + e.getMessage());
                return -2;
            } catch (Exception e2) {
                Log.e(TAG, "enroll() Exception:" + e2.getMessage());
                return -2;
            }
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int swipeEnroll(String userId, int index) {
        Log.d(TAG, "swipeEnroll() userId = " + userId + ", index = " + index);
        if (userId == null || userId.equals("") || this.indexMapToFinger.get(index) == null) {
            Log.e(TAG, "user input error");
            return -1;
        } else if (!this.mIsEnrollSessionOpen) {
            Log.e(TAG, "no open enrollSession");
            return -4;
        } else {
            checkServiceConnected();
            if (!hasFinger(userId) && !hasPasswd(userId)) {
                this.mIsFingerOrPWValidate = true;
            }
            if (!this.mIsFingerOrPWValidate) {
                Log.e(TAG, "no validate finger or password");
                return -4;
            }
            this.mIsFilterOn = false;
            String egisId = userId + ";" + this.indexMapToFinger.get(index);
            Log.d(TAG, "egisId=" + egisId);
            try {
                if (!this.mFPAuthService.enroll(egisId)) {
                    return -1;
                }
                this.mEnrollUserId = userId;
                this.mEnrollIndex = index;
                return 0;
            } catch (RemoteException e) {
                Log.e(TAG, "swipeEnroll() RemoteException:" + e.getMessage());
                return -2;
            } catch (Exception e2) {
                Log.e(TAG, "swipeEnroll() Exception:" + e2.getMessage());
                return -2;
            }
        }
    }

    private boolean hasFinger(String userId) {
        String enrollList = null;
        try {
            enrollList = this.mFPAuthService.getEnrollList(userId);
            Log.d(TAG, "enrollList=" + enrollList);
        } catch (RemoteException e1) {
            e1.printStackTrace();
        } catch (Exception e12) {
            e12.printStackTrace();
        }
        return enrollList != null && !enrollList.equals("");
    }

    private boolean hasPasswd(String userId) {
        Log.d(TAG, "hasPasswd() userId = " + userId);
        try {
            IFPAuthService iFPAuthService = this.mFPAuthService;
            if (iFPAuthService.DataRead("EGISPWD;" + userId, PASSWORD) != null) {
                return true;
            }
            Log.d(TAG, "DataRead false");
            return false;
        } catch (RemoteException e) {
            e.printStackTrace();
            return false;
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int remove(String userId, int index) {
        Log.d(TAG, "remove userId = " + userId + "index = " + index);
        if (userId == null || userId.equals("") || this.indexMapToFinger.get(index) == null) {
            Log.e(TAG, "user input error");
            return -1;
        } else if (!this.mIsEnrollSessionOpen) {
            Log.e(TAG, "no open enrollSession");
            return -4;
        } else {
            checkServiceConnected();
            if (!hasFinger(userId) && !hasPasswd(userId)) {
                this.mIsFingerOrPWValidate = true;
            }
            if (!this.mIsFingerOrPWValidate) {
                Log.e(TAG, "no validate finger or password");
                return -4;
            } else if (!hasFinger(userId)) {
                Log.e(TAG, "no finger");
                return -1;
            } else {
                try {
                    if (!this.mFPAuthService.deleteFeature(userId + ";" + this.indexMapToFinger.get(index))) {
                        Log.e(TAG, "deleteFeature error");
                        return -1;
                    }
                    IFPAuthService iFPAuthService = this.mFPAuthService;
                    iFPAuthService.DataDelete("EGISFPID;" + userId + ";" + this.indexMapToFinger.get(index), PASSWORD);
                    String enrollList = this.mFPAuthService.getEnrollList(userId);
                    StringBuilder sb = new StringBuilder();
                    sb.append("enrollList=");
                    sb.append(enrollList);
                    Log.d(TAG, sb.toString());
                    if (enrollList != null && !enrollList.equals("")) {
                        return 0;
                    }
                    Log.d(TAG, "+++++ no finger, so delete password");
                    IFPAuthService iFPAuthService2 = this.mFPAuthService;
                    iFPAuthService2.DataDelete("EGISPWD;" + userId, PASSWORD);
                    return 0;
                } catch (RemoteException e) {
                    Log.e(TAG, "remove() RemoteException:" + e.getMessage());
                    e.printStackTrace();
                    return -1;
                } catch (Exception e2) {
                    Log.e(TAG, "remove() Exception:" + e2.getMessage());
                    return -1;
                }
            }
        }
    }

    public int request(int status) {
        Log.d(TAG, "request(), status = " + status);
        if (status == 2010 || status == 2011) {
            checkServiceConnected();
            try {
                return this.mFPAuthService.sensorControl(status);
            } catch (RemoteException e) {
                Log.e(TAG, "request() RemoteException:" + e.getMessage());
                e.printStackTrace();
                return -1;
            } catch (Exception e2) {
                Log.e(TAG, "request() Exception:" + e2.getMessage());
                return -1;
            }
        } else {
            Log.e(TAG, "input parameter error status=" + status);
            return -1;
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int cancel() {
        Log.d(TAG, "cancel()");
        checkServiceConnected();
        try {
            if (this.mFPAuthService.abort()) {
                return 0;
            }
            return -1;
        } catch (RemoteException e) {
            Log.e(TAG, "cancel() RemoteException:" + e.getMessage());
            return -1;
        } catch (Exception e2) {
            Log.e(TAG, "cancel() Exception:" + e2.getMessage());
            return -1;
        }
    }

    private void checkServiceConnected() {
        try {
            this.mFPAuthService.checkServiceException();
            if (0 == 0) {
                return;
            }
        } catch (RemoteException e) {
            e.printStackTrace();
            Log.e(TAG, "checkServiceConnected() Exception:" + e.getMessage());
            if (1 == 0) {
                return;
            }
        } catch (Exception e2) {
            Log.e(TAG, "checkServiceConnected() Exception:" + e2.getMessage());
            if (1 == 0) {
                return;
            }
        } catch (Throwable th) {
            if (0 != 0) {
                bind();
            }
            throw th;
        }
        bind();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void notifyOnEnrollStatus() {
        if (this.mFingerprintEventListener != null) {
            int[] enrollInfo = null;
            try {
                enrollInfo = this.mFPAuthService.getEnrollStatus();
            } catch (RemoteException e) {
                Log.e(TAG, "abort() RemoteException:" + e.getMessage());
            } catch (Exception e2) {
                Log.e(TAG, "abort() Exception:" + e2.getMessage());
            }
            Fingerprint.EnrollStatus enrollStatus = new Fingerprint.EnrollStatus();
            enrollStatus.successTrial = enrollInfo[0];
            enrollStatus.badTrial = enrollInfo[1];
            enrollStatus.totalTrial = enrollInfo[0] + enrollInfo[1];
            enrollStatus.progress = enrollInfo[2];
            this.mFingerprintEventListener.onFingerprintEvent(1000, enrollStatus);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void notifyOnEnrollMap() {
        if (this.mFingerprintEventListener != null) {
            try {
                Fingerprint.EnrollBitmap enrollMap = new Fingerprint.EnrollBitmap();
                int[] mapInfo = this.mFPAuthService.getTinyMapInfo();
                Log.d(TAG, "mapInfo[1]=" + mapInfo[1] + " mapInfo[2]=" + mapInfo[2]);
                if (mapInfo[1] == 256 || mapInfo[2] == 256) {
                    byte[] map = this.mFPAuthService.getTinyMap();
                    for (int index = 0; index < map.length; index++) {
                        map[index] = (byte) (map[index] == -1 ? 0 : 255);
                    }
                    Bitmap bitmap = Bitmap.createBitmap(mapInfo[1], mapInfo[2], Bitmap.Config.ALPHA_8);
                    bitmap.copyPixelsFromBuffer(ByteBuffer.wrap(map));
                    enrollMap.enrollMap = bitmap;
                    this.mFingerprintEventListener.onFingerprintEvent(1005, enrollMap);
                }
            } catch (RemoteException e) {
                e.printStackTrace();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void notifyOnBadImage(int quality) {
        try {
            if (this.mFingerprintEventListener != null) {
                try {
                    byte[] rawData = this.mFPAuthService.getMatchedImg();
                    int[] rawDataInfo = this.mFPAuthService.getMatchedImgInfo();
                    Fingerprint.FingerprintBitmap fpBitmap = new Fingerprint.FingerprintBitmap();
                    fpBitmap.width = rawDataInfo[0];
                    fpBitmap.height = rawDataInfo[1];
                    fpBitmap.quality = quality;
                    fpBitmap.bitmap = Bitmap.createBitmap(rawDataInfo[0], rawDataInfo[1], Bitmap.Config.ALPHA_8);
                    for (int index = 0; index < rawData.length; index++) {
                        rawData[index] = (byte) (~rawData[index]);
                    }
                    fpBitmap.bitmap.copyPixelsFromBuffer(ByteBuffer.wrap(rawData));
                    Log.d(TAG, "rawData len=" + rawData.length);
                    this.mFingerprintEventListener.onFingerprintEvent(1045, fpBitmap);
                } catch (RemoteException e) {
                    e.printStackTrace();
                } catch (NullPointerException e2) {
                    Log.e(TAG, "doOnGetRawData get null pointer");
                    e2.printStackTrace();
                }
            }
            if (this.mFPAuthService.getOperationType() == 102) {
                this.mIsFilterOn = true;
                Fingerprint.IdentifyResult identifyResult = new Fingerprint.IdentifyResult();
                identifyResult.index = -1;
                identifyResult.result = 1025;
                this.mFingerprintEventListener.onFingerprintEvent(1021, identifyResult);
                this.mFPAuthService.abort();
            }
        } catch (RemoteException e1) {
            e1.printStackTrace();
        }
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int request(int status, Object obj) {
        return 0;
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int verifySensorState(int cmd, int sId, int opt, int logOpt, int uId) {
        return 0;
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int cleanup() {
        return 0;
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int enableSensorDevice(boolean enable) {
        return 0;
    }

    @Override // egistec.csa.client.api.IFingerprint
    public int eeprom_test(int cmd, int addr, int value) {
        return 0;
    }
}
