package com.google.zxing.oned;

import com.google.zxing.BinaryBitmap;
import com.google.zxing.ChecksumException;
import com.google.zxing.DecodeHintType;
import com.google.zxing.FormatException;
import com.google.zxing.NotFoundException;
import com.google.zxing.Reader;
import com.google.zxing.ReaderException;
import com.google.zxing.Result;
import com.google.zxing.ResultMetadataType;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.BitArray;
import com.sec.factory.app.factorytest.FactoryTestManager;
import java.util.Arrays;
import java.util.EnumMap;
import java.util.Map;

public abstract class OneDReader implements Reader {
    public abstract Result decodeRow(int i, BitArray bitArray, Map<DecodeHintType, ?> map) throws NotFoundException, ChecksumException, FormatException;

    @Override // com.google.zxing.Reader
    public Result decode(BinaryBitmap image) throws NotFoundException, FormatException {
        return decode(image, null);
    }

    @Override // com.google.zxing.Reader
    public Result decode(BinaryBitmap image, Map<DecodeHintType, ?> hints) throws NotFoundException, FormatException {
        try {
            return doDecode(image, hints);
        } catch (NotFoundException nfe) {
            if (!(hints != null && hints.containsKey(DecodeHintType.TRY_HARDER)) || !image.isRotateSupported()) {
                throw nfe;
            }
            BinaryBitmap rotatedImage = image.rotateCounterClockwise();
            Result result = doDecode(rotatedImage, hints);
            Map<ResultMetadataType, ?> metadata = result.getResultMetadata();
            int orientation = 270;
            if (metadata != null && metadata.containsKey(ResultMetadataType.ORIENTATION)) {
                orientation = (((Integer) metadata.get(ResultMetadataType.ORIENTATION)).intValue() + 270) % FactoryTestManager.TEST_UDC_CAPTURE;
            }
            result.putMetadata(ResultMetadataType.ORIENTATION, Integer.valueOf(orientation));
            ResultPoint[] points = result.getResultPoints();
            if (points != null) {
                int height = rotatedImage.getHeight();
                for (int i = 0; i < points.length; i++) {
                    points[i] = new ResultPoint((((float) height) - points[i].getY()) - 1.0f, points[i].getX());
                }
            }
            return result;
        }
    }

    @Override // com.google.zxing.Reader
    public void reset() {
    }

    /* JADX WARNING: Code restructure failed: missing block: B:75:0x00fd, code lost:
        return r0;
     */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x008d A[SYNTHETIC, Splitter:B:43:0x008d] */
    /* JADX WARNING: Removed duplicated region for block: B:89:0x00f9 A[SYNTHETIC] */
    private Result doDecode(BinaryBitmap image, Map<DecodeHintType, ?> hints) throws NotFoundException {
        int maxLines;
        int middle;
        int height;
        boolean z;
        Map<DecodeHintType, Object> newHints;
        Map<DecodeHintType, Object> hints2;
        int middle2;
        int height2;
        boolean z2;
        int width = image.getWidth();
        int height3 = image.getHeight();
        BitArray row = new BitArray(width);
        int middle3 = height3 >> 1;
        boolean z3 = true;
        boolean tryHarder = hints != null && hints.containsKey(DecodeHintType.TRY_HARDER);
        int rowStep = Math.max(1, height3 >> (tryHarder ? 8 : 5));
        if (tryHarder) {
            maxLines = height3;
        } else {
            maxLines = 15;
        }
        int x = 0;
        BitArray row2 = row;
        Map<DecodeHintType, Object> hints3 = hints;
        loop0:
        while (true) {
            if (x >= maxLines) {
                break;
            }
            int rowStepsAboveOrBelow = (x + 1) / 2;
            int rowNumber = middle3 + (((x & 1) == 0 ? z3 : false ? rowStepsAboveOrBelow : -rowStepsAboveOrBelow) * rowStep);
            if (rowNumber < 0) {
                break;
            }
            if (rowNumber >= height3) {
                break;
            }
            try {
                row2 = image.getBlackRow(rowNumber, row2);
                int attempt = 0;
                Map<DecodeHintType, Object> hints4 = hints3;
                for (int i = 2; attempt < i; i = 2) {
                    if (attempt == z3) {
                        row2.reverse();
                        if (hints4 != null && hints4.containsKey(DecodeHintType.NEED_RESULT_POINT_CALLBACK)) {
                            newHints = new EnumMap<>(DecodeHintType.class);
                            newHints.putAll(hints4);
                            newHints.remove(DecodeHintType.NEED_RESULT_POINT_CALLBACK);
                            Result result = decodeRow(rowNumber, row2, newHints);
                            height2 = height3;
                            if (attempt == 1) {
                                break loop0;
                            }
                            try {
                                middle2 = middle3;
                            } catch (ReaderException e) {
                                middle2 = middle3;
                                hints2 = newHints;
                                z2 = true;
                                attempt++;
                                z3 = z2;
                                height3 = height2;
                                middle3 = middle2;
                                hints4 = hints2;
                            }
                            try {
                                result.putMetadata(ResultMetadataType.ORIENTATION, 180);
                                ResultPoint[] points = result.getResultPoints();
                                if (points == null) {
                                    break loop0;
                                }
                                try {
                                    hints2 = newHints;
                                    try {
                                        points[0] = new ResultPoint((((float) width) - points[0].getX()) - 1.0f, points[0].getY());
                                    } catch (ReaderException e2) {
                                        z2 = true;
                                        attempt++;
                                        z3 = z2;
                                        height3 = height2;
                                        middle3 = middle2;
                                        hints4 = hints2;
                                    }
                                } catch (ReaderException e3) {
                                    hints2 = newHints;
                                    z2 = true;
                                    attempt++;
                                    z3 = z2;
                                    height3 = height2;
                                    middle3 = middle2;
                                    hints4 = hints2;
                                }
                                try {
                                    z2 = true;
                                    try {
                                        points[1] = new ResultPoint((((float) width) - points[1].getX()) - 1.0f, points[1].getY());
                                        break loop0;
                                    } catch (ReaderException e4) {
                                    }
                                } catch (ReaderException e5) {
                                    z2 = true;
                                    attempt++;
                                    z3 = z2;
                                    height3 = height2;
                                    middle3 = middle2;
                                    hints4 = hints2;
                                }
                            } catch (ReaderException e6) {
                                hints2 = newHints;
                                z2 = true;
                                attempt++;
                                z3 = z2;
                                height3 = height2;
                                middle3 = middle2;
                                hints4 = hints2;
                            }
                        }
                    }
                    newHints = hints4;
                    try {
                        Result result2 = decodeRow(rowNumber, row2, newHints);
                        height2 = height3;
                        if (attempt == 1) {
                        }
                    } catch (ReaderException e7) {
                        height2 = height3;
                        middle2 = middle3;
                        hints2 = newHints;
                        z2 = true;
                        attempt++;
                        z3 = z2;
                        height3 = height2;
                        middle3 = middle2;
                        hints4 = hints2;
                    }
                }
                height = height3;
                middle = middle3;
                z = z3;
                hints3 = hints4;
            } catch (NotFoundException e8) {
                height = height3;
                middle = middle3;
                z = z3;
            }
            x++;
            z3 = z;
            height3 = height;
            middle3 = middle;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    protected static void recordPattern(BitArray row, int start, int[] counters) throws NotFoundException {
        int numCounters = counters.length;
        Arrays.fill(counters, 0, numCounters, 0);
        int end = row.getSize();
        if (start < end) {
            boolean isWhite = !row.get(start);
            int counterPosition = 0;
            int i = start;
            while (i < end) {
                if (row.get(i) ^ isWhite) {
                    counters[counterPosition] = counters[counterPosition] + 1;
                } else {
                    counterPosition++;
                    if (counterPosition == numCounters) {
                        break;
                    }
                    counters[counterPosition] = 1;
                    isWhite = !isWhite;
                }
                i++;
            }
            if (counterPosition == numCounters) {
                return;
            }
            if (counterPosition != numCounters - 1 || i != end) {
                throw NotFoundException.getNotFoundInstance();
            }
            return;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    protected static void recordPatternInReverse(BitArray row, int start, int[] counters) throws NotFoundException {
        int numTransitionsLeft = counters.length;
        boolean last = row.get(start);
        while (start > 0 && numTransitionsLeft >= 0) {
            start--;
            if (row.get(start) != last) {
                numTransitionsLeft--;
                last = !last;
            }
        }
        if (numTransitionsLeft < 0) {
            recordPattern(row, start + 1, counters);
            return;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    protected static float patternMatchVariance(int[] counters, int[] pattern, float maxIndividualVariance) {
        int numCounters = counters.length;
        int total = 0;
        int patternLength = 0;
        for (int i = 0; i < numCounters; i++) {
            total += counters[i];
            patternLength += pattern[i];
        }
        if (total < patternLength) {
            return Float.POSITIVE_INFINITY;
        }
        float unitBarWidth = ((float) total) / ((float) patternLength);
        float maxIndividualVariance2 = maxIndividualVariance * unitBarWidth;
        float totalVariance = 0.0f;
        for (int x = 0; x < numCounters; x++) {
            int counter = counters[x];
            float scaledPattern = ((float) pattern[x]) * unitBarWidth;
            float variance = ((float) counter) > scaledPattern ? ((float) counter) - scaledPattern : scaledPattern - ((float) counter);
            if (variance > maxIndividualVariance2) {
                return Float.POSITIVE_INFINITY;
            }
            totalVariance += variance;
        }
        return totalVariance / ((float) total);
    }
}
