package com.sec.factory.aporiented.athandler;

import android.content.Context;
import android.hardware.Camera;
import android.hardware.fingerprint.FingerprintManager;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.os.PowerManager;
import android.text.TextUtils;
import com.goodix.cap.fingerprint.sec.mt.GFTestManager;
import com.sec.factory.app.factorytest.FactoryTestManager;
import com.sec.factory.common.CommonFingerprintEgis;
import com.sec.factory.common.CommonFingerprintGoodix;
import com.sec.factory.common.CommonFingerprintQcom;
import com.sec.factory.modules.ModuleCommunicationService;
import com.sec.factory.modules.ModuleDevice;
import com.sec.factory.modules.ModuleForceTouch;
import com.sec.factory.modules.ModuleTouchScreen;
import com.sec.factory.support.FtUtil;
import com.sec.xmldata.support.Support;
import egis.client.api.EgisFingerprint;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Locale;

public class AtFirmvers extends AtCommandHandler {
    private static final int DONE_FAIL_FIRMWARE_UPGRADE = 1003;
    private static final String DONE_FAIL_TSP_UPGRADE = "FAIL";
    private static final int DONE_PASS_FIRMWARE_UPGRADE = 1002;
    private static final String DONE_PASS_TSP_UPGRADE = "PASS";
    private static final int DOWNLOADING_FIRMWARE_UPGRADE = 1001;
    private static final String DOWNLOADING_TSP_UPGRADE = "DOWNLOADING";
    private static final int NO_STATUS_FIRMWARE_UPGRADE = 1000;
    private static final String NO_STATUS_TSP_UPGRADE = "NG";
    private static final byte[] OTG_MUIC_OFF = {FactoryTestManager.TEST_SENSORHUB, 0};
    private static final byte[] OTG_MUIC_ON = {FactoryTestManager.MACRO_AF, 0};
    private static String mTSP2UpdateStatus = "NG";
    private static String mTSPUpdateStatus = "NG";
    private final int KEYLESS_FW_BIN = 2002;
    private final int KEYLESS_FW_IC = 2001;
    private String TSP_ENABLED = EgisFingerprint.MAJOR_VERSION;
    private Camera mCameraDevice;
    private CommonFingerprintQcom mCommonFingerprintQcom;
    protected boolean mDetected;
    protected boolean mFwupdateComplete;
    Handler mTsp2FirmwareUpdateHandler;
    Handler mTspFirmwareUpdateHandler;
    Handler mWacomFirmwareUpdateHandler;
    private String mWacomUpdateStatus = "NG";
    PowerManager.WakeLock mWakeLock;
    private int tspDevCount;
    private String tspEnablePath;
    private String tspEnabledValue;
    public String tspUpdateResult = "";
    public String tspUpdateStatus = "";

    public AtFirmvers(Context context) {
        super(context);
        this.CMD_NAME = "FIRMVERS";
        this.CLASS_NAME = "AtFirmvers";
        this.NUM_ARGS = 3;
        if (FtUtil.isFactoryBinary() && Looper.myLooper() == null) {
            Looper.prepare();
        }
    }

    /* JADX INFO: Multiple debug info for r8v35 java.lang.String: [D('version' java.lang.String), D('tempVersion' java.lang.String)] */
    @Override // com.sec.factory.aporiented.athandler.AtCommandHandler
    public synchronized String handleCommand(String[] argu) {
        String str;
        String version;
        String resData = null;
        if (argu.length != (STAGE_PARALLEL ? this.NUM_ARGS + 1 : this.NUM_ARGS)) {
            return responseNA();
        }
        if (checkArgu(argu, new String[]{"0", "0", "0"})) {
            resData = responseNA();
        } else if (checkArgu(argu, new String[]{"0", "0", EgisFingerprint.MAJOR_VERSION})) {
            resData = responseNA();
        } else if (checkArgu(argu, new String[]{"0", EgisFingerprint.MAJOR_VERSION, "0"})) {
            mTSPUpdateStatus = DOWNLOADING_TSP_UPGRADE;
            this.mTspFirmwareUpdateHandler = null;
            this.mTspFirmwareUpdateHandler = new Handler(this.context.getMainLooper()) {
                /* class com.sec.factory.aporiented.athandler.AtFirmvers.AnonymousClass1 */

                public void handleMessage(Message msg) {
                    String str = AtFirmvers.this.CLASS_NAME;
                    FtUtil.log_d(str, "tspFirmwareUpdateHandler", "msg.what = " + msg.what);
                    if (msg.what == ModuleTouchScreen.TSP_WHAT_STATUS_OK) {
                        FtUtil.log_d(AtFirmvers.this.CLASS_NAME, "tspFirmwareUpdateHandler", "TSP_WHAT_STATUS_OK");
                        if (msg.arg1 == ModuleTouchScreen.TSP_ID__FW_UPDATE) {
                            if (msg.obj.toString().contains("OK")) {
                                String unused = AtFirmvers.mTSPUpdateStatus = "PASS";
                            } else {
                                String unused2 = AtFirmvers.mTSPUpdateStatus = "FAIL";
                            }
                        }
                    } else if (msg.what == ModuleTouchScreen.TSP_WHAT_STATUS_NG) {
                        String unused3 = AtFirmvers.mTSPUpdateStatus = "FAIL";
                        FtUtil.log_d(AtFirmvers.this.CLASS_NAME, "tspFirmwareUpdateHandler", "TSP_WHAT_STATUS_NG");
                    } else if (msg.what == ModuleTouchScreen.TSP_WHAT_STATUS_NA) {
                        FtUtil.log_d(AtFirmvers.this.CLASS_NAME, "tspFirmwareUpdateHandler", AtFirmvers.mTSPUpdateStatus);
                        String unused4 = AtFirmvers.mTSPUpdateStatus = "FAIL";
                    }
                    FtUtil.log_d(AtFirmvers.this.CLASS_NAME, "tspFirmwareUpdateHandler", AtFirmvers.mTSPUpdateStatus);
                }
            };
            if (mModuleTouchScreen.getTSPResult(ModuleTouchScreen.TSP_ID__FW_UPDATE, "0", this.mTspFirmwareUpdateHandler)) {
                resData = responseOK(argu[0]);
            } else {
                resData = responseNG(argu[0]);
                mTSPUpdateStatus = "NG";
            }
        } else if (checkArgu(argu, new String[]{"0", EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION})) {
            resData = responseString(argu[0], mTSPUpdateStatus);
        } else if (checkArgu(argu, new String[]{"0", "2", "0"})) {
            if (!isSupportTSK()) {
                writeTspCmd("fw_update,0");
                String status = ModuleForceTouch.RUNNING;
                int EXPIRED_COUNTER = 20;
                while (true) {
                    if (!ModuleForceTouch.RUNNING.equalsIgnoreCase(status)) {
                        break;
                    }
                    status = readStatus();
                    int EXPIRED_COUNTER2 = EXPIRED_COUNTER - 1;
                    if (EXPIRED_COUNTER < 0) {
                        FtUtil.log_e(this.CLASS_NAME, "Failed TSP update (Timeout 120s)");
                        resData = responseNG(argu[0]);
                        break;
                    } else if ("OK".equalsIgnoreCase(status)) {
                        String result = readResult();
                        FtUtil.log_i(this.CLASS_NAME, "TSP update (result == " + result + ")");
                        if (result == null || !result.contains("OK")) {
                            resData = responseNG(argu[0]);
                        } else {
                            resData = responseOK(argu[0]);
                        }
                    } else if ("FAIL".equalsIgnoreCase(status)) {
                        FtUtil.log_e(this.CLASS_NAME, "Failed TSP update (Status == FAIL)");
                        resData = responseNG(argu[0]);
                        break;
                    } else {
                        try {
                            Thread.sleep(5000);
                        } catch (InterruptedException ie) {
                            ie.printStackTrace();
                        }
                        EXPIRED_COUNTER = EXPIRED_COUNTER2;
                    }
                }
            } else if (mModuleDevice.firmwareDownload(2)) {
                resData = responseOK(argu[0]);
            } else {
                resData = responseNG(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{"0", "2", EgisFingerprint.MAJOR_VERSION})) {
            resData = responseString(argu[0], mModuleDevice.readModuleUpdateStatus(2));
        } else if (checkArgu(argu, new String[]{"0", egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "0"})) {
            boolean result2 = Support.Kernel.writeToPath("/sys/class/sec/sec_epen/epen_firm_update", "k");
            Thread updateThread = new Thread(new Runnable() {
                /* class com.sec.factory.aporiented.athandler.AtFirmvers.AnonymousClass2 */

                public void run() {
                    Message msg = AtFirmvers.this.mWacomFirmwareUpdateHandler.obtainMessage();
                    msg.obj = 1001;
                    AtFirmvers.this.mWacomFirmwareUpdateHandler.sendMessage(msg);
                    AtFirmvers.this.mWacomUpdateStatus = Support.Kernel.read(Support.Kernel.EPEN_FIRMWARE_UPDATE_STATUS);
                    while (AtFirmvers.DOWNLOADING_TSP_UPGRADE.equals(AtFirmvers.this.mWacomUpdateStatus) && 50 > 0) {
                        try {
                            Thread.sleep(50);
                        } catch (Exception e) {
                            e.printStackTrace();
                        }
                        AtFirmvers.this.mWacomUpdateStatus = Support.Kernel.read(Support.Kernel.EPEN_FIRMWARE_UPDATE_STATUS);
                    }
                    Message msg2 = AtFirmvers.this.mWacomFirmwareUpdateHandler.obtainMessage();
                    if ("PASS".equals(AtFirmvers.this.mWacomUpdateStatus)) {
                        msg2.obj = 1002;
                    } else {
                        msg2.obj = 1003;
                    }
                    AtFirmvers.this.mWacomFirmwareUpdateHandler.sendMessage(msg2);
                }
            });
            this.mWacomFirmwareUpdateHandler = new Handler(this.context.getMainLooper()) {
                /* class com.sec.factory.aporiented.athandler.AtFirmvers.AnonymousClass3 */

                public void handleMessage(Message msg) {
                    String str = AtFirmvers.this.CLASS_NAME;
                    FtUtil.log_d(str, "mWacomFirmwareUpdateHandler", "msg.what = " + msg.what);
                    if (msg.what == 1001) {
                        FtUtil.log_d(AtFirmvers.this.CLASS_NAME, "mWacomFirmwareUpdateHandler", "Downloading");
                        AtFirmvers.this.mWacomUpdateStatus = AtFirmvers.DOWNLOADING_TSP_UPGRADE;
                    } else if (msg.what == 1002) {
                        FtUtil.log_d(AtFirmvers.this.CLASS_NAME, "mWacomFirmwareUpdateHandler", "Pass");
                        AtFirmvers.this.mWacomUpdateStatus = "PASS";
                    } else if (msg.what == 1003) {
                        FtUtil.log_d(AtFirmvers.this.CLASS_NAME, "mWacomFirmwareUpdateHandler", "Fail");
                        AtFirmvers.this.mWacomUpdateStatus = "FAIL";
                    }
                    FtUtil.log_d(AtFirmvers.this.CLASS_NAME, "tspFirmwareUpdateHandler", AtFirmvers.mTSPUpdateStatus);
                }
            };
            updateThread.start();
            if (result2) {
                resData = responseOK(argu[0]);
            } else {
                resData = responseNG(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{"0", egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION})) {
            resData = responseString(argu[0], this.mWacomUpdateStatus);
        } else if (checkArgu(argu, new String[]{"0", "8", "0"})) {
            this.mFwupdateComplete = false;
            if (Support.Feature.getBoolean(Support.Feature.SUPPORT_IDT)) {
                if (Support.Kernel.isExistFile(Support.Kernel.OTG_MUIC_SET)) {
                    Support.Kernel.write(Support.Kernel.OTG_MUIC_SET, OTG_MUIC_ON);
                    try {
                        Thread.sleep(100);
                    } catch (InterruptedException ie2) {
                        ie2.printStackTrace();
                    }
                }
                if (Support.Kernel.isExistFile(Support.Kernel.IDT_OTP_ON_OFF)) {
                    Support.Kernel.write(Support.Kernel.IDT_OTP_ON_OFF, EgisFingerprint.MAJOR_VERSION);
                    try {
                        Thread.sleep(200);
                    } catch (InterruptedException ie3) {
                        ie3.printStackTrace();
                    }
                }
                Support.Kernel.write(Support.Kernel.IDT_OTP_FIRMWARE_UPDATE_STATUS, "2");
                new Thread(new Runnable() {
                    /* class com.sec.factory.aporiented.athandler.AtFirmvers.AnonymousClass4 */

                    public void run() {
                        Support.Kernel.write(Support.Kernel.IDT_OTP_FIRMWARE_UPDATE, EgisFingerprint.MAJOR_VERSION);
                        AtFirmvers.this.mFwupdateComplete = true;
                    }
                }).start();
                try {
                    Thread.sleep(500);
                } catch (InterruptedException ie4) {
                    ie4.printStackTrace();
                }
                String status2 = ModuleForceTouch.RUNNING;
                int EXPIRED_COUNTER3 = 12;
                while (true) {
                    if (!ModuleForceTouch.RUNNING.equalsIgnoreCase(status2)) {
                        break;
                    }
                    status2 = readIDTStatus();
                    int EXPIRED_COUNTER4 = EXPIRED_COUNTER3 - 1;
                    if (EXPIRED_COUNTER3 < 0) {
                        FtUtil.log_e(this.CLASS_NAME, "Failed IDT F/W update (Timeout 10s)");
                        resData = responseNG(argu[0]);
                        break;
                    } else if ("PASS".equalsIgnoreCase(status2)) {
                        FtUtil.log_i(this.CLASS_NAME, "IDT F/W update (result == " + status2 + ")");
                        resData = responseOK(argu[0]);
                        break;
                    } else if ("FAIL".equalsIgnoreCase(status2) || "nostring".equalsIgnoreCase(status2)) {
                        FtUtil.log_e(this.CLASS_NAME, "Failed IDT F/W update (Status == FAIL)");
                        resData = responseNG(argu[0]);
                    } else {
                        try {
                            Thread.sleep(2000);
                        } catch (InterruptedException ie5) {
                            ie5.printStackTrace();
                        }
                        EXPIRED_COUNTER3 = EXPIRED_COUNTER4;
                    }
                }
                FtUtil.log_e(this.CLASS_NAME, "Failed IDT F/W update (Status == FAIL)");
                resData = responseNG(argu[0]);
                int COUNTER = 5;
                while (true) {
                    if (this.mFwupdateComplete) {
                        break;
                    }
                    int COUNTER2 = COUNTER - 1;
                    if (COUNTER < 0) {
                        COUNTER = COUNTER2;
                        break;
                    }
                    try {
                        Thread.sleep(1000);
                    } catch (InterruptedException ie6) {
                        ie6.printStackTrace();
                    }
                    COUNTER = COUNTER2;
                }
                if (Support.Kernel.isExistFile(Support.Kernel.IDT_OTP_ON_OFF)) {
                    Support.Kernel.write(Support.Kernel.IDT_OTP_ON_OFF, "0");
                    try {
                        Thread.sleep(300);
                    } catch (InterruptedException ie7) {
                        ie7.printStackTrace();
                    }
                }
                if (Support.Kernel.isExistFile(Support.Kernel.OTG_MUIC_SET)) {
                    Support.Kernel.write(Support.Kernel.OTG_MUIC_SET, OTG_MUIC_OFF);
                    try {
                        Thread.sleep(300);
                    } catch (InterruptedException ie8) {
                        ie8.printStackTrace();
                    }
                }
                if (COUNTER < 0) {
                    resData = responseNG(argu[0]);
                }
            } else {
                resData = responseNG(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "0", "0"})) {
            String rear_cam_isp_version = null;
            startCameraforFwRead();
            try {
                String rearCamFwStr = mModuleCommon.readCameraRearFWver();
                if (rearCamFwStr != null) {
                    rear_cam_isp_version = rearCamFwStr.contains(" ") ? rearCamFwStr.split(" ")[0] : rearCamFwStr.contains("_") ? rearCamFwStr.split("_")[1] : rearCamFwStr;
                }
            } catch (Exception e) {
                FtUtil.log_e(this.CLASS_NAME, "handleCommand", "Failed to read rearCamera's F/W");
            }
            try {
                stopCameraforFwRead();
            } catch (Exception e2) {
                FtUtil.log_e(this.CLASS_NAME, "handleCommand", "stopCamera failed");
            }
            if (rear_cam_isp_version == null || rear_cam_isp_version.equals("N")) {
                String type = mModuleCommon.readCameraRearType();
                if (type == null) {
                    resData = responseNG(argu[0]);
                } else if (type.contains("_")) {
                    String[] cameraType_rear = type.split("_");
                    FtUtil.log_i(this.CLASS_NAME, "handleCommand", "rearCamType : " + cameraType_rear[1]);
                    resData = responseString(argu[0], cameraType_rear[1]);
                } else {
                    FtUtil.log_i(this.CLASS_NAME, "handleCommand", "rearCamType : " + type);
                    resData = responseString(argu[0], type);
                }
            } else {
                resData = responseString(argu[0], rear_cam_isp_version);
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "0", EgisFingerprint.MAJOR_VERSION})) {
            resData = responseNA();
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION, "0"})) {
            resData = responseString(argu[0], mModuleTouchScreen.getTSPFirmwareVersionIC());
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION})) {
            resData = responseString(argu[0], mModuleTouchScreen.getTSPFirmwareVersionBinary());
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "2", "0"})) {
            resData = responseString(argu[0], mModuleDevice.readModuleFirmwareVersion(2));
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "2", EgisFingerprint.MAJOR_VERSION})) {
            resData = responseString(argu[0], mModuleDevice.readModuleBinVersion(2));
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "0"})) {
            resData = responseString(argu[0], mModuleDevice.readModuleFirmwareVersion(3));
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "4", "0"})) {
            try {
                resData = responseString(argu[0], mModuleDevice.readModuleFirmwareVersion(5).split(",")[0]);
            } catch (Exception e3) {
                resData = responseNG(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "4", EgisFingerprint.MAJOR_VERSION})) {
            try {
                resData = responseString(argu[0], mModuleDevice.readModuleFirmwareVersion(5).split(",")[1]);
            } catch (Exception e4) {
                resData = responseNG(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "5", "0"})) {
            resData = responseString(argu[0], mModuleDevice.readModuleFirmwareVersion(7));
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "6", EgisFingerprint.MAJOR_VERSION})) {
            if (!"true".equals(Support.FactoryTestMenu.getEnableForAllMenu("67"))) {
                return responseNA();
            }
            String mFingerPrint_Vendor = Support.Kernel.read(Support.Kernel.FINGERPRINT_VENDOR);
            String mFingerPrint_Name = Support.Kernel.read(Support.Kernel.FINGERPRINT_CHIP_NAME);
            boolean isFactoryBinary = FtUtil.isFactoryBinary();
            FtUtil.log_d(this.CLASS_NAME, "handleCommand", " mFingerPrint_Vendor:" + mFingerPrint_Vendor + " mFingerPrint_Name:" + mFingerPrint_Name);
            if ("GOODIX".equals(mFingerPrint_Vendor)) {
                if (!isFactoryBinary) {
                    version = ((FingerprintManager) this.context.getSystemService("fingerprint")).semGetDaemonVersion();
                } else if (mFingerPrint_Name == null || !mFingerPrint_Name.contains("GW9558")) {
                    version = new GFTestManager(this.context).getVersion();
                } else {
                    version = CommonFingerprintGoodix.instance(this.context).getVersion();
                }
            } else if ("QCOM".equals(mFingerPrint_Vendor)) {
                if (isFactoryBinary) {
                    CommonFingerprintQcom commonFingerprintQcom = new CommonFingerprintQcom(this.context, this.CLASS_NAME);
                    this.mCommonFingerprintQcom = commonFingerprintQcom;
                    version = commonFingerprintQcom.getFpVersion();
                } else {
                    version = ((FingerprintManager) this.context.getSystemService("fingerprint")).semGetDaemonVersion();
                }
            } else if ("EGISTEC".equals(mFingerPrint_Vendor)) {
                try {
                    version = CommonFingerprintEgis.instance(this.context).getVersion();
                } catch (NullPointerException ne) {
                    FtUtil.log_e(ne);
                    version = null;
                }
            } else {
                version = ((FingerprintManager) this.context.getSystemService("fingerprint")).semGetDaemonVersion();
            }
            FtUtil.log_d(this.CLASS_NAME, "fingerprint version : " + version);
            if (version == null) {
                return responseNG(argu[0]);
            }
            String tempVersion = version.toUpperCase(Locale.ENGLISH);
            if (tempVersion.replaceAll("[^0-9]", "").replaceAll("[0]", "").isEmpty()) {
                FtUtil.log_e(this.CLASS_NAME, "Fingerprint version is abnormal");
                return responseNG(argu[0]);
            }
            resData = responseString(argu[0], tempVersion);
        } else if (checkArgu(argu, new String[]{EgisFingerprint.MAJOR_VERSION, "8", "0"})) {
            if (Support.Feature.getBoolean(Support.Feature.SUPPORT_IDT)) {
                if (Support.Kernel.isExistFile(Support.Kernel.OTG_MUIC_SET)) {
                    Support.Kernel.write(Support.Kernel.OTG_MUIC_SET, OTG_MUIC_ON);
                    try {
                        Thread.sleep(100);
                    } catch (InterruptedException ie9) {
                        ie9.printStackTrace();
                    }
                }
                if (Support.Kernel.isExistFile(Support.Kernel.IDT_OTP_ON_OFF)) {
                    Support.Kernel.write(Support.Kernel.IDT_OTP_ON_OFF, EgisFingerprint.MAJOR_VERSION);
                    try {
                        Thread.sleep(200);
                    } catch (InterruptedException ie10) {
                        ie10.printStackTrace();
                    }
                }
                String idt_IC_fw_version = Support.Kernel.read(Support.Kernel.IDT_OTP_FIRMWARE_VERSION);
                String idt_bin_fw_version = Support.Kernel.read(Support.Kernel.IDT_PACKAGING_FIRMWARE_VERSION);
                if (idt_IC_fw_version == null || idt_bin_fw_version == null) {
                    resData = responseNG(argu[0]);
                } else if (idt_IC_fw_version.equalsIgnoreCase(idt_bin_fw_version)) {
                    String VerifyResult = Support.Kernel.read(Support.Kernel.IDT_OTP_FIRMWARE_UPDATE);
                    if (VerifyResult == null) {
                        resData = responseNG(argu[0]);
                    } else if (EgisFingerprint.MAJOR_VERSION.equalsIgnoreCase(VerifyResult)) {
                        resData = responseString(argu[0], idt_IC_fw_version);
                    } else {
                        resData = responseString(argu[0], "NG_CS");
                    }
                } else {
                    resData = responseString(argu[0], "NG_NONE");
                }
                if (Support.Kernel.isExistFile(Support.Kernel.IDT_OTP_ON_OFF)) {
                    Support.Kernel.write(Support.Kernel.IDT_OTP_ON_OFF, "0");
                    try {
                        Thread.sleep(300);
                    } catch (InterruptedException ie11) {
                        ie11.printStackTrace();
                    }
                }
                if (Support.Kernel.isExistFile(Support.Kernel.OTG_MUIC_SET)) {
                    Support.Kernel.write(Support.Kernel.OTG_MUIC_SET, OTG_MUIC_OFF);
                    try {
                        Thread.sleep(300);
                    } catch (InterruptedException ie12) {
                        ie12.printStackTrace();
                    }
                }
            } else {
                resData = responseNG(argu[0]);
            }
        } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "2", "2"})) {
            String pdic_fw_module = Support.Kernel.read(Support.Kernel.PDIC_FW_MODULE);
            if (pdic_fw_module == null) {
                resData = responseString(argu[0], "NG_CS");
            } else {
                resData = responseString(argu[0], pdic_fw_module.replace(" ", "."));
            }
        } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "2", "5"})) {
            String grip_touch_ic_module = "";
            int GripCount = Support.TestCase.getInt(Support.TestCase.GRIPSENSOR_GRIP_COUNT);
            for (int index = 1; index <= GripCount; index++) {
                StringBuilder sb = new StringBuilder();
                sb.append(Support.Kernel.GRIP_TOUCH_SENSOR_CRC_CHECK);
                sb.append(index == 1 ? "" : "_" + index);
                String checksum = Support.Kernel.read(sb.toString());
                if (checksum != null && checksum.contains("OK")) {
                    StringBuilder sb2 = new StringBuilder();
                    sb2.append(Support.Kernel.GRIP_SENSOR_FIRMWARE_VERSION_PANEL);
                    sb2.append(index == 1 ? "" : "_" + index);
                    str = grip_touch_ic_module + getGripFWVer(sb2.toString());
                } else if (checksum == null || !checksum.contains("NG")) {
                    str = grip_touch_ic_module + "NG,";
                } else {
                    str = grip_touch_ic_module + "NG_CS,";
                }
                grip_touch_ic_module = str;
            }
            for (int i = 6 - GripCount; i > 0; i--) {
                grip_touch_ic_module = grip_touch_ic_module + "N,";
            }
            resData = responseString(argu[0], grip_touch_ic_module.substring(0, grip_touch_ic_module.length() - 1));
        } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "2", "7"})) {
            int tspDevCount2 = mModuleTouchScreen.getTspDevCount();
            this.tspDevCount = tspDevCount2;
            if (tspDevCount2 > 1) {
                String filePath = Support.Kernel.getFilePath(Support.Kernel.TSP_ENABLE);
                this.tspEnablePath = filePath;
                String replace = filePath.replace("/tsp/", "/tsp2/");
                this.tspEnablePath = replace;
                String readFromPath = Support.Kernel.readFromPath(replace, true);
                this.tspEnabledValue = readFromPath;
                if (!this.TSP_ENABLED.equals(readFromPath)) {
                    Support.Kernel.writeToPath(this.tspEnablePath, EgisFingerprint.MAJOR_VERSION);
                }
                mModuleTouchScreen.getTSPResult(ModuleTouchScreen.TSP_ID__SELECT_TSP, EgisFingerprint.MAJOR_VERSION);
                String result3 = mModuleTouchScreen.getTSPFirmwareVersionIC();
                if (!this.TSP_ENABLED.equals(this.tspEnabledValue)) {
                    Support.Kernel.writeToPath(this.tspEnablePath, "0");
                }
                mModuleTouchScreen.getTSPResult(ModuleTouchScreen.TSP_ID__SELECT_TSP, ModuleCommunicationService.SMD_NOK);
                resData = responseString(argu[0], result3);
            } else {
                resData = responseNA();
            }
        } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "2"})) {
            String pdic_fw_binary = Support.Kernel.read(Support.Kernel.PDIC_FW_BINARY);
            if (pdic_fw_binary == null) {
                resData = responseString(argu[0], "NG_CS");
            } else {
                resData = responseString(argu[0], pdic_fw_binary.replace(" ", "."));
            }
        } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "5"})) {
            String grip_touch_ic_bin = "";
            int GripCount2 = Support.TestCase.getInt(Support.TestCase.GRIPSENSOR_GRIP_COUNT);
            for (int index2 = 1; index2 <= GripCount2; index2++) {
                StringBuilder sb3 = new StringBuilder();
                sb3.append(Support.Kernel.GRIP_SENSOR_FIRMWARE_VERSION_PHONE);
                sb3.append(index2 == 1 ? "" : "_" + index2);
                grip_touch_ic_bin = grip_touch_ic_bin + getGripFWVer(sb3.toString());
            }
            for (int i2 = 6 - GripCount2; i2 > 0; i2--) {
                grip_touch_ic_bin = grip_touch_ic_bin + "N,";
            }
            resData = responseString(argu[0], grip_touch_ic_bin.substring(0, grip_touch_ic_bin.length() - 1));
        } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "7"})) {
            int tspDevCount3 = mModuleTouchScreen.getTspDevCount();
            this.tspDevCount = tspDevCount3;
            if (tspDevCount3 > 1) {
                String filePath2 = Support.Kernel.getFilePath(Support.Kernel.TSP_ENABLE);
                this.tspEnablePath = filePath2;
                String replace2 = filePath2.replace("/tsp/", "/tsp2/");
                this.tspEnablePath = replace2;
                String readFromPath2 = Support.Kernel.readFromPath(replace2, true);
                this.tspEnabledValue = readFromPath2;
                if (!this.TSP_ENABLED.equals(readFromPath2)) {
                    Support.Kernel.writeToPath(this.tspEnablePath, EgisFingerprint.MAJOR_VERSION);
                }
                mModuleTouchScreen.getTSPResult(ModuleTouchScreen.TSP_ID__SELECT_TSP, EgisFingerprint.MAJOR_VERSION);
                String result4 = mModuleTouchScreen.getTSPFirmwareVersionBinary();
                if (!this.TSP_ENABLED.equals(this.tspEnabledValue)) {
                    Support.Kernel.writeToPath(this.tspEnablePath, "0");
                }
                mModuleTouchScreen.getTSPResult(ModuleTouchScreen.TSP_ID__SELECT_TSP, ModuleCommunicationService.SMD_NOK);
                resData = responseString(argu[0], result4);
            } else {
                resData = responseNA();
            }
        } else if (checkArgu(argu, new String[]{"4", "0", "2"})) {
            resData = responseString(argu[0], Support.Kernel.read(Support.Kernel.TOUCH_KEY_CRC_CHECK));
        } else {
            resData = responseNA();
        }
        if (FtUtil.isFactoryBinary()) {
            if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "0", "7"})) {
                int tspDevCount4 = mModuleTouchScreen.getTspDevCount();
                this.tspDevCount = tspDevCount4;
                if (tspDevCount4 > 1) {
                    String filePath3 = Support.Kernel.getFilePath(Support.Kernel.TSP_ENABLE);
                    this.tspEnablePath = filePath3;
                    String replace3 = filePath3.replace("/tsp/", "/tsp2/");
                    this.tspEnablePath = replace3;
                    String readFromPath3 = Support.Kernel.readFromPath(replace3, true);
                    this.tspEnabledValue = readFromPath3;
                    if (!this.TSP_ENABLED.equals(readFromPath3)) {
                        Support.Kernel.writeToPath(this.tspEnablePath, EgisFingerprint.MAJOR_VERSION);
                    }
                    mModuleTouchScreen.getTSPResult(ModuleTouchScreen.TSP_ID__SELECT_TSP, EgisFingerprint.MAJOR_VERSION);
                    mTSP2UpdateStatus = DOWNLOADING_TSP_UPGRADE;
                    this.mTsp2FirmwareUpdateHandler = null;
                    this.mTsp2FirmwareUpdateHandler = new Handler(this.context.getMainLooper()) {
                        /* class com.sec.factory.aporiented.athandler.AtFirmvers.AnonymousClass5 */

                        public void handleMessage(Message msg) {
                            String str = AtFirmvers.this.CLASS_NAME;
                            FtUtil.log_d(str, "tsp2FirmwareUpdateHandler", "msg.what = " + msg.what);
                            if (msg.what == ModuleTouchScreen.TSP_WHAT_STATUS_OK) {
                                FtUtil.log_d(AtFirmvers.this.CLASS_NAME, "tsp2FirmwareUpdateHandler", "TSP_WHAT_STATUS_OK");
                                if (msg.arg1 == ModuleTouchScreen.TSP_ID__FW_UPDATE) {
                                    if (msg.obj.toString().contains("OK")) {
                                        String unused = AtFirmvers.mTSP2UpdateStatus = "PASS";
                                    } else {
                                        String unused2 = AtFirmvers.mTSP2UpdateStatus = "FAIL";
                                    }
                                }
                            } else if (msg.what == ModuleTouchScreen.TSP_WHAT_STATUS_NG) {
                                String unused3 = AtFirmvers.mTSP2UpdateStatus = "FAIL";
                                FtUtil.log_d(AtFirmvers.this.CLASS_NAME, "tsp2FirmwareUpdateHandler", "TSP_WHAT_STATUS_NG");
                            } else if (msg.what == ModuleTouchScreen.TSP_WHAT_STATUS_NA) {
                                FtUtil.log_d(AtFirmvers.this.CLASS_NAME, "tsp2FirmwareUpdateHandler", AtFirmvers.mTSP2UpdateStatus);
                                String unused4 = AtFirmvers.mTSP2UpdateStatus = "FAIL";
                            }
                            FtUtil.log_d(AtFirmvers.this.CLASS_NAME, "tsp2FirmwareUpdateHandler", AtFirmvers.mTSP2UpdateStatus);
                            if (!AtFirmvers.this.TSP_ENABLED.equals(AtFirmvers.this.tspEnabledValue)) {
                                Support.Kernel.writeToPath(AtFirmvers.this.tspEnablePath, "0");
                            }
                            AtCommandHandler.mModuleTouchScreen.getTSPResult(ModuleTouchScreen.TSP_ID__SELECT_TSP, ModuleCommunicationService.SMD_NOK);
                        }
                    };
                    if (mModuleTouchScreen.getTSPResult(ModuleTouchScreen.TSP_ID__FW_UPDATE, "0", this.mTsp2FirmwareUpdateHandler)) {
                        resData = responseOK(argu[0]);
                    } else {
                        resData = responseNG(argu[0]);
                        mTSP2UpdateStatus = "NG";
                    }
                } else {
                    resData = responseNA();
                }
            } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, EgisFingerprint.MAJOR_VERSION, "7"})) {
                int tspDevCount5 = mModuleTouchScreen.getTspDevCount();
                this.tspDevCount = tspDevCount5;
                if (tspDevCount5 > 1) {
                    resData = responseString(argu[0], mTSP2UpdateStatus);
                } else {
                    resData = responseNA();
                }
            } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "2", "8"})) {
                String combinedData = Support.Kernel.read(Support.Kernel.FW_DIGITAL_HALL);
                if (combinedData != null) {
                    resData = responseString(argu[0], combinedData.substring(0, combinedData.indexOf(" ")));
                } else {
                    resData = responseNG(argu[0]);
                }
            } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "2", egis.optical.client.api.EgisFingerprint.JAR_VERSION})) {
                String combinedData2 = Support.Kernel.read(Support.Kernel.FW_DIGITAL_REVERSE_HALL);
                if (combinedData2 != null) {
                    resData = responseString(argu[0], combinedData2.substring(0, combinedData2.indexOf(" ")));
                } else {
                    resData = responseNG(argu[0]);
                }
            } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "2", "A"})) {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", "Read Keyless FW From IC");
                String result5 = readKeylessFW(2001);
                if (TextUtils.isEmpty(result5)) {
                    resData = responseNG(argu[0]);
                } else {
                    resData = responseString(argu[0], result5);
                }
            } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "2", "B"})) {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", "Read Pogo MCU Firmware Version");
                resData = responseString(argu[0], getMcuFirmwareVersion());
            } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "A"})) {
                FtUtil.log_d(this.CLASS_NAME, "handleCommand", "Read Keyless FW From BIN");
                String result6 = readKeylessFW(2002);
                if (TextUtils.isEmpty(result6)) {
                    resData = responseNG(argu[0]);
                } else {
                    resData = responseString(argu[0], result6);
                }
            } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, "8"})) {
                String combinedData3 = Support.Kernel.read(Support.Kernel.FW_DIGITAL_HALL);
                if (combinedData3 != null) {
                    resData = responseString(argu[0], combinedData3.substring(combinedData3.indexOf(" ") + 1));
                } else {
                    resData = responseNG(argu[0]);
                }
            } else if (checkArgu(argu, new String[]{egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.MAJOR_VERSION, egis.optical.client.api.EgisFingerprint.JAR_VERSION})) {
                String combinedData4 = Support.Kernel.read(Support.Kernel.FW_DIGITAL_REVERSE_HALL);
                if (combinedData4 != null) {
                    resData = responseString(argu[0], combinedData4.substring(combinedData4.indexOf(" ") + 1));
                } else {
                    resData = responseNG(argu[0]);
                }
            }
        }
        return resData;
    }

    public void writeTspCmd(String cmd) {
        String str = this.CLASS_NAME;
        FtUtil.log_d(str, "writeTspCmd", "Command = " + cmd);
        BufferedWriter bw = null;
        try {
            bw = new BufferedWriter(new FileWriter("/sys/class/sec/tsp/cmd"));
            bw.write(cmd);
            String str2 = this.CLASS_NAME;
            FtUtil.log_d(str2, "writeTspCmd", "write(" + cmd + ")");
            try {
                bw.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        } catch (Exception e2) {
            FtUtil.log_e(this.CLASS_NAME, "writeTspCmd", e2.getMessage());
            if (bw != null) {
                bw.close();
            }
        } catch (Throwable th) {
            if (bw != null) {
                try {
                    bw.close();
                } catch (IOException e3) {
                    e3.printStackTrace();
                }
            }
            throw th;
        }
    }

    public String readStatus() {
        FtUtil.log_d(this.CLASS_NAME, "readStatus", "***readStatus ()");
        String status = null;
        BufferedReader br = null;
        try {
            br = new BufferedReader(new FileReader("/sys/class/sec/tsp/cmd_status"));
            status = br.readLine();
            String str = this.CLASS_NAME;
            FtUtil.log_d(str, "readStatus", "status = " + status);
            try {
                br.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        } catch (IOException e2) {
            FtUtil.log_e(e2);
            if (br != null) {
                br.close();
            }
        } catch (Throwable th) {
            if (br != null) {
                try {
                    br.close();
                } catch (IOException e3) {
                    e3.printStackTrace();
                }
            }
            throw th;
        }
        return status;
    }

    public String readIDTStatus() {
        String status;
        try {
            status = Support.Kernel.read(Support.Kernel.IDT_OTP_FIRMWARE_UPDATE_STATUS);
        } catch (Exception e) {
            e.printStackTrace();
            status = "FAIL";
        }
        if (status == null || "".equals(status)) {
            return "nostring";
        }
        if ("2".equalsIgnoreCase(status.trim())) {
            return ModuleForceTouch.RUNNING;
        }
        if (EgisFingerprint.MAJOR_VERSION.equalsIgnoreCase(status.trim())) {
            return "PASS";
        }
        if ("0".equalsIgnoreCase(status.trim())) {
            return "FAIL";
        }
        return status;
    }

    public String readResult() {
        FtUtil.log_d(this.CLASS_NAME, "readResult", "***readResult ()");
        String result = null;
        BufferedReader br = null;
        try {
            br = new BufferedReader(new FileReader("/sys/class/sec/tsp/cmd_result"));
            result = br.readLine();
            String str = this.CLASS_NAME;
            FtUtil.log_d(str, "readResult", "result = " + result);
            try {
                br.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        } catch (IOException e2) {
            FtUtil.log_e(e2);
            if (br != null) {
                br.close();
            }
        } catch (Throwable th) {
            if (br != null) {
                try {
                    br.close();
                } catch (IOException e3) {
                    e3.printStackTrace();
                }
            }
            throw th;
        }
        return result;
    }

    private boolean startCameraforFwRead() {
        Camera camera;
        FtUtil.log_d(this.CLASS_NAME, "startCameraforFwRead", "openCameraDevice");
        if (this.mCameraDevice == null) {
            try {
                this.mCameraDevice = Camera.open(0);
                if ("EXYNOS5410".equalsIgnoreCase(Support.Feature.getString(Support.Feature.CHIPSET_NAME)) && (camera = this.mCameraDevice) != null) {
                    camera.startPreview();
                }
            } catch (Exception e) {
                FtUtil.log_e(e);
            }
        }
        if (this.mCameraDevice != null) {
            return true;
        }
        return false;
    }

    private boolean stopCameraforFwRead() {
        FtUtil.log_d(this.CLASS_NAME, "stopCameraforFwRead", "releaseCameraDevice");
        if (this.mCameraDevice == null) {
            return true;
        }
        if ("EXYNOS5410".equalsIgnoreCase(Support.Feature.getString(Support.Feature.CHIPSET_NAME))) {
            this.mCameraDevice.stopPreview();
        }
        this.mCameraDevice.release();
        this.mCameraDevice = null;
        return true;
    }

    private String getGripFWVer(String fwPathId) {
        String ver = Support.Kernel.read(fwPathId);
        if (ver == null) {
            return "" + "NG,";
        }
        return "" + ver + ",";
    }

    private String getMcuFirmwareVersion() {
        String result = Support.Kernel.read(Support.Kernel.POGO_MCU_FIRMWARE_VERSION);
        if (result == null) {
            return "NG";
        }
        return result;
    }

    private boolean isSupportTSK() {
        if (!Support.Kernel.isExistFile(Support.Kernel.TSK_FIRMWARE_UPDATE) || !Support.Kernel.isExistFile(Support.Kernel.TSK_FIRMWARE_VERSION_PANEL) || !Support.Kernel.isExistFile(Support.Kernel.TSK_FIRMWARE_VERSION_PHONE)) {
            FtUtil.log_d(this.CLASS_NAME, "isSupportTSK", "isSupportTSK = false");
            return false;
        }
        FtUtil.log_d(this.CLASS_NAME, "isSupportTSK", "isSupportTSK = true");
        return true;
    }

    public String readKeylessFW(int fwType) {
        if (fwType == 2001) {
            Support.Kernel.write(Support.Kernel.SIDEKEY_COMMAND_CMD, "get_crc_check");
            if ("OK".equals(Support.Kernel.read(Support.Kernel.SIDEKEY_COMMAND_STATUS))) {
                String crcResult = Support.Kernel.read(Support.Kernel.SIDEKEY_COMMAND_RESULT);
                if (crcResult == null || !crcResult.contains("OK")) {
                    FtUtil.log_d(this.CLASS_NAME, "checksumCheck", "CRC Check Fail");
                    return null;
                }
                FtUtil.log_d(this.CLASS_NAME, "checksumCheck", "CRC Check Pass");
                Support.Kernel.write(Support.Kernel.SIDEKEY_COMMAND_CMD, ModuleDevice.TSP_FIRMWARE_VERSION_PANEL);
                if ("OK".equals(Support.Kernel.read(Support.Kernel.SIDEKEY_COMMAND_STATUS))) {
                    String tempResult = Support.Kernel.read(Support.Kernel.SIDEKEY_COMMAND_RESULT);
                    if (tempResult != null && tempResult.contains(ModuleDevice.TSP_FIRMWARE_VERSION_PANEL)) {
                        return tempResult.substring(ModuleDevice.TSP_FIRMWARE_VERSION_PANEL.length() + 1, tempResult.length());
                    }
                    String str = this.CLASS_NAME;
                    FtUtil.log_d(str, "checksumCheck", "Read FW Status Check Fail, readvalue: " + tempResult);
                    return null;
                }
                FtUtil.log_d(this.CLASS_NAME, "checksumCheck", "Read FW Status Check Fail");
                return null;
            }
            FtUtil.log_d(this.CLASS_NAME, "checksumCheck", "CRC Status Check Fail");
            return null;
        } else if (fwType == 2002) {
            Support.Kernel.write(Support.Kernel.SIDEKEY_COMMAND_CMD, ModuleDevice.TSP_FIRMWARE_VERSION_PHONE);
            if ("OK".equals(Support.Kernel.read(Support.Kernel.SIDEKEY_COMMAND_STATUS))) {
                String tempResult2 = Support.Kernel.read(Support.Kernel.SIDEKEY_COMMAND_RESULT);
                if (tempResult2 != null && tempResult2.contains(ModuleDevice.TSP_FIRMWARE_VERSION_PHONE)) {
                    return tempResult2.substring(ModuleDevice.TSP_FIRMWARE_VERSION_PHONE.length() + 1, tempResult2.length());
                }
                String str2 = this.CLASS_NAME;
                FtUtil.log_d(str2, "checksumCheck", "Read FW Status Check Fail, readvalue: " + tempResult2);
                return null;
            }
            FtUtil.log_d(this.CLASS_NAME, "checksumCheck", "Read FW Status Check Fail");
            return null;
        } else {
            FtUtil.log_d(this.CLASS_NAME, "checksumCheck", "Parsing Fail");
            return null;
        }
    }
}
