package com.sec.xmldata.support;

import android.graphics.Point;
import android.graphics.PointF;
import android.os.Environment;
import android.os.SystemProperties;
import com.sec.factory.app.ui.UITSPDrawingSegmentation;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.regex.Pattern;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class Support {
    private static final String CLASS_NAME = "Support";

    public static class Version {
        public static final String FACTORY_TEST_APP = "FACTORY_TEST_APP";
        public static final String FACTORY_TEST_COMMAND = "FACTORY_TEST_COMMAND";
        public static final String TAG = "Version";
        public static final String XML_DOCUMENT = "XML_DOCUMENT";

        public static String getString(String id) {
            return Values.getString(id, "value");
        }
    }

    public static class Feature {
        public static final String ATD_RECONNECT_FROM_SSRM = "ATD_RECONNECT_FROM_SSRM";
        public static final String AUDIO_AMP_TYPE = "AUDIO_AMP_TYPE";
        public static final String AUDIO_PATH_OFF_WHEN_15_LOOPBACK = "AUDIO_PATH_OFF_WHEN_15_LOOPBACK";
        public static final String BATTERY_CHARGE_LIMIT = "BATTERY_CHARGE_LIMIT";
        public static final String BATT_TYPE = "BATT_TYPE";
        public static final String BOOT_CHECK_TOUCHKEY_WO_SVCLED = "BOOT_CHECK_TOUCHKEY_WO_SVCLED";
        public static final String CAL_AP_TEMP = "CAL_AP_TEMP";
        public static final String CHARGER_SUSPEND_MODE_ENABLE = "CHARGER_SUSPEND_MODE_ENABLE";
        public static final String CHIPSET_CP_MANUFACTURE = "CHIPSET_CP_MANUFACTURE";
        public static final String CHIPSET_MANUFACTURE = "CHIPSET_MANUFACTURE";
        public static final String CHIPSET_NAME = "CHIPSET_NAME";
        public static final String CHIPSET_NAME_CP = "CHIPSET_NAME_CP";
        public static final String DEVICE_TYPE = "DEVICE_TYPE";
        public static final String DISABLE_TOUCH_SOUND = "DISABLE_TOUCH_SOUND";
        public static final String DISPLAY_INPUT_CURRENT_VERSION = "DISPLAY_INPUT_CURRENT_VERSION";
        public static final String FACTORY_TEST_MAIN_DIMMING_TIME_OUT = "FACTORY_TEST_MAIN_DIMMING_TIME_OUT";
        public static final String FACTORY_TEST_MAIN_LCD_OFF_TIME_OUT = "FACTORY_TEST_MAIN_LCD_OFF_TIME_OUT";
        public static final String FAILHIST_VERSION = "FAILHIST_VERSION";
        public static final String FEATURE_ENABLE_DYNAMIC_MULTI_SIM = "FEATURE_ENABLE_DYNAMIC_MULTI_SIM";
        public static final String FEATURE_ENABLE_DYNAMIC_NFC = "FEATURE_ENABLE_DYNAMIC_NFC";
        public static final String FONT_SIZE = "FONT_SIZE";
        public static final String FORCE_ENABLE_TSP_SELFTEST = "FORCE_ENABLE_TSP_SELFTEST";
        public static final String FRONT_CAMERA_TYPE = "FRONT_CAMERA_TYPE";
        public static final String FTA_HW_VER = "FTA_HW_VER";
        public static final String FTA_SW_VER = "FTA_SW_VER";
        public static final String GRIPSENSOR_2ND_TYPE = "GRIPSENSOR_2ND_TYPE";
        public static final String GRIPSENSOR_IGNORE_FOR_SMD = "GRIPSENSOR_IGNORE_FOR_SMD";
        public static final String GRIPSENSOR_TYPE = "GRIPSENSOR_TYPE";
        public static final String GRIP_SENSOR_FONT_SIZE = "GRIP_SENSOR_FONT_SIZE";
        public static final String GRIP_TOUCHIC_ENABLE = "GRIP_TOUCHIC_ENABLE";
        public static final String HW_VER_EFS = "HW_VER_EFS";
        public static final String IRLED_CONCEPT = "IRLED_CONCEPT";
        public static final String IS_DUAL_CLOCK_AUDIO = "IS_DUAL_CLOCK_AUDIO";
        public static final String IS_FLICKER_SENSOR_EOL_MODE_USE_FLASH = "IS_FLICKER_SENSOR_EOL_MODE_USE_FLASH";
        public static final String IS_LANDSCAPE_CUTOUT = "IS_LANDSCAPE_CUTOUT";
        public static final String IS_MULTI_SIM_FRAMEWORK = "IS_MULTI_SIM_FRAMEWORK";
        public static final String IS_PROXIMITY_AUTO_CALIBRATION = "IS_PROXIMITY_AUTO_CALIBRATION";
        public static final String IS_RESET_SLPI_FOR_3D_DIGITAL_HALL_CAL = "IS_RESET_SLPI_FOR_3D_DIGITAL_HALL_CAL";
        public static final String IS_TOUCHKEY_GRAPH = "IS_TOUCHKEY_GRAPH";
        public static final String KEYTEST_VOLUME_INDEX = "KEYTEST_VOLUME_INDEX";
        public static final String LCD_TYPE = "LCD_TYPE";
        public static final String LEGACY_MODEL_POLICY_FOR_POS = "LEGACY_MODEL_POLICY_FOR_POS";
        public static final String LOOPTEST_COMMAND_DROP_COUNT = "LOOPTEST_COMMAND_DROP_COUNT";
        public static final String LOOPTEST_COMMAND_DUALMIC_EAR = "LOOPTEST_COMMAND_DUALMIC_EAR";
        public static final String MAGNETIC_ROTATE_DEGREE = "MAGNETIC_ROTATE_DEGREE";
        public static final String MENU_SORT = "MENU_SORT";
        public static final String MIC_COUNT = "MIC_COUNT";
        public static final String MODEL_COMMUNICATION_MODE = "MODEL_COMMUNICATION_MODE";
        public static final String MODEL_NAME = "MODEL_NAME";
        public static final String MODEL_NUMBER = "MODEL_NUMBER";
        public static final String MULTICORE_THERMISTER_CELCIUS_DIVIDER = "MULTICORE_THERMISTER_CELCIUS_DIVIDER";
        public static final String NEED_IMEM_CHECK_DEVICESIZE = "NEED_IMEM_CHECK_DEVICESIZE";
        public static final String NEED_LPA_MODE_SET = "NEED_LPA_MODE_SET";
        public static final String NEED_LPM_MODE_SET = "NEED_LPM_MODE_SET";
        public static final String NEED_NOTI_AUDIO_MANAGER = "NEED_NOTI_AUDIO_MANAGER";
        public static final String NOT_SUPPORT_AUDIO_SOUND_AMP_SPEAKER = "NOT_SUPPORT_AUDIO_SOUND_AMP_SPEAKER";
        public static final String NUMBER_OF_AP_CORE = "NUMBER_OF_AP_CORE";
        public static final String NUMBER_OF_AP_THERMISTOR = "NUMBER_OF_AP_THERMISTOR";
        public static final String PANEL_TYPE = "PANEL_TYPE";
        public static final String PREVENT_ACCESS_TO_ALPM_NODE_WHEN_ENTERING_15TEST = "PREVENT_ACCESS_TO_ALPM_NODE_WHEN_ENTERING_15TEST";
        public static final String PROX_CHECK_INT_SUPPORT = "PROX_CHECK_INT_SUPPORT";
        public static final String PROX_SENSOR_NOT_SUPPORT_ADC = "PROX_SENSOR_NOT_SUPPORT_ADC";
        public static final String RCV_AMP_TYPE = "RCV_AMP_TYPE";
        public static final String REAR_CAMERA_TYPE = "REAR_CAMERA_TYPE";
        public static final String REAR_FLASH_COUNT = "REAR_FLASH_COUNT";
        public static final String SENSOR_NAME_GYROSCOPE = "SENSOR_NAME_GYROSCOPE";
        public static final String SENSOR_NAME_MAGNETIC = "SENSOR_NAME_MAGNETIC";
        public static final String SKIP_TRANSITION_ANIMATION_SCALE = "SKIP_TRANSITION_ANIMATION_SCALE";
        public static final String SPEAKER_COUNT = "SPEAKER_COUNT";
        public static final String SPEAKER_RESOURCE_ADD_6DB = "SPEAKER_RESOURCE_ADD_6DB";
        public static final String SPEN_BLE_CHARGE_VER = "SPEN_BLE_CHARGE_VER";
        public static final String SPEN_BLE_INTERVAL_VER = "SPEN_BLE_INTERVAL_VER";
        public static final String SPK_TEST_CHECK_FINGER_SENSOR_CONNECTION = "SPK_TEST_CHECK_FINGER_SENSOR_CONNECTION";
        public static final String START_TYPE = "START_TYPE";
        public static final String STATUS_BAR_SIZE = "STATUS_BAR_SIZE";
        public static final String SUPPORT_1234_KEYSTR_OLD_CONCEPT = "SUPPORT_1234_KEYSTR_OLD_CONCEPT";
        public static final String SUPPORT_2LINE_STATUS_BAR = "SUPPORT_2LINE_STATUS_BAR";
        public static final String SUPPORT_APCHIP_DATA_EXYNOS = "SUPPORT_APCHIP_DATA_EXYNOS";
        public static final String SUPPORT_AP_EX_THERM_ADC = "SUPPORT_AP_EX_THERM_ADC";
        public static final String SUPPORT_AT_NCAMTEST = "SUPPORT_AT_NCAMTEST";
        public static final String SUPPORT_AUDIO_NEW_NXP = "SUPPORT_AUDIO_NEW_NXP";
        public static final String SUPPORT_AUDIO_NEW_RICHTEK = "SUPPORT_AUDIO_NEW_RICHTEK";
        public static final String SUPPORT_BATT_CHECK_PHASE_1 = "SUPPORT_BATT_CHECK_PHASE_1";
        public static final String SUPPORT_BOOK_COVER = "SUPPORT_BOOK_COVER";
        public static final String SUPPORT_BOOST_MEDIASCAN = "SUPPORT_BOOST_MEDIASCAN";
        public static final String SUPPORT_BT_FINAL_MODE = "SUPPORT_BT_FINAL_MODE";
        public static final String SUPPORT_CABLE_CONNECT_DETECT = "SUPPORT_CABLE_CONNECT_DETECT";
        public static final String SUPPORT_CHECKING_GHOST_TSK = "SUPPORT_CHECKING_GHOST_TSK";
        public static final String SUPPORT_CHECK_SDCARD_TRAY = "SUPPORT_CHECK_SDCARD_TRAY";
        public static final String SUPPORT_CNLABEL_TEST = "SUPPORT_CNLABEL_TEST";
        public static final String SUPPORT_CX_DATA_ALL_DISPLAY = "SUPPORT_CX_DATA_ALL_DISPLAY";
        public static final String SUPPORT_CX_DATA_GAP_DISPLAY = "SUPPORT_CX_DATA_GAP_DISPLAY";
        public static final String SUPPORT_DELAY_PREVOLTAGE_CHECK = "SUPPORT_DELAY_PREVOLTAGE_CHECK";
        public static final String SUPPORT_DISABLE_TSP_DEADZONE = "SUPPORT_DISABLE_TSP_DEADZONE";
        public static final String SUPPORT_DP_PRESENTATION_TEST = "SUPPORT_DP_PRESENTATION_TEST";
        public static final String SUPPORT_DUAL_INTEGRATED_BINARY = "SUPPORT_DUAL_INTEGRATED_BINARY";
        public static final String SUPPORT_DUAL_LCD_FOLDER = "SUPPORT_DUAL_LCD_FOLDER";
        public static final String SUPPORT_ECHO_TEST_JIG_CHECK = "SUPPORT_ECHO_TEST_JIG_CHECK";
        public static final String SUPPORT_ECHO_TEST_JIG_CHECK_PROX = "SUPPORT_ECHO_TEST_JIG_CHECK_PROX";
        public static final String SUPPORT_ECHO_TEST_NOSOUND = "SUPPORT_ECHO_TEST_NOSOUND";
        public static final String SUPPORT_ECHO_TEST_NOSOUND_SET_PATH = "SUPPORT_ECHO_TEST_NOSOUND_SET_PATH";
        public static final String SUPPORT_ENABLE_IRISBTN_IN_AUTOCAL = "SUPPORT_ENABLE_IRISBTN_IN_AUTOCAL";
        public static final String SUPPORT_ENABLE_TSP_DEADZONE = "SUPPORT_ENABLE_TSP_DEADZONE";
        public static final String SUPPORT_EPEN = "SUPPORT_EPEN";
        public static final String SUPPORT_EPEN_INSERT_SYSFS = "SUPPORT_EPEN_INSERT_SYSFS";
        public static final String SUPPORT_EPEN_WITHOUT_INSERT = "SUPPORT_EPEN_WITHOUT_INSERT";
        public static final String SUPPORT_FACTORY_CHARGING_TEST = "SUPPORT_FACTORY_CHARGING_TEST";
        public static final String SUPPORT_FRONT_CAMERA = "SUPPORT_FRONT_CAMERA";
        public static final String SUPPORT_GLOVE_MODE = "SUPPORT_GLOVE_MODE";
        public static final String SUPPORT_GRAPHIC_ACCLETOR = "SUPPORT_GRAPHIC_ACCLETOR";
        public static final String SUPPORT_GRIPSENSOR_TEMP_CAL = "SUPPORT_GRIPSENSOR_TEMP_CAL";
        public static final String SUPPORT_GRIP_SENSOR_FW_UPDATE_INTERNAL = "SUPPORT_GRIP_SENSOR_FW_UPDATE_INTERNAL";
        public static final String SUPPORT_HARDWARE_ACCELERATED = "SUPPORT_HARDWARE_ACCELERATED";
        public static final String SUPPORT_HRM_CONCEPT_ONCE = "SUPPORT_HRM_CONCEPT_ONCE";
        public static final String SUPPORT_HYBRID_DUAL_SOCKET_VERSION = "SUPPORT_HYBRID_DUAL_SOCKET_VERSION";
        public static final String SUPPORT_IDT = "SUPPORT_IDT";
        public static final String SUPPORT_IMAGIS_WET_MODE = "SUPPORT_IMAGIS_WET_MODE";
        public static final String SUPPORT_IN_BATTERY_OCV = "SUPPORT_IN_BATTERY_OCV";
        public static final String SUPPORT_JITTER = "SUPPORT_JITTER";
        public static final String SUPPORT_LCD_FAST_DISCHARGE = "SUPPORT_LCD_FAST_DISCHARGE";
        public static final String SUPPORT_LIGHT_CCT = "SUPPORT_LIGHT_CCT";
        public static final String SUPPORT_LTE = "SUPPORT_LTE";
        public static final String SUPPORT_MARGIN_TOP_FOR_UV_SCREEN_CUT = "SUPPORT_MARGIN_TOP_FOR_UV_SCREEN_CUT";
        public static final String SUPPORT_MULTI_THERMISTOR = "SUPPORT_MULTI_THERMISTOR";
        public static final String SUPPORT_NEW_UI_TOUCHSENSITIVITY = "SUPPORT_NEW_UI_TOUCHSENSITIVITY";
        public static final String SUPPORT_NFC_CHECK_WHEN_ENTER_15 = "SUPPORT_NFC_CHECK_WHEN_ENTER_15";
        public static final String SUPPORT_NO_CHECK_SIM_STATE_CHANGED = "SUPPORT_NO_CHECK_SIM_STATE_CHANGED";
        public static final String SUPPORT_NO_GPIO_SSDS_SIMPLE_VERSION = "SUPPORT_NO_GPIO_SSDS_SIMPLE_VERSION";
        public static final String SUPPORT_NO_READ_SYSFS_MOTOR = "SUPPORT_NO_READ_SYSFS_MOTOR";
        public static final String SUPPORT_OCTA_CORE = "SUPPORT_OCTA_CORE";
        public static final String SUPPORT_OCTA_SPI_SELF_MASK = "SUPPORT_OCTA_SPI_SELF_MASK";
        public static final String SUPPORT_ONE_BINARY_FOR_DYNAMIC_NFC = "SUPPORT_ONE_BINARY_FOR_DYNAMIC_NFC";
        public static final String SUPPORT_ONE_CP_VERSION = "SUPPORT_ONE_CP_VERSION";
        public static final String SUPPORT_ONLY_DS_NOT_MST_SIMPLE_VERSION = "SUPPORT_ONLY_DS_NOT_MST_SIMPLE_VERSION";
        public static final String SUPPORT_ONLY_POWER_KEY = "SUPPORT_ONLY_POWER_KEY";
        public static final String SUPPORT_ORIGINAL_RINGTONE = "SUPPORT_ORIGINAL_RINGTONE";
        public static final String SUPPORT_OUTSIDE_MODE_TEST = "SUPPORT_OUTSIDE_MODE_TEST";
        public static final String SUPPORT_PALM_TOUCH = "SUPPORT_PALM_TOUCH";
        public static final String SUPPORT_PARTIAL_WAKELOCK = "SUPPORT_PARTIAL_WAKELOCK";
        public static final String SUPPORT_PRESSURE_TOUCH = "SUPPORT_PRESSURE_TOUCH";
        public static final String SUPPORT_PREWATERPROOF_TEST = "SUPPORT_PREWATERPROOF_TEST";
        public static final String SUPPORT_QC_HMAC_PROP = "SUPPORT_QC_HMAC_PROP";
        public static final String SUPPORT_RCV_SPK_COMBINANTION = "SUPPORT_RCV_SPK_COMBINANTION";
        public static final String SUPPORT_REALTIME_TYPE_FOR_WIFI = "SUPPORT_REALTIME_TYPE_FOR_WIFI";
        public static final String SUPPORT_REAR_CAMERA = "SUPPORT_REAR_CAMERA";
        public static final String SUPPORT_REAR_CAM_OIS = "SUPPORT_REAR_CAM_OIS";
        public static final String SUPPORT_RUN_REF = "SUPPORT_RUN_REF";
        public static final String SUPPORT_SELF_PRE_DELTA_DISPLAY = "SUPPORT_SELF_PRE_DELTA_DISPLAY";
        public static final String SUPPORT_SENSORHUB = "SUPPORT_SENSORHUB";
        public static final String SUPPORT_SEPARATED_RECORD_PATH = "SUPPORT_SEPARATED_RECORD_PATH";
        public static final String SUPPORT_SERVICE_LED = "SUPPORT_SERVICE_LED";
        public static final String SUPPORT_SKIP_GHOST_TSK = "SUPPORT_SKIP_GHOST_TSK";
        public static final String SUPPORT_SKIP_RID_CHECK = "SUPPORT_SKIP_RID_CHECK";
        public static final String SUPPORT_SPEN_BLE_ACCGYRO = "SUPPORT_SPEN_BLE_ACCGYRO";
        public static final String SUPPORT_SPEN_BLE_BATT34_DYNAMIC_SPEC = "SUPPORT_SPEN_BLE_BATT34_DYNAMIC_SPEC";
        public static final String SUPPORT_SPEN_BLE_COLOR_SELECT_SKIP = "SUPPORT_SPEN_BLE_COLOR_SELECT_SKIP";
        public static final String SUPPORT_SPEN_BLE_CONNECTION_INTERVAL_SKIP = "SUPPORT_SPEN_BLE_CONNECTION_INTERVAL_SKIP";
        public static final String SUPPORT_SPEN_BLE_TEST = "SUPPORT_SPEN_BLE_TEST";
        public static final String SUPPORT_SRS_START_AUTOMATICALLY = "SUPPORT_SRS_START_AUTOMATICALLY";
        public static final String SUPPORT_STATUS_BAR_MARGIN_LR = "SUPPORT_STATUS_BAR_MARGIN_LR";
        public static final String SUPPORT_STATUS_BAR_MARGIN_UD = "SUPPORT_STATUS_BAR_MARGIN_UD";
        public static final String SUPPORT_SUB_ACC = "SUPPORT_SUB_ACC";
        public static final String SUPPORT_SUB_TSK = "SUPPORT_SUB_TSK";
        public static final String SUPPORT_SUB_TSP = "SUPPORT_SUB_TSP";
        public static final String SUPPORT_THIRD_STATUS_BAR = "SUPPORT_THIRD_STATUS_BAR";
        public static final String SUPPORT_TOUCHKEY_CX2_DISPLAY = "SUPPORT_TOUCHKEY_CX2_DISPLAY";
        public static final String SUPPORT_TOUCHKEY_RAW_DATA_DISPLAY = "SUPPORT_TOUCHKEY_RAW_DATA_DISPLAY";
        public static final String SUPPORT_TSK_FW_UPDATE_INTERNAL = "SUPPORT_TSK_FW_UPDATE_INTERNAL";
        public static final String SUPPORT_TSPCAL_APP = "SUPPORT_TSPCAL_APP";
        public static final String SUPPORT_TSPCAL_WHITE = "SUPPORT_TSPCAL_WHITE";
        public static final String SUPPORT_TSP_DATA_RUN_ALL_READ = "SUPPORT_TSP_DATA_RUN_ALL_READ";
        public static final String SUPPORT_TSP_MICRO_SHORT_SKIP = "SUPPORT_TSP_MICRO_SHORT_SKIP";
        public static final String SUPPORT_TSP_OPENSHORT_COMMON_CONCEPT = "SUPPORT_TSP_OPENSHORT_COMMON_CONCEPT";
        public static final String SUPPORT_TSP_PIN_STATE = "SUPPORT_TSP_PIN_STATE";
        public static final String SUPPORT_TSP_SELFTEST_SLOPE = "SUPPORT_TSP_SELFTEST_SLOPE";
        public static final String SUPPORT_UFS = "SUPPORT_UFS";
        public static final String SUPPORT_VIBRATOR = "SUPPORT_VIBRATOR";
        public static final String SUPPORT_VOICE_CALL_FORCIBLY = "SUPPORT_VOICE_CALL_FORCIBLY";
        public static final String SUPPORT_VOLTAGE_CHECK_IN_CHARGING_TEST = "SUPPORT_VOLTAGE_CHECK_IN_CHARGING_TEST";
        public static final String SUPPORT_VOLTAGE_CHECK_IN_PD_CHARGING_TEST = "SUPPORT_VOLTAGE_CHECK_IN_PD_CHARGING_TEST";
        public static final String SUPPORT_WATERPROOF_TEST = "SUPPORT_WATERPROOF_TEST";
        public static final String SUPPORT_WATER_INT_SYSFS = "SUPPORT_WATER_INT_SYSFS";
        public static final String SUPPORT_WTR_IX_DATA_DISPLAY = "SUPPORT_WTR_IX_DATA_DISPLAY";
        public static final String SUPPORT_WTR_SELF_RAW_DISPLAY = "SUPPORT_WTR_SELF_RAW_DISPLAY";
        public static final String SUPPORT_XO_OSC_THERMISTOR = "SUPPORT_XO_OSC_THERMISTOR";
        public static final String SUPPORT_ZINITIX_DND_DIFF_DISPLAY = "SUPPORT_ZINITIX_DND_DIFF_DISPLAY";
        public static final String SUPPORT_ZINITIX_HF_DND_DISPLAY = "SUPPORT_ZINITIX_HF_DND_DISPLAY";
        public static final String SUPPORT_ZINITIX_HF_DND_H_V_GAP_DISPLAY = "SUPPORT_ZINITIX_HF_DND_H_V_GAP_DISPLAY";
        public static final String SUPPORT_ZINITIX_H_V_GAP_DISPLAY = "SUPPORT_ZINITIX_H_V_GAP_DISPLAY";
        public static final String SUPPORT_ZINITIX_SELF_DND = "SUPPORT_ZINITIX_SELF_DND";
        public static final String SUPPORT_ZINITIX_SELF_DND_H_GAP = "SUPPORT_ZINITIX_SELF_DND_H_GAP";
        public static final String SUPPORT_ZINITIX_SELF_DND_TX = "SUPPORT_ZINITIX_SELF_DND_TX";
        public static final String SUPPORT_ZINITIX_SELF_DND_V_GAP = "SUPPORT_ZINITIX_SELF_DND_V_GAP";
        public static final String SUPPORT_ZINITIX_SELF_SATURATION_RX = "SUPPORT_ZINITIX_SELF_SATURATION_RX";
        public static final String SUPPORT_ZINITIX_SELF_SATURATION_TX = "SUPPORT_ZINITIX_SELF_SATURATION_TX";
        public static final String SUPPORT_ZINITIX_TSP_CONNECTION_REFERENCE_VALUE = "SUPPORT_ZINITIX_TSP_CONNECTION_REFERENCE_VALUE";
        public static final String SUPPORT_ZINITIX_TXRX_SHORT_BY_BIT_DISPLAY = "SUPPORT_ZINITIX_TXRX_SHORT_BY_BIT_DISPLAY";
        public static final String SUPPORT_ZINITIX_WET_MODE = "SUPPORT_ZINITIX_WET_MODE";
        public static final String SVC_LED_TEST_BRIGHTNESS = "SVC_LED_TEST_BRIGHTNESS";
        public static final String TABLET_DEFAULT_ORIENTATION = "TABLET_DEFAULT_ORIENTATION";
        public static final String TAG = "Feature";
        public static final String TORCH_MODE_FLASH_1_OFF = "TORCH_MODE_FLASH_1_OFF";
        public static final String TORCH_MODE_FLASH_1_ON = "TORCH_MODE_FLASH_1_ON";
        public static final String TORCH_MODE_FLASH_ON_CURRENT = "TORCH_MODE_FLASH_ON_CURRENT";
        public static final String USE_AFC_SET_VOLTAGE = "USE_AFC_SET_VOLTAGE";
        public static final String USE_CHARGE_MODE = "USE_CHARGE_MODE";
        public static final String USE_DUAL_CHARGE_CHIP = "USE_DUAL_CHARGE_CHIP";
        public static final String USE_DUAL_SENSOR_MAGNETIC = "USE_DUAL_SENSOR_MAGNETIC";
        public static final String USE_MODEL_NUMBER = "USE_MODEL_NUMBER";
        public static final String USE_SYSFS_FOR_SENSOR_NAME = "USE_SYSFS_FOR_SENSOR_NAME";
        public static final String USE_WIRELESS_CHARGE_MODE = "USE_WIRELESS_CHARGE_MODE";

        public static boolean getBoolean(String id) {
            return Values.getBoolean(id, "value");
        }

        public static boolean getBoolean(String id, boolean defaultValue) {
            return Values.getBoolean(id, "value", defaultValue);
        }

        public static byte getByte(String id) {
            return Values.getByte(id, "value");
        }

        public static String getString(String id) {
            return Values.getString(id, "value");
        }

        public static int getInt(String id) {
            return Values.getInt(id, "value");
        }

        public static float getFloat(String id) {
            return Values.getFloat(id, "value");
        }

        public static double getDouble(String id) {
            return Values.getDouble(id, "value");
        }

        public static float getFactoryTextSize() {
            String fontsize = Values.getString(FONT_SIZE, "value");
            XmlUtil.log_d(Support.CLASS_NAME, "getFactoryTextSize", "FONT_SIZE : " + fontsize);
            if (fontsize == null || fontsize.isEmpty() || fontsize == Properties.PROPERTIES_DEFAULT_STRING) {
                return 0.0f;
            }
            return Float.parseFloat(fontsize);
        }
    }

    public static class FactoryTestMenu {
        public static String TAG = "FactoryTestMenu";

        public static String getFactoryTestMenuElemName() {
            String strFactoryTestMenu = TAG;
            if (!Feature.getBoolean(Feature.SUPPORT_DUAL_LCD_FOLDER, false) || XmlUtil.isFolderOpen()) {
                return strFactoryTestMenu;
            }
            return strFactoryTestMenu + "Sub";
        }

        public static String[] getFactoryTestInfo(String XMLRootTAG) {
            TAG = XMLRootTAG;
            return getFactoryTestInfo();
        }

        /* JADX INFO: Multiple debug info for r9v3 org.w3c.dom.Element: [D('items' org.w3c.dom.Element[]), D('item' org.w3c.dom.Element)] */
        public static String[] getFactoryTestInfo() {
            Exception e;
            boolean parent_Enable;
            StringBuilder sb;
            String str;
            String str2;
            String str3;
            String str4;
            String str5;
            ArrayList<String> testList;
            int i;
            String str6;
            boolean parent_Enable2;
            ArrayList<String> group_childList;
            String parent_Name;
            String parent_ID;
            String parent_Order;
            String str7;
            String str8;
            String str9;
            int i2;
            String str10;
            String str11;
            String str12;
            String str13;
            ArrayList<String> group_childList2;
            String parent_Extra;
            String child_ID;
            String child_Extra;
            String str14 = "order";
            String parent_Order2 = "action";
            String parent_Extra2 = ", enable=";
            String parent_ID2 = "enable";
            String parent_Name2 = "name";
            String str15 = "extra";
            Element[] items = XMLDataStorage.instance().getChildElementSet(getFactoryTestMenuElemName());
            ArrayList<String> testList2 = new ArrayList<>();
            ArrayList<String> childList = new ArrayList<>();
            String parent_NV = null;
            String parent_Extra3 = null;
            String parent_Order3 = null;
            String parent_ID3 = null;
            if (items != null) {
                try {
                    int length = items.length;
                    String parent_Name3 = null;
                    int i3 = 0;
                    while (i3 < length) {
                        try {
                            Element item = items[i3];
                            ArrayList<String> group_childList3 = new ArrayList<>();
                            Element item2 = item;
                            try {
                                parent_Enable = Boolean.parseBoolean(item2.getAttribute(parent_ID2));
                                sb = new StringBuilder();
                                sb.append("name=");
                            } catch (Exception e2) {
                                e = e2;
                                e.printStackTrace();
                                return null;
                            }
                            try {
                                sb.append(item2.getAttribute(parent_Name2));
                                sb.append(parent_Extra2);
                                sb.append(parent_Enable);
                                XmlUtil.log_v(Support.CLASS_NAME, "getFact", sb.toString());
                                if (parent_Enable) {
                                    try {
                                        parent_Name3 = item2.getAttribute(parent_Name2);
                                        parent_ID3 = item2.getAttribute(parent_Order2);
                                        if (item2.getAttribute(str15) != null) {
                                            try {
                                                str7 = item2.getAttribute(str15);
                                            } catch (Exception e3) {
                                                e = e3;
                                            }
                                        } else {
                                            str7 = "default";
                                        }
                                        String parent_Extra4 = str7;
                                        try {
                                            String parent_Order4 = item2.getAttribute(str14).isEmpty() ? "9999" : item2.getAttribute(str14);
                                            str6 = str14;
                                            String str16 = "nv";
                                            if (item2.getNodeName().equals("item-group")) {
                                                NodeList childNodes = item2.getChildNodes();
                                                i = i3;
                                                int i4 = 0;
                                                while (true) {
                                                    testList = testList2;
                                                    try {
                                                        if (i4 >= childNodes.getLength()) {
                                                            break;
                                                        }
                                                        Node child = childNodes.item(i4);
                                                        if (child.getNodeType() == 1) {
                                                            boolean child_Enable = Boolean.parseBoolean(((Element) child).getAttribute(parent_ID2));
                                                            if (child_Enable) {
                                                                String child_Name = child.getAttributes().getNamedItem(parent_Name2).getNodeValue();
                                                                str13 = parent_ID2;
                                                                try {
                                                                    child_ID = child.getAttributes().getNamedItem(parent_Order2).getNodeValue();
                                                                    str12 = parent_Order2;
                                                                } catch (Exception e4) {
                                                                    e = e4;
                                                                    e.printStackTrace();
                                                                    return null;
                                                                }
                                                                try {
                                                                    String child_NV = child.getAttributes().getNamedItem(str16).getNodeValue();
                                                                    str11 = parent_Name2;
                                                                    try {
                                                                        str10 = str16;
                                                                        if (((Element) child).getAttribute(str15) != null) {
                                                                            try {
                                                                                StringBuilder sb2 = new StringBuilder();
                                                                                i2 = i4;
                                                                                sb2.append(((Element) child).getAttribute(str15));
                                                                                sb2.append("|invisibility");
                                                                                child_Extra = sb2.toString();
                                                                            } catch (Exception e5) {
                                                                                e = e5;
                                                                            }
                                                                        } else {
                                                                            i2 = i4;
                                                                            child_Extra = "invisibility";
                                                                        }
                                                                        str9 = str15;
                                                                        try {
                                                                            XmlUtil.log_v(Support.CLASS_NAME, "getFact", "name=" + child_Name + parent_Extra2 + child_Enable);
                                                                            str8 = parent_Extra2;
                                                                            parent_Extra = parent_Extra4;
                                                                        } catch (Exception e6) {
                                                                            e = e6;
                                                                            e.printStackTrace();
                                                                            return null;
                                                                        }
                                                                    } catch (Exception e7) {
                                                                        e = e7;
                                                                        e.printStackTrace();
                                                                        return null;
                                                                    }
                                                                    try {
                                                                        if (parent_Extra.contains("group")) {
                                                                            group_childList2 = group_childList3;
                                                                            group_childList2.add(child_ID + "," + child_Name + "," + child_NV + "," + child_Extra.replace("|invisibility", "") + "," + parent_ID3 + ",null,");
                                                                        } else {
                                                                            group_childList2 = group_childList3;
                                                                            childList.add(child_ID + "," + child_Name + "," + child_NV + "," + child_Extra + "," + parent_ID3 + ",null,");
                                                                        }
                                                                    } catch (Exception e8) {
                                                                        e = e8;
                                                                        e.printStackTrace();
                                                                        return null;
                                                                    }
                                                                } catch (Exception e9) {
                                                                    e = e9;
                                                                    e.printStackTrace();
                                                                    return null;
                                                                }
                                                            } else {
                                                                str12 = parent_Order2;
                                                                str8 = parent_Extra2;
                                                                str13 = parent_ID2;
                                                                str11 = parent_Name2;
                                                                str9 = str15;
                                                                i2 = i4;
                                                                str10 = str16;
                                                                group_childList2 = group_childList3;
                                                                parent_Extra = parent_Extra4;
                                                            }
                                                        } else {
                                                            str12 = parent_Order2;
                                                            str8 = parent_Extra2;
                                                            str13 = parent_ID2;
                                                            str11 = parent_Name2;
                                                            str9 = str15;
                                                            i2 = i4;
                                                            str10 = str16;
                                                            group_childList2 = group_childList3;
                                                            parent_Extra = parent_Extra4;
                                                        }
                                                        i4 = i2 + 1;
                                                        parent_Extra4 = parent_Extra;
                                                        group_childList3 = group_childList2;
                                                        testList2 = testList;
                                                        childNodes = childNodes;
                                                        item2 = item2;
                                                        parent_ID2 = str13;
                                                        parent_Order2 = str12;
                                                        parent_Name2 = str11;
                                                        str16 = str10;
                                                        str15 = str9;
                                                        parent_Extra2 = str8;
                                                    } catch (Exception e10) {
                                                        e = e10;
                                                        e.printStackTrace();
                                                        return null;
                                                    }
                                                }
                                                str4 = parent_Order2;
                                                str = parent_Extra2;
                                                str5 = parent_ID2;
                                                str3 = parent_Name2;
                                                str2 = str15;
                                                group_childList = group_childList3;
                                                parent_Extra2 = parent_Extra4;
                                                try {
                                                    if (!childList.isEmpty() || !group_childList.isEmpty()) {
                                                        parent_Enable2 = parent_Enable;
                                                    } else {
                                                        parent_Enable2 = false;
                                                    }
                                                    parent_Order = parent_Order4;
                                                    parent_ID = parent_ID3;
                                                    parent_Name = parent_Name3;
                                                    parent_NV = "0x1F4";
                                                } catch (Exception e11) {
                                                    e = e11;
                                                    e.printStackTrace();
                                                    return null;
                                                }
                                            } else {
                                                str4 = parent_Order2;
                                                str = parent_Extra2;
                                                str5 = parent_ID2;
                                                str3 = parent_Name2;
                                                str2 = str15;
                                                testList = testList2;
                                                i = i3;
                                                group_childList = group_childList3;
                                                parent_Extra2 = parent_Extra4;
                                                parent_NV = item2.getAttribute(str16);
                                                parent_Order = parent_Order4;
                                                parent_ID = parent_ID3;
                                                parent_Name = parent_Name3;
                                                parent_Enable2 = parent_Enable;
                                            }
                                        } catch (Exception e12) {
                                            e = e12;
                                            e.printStackTrace();
                                            return null;
                                        }
                                    } catch (Exception e13) {
                                        e = e13;
                                        e.printStackTrace();
                                        return null;
                                    }
                                } else {
                                    str6 = str14;
                                    str4 = parent_Order2;
                                    str = parent_Extra2;
                                    str5 = parent_ID2;
                                    str3 = parent_Name2;
                                    str2 = str15;
                                    testList = testList2;
                                    i = i3;
                                    group_childList = group_childList3;
                                    parent_Order = parent_Order3;
                                    parent_ID = parent_ID3;
                                    parent_Name = parent_Name3;
                                    parent_Extra2 = parent_Extra3;
                                    parent_NV = parent_NV;
                                    parent_Enable2 = parent_Enable;
                                }
                                if (parent_Enable2) {
                                    try {
                                        testList2 = testList;
                                        try {
                                            testList2.add(parent_ID + "," + parent_Name + "," + parent_NV + "," + parent_Extra2 + ",null," + parent_Order + ",");
                                        } catch (Exception e14) {
                                            e = e14;
                                            e.printStackTrace();
                                            return null;
                                        }
                                    } catch (Exception e15) {
                                        e = e15;
                                        e.printStackTrace();
                                        return null;
                                    }
                                } else {
                                    testList2 = testList;
                                }
                                if (!group_childList.isEmpty()) {
                                    testList2.addAll(group_childList);
                                }
                                i3 = i + 1;
                                parent_Order3 = parent_Order;
                                parent_Extra3 = parent_Extra2;
                                parent_ID3 = parent_ID;
                                parent_Name3 = parent_Name;
                                items = items;
                                length = length;
                                str14 = str6;
                                parent_ID2 = str5;
                                parent_Order2 = str4;
                                parent_Name2 = str3;
                                str15 = str2;
                                parent_Extra2 = str;
                            } catch (Exception e16) {
                                e = e16;
                                e.printStackTrace();
                                return null;
                            }
                        } catch (Exception e17) {
                            e = e17;
                            e.printStackTrace();
                            return null;
                        }
                    }
                } catch (Exception e18) {
                    e = e18;
                    e.printStackTrace();
                    return null;
                }
            }
            try {
                testList2.addAll(childList);
                return (String[]) testList2.toArray(new String[0]);
            } catch (Exception e19) {
                e = e19;
                e.printStackTrace();
                return null;
            }
        }

        public static boolean isExistFactoryTestItem(String action) {
            return getFactoryTestName(action, "dummy") == null;
        }

        public static String getFactoryTestName(String field, String value) {
            String name = XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), field, value, "name");
            XmlUtil.log_d(Support.CLASS_NAME, "FactoryTestMenu.getFactoryTestName", "name=" + name);
            return name;
        }

        public static String getEnable(String action) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, "enable");
        }

        public static String getEnableForAllMenu(String action) {
            return String.valueOf("true".equals(XMLDataStorage.instance().getAttributeValueByAttributeOnTarget("FactoryTestMenu", "action", action, "enable")) || "true".equals(XMLDataStorage.instance().getAttributeValueByAttributeOnTarget("FactoryTestMenuSub", "action", action, "enable")));
        }

        public static String getTestItemNv(String action) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, "nv");
        }

        public static String getTestCase(String action) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, "testcase");
        }

        public static String getTestName(String action) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, "testname");
        }

        public static String getOrientation(String action) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, "orientation");
        }

        public static float getUIRate(String action) {
            String rate = XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, "uirate");
            if (rate == null || rate.isEmpty()) {
                return 0.0f;
            }
            return Float.parseFloat(rate);
        }

        public static int getLogLevel(String action) {
            String level = XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, "loglevel");
            if (level == null || level.isEmpty()) {
                return 1;
            }
            return Integer.parseInt(level);
        }

        public static String getGammaPath(String action) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, "gammapath");
        }

        public static String getKeywordPath(String action) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, "keywordpath");
        }

        public static String getSupportMatrix(String action) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, UITSPDrawingSegmentation.Options.TAG_SUPPORT_MATRIX);
        }

        public static String getMargin(String action) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, UITSPDrawingSegmentation.Options.TAG_MATRIX_DEAD_ZONE);
        }

        public static String getOuterRect(String action) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, UITSPDrawingSegmentation.Options.TAG_OUTER_RECT);
        }

        public static String getCrossRect(String action) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, UITSPDrawingSegmentation.Options.TAG_CROSS_RECT);
        }

        public static String getSupportDevice(String action) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, UITSPDrawingSegmentation.Options.TAG_SUPPORT_DEVICE);
        }

        public static String getSpec(String action) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", action, "spec");
        }

        public static String getExtra(int itemId) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", String.valueOf(itemId), "extra");
        }

        public static String getExtra(String itemId) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", itemId, "extra");
        }

        public static String getCount(int itemId) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", String.valueOf(itemId), "count");
        }

        public static String getAudioPath(String itemId) {
            return XMLDataStorage.instance().getAttributeValueByAttributeOnTarget(getFactoryTestMenuElemName(), "action", itemId, "audioPath");
        }
    }

    public static class HwTestMenu {
        public static final String HALL_IC_TEST = "25";
        public static final String HDMI_TYPE = "18";
        public static final int ID_GRIP = 15;
        public static final int ID_TSP_HOVERING = 26;
        public static final String LCD_TEST_FRONT_CAM = "06";
        public static final String LCD_TEST_GRIP = "15";
        public static final String LCD_TEST_TOUCH = "04";
        public static final String LCD_TEST_TOUCH_2 = "27";
        public static final String SPEN_TEST = "35";
        public static final String SUB_LCD_TEST_TOUCH = "49";
        public static final String TAG = "HwTestMenu";

        public static String[] getTestMenu() {
            String parent_Extra;
            Element[] items = XMLDataStorage.instance().getChildElementSet(TAG);
            ArrayList<String> testList = new ArrayList<>();
            for (Element item : items) {
                boolean parent_Enable = Boolean.parseBoolean(item.getAttribute("enable"));
                XmlUtil.log_v(Support.CLASS_NAME, "getFact", "name=" + item.getAttribute("name") + ", enable=" + parent_Enable);
                if (parent_Enable) {
                    String parent_Name = item.getAttribute("name");
                    String parent_ID = item.getAttribute("action");
                    if (item.getAttribute("extra") != null) {
                        parent_Extra = item.getAttribute("extra");
                    } else {
                        parent_Extra = "default";
                    }
                    if (Integer.parseInt(parent_ID) != 15) {
                        testList.add(parent_ID + "," + parent_Name + "," + parent_Extra + ",null");
                    } else if (checkHwRevision()) {
                        testList.add(parent_ID + "," + parent_Name + "," + parent_Extra + ",null");
                    }
                }
            }
            return (String[]) testList.toArray(new String[0]);
        }

        private static boolean checkHwRevision() {
            XmlUtil.log_v(Support.CLASS_NAME, "checkHwRevision", "");
            if (!"SM-N910V".equals(Feature.getString(Feature.MODEL_NAME))) {
                return true;
            }
            int hwRev = Integer.parseInt(SystemProperties.get("ro.revision"));
            XmlUtil.log_v(Support.CLASS_NAME, "checkHwRevision", "ro.revision=" + hwRev);
            if (hwRev < 13) {
                return false;
            }
            return true;
        }

        public static String getTestCase(String action) {
            String result = null;
            Element[] items = XMLDataStorage.instance().getChildElementSet(TAG);
            for (Element item : items) {
                if (action.equals(item.getAttribute("action"))) {
                    result = item.getAttribute("testcase");
                    XmlUtil.log_v(Support.CLASS_NAME, "getTestCase", "action =" + action + ", testcase =" + result);
                }
            }
            return result;
        }

        public static String getEnabled(int id) {
            String result = null;
            Element[] items = XMLDataStorage.instance().getChildElementSet(TAG);
            for (Element item : items) {
                if (Integer.toString(id).equals(item.getAttribute("action"))) {
                    result = item.getAttribute("enable");
                    XmlUtil.log_v(Support.CLASS_NAME, "getEnabled", "action =" + Integer.toString(id) + ", enable =" + result);
                }
            }
            return result;
        }

        public static float getUIRate(int action) {
            String rate = null;
            Element[] items = XMLDataStorage.instance().getChildElementSet(TAG);
            for (Element item : items) {
                if (String.format("%02d", Integer.valueOf(action)).equals(item.getAttribute("action"))) {
                    rate = item.getAttribute("uirate");
                    XmlUtil.log_v(Support.CLASS_NAME, "getUIRate", "action =" + String.format("%02d", Integer.valueOf(action)) + ", uirate = " + rate);
                }
            }
            if (rate == null || rate.isEmpty()) {
                return 0.0f;
            }
            return Float.parseFloat(rate);
        }
    }

    public static class SensorTestMenu {
        public static final String NAME_LIGHT_LUX = "Light_LUX";
        public static final String SENSOR_TEST_NAME_HRM = "HRM";
        public static final String TAG = "SensorTestMenu";

        public static String[] getSensorTest() {
            String parent_Testcase;
            Element[] items = XMLDataStorage.instance().getChildElementSet(TAG);
            ArrayList<String> testList = new ArrayList<>();
            for (Element item : items) {
                boolean parent_Enable = Boolean.parseBoolean(item.getAttribute("enable"));
                XmlUtil.log_v(Support.CLASS_NAME, "getFact", "name=" + item.getAttribute("name") + ", enable=" + parent_Enable);
                if (parent_Enable) {
                    String parent_Name = item.getAttribute("name");
                    String parent_ID = item.getAttribute("action");
                    if (item.getAttribute("testcase") != null) {
                        parent_Testcase = item.getAttribute("testcase");
                    } else {
                        parent_Testcase = "default";
                    }
                    testList.add(parent_ID + "," + parent_Name + "," + parent_Testcase + ",null");
                }
            }
            return (String[]) testList.toArray(new String[0]);
        }

        public static String getTestCase(String name) {
            String result = null;
            Element[] items = XMLDataStorage.instance().getChildElementSet(TAG);
            for (Element item : items) {
                if (name.equals(item.getAttribute("name"))) {
                    result = item.getAttribute("testcase");
                    XmlUtil.log_v(Support.CLASS_NAME, "getTestCase", "name =" + name + ", testcase =" + result);
                }
            }
            return result;
        }

        public static String getEnabled(String name) {
            String result = null;
            Element[] items = XMLDataStorage.instance().getChildElementSet(TAG);
            for (Element item : items) {
                if (name.equals(item.getAttribute("name"))) {
                    result = item.getAttribute("enable");
                    XmlUtil.log_v(Support.CLASS_NAME, "getEnabled", "name =" + name + ", enable =" + result);
                }
            }
            return result;
        }

        public static float getUIRate(String name) {
            String rate = null;
            Element[] items = XMLDataStorage.instance().getChildElementSet(HwTestMenu.TAG);
            for (Element item : items) {
                if (name.equals(item.getAttribute("name"))) {
                    rate = item.getAttribute("uirate");
                    XmlUtil.log_v(Support.CLASS_NAME, "getUIRate", "name =" + name + ", uirate = " + rate);
                }
            }
            if (rate == null || rate.isEmpty()) {
                return 1.0f;
            }
            return Float.parseFloat(rate);
        }
    }

    public static class TestCase {
        public static final String ACCELEROMETER_FULL_SCALE = "ACCELEROMETER_FULL_SCALE";
        public static final String ACCSENSOR_DATA_RANGE = "ACCSENSOR_DATA_RANGE";
        public static final String AT_BATTEST_RESET_WHEN_READ = "AT_BATTEST_RESET_WHEN_READ";
        public static final String AT_CALIDATE = "AT_CALIDATE";
        public static final String AT_GPSSTEST = "AT_GPSSTEST";
        public static final String AT_HMACMISM = "AT_HMACMISM";
        public static final String AT_ISDBTEST = "AT_ISDBTEST";
        public static final String AUDIO_AMP_VALIDATION_OPTION = "AUDIO_AMP_VALIDATION_OPTION";
        public static final String AUDIO_RCV_AMP_VALIDATION_OPTION = "AUDIO_RCV_AMP_VALIDATION_OPTION";
        public static final String CAMERA_TORCH_MODE_RESPONSE_MARGINE = "CAMERA_TORCH_MODE_RESPONSE_MARGINE";
        public static final String CCIC_LPM_MODE_ENABLE_VALUE = "CCIC_LPM_MODE_ENABLE_VALUE";
        public static final String CROSSTALK_VALUE_DIRECTION = "CROSSTALK_VALUE_DIRECTION";
        public static final String DELAY_BEFORE_ECHO_TEST = "DELAY_BEFORE_ECHO_TEST";
        public static final String FINGERPRINT_TEST_BRIGHTNESS = "FINGERPRINT_TEST_BRIGHTNESS";
        public static final String FORCE_TOUCH_CAL_APPLY_WEIGHT = "FORCE_TOUCH_CAL_APPLY_WEIGHT";
        public static final String FORCE_TOUCH_CAL_EXCLUDE_MIN_MAX_VALUE = "FORCE_TOUCH_CAL_EXCLUDE_MIN_MAX_VALUE";
        public static final String FORCE_TOUCH_CAL_EXCLUDE_PEAK_VALUE = "FORCE_TOUCH_CAL_EXCLUDE_PEAK_VALUE";
        public static final String FORCE_TOUCH_CAL_STRENGTH_READ_COUNT = "FORCE_TOUCH_CAL_STRENGTH_READ_COUNT";
        public static final String FORCE_TOUCH_CAL_TEST_COUNT = "FORCE_TOUCH_CAL_TEST_COUNT";
        public static final String FORCE_TOUCH_DELAY_FOR_MEASUREMENT = "FORCE_TOUCH_DELAY_FOR_MEASUREMENT";
        public static final String FORCE_TOUCH_MAKE_OPEN_SPEC = "FORCE_TOUCH_MAKE_OPEN_SPEC";
        public static final String FORCE_TOUCH_PRESS_STRENGTH_READ_COUNT = "FORCE_TOUCH_PRESS_STRENGTH_READ_COUNT";
        public static final String FORCE_TOUCH_SELF_TEST_CHANNEL = "FORCE_TOUCH_SELF_TEST_CHANNEL";
        public static final String FORCE_TOUCH_TEST_CENTER = "FORCE_TOUCH_TEST_CENTER";
        public static final String FORCE_TOUCH_TEST_LEFT = "FORCE_TOUCH_TEST_LEFT";
        public static final String FORCE_TOUCH_TEST_RIGHT = "FORCE_TOUCH_TEST_RIGHT";
        public static final String FORCE_TOUCH_USING_UNIT_MM = "FORCE_TOUCH_USING_UNIT_MM";
        public static final String GEOMAGNETIC_ALPS_CAL_DELTA_SPEC = "GEOMAGNETIC_ALPS_CAL_DELTA_SPEC";
        public static final String GEOMAGNETIC_IC_POINT = "GEOMAGNETIC_IC_POINT";
        public static final String GESTURE_SENSOR_IR_CURRENT_CHANGE = "GESTURE_SENSOR_IR_CURRENT_CHANGE";
        public static final String GESTURE_SENSOR_PEEK_TO_PEEK = "GESTURE_SENSOR_PEEK_TO_PEEK";
        public static final String GRIPSENSOR_GRIP_COUNT = "GRIPSENSOR_GRIP_COUNT";
        public static final String HALLIC_TEST_EXIT_BUTTON_GRAVITY = "HALLIC_TEST_EXIT_BUTTON_GRAVITY";
        public static final String HALLIC_TEST_MILLIS_SEC = "HALLIC_TEST_MILLIS_SEC";
        public static final String HALLLESS_TEST_MILLIS_SEC = "HALLLESS_TEST_MILLIS_SEC";
        public static final String HALL_IC_TEST = "HALL_IC_TEST";
        public static final String HALL_IC_TEST_2ND = "HALL_IC_TEST_2ND";
        public static final String HALL_IC_TEST_3RD = "HALL_IC_TEST_3RD";
        public static final String HALL_IC_TEST_4TH = "HALL_IC_TEST_4TH";
        public static final String HUMITEMP_TEST = "HUMITEMP_TEST";
        public static final String HV_CHARGE = "HV_CHARGE";
        public static final String INTERVAL_FOR_ACC_SENSOR_FLATNESS = "INTERVAL_FOR_ACC_SENSOR_FLATNESS";
        public static final String IN_DISPLAY_FINGERPRINT_AREA = "IN_DISPLAY_FINGERPRINT_AREA";
        public static final String IN_DISPLAY_FINGERPRINT_MSG = "IN_DISPLAY_FINGERPRINT_MSG";
        public static final String IS_ASAHI_USING_SYSFS = "IS_ASAHI_USING_SYSFS";
        public static final String IS_BACKLIGHT_ON_FOR_GREEN_LCD = "IS_BACKLIGHT_ON_FOR_GREEN_LCD";
        public static final String IS_CM_GAP_TX_RX = "IS_CM_GAP_TX_RX";
        public static final String IS_CP_LPM_CHECK = "IS_CP_LPM_CHECK";
        public static final String IS_CP_SHORT_CHECK = "IS_CP_SHORT_CHECK";
        public static final String IS_CR_CHECK = "IS_CR_CHECK";
        public static final String IS_DISPLAY_LIGHT_SENSOR_ADC_ONLY = "IS_DISPLAY_LIGHT_SENSOR_ADC_ONLY";
        public static final String IS_DISPLAY_LIGHT_SENSOR_SLOW = "IS_DISPLAY_LIGHT_SENSOR_SLOW";
        public static final String IS_DISPLAY_LUX_ADC = "IS_DISPLAY_LUX_ADC";
        public static final String IS_HIDDEN_TOUCHKEY = "IS_HIDDEN_TOUCHKEY";
        public static final String IS_HVDD_CHECK = "IS_HVDD_CHECK";
        public static final String IS_INNER_OUTER_TOUCHKEY_KEYSTRING = "IS_INNER_OUTER_TOUCHKEY_KEYSTRING";
        public static final String IS_IRLED_TEST_SPLIT_COMMAND = "IS_IRLED_TEST_SPLIT_COMMAND";
        public static final String IS_KEY_TEST_THRESHOLD = "IS_KEY_TEST_THRESHOLD";
        public static final String IS_MIS_CALIBRATION_CHECK = "IS_MIS_CALIBRATION_CHECK";
        public static final String IS_NEW_TSP_SELFTEST_SYNAPTICS = "IS_NEW_TSP_SELFTEST_SYNAPTICS";
        public static final String IS_NEW_TSP_SELFTEST_ZINITIX = "IS_NEW_TSP_SELFTEST_ZINITIX";
        public static final String IS_NEW_TSP_SELFTEST_ZINITIX_GF1 = "IS_NEW_TSP_SELFTEST_ZINITIX_GF1";
        public static final String IS_PROXIMITY_TEST_MOTOR_FEEDBACK = "IS_PROXIMITY_TEST_MOTOR_FEEDBACK";
        public static final String IS_RUN_CALIBRATION = "IS_RUN_CALIBRATION";
        public static final String IS_SENSOR_TEST_ACC_REVERSE = "IS_SENSOR_TEST_ACC_REVERSE";
        public static final String IS_TSP_CM_RATIO = "IS_TSP_CM_RATIO";
        public static final String IS_TSP_HOVERING_TEST_SET_EDGE_DEADLOCK = "IS_TSP_HOVERING_TEST_SET_EDGE_DEADLOCK";
        public static final String IS_TSP_SECOND_LCD_TEST = "IS_TSP_SECOND_LCD_TEST";
        public static final String IS_TSP_SEC_CM_OFFSET_GAP_GREAT_STYLE = "IS_TSP_SEC_CM_OFFSET_GAP_GREAT_STYLE";
        public static final String IS_TSP_SEC_CM_SPEC_OVER = "IS_TSP_SEC_CM_SPEC_OVER";
        public static final String IS_TSP_SEC_SPLIT_CORNER = "IS_TSP_SEC_SPLIT_CORNER";
        public static final String IS_TSP_SEC_UB_CROSS_ROUTING_PORTRAIT = "IS_TSP_SEC_UB_CROSS_ROUTING_PORTRAIT";
        public static final String IS_TSP_SELFTEST_SEC = "IS_TSP_SELFTEST_SEC";
        public static final String IS_TSP_SELFTEST_ZINITIX_H_V_GAP_KEY = "IS_TSP_SELFTEST_ZINITIX_H_V_GAP_KEY";
        public static final String IS_TSP_STANDARD_CHANNEL = "IS_TSP_STANDARD_CHANNEL";
        public static final String IS_TX_RX_SELF_CR = "IS_TX_RX_SELF_CR";
        public static final String IS_USING_SENSOR_MANAGER_IN_POWER_NOISE = "IS_USING_SENSOR_MANAGER_IN_POWER_NOISE";
        public static final String IS_VIBETONZ_UNSUPPORTED = "IS_VIBETONZ_UNSUPPORTED";
        public static final String IS_VIBETONZ_UNSUPPORTED_HW = "IS_VIBETONZ_UNSUPPORTED_HW";
        public static final int KEYCODE_END = 6;
        public static final String KEY_TEST_0 = "KEY_TEST_0";
        public static final String KEY_TEST_1 = "KEY_TEST_1";
        public static final String KEY_TEST_2 = "KEY_TEST_2";
        public static final String KEY_TEST_3 = "KEY_TEST_3";
        public static final String KEY_TEST_4 = "KEY_TEST_4";
        public static final String KEY_TEST_5 = "KEY_TEST_5";
        public static final String KEY_TEST_6 = "KEY_TEST_6";
        public static final String KEY_TEST_7 = "KEY_TEST_7";
        public static final String KEY_TEST_8 = "KEY_TEST_8";
        public static final String KEY_TEST_9 = "KEY_TEST_9";
        public static final String KEY_TEST_APP_RECENT = "KEY_TEST_APP_RECENT";
        public static final String KEY_TEST_APP_SELECT = "KEY_TEST_APP_SELECT";
        public static final String KEY_TEST_APP_SWITCH = "KEY_TEST_APP_SWITCH";
        public static final String KEY_TEST_BACK = "KEY_TEST_BACK";
        public static final String KEY_TEST_BEAM = "KEY_TEST_BEAM";
        public static final String KEY_TEST_BUTTON_SPACE = "KEY_TEST_BUTTON_SPACE";
        public static final String KEY_TEST_CALL = "KEY_TEST_CALL";
        public static final String KEY_TEST_CAMERA = "KEY_TEST_CAMERA";
        public static final String KEY_TEST_CONTACTS = "KEY_TEST_CONTACTS";
        public static final String KEY_TEST_DEL = "KEY_TEST_DEL";
        public static final String KEY_TEST_DPAD_CENTER = "KEY_TEST_DPAD_CENTER";
        public static final String KEY_TEST_DPAD_DOWN = "KEY_TEST_DPAD_DOWN";
        public static final String KEY_TEST_DPAD_LEFT = "KEY_TEST_DPAD_LEFT";
        public static final String KEY_TEST_DPAD_RIGHT = "KEY_TEST_DPAD_RIGHT";
        public static final String KEY_TEST_DPAD_UP = "KEY_TEST_DPAD_UP";
        public static final String KEY_TEST_EMERGENCY = "KEY_TEST_EMERGENCY";
        public static final String KEY_TEST_END = "KEY_TEST_END";
        public static final String KEY_TEST_F1 = "KEY_TEST_F1";
        public static final String KEY_TEST_FOCUS = "KEY_TEST_FOCUS";
        public static final String KEY_TEST_HIDDEN_1 = "KEY_TEST_HIDDEN_1";
        public static final String KEY_TEST_HIDDEN_2 = "KEY_TEST_HIDDEN_2";
        public static final String KEY_TEST_HIDDEN_3 = "KEY_TEST_HIDDEN_3";
        public static final String KEY_TEST_HIDDEN_4 = "KEY_TEST_HIDDEN_4";
        public static final String KEY_TEST_HOME = "KEY_TEST_HOME";
        public static final String KEY_TEST_INTELLI = "KEY_TEST_INTELLI";
        public static final String KEY_TEST_MEDIA = "KEY_TEST_MEDIA";
        public static final String KEY_TEST_MENU = "KEY_TEST_MENU";
        public static final String KEY_TEST_MESSAGE = "KEY_TEST_MESSAGE";
        public static final String KEY_TEST_MUTE = "KEY_TEST_MUTE";
        public static final String KEY_TEST_NETWOR_SEL = "KEY_TEST_NETWOR_SEL";
        public static final String KEY_TEST_POUND = "KEY_TEST_POUND";
        public static final String KEY_TEST_POWER = "KEY_TEST_POWER";
        public static final String KEY_TEST_REFERENCE1 = "KEY_TEST_REFERENCE1";
        public static final String KEY_TEST_REFERENCE2 = "KEY_TEST_REFERENCE2";
        public static final String KEY_TEST_SEARCH = "KEY_TEST_SEARCH";
        public static final String KEY_TEST_STAR = "KEY_TEST_STAR";
        public static final String KEY_TEST_SUB_APP_RECENT = "KEY_TEST_SUB_APP_RECENT";
        public static final String KEY_TEST_SUB_BACK = "KEY_TEST_SUB_BACK";
        public static final String KEY_TEST_TEXT_SIZE = "KEY_TEST_TEXT_SIZE";
        public static final String KEY_TEST_TOUCH_KEY_ODER = "KEY_TEST_TOUCH_KEY_ODER";
        public static final String KEY_TEST_TOUCH_KEY_ODER_HIDDEN = "KEY_TEST_TOUCH_KEY_ODER_HIDDEN";
        public static final String KEY_TEST_USER = "KEY_TEST_USER";
        public static final String KEY_TEST_VIEW_TABLE = "KEY_TEST_VIEW_TABLE";
        public static final String KEY_TEST_VOLUME_DOWN = "KEY_TEST_VOLUME_DOWN";
        public static final String KEY_TEST_VOLUME_UP = "KEY_TEST_VOLUME_UP";
        public static final String LATIN_CSC_CASE = "LATIN_CSC_CASE";
        public static final String LOAD_CHARGE = "LOAD_CHARGE";
        public static final String LPA_MODE_DISABLE_VALUE = "LPA_MODE_DISABLE_VALUE";
        public static final String LPA_MODE_ENABLE_VALUE = "LPA_MODE_ENABLE_VALUE";
        public static final String LPM_MODE_DISABLE_VALUE = "LPM_MODE_DISABLE_VALUE";
        public static final String MAGNETIC_POWERNOISE_GRAPH_Y_RANGE = "MAGNETIC_POWERNOISE_GRAPH_Y_RANGE";
        public static final String MIS_CALIBRATION_CHECK_SPEC = "MIS_CALIBRATION_CHECK_SPEC";
        public static final String MOBILE_TV_TYPE = "MOBILE_TV_TYPE";
        public static final String MOTOR_SPEC = "MOTOR_SPEC";
        public static final String NEED_POWER_POLICY_ENABLE = "NEED_POWER_POLICY_ENABLE";
        public static final String NFC_CARD_MODE_UI_NOT_USE = "NFC_CARD_MODE_UI_NOT_USE";
        public static final String NFC_TYPE_B_TEST_ITEM = "NFC_TYPE_B_TEST_ITEM";
        public static final String OTG2 = "OTG2";
        public static final String OTG3 = "OTG3";
        public static final String PA0_TEMP_ADC = "PA0_TEMP_ADC";
        public static final String PA0_THERMISTER_CELCIUS_DIVIDER = "PA0_THERMISTER_CELCIUS_DIVIDER";
        public static final String PA1_TEMP_ADC = "PA1_TEMP_ADC";
        public static final String PA1_THERMISTER_CELCIUS_DIVIDER = "PA1_THERMISTER_CELCIUS_DIVIDER";
        public static final String PATH_RCV_CAL = "PATH_RCV_CAL";
        public static final String PATH_SPK_CAL = "PATH_SPK_CAL";
        public static final String PA_TEMP_ADC_VAL_TYPE = "PA_TEMP_ADC_VAL_TYPE";
        public static final String PD_CHARGE = "PD_CHARGE";
        public static final String QWERTY_EXIT_BUTTON_SIZE = "QWERTY_EXIT_BUTTON_SIZE";
        public static final String QWERTY_KEY_TEST_ROW_1 = "QWERTY_KEY_TEST_ROW_1";
        public static final String QWERTY_KEY_TEST_ROW_10 = "QWERTY_KEY_TEST_ROW_10";
        public static final String QWERTY_KEY_TEST_ROW_11 = "QWERTY_KEY_TEST_ROW_11";
        public static final String QWERTY_KEY_TEST_ROW_2 = "QWERTY_KEY_TEST_ROW_2";
        public static final String QWERTY_KEY_TEST_ROW_3 = "QWERTY_KEY_TEST_ROW_3";
        public static final String QWERTY_KEY_TEST_ROW_4 = "QWERTY_KEY_TEST_ROW_4";
        public static final String QWERTY_KEY_TEST_ROW_5 = "QWERTY_KEY_TEST_ROW_5";
        public static final String QWERTY_KEY_TEST_ROW_6 = "QWERTY_KEY_TEST_ROW_6";
        public static final String QWERTY_KEY_TEST_ROW_7 = "QWERTY_KEY_TEST_ROW_7";
        public static final String QWERTY_KEY_TEST_ROW_8 = "QWERTY_KEY_TEST_ROW_8";
        public static final String QWERTY_KEY_TEST_ROW_9 = "QWERTY_KEY_TEST_ROW_9";
        public static final String QWERTY_KEY_TEXT_SIZE = "QWERTY_KEY_TEXT_SIZE";
        public static final String QWERTY_KEY_TEXT_VIEW_HEIGHT = "QWERTY_KEY_TEXT_VIEW_HEIGHT";
        public static final String READ_TARGET_GEOMAGNETIC = "READ_TARGET_GEOMAGNETIC";
        public static final String SENSOR_TEST_ACC_BIT = "SENSOR_TEST_ACC_BIT";
        public static final String SENSOR_TEST_MARGIN = "SENSOR_TEST_MARGIN";
        public static final String SENSOR_TEST_MARGIN_TOP = "SENSOR_TEST_MARGIN_TOP";
        public static final String SIMPLE_SIDE_KEY_TEST_EMERGENCY = "SIMPLE_SIDE_KEY_TEST_EMERGENCY";
        public static final String SIMPLE_SIDE_KEY_TEST_INTELLI = "SIMPLE_SIDE_KEY_TEST_INTELLI";
        public static final String SIMPLE_SIDE_KEY_TEST_POWER = "SIMPLE_SIDE_KEY_TEST_POWER";
        public static final String SIMPLE_SIDE_KEY_TEST_USER = "SIMPLE_SIDE_KEY_TEST_USER";
        public static final String SIMPLE_SIDE_KEY_TEST_VOLUME_DOWN = "SIMPLE_SIDE_KEY_TEST_VOLUME_DOWN";
        public static final String SIMPLE_SIDE_KEY_TEST_VOLUME_UP = "SIMPLE_SIDE_KEY_TEST_VOLUME_UP";
        public static final String SIMPLE_TEST_MEGACAM_SCALE_VALUE = "SIMPLE_TEST_MEGACAM_SCALE_VALUE";
        public static final String SIMPLE_TEST_SUBCAM_SCALE_VALUE = "SIMPLE_TEST_SUBCAM_SCALE_VALUE";
        public static final String SPEAKER_POSITION = "SPEAKER_POSITION";
        public static final String SUPPORT_CHARGE_COUNT = "SUPPORT_CHARGE_COUNT";
        public static final String SUPPORT_CMR_GAP_DISPLAY = "SUPPORT_CMR_GAP_DISPLAY";
        public static final String SUPPORT_COMPLEX_LOOPBACK_PATH = "SUPPORT_COMPLEX_LOOPBACK_PATH";
        public static final String SUPPORT_GEOMAGNETIC_ALPS_CAL = "SUPPORT_GEOMAGNETIC_ALPS_CAL";
        public static final String SUPPORT_GYRO_SET_DPS = "SUPPORT_GYRO_SET_DPS";
        public static final String SUPPORT_SYNAPTICS_TRX_OPEN_AVERAGE_TEST = "SUPPORT_SYNAPTICS_TRX_OPEN_AVERAGE_TEST";
        public static final String SUPPORT_SYNAPTICS_TRX_OPEN_TEST = "SUPPORT_SYNAPTICS_TRX_OPEN_TEST";
        public static final String SUPPORT_TSP_SELFTEST_INCELL = "SUPPORT_TSP_SELFTEST_INCELL";
        public static final String SUPPORT_TSP_SELFTEST_TX_RX_SHORT = "SUPPORT_TSP_SELFTEST_TX_RX_SHORT";
        public static final String SUPPORT_TSP_SRAM_TEST = "SUPPORT_TSP_SRAM_TEST";
        public static final String TAG = "TestCase";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_CAL_CLOSE = "THREE_DIMENSION_DIGITAL_HALL_IC_CAL_CLOSE";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_CAL_HALF = "THREE_DIMENSION_DIGITAL_HALL_IC_CAL_HALF";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_CAL_OPEN = "THREE_DIMENSION_DIGITAL_HALL_IC_CAL_OPEN";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_TEST_HALF_TO_CLOSE = "THREE_DIMENSION_DIGITAL_HALL_IC_TEST_HALF_TO_CLOSE";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_TEST_OPEN_TO_HALF = "THREE_DIMENSION_DIGITAL_HALL_IC_TEST_OPEN_TO_HALF";
        public static final String TSP_DISABLE_FOR_TDDI_WHEN_SPEN_DRAWING_TEST = "TSP_DISABLE_FOR_TDDI_WHEN_SPEN_DRAWING_TEST";
        public static final String TSP_DISABLE_WHEN_SPEN_DRAWING_TEST = "TSP_DISABLE_WHEN_SPEN_DRAWING_TEST";
        public static final String TSP_SELFTEST_OPEN_SHORT_ZINITIX = "TSP_SELFTEST_OPEN_SHORT_ZINITIX";
        public static final String TSP_SELFTEST_SEPARATE_COUNT = "TSP_SELFTEST_SEPARATE_COUNT";
        public static final String TSP_SELFTEST_SEPARATE_DIRECTION_POINT = "TSP_SELFTEST_SEPARATE_DIRECTION_POINT";
        public static final String USB3 = "USB3";
        public static final String USB31 = "USB31";
        public static final String USB32 = "USB32";
        public static final String USE_DIFFERENT_TSP_CONNECTION_CHECK = "USE_DIFFERENT_TSP_CONNECTION_CHECK";
        public static final String VCONN_CHARGE = "VCONN_CHARGE";
        public static final String WATER_DETECT = "WATER_DETECT";

        public static boolean isTouchkey(String id) {
            return Values.getString(id, "keytype").equalsIgnoreCase("touch");
        }

        public static Point getViewPoint(String id) {
            String position = Values.getString(id, "point");
            Point point = new Point();
            if (position != null) {
                String[] pointStr = position.split(",");
                point.x = Integer.parseInt(pointStr[0]);
                point.y = Integer.parseInt(pointStr[1]);
            }
            return point;
        }

        public static PointF getViewPointF(String id) {
            String position = Values.getString(id, "point");
            PointF point = new PointF();
            if (position != null) {
                String[] pointStr = position.split(",");
                point.x = Float.parseFloat(pointStr[0]);
                point.y = Float.parseFloat(pointStr[1]);
            }
            return point;
        }

        public static float getKeyTextSize(String id) {
            return Values.getFloat(id, "size");
        }

        public static String getUnit(String id) {
            return Values.getString(id, "unit");
        }

        public static boolean getEnabled(String id) {
            return Values.getBoolean(id, "enable");
        }

        public static String getOption(String id) {
            return Values.getString(id, "option");
        }

        public static String getParam(String id) {
            return Values.getString(id, "param");
        }

        public static String getString(String id) {
            return Values.getString(id, "value");
        }

        public static String getTestName(String id) {
            return Values.getString(id, "testname");
        }

        public static int getTestOrder(String id) {
            return Values.getInt(id, "order");
        }

        public static int getInt(String id) {
            return Values.getInt(id, "value");
        }

        public static double getDouble(String id) {
            return Values.getDouble(id, "value");
        }

        public static int getCount(String id) {
            return Values.getInt(id, "count");
        }

        public static int getIntValue(String id) {
            return Values.getInt(id, "intValue");
        }

        public static float getSize(String id) {
            return Values.getFloat(id, "size");
        }

        public static String getKeyType(String id) {
            return Values.getString(id, "keytype");
        }

        public static String getAttribute(String id, String attr, String deafult) {
            String ret = Values.getString(id, attr, true);
            if (Properties.PROPERTIES_DEFAULT_STRING.equals(ret) || "".equals(ret)) {
                return deafult;
            }
            return ret;
        }
    }

    public static class Path {
        public static final String SPEAKER_TEST_MEDIA = "SPEAKER_TEST_MEDIA";
        public static final String SPEAKER_TEST_MEDIA2 = "SPEAKER_TEST_MEDIA2";
        public static final String SPEAKER_TEST_MEDIA_RINGTONE1 = "SPEAKER_TEST_MEDIA_RINGTONE1";
        public static final String SPEAKER_TEST_MEDIA_RINGTONE2 = "SPEAKER_TEST_MEDIA_RINGTONE2";

        public static String getPath(String id) {
            return Values.getString(id, "path");
        }

        public static boolean isExistPath(String id) {
            if (id != null) {
                return new File(getPath(id)).exists();
            }
            return false;
        }
    }

    public static class Spec {
        public static final String AFC2_CURRRENT_SPEC_MAX = "AFC2_CURRRENT_SPEC_MAX";
        public static final String AFC2_CURRRENT_SPEC_MIN = "AFC2_CURRRENT_SPEC_MIN";
        public static final String AFC_CURRRENT_SPEC_MAX = "AFC_CURRRENT_SPEC_MAX";
        public static final String AFC_CURRRENT_SPEC_MIN = "AFC_CURRRENT_SPEC_MIN";
        public static final String AFC_VOLTAGE = "AFC_VOLTAGE";
        public static final String AF_CHARGE_CURRENT_CHECK_DELAY = "AF_CHARGE_CURRENT_CHECK_DELAY";
        public static final String AF_CHARGE_HV_CHECK_DELAY = "AF_CHARGE_HV_CHECK_DELAY";
        public static final String ALWAYSON_MIC_EAR_VOLUME = "ALWAYSON_MIC_EAR_VOLUME";
        public static final String ALWAYSON_MIC_VOLUME = "ALWAYSON_MIC_VOLUME";
        public static final String APERTURE_BIG_CENTER = "APERTURE_BIG_CENTER";
        public static final String APERTURE_BIG_RANGE_MAX = "APERTURE_BIG_RANGE_MAX";
        public static final String APERTURE_BIG_RANGE_MIN = "APERTURE_BIG_RANGE_MIN";
        public static final String APERTURE_SMALL_CENTER = "APERTURE_SMALL_CENTER";
        public static final String APERTURE_SMALL_RANGE_MAX = "APERTURE_SMALL_RANGE_MAX";
        public static final String APERTURE_SMALL_RANGE_MIN = "APERTURE_SMALL_RANGE_MIN";
        public static final String BLACK_LCD_BRIGHTNESS = "BLACK_LCD_BRIGHTNESS";
        public static final String COLORLED_BLUE = "COLORLED_BLUE";
        public static final String COLORLED_CYAN = "COLORLED_CYAN";
        public static final String COLORLED_GREEN = "COLORLED_GREEN";
        public static final String COLORLED_MAGENTA = "COLORLED_MAGENTA";
        public static final String COLORLED_RED = "COLORLED_RED";
        public static final String COLORLED_WHITE = "COLORLED_WHITE";
        public static final String COLORLED_YELLOW = "COLORLED_YELLOW";
        public static final String COLOR_BALANCE_DEFAULT_VALUE = "COLOR_BALANCE_DEFAULT_VALUE";
        public static final String COLOR_BALANCE_DEFAULT_VALUE_2 = "COLOR_BALANCE_DEFAULT_VALUE";
        public static final String COLOR_BALANCE_VALUE_LIST = "COLOR_BALANCE_VALUE_LIST";
        public static final String COPR_READ_PASS_VAL = "COPR_READ_PASS_VAL";
        public static final String D2DC_VOLTAGE_SPEC_MAX = "D2DC_VOLTAGE_SPEC_MAX";
        public static final String D2DC_VOLTAGE_SPEC_MIN = "D2DC_VOLTAGE_SPEC_MIN";
        public static final String D2D_CHARGE_VOLTAGE_CHECK_DELAY = "D2D_CHARGE_VOLTAGE_CHECK_DELAY";
        public static final String DDI_TEST_REFERENCE_CHECKSUM = "DDI_TEST_REFERENCE_CHECKSUM";
        public static final String DEFAULT_BATT_TYPE = "DEFAULT_BATT_TYPE";
        public static final String DIGITIZER_HEIGHT_BASIS = "DIGITIZER_HEIGHT_BASIS";
        public static final String DIGITIZER_WIDTH_BASIS = "DIGITIZER_WIDTH_BASIS";
        public static final String DIRECT_CHARGE_CHECK_CURRENT_DELAY = "DIRECT_CHARGE_CHECK_CURRENT_DELAY";
        public static final String DIRECT_CHARGE_CHECK_VOLTAGE_DELAY = "DIRECT_CHARGE_CHECK_VOLTAGE_DELAY";
        public static final String DIRECT_CHARGE_RATIO_SPEC_MAX = "DIRECT_CHARGE_RATIO_SPEC_MAX";
        public static final String DIRECT_CHARGE_RATIO_SPEC_MIN = "DIRECT_CHARGE_RATIO_SPEC_MIN";
        public static final String DIRECT_CHARGE_SPEC_STEP1_MAX = "DIRECT_CHARGE_SPEC_STEP1_MAX";
        public static final String DIRECT_CHARGE_SPEC_STEP1_MIN = "DIRECT_CHARGE_SPEC_STEP1_MIN";
        public static final String DIRECT_CHARGE_SPEC_STEP2_MAX = "DIRECT_CHARGE_SPEC_STEP2_MAX";
        public static final String DIRECT_CHARGE_SPEC_STEP2_MIN = "DIRECT_CHARGE_SPEC_STEP2_MIN";
        public static final String DIRECT_CHARGE_SPEC_STEP3_MAX = "DIRECT_CHARGE_SPEC_STEP3_MAX";
        public static final String DIRECT_CHARGE_SPEC_STEP3_MIN = "DIRECT_CHARGE_SPEC_STEP3_MIN";
        public static final String DPSWITCH_CCIC_SPEC_MAX = "DPSWITCH_CCIC_SPEC_MAX";
        public static final String DPSWITCH_CCIC_SPEC_MIN = "DPSWITCH_CCIC_SPEC_MIN";
        public static final String DPSWITCH_SBU_SPEC_MAX = "DPSWITCH_SBU_SPEC_MAX";
        public static final String DPSWITCH_SBU_SPEC_MIN = "DPSWITCH_SBU_SPEC_MIN";
        public static final String FINGERPRINT_AFEBALANCE_MAX_NAMSAN = "FINGERPRINT_AFEBALANCE_MAX_NAMSAN";
        public static final String FINGERPRINT_AFEBALANCE_MIN_NAMSAN = "FINGERPRINT_AFEBALANCE_MIN_NAMSAN";
        public static final String FINGERPRINT_AFE_MAX = "FINGERPRINT_AFE_MAX";
        public static final String FINGERPRINT_AFE_MIN = "FINGERPRINT_AFE_MIN";
        public static final String FINGERPRINT_ALLOWED_COUNTS_MAX = "FINGERPRINT_ALLOWED_COUNTS_MAX";
        public static final String FINGERPRINT_ALLOWED_COUNTS_MIN = "FINGERPRINT_ALLOWED_COUNTS_MIN";
        public static final String FINGERPRINT_AREA_MAX_PIXEL_FAIL_MAX_NAMSAN = "FINGERPRINT_AREA_MAX_PIXEL_FAIL_MAX_NAMSAN";
        public static final String FINGERPRINT_AREA_MAX_PIXEL_FAIL_MIN_NAMSAN = "FINGERPRINT_AREA_MAX_PIXEL_FAIL_MIN_NAMSAN";
        public static final String FINGERPRINT_BAD_PIXEL_BLOCK_MAX_EGIS = "FINGERPRINT_BAD_PIXEL_BLOCK_MAX_EGIS";
        public static final String FINGERPRINT_BAD_PIXEL_BLOCK_MIN_EGIS = "FINGERPRINT_BAD_PIXEL_BLOCK_MIN_EGIS";
        public static final String FINGERPRINT_BAD_PIXEL_CONSECUTIVE_MAX_EGIS = "FINGERPRINT_BAD_PIXEL_CONSECUTIVE_MAX_EGIS";
        public static final String FINGERPRINT_BAD_PIXEL_CONSECUTIVE_MIN_EGIS = "FINGERPRINT_BAD_PIXEL_CONSECUTIVE_MIN_EGIS";
        public static final String FINGERPRINT_BAD_PIXEL_MAX = "FINGERPRINT_BAD_PIXEL_MAX";
        public static final String FINGERPRINT_BAD_PIXEL_MIN = "FINGERPRINT_BAD_PIXEL_MIN";
        public static final String FINGERPRINT_BAD_PIXEL_TOTAL_MAX_EGIS = "FINGERPRINT_BAD_PIXEL_TOTAL_MAX_EGIS";
        public static final String FINGERPRINT_BAD_PIXEL_TOTAL_MIN_EGIS = "FINGERPRINT_BAD_PIXEL_TOTAL_MIN_EGIS";
        public static final String FINGERPRINT_BAD_TOTAL_BAD_PIXEL_MAX = "FINGERPRINT_BAD_TOTAL_BAD_PIXEL_MAX";
        public static final String FINGERPRINT_BAD_TOTAL_BAD_PIXEL_MIN = "FINGERPRINT_BAD_TOTAL_BAD_PIXEL_MIN";
        public static final String FINGERPRINT_BK_SCORE_MAX_EGIS = "FINGERPRINT_BK_SCORE_MAX_EGIS";
        public static final String FINGERPRINT_BK_SCORE_MIN_EGIS = "FINGERPRINT_BK_SCORE_MIN_EGIS";
        public static final String FINGERPRINT_BLACK_DOT_MAX = "FINGERPRINT_BLACK_DOT_MAX";
        public static final String FINGERPRINT_BLACK_DOT_MIN = "FINGERPRINT_BLACK_DOT_MIN";
        public static final String FINGERPRINT_BLACK_TOTAL_BAD_PIXEL_MAX = "FINGERPRINT_BLACK_TOTAL_BAD_PIXEL_MAX";
        public static final String FINGERPRINT_BLACK_TOTAL_BAD_PIXEL_MIN = "FINGERPRINT_BLACK_TOTAL_BAD_PIXEL_MIN";
        public static final String FINGERPRINT_CAP_TOUCH_DATA_DIFFERENCE_MAX = "FINGERPRINT_CAP_TOUCH_DATA_DIFFERENCE_MAX";
        public static final String FINGERPRINT_CAP_TOUCH_DATA_DIFFERENCE_MIN = "FINGERPRINT_CAP_TOUCH_DATA_DIFFERENCE_MIN";
        public static final String FINGERPRINT_CAP_TOUCH_DELTA_PIXEL_LOCAL_MAX = "FINGERPRINT_CAP_TOUCH_DELTA_PIXEL_LOCAL_MAX";
        public static final String FINGERPRINT_CAP_TOUCH_DELTA_PIXEL_LOCAL_MIN = "FINGERPRINT_CAP_TOUCH_DELTA_PIXEL_LOCAL_MIN";
        public static final String FINGERPRINT_CAP_TOUCH_DELTA_PIXEL_TOTAL_MAX = "FINGERPRINT_CAP_TOUCH_DELTA_PIXEL_TOTAL_MAX";
        public static final String FINGERPRINT_CAP_TOUCH_DELTA_PIXEL_TOTAL_MIN = "FINGERPRINT_CAP_TOUCH_DELTA_PIXEL_TOTAL_MIN";
        public static final String FINGERPRINT_CAP_TOUCH_NOISE_MAX = "FINGERPRINT_CAP_TOUCH_NOISE_MAX";
        public static final String FINGERPRINT_CAP_TOUCH_NOISE_MIN = "FINGERPRINT_CAP_TOUCH_NOISE_MIN";
        public static final String FINGERPRINT_CAP_TOUCH_PERFORMANCE_MAX = "FINGERPRINT_CAP_TOUCH_PERFORMANCE_MAX";
        public static final String FINGERPRINT_CAP_TOUCH_PERFORMANCE_MIN = "FINGERPRINT_CAP_TOUCH_PERFORMANCE_MIN";
        public static final String FINGERPRINT_CAP_TOUCH_PIN_OPEN_SHORT_INT = "FINGERPRINT_CAP_TOUCH_PIN_OPEN_SHORT_INT";
        public static final String FINGERPRINT_CAP_TOUCH_PIN_OPEN_SHORT_RST = "FINGERPRINT_CAP_TOUCH_PIN_OPEN_SHORT_RST";
        public static final String FINGERPRINT_CAP_TOUCH_RUBBER_PLACEMENT_MAX = "FINGERPRINT_CAP_TOUCH_RUBBER_PLACEMENT_MAX";
        public static final String FINGERPRINT_CAP_TOUCH_RUBBER_PLACEMENT_MIN = "FINGERPRINT_CAP_TOUCH_RUBBER_PLACEMENT_MIN";
        public static final String FINGERPRINT_CAP_TOUCH_SATURATION_MAX_DOWN_MAX = "FINGERPRINT_CAP_TOUCH_SATURATION_MAX_DOWN_MAX";
        public static final String FINGERPRINT_CAP_TOUCH_SATURATION_MAX_DOWN_MIN = "FINGERPRINT_CAP_TOUCH_SATURATION_MAX_DOWN_MIN";
        public static final String FINGERPRINT_CAP_TOUCH_SATURATION_MAX_UP_MAX = "FINGERPRINT_CAP_TOUCH_SATURATION_MAX_UP_MAX";
        public static final String FINGERPRINT_CAP_TOUCH_SATURATION_MAX_UP_MIN = "FINGERPRINT_CAP_TOUCH_SATURATION_MAX_UP_MIN";
        public static final String FINGERPRINT_CAP_TOUCH_SNR_MAX = "FINGERPRINT_CAP_TOUCH_SNR_MAX";
        public static final String FINGERPRINT_CAP_TOUCH_SNR_MIN = "FINGERPRINT_CAP_TOUCH_SNR_MIN";
        public static final String FINGERPRINT_CAP_UNTOUCH_BAD_PIXEL_STREAK_MAX = "FINGERPRINT_CAP_UNTOUCH_BAD_PIXEL_STREAK_MAX";
        public static final String FINGERPRINT_CAP_UNTOUCH_BAD_PIXEL_STREAK_MIN = "FINGERPRINT_CAP_UNTOUCH_BAD_PIXEL_STREAK_MIN";
        public static final String FINGERPRINT_CAP_UNTOUCH_FDT_PIXEL_OPEN_SHORT_8x1_FDT_ZONE_MAX = "FINGERPRINT_CAP_UNTOUCH_FDT_PIXEL_OPEN_SHORT_8x1_FDT_ZONE_MAX";
        public static final String FINGERPRINT_CAP_UNTOUCH_FDT_PIXEL_OPEN_SHORT_8x1_FDT_ZONE_MIN = "FINGERPRINT_CAP_UNTOUCH_FDT_PIXEL_OPEN_SHORT_8x1_FDT_ZONE_MIN";
        public static final String FINGERPRINT_CAP_UNTOUCH_FDT_PIXEL_OPEN_SHORT_8x7_FDT_ZONE_MAX = "FINGERPRINT_CAP_UNTOUCH_FDT_PIXEL_OPEN_SHORT_8x7_FDT_ZONE_MAX";
        public static final String FINGERPRINT_CAP_UNTOUCH_FDT_PIXEL_OPEN_SHORT_8x7_FDT_ZONE_MIN = "FINGERPRINT_CAP_UNTOUCH_FDT_PIXEL_OPEN_SHORT_8x7_FDT_ZONE_MIN";
        public static final String FINGERPRINT_CAP_UNTOUCH_OTP = "FINGERPRINT_CAP_UNTOUCH_OTP";
        public static final String FINGERPRINT_CAP_UNTOUCH_PIN_OPEN_SHORT_SPI = "FINGERPRINT_CAP_UNTOUCH_PIN_OPEN_SHORT_SPI";
        public static final String FINGERPRINT_CAP_UNTOUCH_PIXEL_OPEN_SHORT_LOCAL_MAX = "FINGERPRINT_CAP_UNTOUCH_PIXEL_OPEN_SHORT_LOCAL_MAX";
        public static final String FINGERPRINT_CAP_UNTOUCH_PIXEL_OPEN_SHORT_LOCAL_MIN = "FINGERPRINT_CAP_UNTOUCH_PIXEL_OPEN_SHORT_LOCAL_MIN";
        public static final String FINGERPRINT_CAP_UNTOUCH_PIXEL_OPEN_SHORT_TOTAL_MAX = "FINGERPRINT_CAP_UNTOUCH_PIXEL_OPEN_SHORT_TOTAL_MAX";
        public static final String FINGERPRINT_CAP_UNTOUCH_PIXEL_OPEN_SHORT_TOTAL_MIN = "FINGERPRINT_CAP_UNTOUCH_PIXEL_OPEN_SHORT_TOTAL_MIN";
        public static final String FINGERPRINT_CET_MAX_EGIS = "FINGERPRINT_CET_MAX_EGIS";
        public static final String FINGERPRINT_CET_MIN_EGIS = "FINGERPRINT_CET_MIN_EGIS";
        public static final String FINGERPRINT_CON_FLOORED_PIXEL_COL_MAX_NAMSAN = "FINGERPRINT_CON_FLOORED_PIXEL_COL_MAX_NAMSAN";
        public static final String FINGERPRINT_CON_FLOORED_PIXEL_COL_MIN_NAMSAN = "FINGERPRINT_CON_FLOORED_PIXEL_COL_MIN_NAMSAN";
        public static final String FINGERPRINT_CON_PEGGED_PIXEL_COL_MAX_NAMSAN = "FINGERPRINT_CON_PEGGED_PIXEL_COL_MAX_NAMSAN";
        public static final String FINGERPRINT_CON_PEGGED_PIXEL_COL_MIN_NAMSAN = "FINGERPRINT_CON_PEGGED_PIXEL_COL_MIN_NAMSAN";
        public static final String FINGERPRINT_DEFECT_PIXEL_MAX = "FINGERPRINT_DEFECT_PIXEL_MAX";
        public static final String FINGERPRINT_DEFECT_PIXEL_MIN = "FINGERPRINT_DEFECT_PIXEL_MIN";
        public static final String FINGERPRINT_DEFECT_TOTAL_BAD_PIXEL_MAX = "FINGERPRINT_DEFECT_TOTAL_BAD_PIXEL_MAX";
        public static final String FINGERPRINT_DEFECT_TOTAL_BAD_PIXEL_MIN = "FINGERPRINT_DEFECT_TOTAL_BAD_PIXEL_MIN";
        public static final String FINGERPRINT_DELTA_PIXEL_COL_MAX = "FINGERPRINT_DELTA_PIXEL_COL_MAX";
        public static final String FINGERPRINT_DELTA_PIXEL_COL_MIN = "FINGERPRINT_DELTA_PIXEL_COL_MIN";
        public static final String FINGERPRINT_DELTA_PIXEL_ROW_MAX = "FINGERPRINT_DELTA_PIXEL_ROW_MAX";
        public static final String FINGERPRINT_DELTA_PIXEL_ROW_MIN = "FINGERPRINT_DELTA_PIXEL_ROW_MIN";
        public static final String FINGERPRINT_DETECT_SCORE_MAX_NAMSAN = "FINGERPRINT_DETECT_SCORE_MAX_NAMSAN";
        public static final String FINGERPRINT_DETECT_SCORE_MIN_NAMSAN = "FINGERPRINT_DETECT_SCORE_MIN_NAMSAN";
        public static final String FINGERPRINT_FEA_X_MAX_EGIS = "FINGERPRINT_FEA_X_MAX_EGIS";
        public static final String FINGERPRINT_FEA_X_MIN_EGIS = "FINGERPRINT_FEA_X_MIN_EGIS";
        public static final String FINGERPRINT_FEA_Y_MAX_EGIS = "FINGERPRINT_FEA_Y_MAX_EGIS";
        public static final String FINGERPRINT_FEA_Y_MIN_EGIS = "FINGERPRINT_FEA_Y_MIN_EGIS";
        public static final String FINGERPRINT_FLASHCHECKSUM_MAX_NAMSAN = "FINGERPRINT_FLASHCHECKSUM_MAX_NAMSAN";
        public static final String FINGERPRINT_FLASHCHECKSUM_MIN_NAMSAN = "FINGERPRINT_FLASHCHECKSUM_MIN_NAMSAN";
        public static final String FINGERPRINT_FLOORED_PIXEL_COL_MAX = "FINGERPRINT_FLOORED_PIXEL_COL_MAX";
        public static final String FINGERPRINT_FLOORED_PIXEL_COL_MIN = "FINGERPRINT_FLOORED_PIXEL_COL_MIN";
        public static final String FINGERPRINT_FLOORED_PIXEL_MAX = "FINGERPRINT_FLOORED_PIXEL_MAX";
        public static final String FINGERPRINT_FLOORED_PIXEL_MIN = "FINGERPRINT_FLOORED_PIXEL_MIN";
        public static final String FINGERPRINT_FLOORED_PIXEL_ROW_MAX = "FINGERPRINT_FLOORED_PIXEL_ROW_MAX";
        public static final String FINGERPRINT_FLOORED_PIXEL_ROW_MAX_NAMSAN = "FINGERPRINT_FLOORED_PIXEL_ROW_MAX_NAMSAN";
        public static final String FINGERPRINT_FLOORED_PIXEL_ROW_MIN = "FINGERPRINT_FLOORED_PIXEL_ROW_MIN";
        public static final String FINGERPRINT_FLOORED_PIXEL_ROW_MIN_NAMSAN = "FINGERPRINT_FLOORED_PIXEL_ROW_MIN_NAMSAN";
        public static final String FINGERPRINT_IMAGE_DEVIATION_MAX = "FINGERPRINT_IMAGE_DEVIATION_MAX";
        public static final String FINGERPRINT_IMAGE_DEVIATION_MIN = "FINGERPRINT_IMAGE_DEVIATION_MIN";
        public static final String FINGERPRINT_MAXIMUM_DELTA_MAX = "FINGERPRINT_MAXIMUM_DELTA_MAX";
        public static final String FINGERPRINT_MAXIMUM_DELTA_MIN = "FINGERPRINT_MAXIMUM_DELTA_MIN";
        public static final String FINGERPRINT_MAX_NEG_DELTA_MAX = "FINGERPRINT_MAX_NEG_DELTA_MAX";
        public static final String FINGERPRINT_MAX_NEG_DELTA_MIN = "FINGERPRINT_MAX_NEG_DELTA_MIN";
        public static final String FINGERPRINT_MAX_POS_DELTA_MAX = "FINGERPRINT_MAX_POS_DELTA_MAX";
        public static final String FINGERPRINT_MAX_POS_DELTA_MIN = "FINGERPRINT_MAX_POS_DELTA_MIN";
        public static final String FINGERPRINT_MFG_CAL_OVERALL_MAX_NAMSAN = "FINGERPRINT_MFG_CAL_OVERALL_MAX_NAMSAN";
        public static final String FINGERPRINT_MFG_CAL_OVERALL_MIN_NAMSAN = "FINGERPRINT_MFG_CAL_OVERALL_MIN_NAMSAN";
        public static final String FINGERPRINT_MFG_CAL_ZONE_MAX_NAMSAN = "FINGERPRINT_MFG_CAL_ZONE_MAX_NAMSAN";
        public static final String FINGERPRINT_MFG_CAL_ZONE_MIN_NAMSAN = "FINGERPRINT_MFG_CAL_ZONE_MIN_NAMSAN";
        public static final String FINGERPRINT_MINIMUM_DELTA_MAX = "FINGERPRINT_MINIMUM_DELTA_MAX";
        public static final String FINGERPRINT_MINIMUM_DELTA_MIN = "FINGERPRINT_MINIMUM_DELTA_MIN";
        public static final String FINGERPRINT_M_FACTOR_MAX_EGIS = "FINGERPRINT_M_FACTOR_MAX_EGIS";
        public static final String FINGERPRINT_M_FACTOR_MIN_EGIS = "FINGERPRINT_M_FACTOR_MIN_EGIS";
        public static final String FINGERPRINT_NOISE_MAX_EGIS = "FINGERPRINT_NOISE_MAX_EGIS";
        public static final String FINGERPRINT_NOISE_MAX_NAMSAN = "FINGERPRINT_NOISE_MAX_NAMSAN";
        public static final String FINGERPRINT_NOISE_MIN_EGIS = "FINGERPRINT_NOISE_MIN_EGIS";
        public static final String FINGERPRINT_NOISE_MIN_NAMSAN = "FINGERPRINT_NOISE_MIN_NAMSAN";
        public static final String FINGERPRINT_NOISE_SPEC_MAX = "FINGERPRINT_NOISE_SPEC_MAX";
        public static final String FINGERPRINT_NOISE_SPEC_MIN = "FINGERPRINT_NOISE_SPEC_MIN";
        public static final String FINGERPRINT_NOISE_ZONE_MAX_NAMSAN = "FINGERPRINT_NOISE_ZONE_MAX_NAMSAN";
        public static final String FINGERPRINT_NOISE_ZONE_MIN_NAMSAN = "FINGERPRINT_NOISE_ZONE_MIN_NAMSAN";
        public static final String FINGERPRINT_OPEN_SHORT_RX_IMAGE_MAX_NAMSAN = "FINGERPRINT_OPEN_SHORT_RX_IMAGE_MAX_NAMSAN";
        public static final String FINGERPRINT_OPEN_SHORT_RX_IMAGE_MIN_NAMSAN = "FINGERPRINT_OPEN_SHORT_RX_IMAGE_MIN_NAMSAN";
        public static final String FINGERPRINT_OPEN_SHORT_RX_RANGE_MAX_NAMSAN = "FINGERPRINT_OPEN_SHORT_RX_RANGE_MAX_NAMSAN";
        public static final String FINGERPRINT_OPEN_SHORT_RX_RANGE_MIN_NAMSAN = "FINGERPRINT_OPEN_SHORT_RX_RANGE_MIN_NAMSAN";
        public static final String FINGERPRINT_OPEN_SHORT_RX_SHORT_MAX_NAMSAN = "FINGERPRINT_OPEN_SHORT_RX_SHORT_MAX_NAMSAN";
        public static final String FINGERPRINT_OPEN_SHORT_RX_SHORT_MIN_NAMSAN = "FINGERPRINT_OPEN_SHORT_RX_SHORT_MIN_NAMSAN";
        public static final String FINGERPRINT_OPEN_SHORT_TX_SHORT_MAX_NAMSAN = "FINGERPRINT_OPEN_SHORT_TX_SHORT_MAX_NAMSAN";
        public static final String FINGERPRINT_OPEN_SHORT_TX_SHORT_MIN_NAMSAN = "FINGERPRINT_OPEN_SHORT_TX_SHORT_MIN_NAMSAN";
        public static final String FINGERPRINT_OPEN_SHORT_TX_SUM_MAX_NAMSAN = "FINGERPRINT_OPEN_SHORT_TX_SUM_MAX_NAMSAN";
        public static final String FINGERPRINT_OPEN_SHORT_TX_SUM_MIN_NAMSAN = "FINGERPRINT_OPEN_SHORT_TX_SUM_MIN_NAMSAN";
        public static final String FINGERPRINT_PEGGED_PIXEL_COL_MAX = "FINGERPRINT_PEGGED_PIXEL_COL_MAX";
        public static final String FINGERPRINT_PEGGED_PIXEL_COL_MIN = "FINGERPRINT_PEGGED_PIXEL_COL_MIN";
        public static final String FINGERPRINT_PEGGED_PIXEL_MAX = "FINGERPRINT_PEGGED_PIXEL_MAX";
        public static final String FINGERPRINT_PEGGED_PIXEL_MIN = "FINGERPRINT_PEGGED_PIXEL_MIN";
        public static final String FINGERPRINT_PEGGED_PIXEL_ROW_MAX = "FINGERPRINT_PEGGED_PIXEL_ROW_MAX";
        public static final String FINGERPRINT_PEGGED_PIXEL_ROW_MAX_NAMSAN = "FINGERPRINT_PEGGED_PIXEL_ROW_MAX_NAMSAN";
        public static final String FINGERPRINT_PEGGED_PIXEL_ROW_MIN = "FINGERPRINT_PEGGED_PIXEL_ROW_MIN";
        public static final String FINGERPRINT_PEGGED_PIXEL_ROW_MIN_NAMSAN = "FINGERPRINT_PEGGED_PIXEL_ROW_MIN_NAMSAN";
        public static final String FINGERPRINT_PLACEMENT_TEST_MAX = "FINGERPRINT_PLACEMENT_TEST_MAX";
        public static final String FINGERPRINT_PLACEMENT_TEST_MIN = "FINGERPRINT_PLACEMENT_TEST_MIN";
        public static final String FINGERPRINT_PRESENT_MAX_NAMSAN = "FINGERPRINT_PRESENT_MAX_NAMSAN";
        public static final String FINGERPRINT_PRESENT_MIN_NAMSAN = "FINGERPRINT_PRESENT_MIN_NAMSAN";
        public static final String FINGERPRINT_RATIO_ZONE_MAX_NAMSAN = "FINGERPRINT_RATIO_ZONE_MAX_NAMSAN";
        public static final String FINGERPRINT_RATIO_ZONE_MIN_NAMSAN = "FINGERPRINT_RATIO_ZONE_MIN_NAMSAN";
        public static final String FINGERPRINT_RX_DELTA_MAX_NAMSAN = "FINGERPRINT_RX_DELTA_MAX_NAMSAN";
        public static final String FINGERPRINT_RX_DELTA_MIN_NAMSAN = "FINGERPRINT_RX_DELTA_MIN_NAMSAN";
        public static final String FINGERPRINT_RX_MAX_PIXEL_FAIL_MAX_NAMSAN = "FINGERPRINT_RX_MAX_PIXEL_FAIL_MAX_NAMSAN";
        public static final String FINGERPRINT_RX_MAX_PIXEL_FAIL_MIN_NAMSAN = "FINGERPRINT_RX_MAX_PIXEL_FAIL_MIN_NAMSAN";
        public static final String FINGERPRINT_SIGNAL_MAX_EGIS = "FINGERPRINT_SIGNAL_MAX_EGIS";
        public static final String FINGERPRINT_SIGNAL_MAX_NAMSAN = "FINGERPRINT_SIGNAL_MAX_NAMSAN";
        public static final String FINGERPRINT_SIGNAL_MIN_EGIS = "FINGERPRINT_SIGNAL_MIN_EGIS";
        public static final String FINGERPRINT_SIGNAL_MIN_NAMSAN = "FINGERPRINT_SIGNAL_MIN_NAMSAN";
        public static final String FINGERPRINT_SIGNAL_SPEC_MAX = "FINGERPRINT_SIGNAL_SPEC_MAX";
        public static final String FINGERPRINT_SIGNAL_SPEC_MIN = "FINGERPRINT_SIGNAL_SPEC_MIN";
        public static final String FINGERPRINT_SIGNAL_ZONE_MAX_NAMSAN = "FINGERPRINT_SIGNAL_ZONE_MAX_NAMSAN";
        public static final String FINGERPRINT_SIGNAL_ZONE_MIN_NAMSAN = "FINGERPRINT_SIGNAL_ZONE_MIN_NAMSAN";
        public static final String FINGERPRINT_SNR_MAX_EGIS = "FINGERPRINT_SNR_MAX_EGIS";
        public static final String FINGERPRINT_SNR_MAX_NAMSAN = "FINGERPRINT_SNR_MAX_NAMSAN";
        public static final String FINGERPRINT_SNR_MIN_EGIS = "FINGERPRINT_SNR_MIN_EGIS";
        public static final String FINGERPRINT_SNR_MIN_NAMSAN = "FINGERPRINT_SNR_MIN_NAMSAN";
        public static final String FINGERPRINT_SNR_SPEC_MAX = "FINGERPRINT_SNR_SPEC_MAX";
        public static final String FINGERPRINT_SNR_SPEC_MIN = "FINGERPRINT_SNR_SPEC_MIN";
        public static final String FINGERPRINT_SNR_ZONE_MAX_NAMSAN = "FINGERPRINT_SNR_ZONE_MAX_NAMSAN";
        public static final String FINGERPRINT_SNR_ZONE_MIN_NAMSAN = "FINGERPRINT_SNR_ZONE_MIN_NAMSAN";
        public static final String FINGERPRINT_STANDARD_DEVIATION_MAX = "FINGERPRINT_STANDARD_DEVIATION_MAX";
        public static final String FINGERPRINT_STANDARD_DEVIATION_MIN = "FINGERPRINT_STANDARD_DEVIATION_MIN";
        public static final String FINGERPRINT_TOTAL_2D_DELTA_FAIL_MAX = "FINGERPRINT_TOTAL_2D_DELTA_FAIL_MAX";
        public static final String FINGERPRINT_TOTAL_2D_DELTA_FAIL_MIN = "FINGERPRINT_TOTAL_2D_DELTA_FAIL_MIN";
        public static final String FINGERPRINT_TOTAL_BAD_PIXCEL_COUNT_MAX_NAMSAN = "FINGERPRINT_TOTAL_BAD_PIXCEL_COUNT_MAX_NAMSAN";
        public static final String FINGERPRINT_TOTAL_BAD_PIXCEL_COUNT_MIN_NAMSAN = "FINGERPRINT_TOTAL_BAD_PIXCEL_COUNT_MIN_NAMSAN";
        public static final String FINGERPRINT_TOTAL_BAD_PIXEL_MAX_NAMSAN = "FINGERPRINT_TOTAL_BAD_PIXEL_MAX_NAMSAN";
        public static final String FINGERPRINT_TOTAL_BAD_PIXEL_MIN_NAMSAN = "FINGERPRINT_TOTAL_BAD_PIXEL_MIN_NAMSAN";
        public static final String FINGERPRINT_TX_MAX_PIXEL_FAIL_MAX_NAMSAN = "FINGERPRINT_TX_MAX_PIXEL_FAIL_MAX_NAMSAN";
        public static final String FINGERPRINT_TX_MAX_PIXEL_FAIL_MIN_NAMSAN = "FINGERPRINT_TX_MAX_PIXEL_FAIL_MIN_NAMSAN";
        public static final String FINGERPRINT_VARIANCE_MAX = "FINGERPRINT_VARIANCE_MAX";
        public static final String FINGERPRINT_VARIANCE_MAX_DC = "FINGERPRINT_VARIANCE_MAX_DC";
        public static final String FINGERPRINT_VARIANCE_MIN = "FINGERPRINT_VARIANCE_MIN";
        public static final String FINGERPRINT_VARIANCE_MIN_DC = "FINGERPRINT_VARIANCE_MIN_DC";
        public static final String FINGERPRINT_WHITE_DOT_MAX = "FINGERPRINT_WHITE_DOT_MAX";
        public static final String FINGERPRINT_WHITE_DOT_MIN = "FINGERPRINT_WHITE_DOT_MIN";
        public static final String FINGERPRINT_WHITE_TOTAL_BAD_PIXEL_MAX = "FINGERPRINT_WHITE_TOTAL_BAD_PIXEL_MAX";
        public static final String FINGERPRINT_WHITE_TOTAL_BAD_PIXEL_MIN = "FINGERPRINT_WHITE_TOTAL_BAD_PIXEL_MIN";
        public static final String FOLDER_TENSION_TEST_DELTA = "FOLDER_TENSION_TEST_DELTA";
        public static final String FOLDER_TENSION_TEST_REF_ANGLE = "FOLDER_TENSION_TEST_REF_ANGLE";
        public static final String FORCE_TOUCH_CAL_SPEC_MAX = "FORCE_TOUCH_CAL_SPEC_MAX";
        public static final String FORCE_TOUCH_CAL_SPEC_MIN = "FORCE_TOUCH_CAL_SPEC_MIN";
        public static final String FORCE_TOUCH_IX_MAX_STM = "FORCE_TOUCH_IX_MAX_STM";
        public static final String FORCE_TOUCH_IX_MIN_STM = "FORCE_TOUCH_IX_MIN_STM";
        public static final String FORCE_TOUCH_JITTER_MAX = "FORCE_TOUCH_JITTER_MAX";
        public static final String FORCE_TOUCH_LOWER_WEIGHT = "FORCE_TOUCH_LOWER_WEIGHT";
        public static final String FORCE_TOUCH_OFFSET_MAX_SEC = "FORCE_TOUCH_OFFSET_MAX_SEC";
        public static final String FORCE_TOUCH_OFFSET_MIN_SEC = "FORCE_TOUCH_OFFSET_MIN_SEC";
        public static final String FORCE_TOUCH_PRESS_SPEC_MAX = "FORCE_TOUCH_PRESS_SPEC_MAX";
        public static final String FORCE_TOUCH_PRESS_SPEC_MIN = "FORCE_TOUCH_PRESS_SPEC_MIN";
        public static final String FORCE_TOUCH_PRE_DELTA_MAX_SEC = "FORCE_TOUCH_PRE_DELTA_MAX_SEC";
        public static final String FORCE_TOUCH_PRE_DELTA_MIN_SEC = "FORCE_TOUCH_PRE_DELTA_MIN_SEC";
        public static final String FORCE_TOUCH_RAW_CAP_MAX_STM = "FORCE_TOUCH_RAW_CAP_MAX_STM";
        public static final String FORCE_TOUCH_RAW_CAP_MIN_STM = "FORCE_TOUCH_RAW_CAP_MIN_STM";
        public static final String FORCE_TOUCH_REF_VALUE_FOR_WEIGHT = "FORCE_TOUCH_REF_VALUE_FOR_WEIGHT";
        public static final String FORCE_TOUCH_REF_VALUE_FOR_WEIGHT_SECOND = "FORCE_TOUCH_REF_VALUE_FOR_WEIGHT_SECOND";
        public static final String FORCE_TOUCH_UPPER_WEIGHT = "FORCE_TOUCH_UPPER_WEIGHT";
        public static final String GEOMAGNETIC_POWERNOISE_MAX = "GEOMAGNETIC_POWERNOISE_MAX";
        public static final String GEOMAGNETIC_SPEC_ADC = "GEOMAGNETIC_SPEC_ADC";
        public static final String GESTURESENSOR_IR_CURRENT = "GESTURESENSOR_IR_CURRENT";
        public static final String GESTURESENSOR_PEEK_TO_PEEK_SPEC_MAX = "GESTURESENSOR_PEEK_TO_PEEK_SPEC_MAX";
        public static final String GESTURESENSOR_PEEK_TO_PEEK_SPEC_MIN = "GESTURESENSOR_PEEK_TO_PEEK_SPEC_MIN";
        public static final String GESTURE_CROSSTALK_RAW = "GESTURE_CROSSTALK_RAW";
        public static final String GRIP_MARGIN_SPEC_FOR_CAL_CHECK = "GRIP_MARGIN_SPEC_FOR_CAL_CHECK";
        public static final String GRIP_PROX_DIFF_INDEX = "GRIP_PROX_DIFF_INDEX";
        public static final String GYROSCOPE_HW_SELFTEST = "GYROSCOPE_HW_SELFTEST";
        public static final String GYROSCOPE_SELFTEST_INVENSENSE_MAX = "GYROSCOPE_SELFTEST_INVENSENSE_MAX";
        public static final String GYROSCOPE_SELFTEST_INVENSENSE_MIN = "GYROSCOPE_SELFTEST_INVENSENSE_MIN";
        public static final String GYROSCOPE_SELFTEST_MAX = "GYROSCOPE_SELFTEST_MAX";
        public static final String GYROSCOPE_SELFTEST_MAXIM_MAX = "GYROSCOPE_SELFTEST_BOSCH_MAX";
        public static final String GYROSCOPE_SELFTEST_MAXIM_MIN = "GYROSCOPE_SELFTEST_BOSCH_MIN";
        public static final String GYROSCOPE_SELFTEST_MIN = "GYROSCOPE_SELFTEST_MIN";
        public static final String GYROSCOPE_SELFTEST_STM_MAX = "GYROSCOPE_SELFTEST_STM_MAX";
        public static final String GYROSCOPE_SELFTEST_STM_MIN = "GYROSCOPE_SELFTEST_STM_MIN";
        public static final String HRM_86900A_FREQUENCY_DC_IR = "HRM_86900A_FREQUENCY_DC_IR";
        public static final String HRM_86900A_FREQUENCY_DC_RED = "HRM_86900A_FREQUENCY_DC_RED";
        public static final String HRM_86900A_PEAK_TO_PEAK_DC_IR = "HRM_86900A_PEAK_TO_PEAK_DC_IR";
        public static final String HRM_86900A_PEAK_TO_PEAK_PEAK_IR = "HRM_86900A_PEAK_TO_PEAK_PEAK_IR";
        public static final String HRM_86900A_PEAK_TO_PEAK_PEAK_RED = "HRM_86900A_PEAK_TO_PEAK_PEAK_RED";
        public static final String HRM_BLUE_HIGH_DC = "HRM_BLUE_HIGH_DC";
        public static final String HRM_BLUE_LOW_DC = "HRM_BLUE_LOW_DC";
        public static final String HRM_BLUE_MEDIUM_DC = "HRM_BLUE_MEDIUM_DC";
        public static final String HRM_BLUE_NOISE = "HRM_BLUE_NOISE";
        public static final String HRM_BLUE_XTC_DC = "HRM_BLUE_XTC_DC";
        public static final String HRM_CLOUD_UV_RATIO = "HRM_CLOUD_UV_RATIO";
        public static final String HRM_FREQUENCY = "HRM_FREQUENCY";
        public static final String HRM_FREQUENCY_DC_IR = "HRM_FREQUENCY_DC_IR";
        public static final String HRM_FREQUENCY_DC_RED = "HRM_FREQUENCY_DC_RED";
        public static final String HRM_FREQUENCY_NOISE_IR = "HRM_FREQUENCY_NOISE_IR";
        public static final String HRM_FREQUENCY_NOISE_RED = "HRM_FREQUENCY_NOISE_RED";
        public static final String HRM_FREQUENCY_SAMPLE_NO = "HRM_FREQUENCY_SAMPLE_NO";
        public static final String HRM_GREEN_HIGH_DC = "HRM_GREEN_HIGH_DC";
        public static final String HRM_GREEN_LOW_DC = "HRM_GREEN_LOW_DC";
        public static final String HRM_GREEN_MEDIUM_DC = "HRM_GREEN_MEDIUM_DC";
        public static final String HRM_GREEN_NOISE = "HRM_GREEN_NOISE";
        public static final String HRM_GREEN_XTC_DC = "HRM_GREEN_XTC_DC";
        public static final String HRM_HR_SPO2 = "HRM_HR_SPO2";
        public static final String HRM_IR_AC = "HRM_IR_AC";
        public static final String HRM_IR_AC_DC_RATIO = "HRM_IR_AC_DC_RATIO";
        public static final String HRM_IR_FREQUENCY = "HRM_IR_FREQUENCY";
        public static final String HRM_IR_HIGH_DC = "HRM_IR_HIGH_DC";
        public static final String HRM_IR_HI_DC = "HRM_IR_HI_DC";
        public static final String HRM_IR_LOW_DC = "HRM_IR_LOW_DC";
        public static final String HRM_IR_MEDIUM_DC = "HRM_IR_MEDIUM_DC";
        public static final String HRM_IR_MEDIUM_SQUARED_NOISE = "HRM_IR_MEDIUM_SQUARED_NOISE";
        public static final String HRM_IR_NOISE = "HRM_IR_NOISE";
        public static final String HRM_IR_RED_R_RATIO = "HRM_IR_RED_R_RATIO";
        public static final String HRM_IR_XTC_DC = "HRM_IR_XTC_DC";
        public static final String HRM_PEAK_TO_PEAK_DC_IR = "HRM_PEAK_TO_PEAK_DC_IR";
        public static final String HRM_PEAK_TO_PEAK_DC_RED = "HRM_PEAK_TO_PEAK_DC_RED";
        public static final String HRM_PEAK_TO_PEAK_PEAK_IR = "HRM_PEAK_TO_PEAK_PEAK_IR";
        public static final String HRM_PEAK_TO_PEAK_PEAK_RED = "HRM_PEAK_TO_PEAK_PEAK_RED";
        public static final String HRM_PEAK_TO_PEAK_RATIO_IR = "HRM_PEAK_TO_PEAK_RATIO_IR";
        public static final String HRM_PEAK_TO_PEAK_RATIO_RED = "HRM_PEAK_TO_PEAK_RATIO_RED";
        public static final String HRM_RED_AC = "HRM_RED_AC";
        public static final String HRM_RED_AC_DC_RATIO = "HRM_RED_AC_DC_RATIO";
        public static final String HRM_RED_HIGH_DC = "HRM_RED_HIGH_DC";
        public static final String HRM_RED_HI_DC = "HRM_RED_HI_DC";
        public static final String HRM_RED_LOW_DC = "HRM_RED_LOW_DC";
        public static final String HRM_RED_LOW_NOISE = "HRM_RED_LOW_NOISE";
        public static final String HRM_RED_MEDIUM_DC = "HRM_RED_MEDIUM_DC";
        public static final String HRM_RED_MEDIUM_SQUARED_NOISE = "HRM_RED_MEDIUM_SQUARED_NOISE";
        public static final String HRM_RED_NOISE = "HRM_RED_NOISE";
        public static final String HRM_RED_XTC_DC = "HRM_RED_XTC_DC";
        public static final String HRM_SYSTEM_NOISE = "HRM_SYSTEM_NOISE";
        public static final String HRM_WINDOW_XTALK_IR_ADC_MAX = "HRM_WINDOW_XTALK_IR_ADC_MAX";
        public static final String HRM_WINDOW_XTALK_IR_ADC_MIN = "HRM_WINDOW_XTALK_IR_ADC_MIN";
        public static final String IRIS_LED_TEST_ADC_THRESHOLD = "IRIS_LED_TEST_ADC_THRESHOLD";
        public static final String IRIS_LED_TEST_SPEC_MAX = "IRIS_LED_TEST_SPEC_MAX";
        public static final String IRIS_LED_TEST_SPEC_MIN = "IRIS_LED_TEST_SPEC_MIN";
        public static final String IRIS_PROX_ADC_SPEC_MAX = "IRIS_PROX_ADC_SPEC_MAX";
        public static final String IRIS_PROX_ADC_SPEC_MIN = "IRIS_PROX_ADC_SPEC_MIN";
        public static final String IRIS_PROX_OFFSET_SPEC_MAX = "IRIS_PROX_OFFSET_SPEC_MAX";
        public static final String IRIS_PROX_OFFSET_SPEC_MIN = "IRIS_PROX_OFFSET_SPEC_MIN";
        public static final String LED_POWER_MAX = "LED_POWER_MAX";
        public static final String LED_POWER_MIN = "LED_POWER_MIN";
        public static final String LIGHT_SENSOR_DOWN_LEVEL_1 = "LIGHT_SENSOR_DOWN_LEVEL_1";
        public static final String LIGHT_SENSOR_DOWN_LEVEL_2 = "LIGHT_SENSOR_DOWN_LEVEL_2";
        public static final String LIGHT_SENSOR_DOWN_LEVEL_3 = "LIGHT_SENSOR_DOWN_LEVEL_3";
        public static final String LIGHT_SENSOR_DOWN_LEVEL_4 = "LIGHT_SENSOR_DOWN_LEVEL_4";
        public static final String LIGHT_SENSOR_DOWN_LEVEL_5 = "LIGHT_SENSOR_DOWN_LEVEL_5";
        public static final String LIGHT_SENSOR_DOWN_LEVEL_6 = "LIGHT_SENSOR_DOWN_LEVEL_6";
        public static final String LIGHT_SENSOR_DOWN_LEVEL_7 = "LIGHT_SENSOR_DOWN_LEVEL_7";
        public static final String LIGHT_SENSOR_UP_LEVEL_1 = "LIGHT_SENSOR_UP_LEVEL_1";
        public static final String LIGHT_SENSOR_UP_LEVEL_2 = "LIGHT_SENSOR_UP_LEVEL_2";
        public static final String LIGHT_SENSOR_UP_LEVEL_3 = "LIGHT_SENSOR_UP_LEVEL_3";
        public static final String LIGHT_SENSOR_UP_LEVEL_4 = "LIGHT_SENSOR_UP_LEVEL_4";
        public static final String LIGHT_SENSOR_UP_LEVEL_5 = "LIGHT_SENSOR_UP_LEVEL_5";
        public static final String LIGHT_SENSOR_UP_LEVEL_6 = "LIGHT_SENSOR_UP_LEVEL_6";
        public static final String LIGHT_SENSOR_UP_LEVEL_7 = "LIGHT_SENSOR_UP_LEVEL_7";
        public static final String LOAD_CHARGE_SPEC_MAX = "LOAD_CHARGE_SPEC_MAX";
        public static final String LOAD_CHARGE_SPEC_MIN = "LOAD_CHARGE_SPEC_MIN";
        public static final String LOOPBACK_VOLUME = "LOOPBACK_VOLUME";
        public static final String MAGNETIC_SENSOR_SELFTEST_X_MAX = "MAGNETIC_SENSOR_SELFTEST_X_MAX";
        public static final String MAGNETIC_SENSOR_SELFTEST_X_MIN = "MAGNETIC_SENSOR_SELFTEST_X_MIN";
        public static final String MIC_DIFF_SPEC_MAX = "MIC_DIFF_SPEC_MAX";
        public static final String MIC_DIFF_SPEC_MIN = "MIC_DIFF_SPEC_MIN";
        public static final String MIC_DIFF_TYPE_VER = "MIC_DIFF_TYPE_VER";
        public static final String MOOD_LED_RGB_COLOR_1 = "MOOD_LED_RGB_COLOR_1";
        public static final String MOOD_LED_RGB_COLOR_2 = "MOOD_LED_RGB_COLOR_2";
        public static final String MOOD_LED_RGB_COLOR_3 = "MOOD_LED_RGB_COLOR_3";
        public static final String MOOD_LED_UX5_COLOR_1 = "MOOD_LED_UX5_COLOR_1";
        public static final String MOOD_LED_UX5_COLOR_2 = "MOOD_LED_UX5_COLOR_2";
        public static final String MOOD_LED_UX5_COLOR_3 = "MOOD_LED_UX5_COLOR_3";
        public static final String MOOD_LED_UX5_COLOR_4 = "MOOD_LED_UX5_COLOR_4";
        public static final String MOOD_LED_UX5_COLOR_5 = "MOOD_LED_UX5_COLOR_5";
        public static final String NORMAL_CHARGE_CURRRENT_SPEC_MAX = "NORMAL_CHARGE_CURRRENT_SPEC_MAX";
        public static final String NORMAL_CHARGE_CURRRENT_SPEC_MIN = "NORMAL_CHARGE_CURRRENT_SPEC_MIN";
        public static final String NORMAL_CHARGE_VOLTAGE = "NORMAL_CHARGE_VOLTAGE";
        public static final String NO_RGBSENSOR_SUPPORT_REV = "NO_RGBSENSOR_SUPPORT_REV";
        public static final String OIS_INITIAL_SPEC_MAX = "OIS_INITIAL_SPEC_MAX";
        public static final String OIS_INITIAL_SPEC_MIN = "OIS_INITIAL_SPEC_MIN";
        public static final String OIS_SELFTEST_SPEC_THRESHOLD = "OIS_SELFTEST_SPEC_THRESHOLD";
        public static final String PD_CHARGE_SELFTEST_DELAY = "PD_CHARGE_SELFTEST_DELAY";
        public static final String PD_CHARGE_SPEC_MAX = "PD_CHARGE_SPEC_MAX";
        public static final String PD_CHARGE_SPEC_MIN = "PD_CHARGE_SPEC_MIN";
        public static final String PD_CURRRENT_SPEC_MAX = "PD_CURRRENT_SPEC_MAX";
        public static final String PD_CURRRENT_SPEC_MIN = "PD_CURRRENT_SPEC_MIN";
        public static final String PD_VOLTAGE = "PD_VOLTAGE";
        public static final String PD_VOLTAGE_IN_USBTYPEC = "PD_VOLTAGE_IN_USBTYPEC";
        public static final String POGO_PIN2_TEST_SPEC_MAX = "POGO_PIN2_TEST_SPEC_MAX";
        public static final String POGO_PIN2_TEST_SPEC_MIN = "POGO_PIN2_TEST_SPEC_MIN";
        public static final String POGO_PIN_TEST_SPEC_MAX = "POGO_PIN_TEST_SPEC_MAX";
        public static final String POGO_PIN_TEST_SPEC_MIN = "POGO_PIN_TEST_SPEC_MIN";
        public static final String QUICK_CHARGE_3_CURRRENT_SPEC_MAX = "QUICK_CHARGE_3_CURRRENT_SPEC_MAX";
        public static final String QUICK_CHARGE_3_CURRRENT_SPEC_MIN = "QUICK_CHARGE_3_CURRRENT_SPEC_MIN";
        public static final String QUICK_CHARGE_3_VOLTAGE_SPEC_MAX = "QUICK_CHARGE_3_VOLTAGE_SPEC_MAX";
        public static final String QUICK_CHARGE_3_VOLTAGE_SPEC_MIN = "QUICK_CHARGE_3_VOLTAGE_SPEC_MIN";
        public static final String QUICK_CHARGE_NORMAL_CURRRENT_SPEC_MAX = "QUICK_CHARGE_NORMAL_CURRRENT_SPEC_MAX";
        public static final String QUICK_CHARGE_NORMAL_CURRRENT_SPEC_MIN = "QUICK_CHARGE_NORMAL_CURRRENT_SPEC_MIN";
        public static final String QUICK_CHARGE_NORMAL_VOLTAGE_SPEC_MAX = "QUICK_CHARGE_NORMAL_VOLTAGE_SPEC_MAX";
        public static final String QUICK_CHARGE_NORMAL_VOLTAGE_SPEC_MIN = "QUICK_CHARGE_NORMAL_VOLTAGE_SPEC_MIN";
        public static final String RANGE_LIGHT_BRIGHT = "RANGE_LIGHT_BRIGHT";
        public static final String RANGE_LIGHT_DARK = "RANGE_LIGHT_DARK";
        public static final String RCV_CAL_NXP_IMPEDANCE_SPEC = "RCV_CAL_NXP_IMPEDANCE_SPEC";
        public static final String RCV_CAL_NXP_TEMPERATURE_SPEC = "RCV_CAL_NXP_TEMPERATURE_SPEC";
        public static final String RGBSENSOR_SUPPORT_WHITE = "RGBSENSOR_SUPPORT_WHITE";
        public static final String SBU_SPEC_MAX = "SBU_SPEC_MAX";
        public static final String SBU_SPEC_MIN = "SBU_SPEC_MIN";
        public static final String SENSING_OPEN_CHECK_SPEC = "SENSING_OPEN_CHECK_SPEC";
        public static final String SIMPLE_TEST_G_MAX = "SIMPLE_TEST_G_MAX";
        public static final String SIMPLE_TEST_G_MIN = "SIMPLE_TEST_G_MIN";
        public static final String SPEN_ACC_SELF_M_X_SPEC_MAX = "SPEN_ACC_SELF_M_X_SPEC_MAX";
        public static final String SPEN_ACC_SELF_M_X_SPEC_MIN = "SPEN_ACC_SELF_M_X_SPEC_MIN";
        public static final String SPEN_ACC_SELF_M_Y_SPEC_MAX = "SPEN_ACC_SELF_M_Y_SPEC_MAX";
        public static final String SPEN_ACC_SELF_M_Y_SPEC_MIN = "SPEN_ACC_SELF_M_Y_SPEC_MIN";
        public static final String SPEN_ACC_SELF_M_Z_SPEC_MAX = "SPEN_ACC_SELF_M_Z_SPEC_MAX";
        public static final String SPEN_ACC_SELF_M_Z_SPEC_MIN = "SPEN_ACC_SELF_M_Z_SPEC_MIN";
        public static final String SPEN_ACC_SELF_P_X_SPEC_MAX = "SPEN_ACC_SELF_P_X_SPEC_MAX";
        public static final String SPEN_ACC_SELF_P_X_SPEC_MIN = "SPEN_ACC_SELF_P_X_SPEC_MIN";
        public static final String SPEN_ACC_SELF_P_Y_SPEC_MAX = "SPEN_ACC_SELF_P_Y_SPEC_MAX";
        public static final String SPEN_ACC_SELF_P_Y_SPEC_MIN = "SPEN_ACC_SELF_P_Y_SPEC_MIN";
        public static final String SPEN_ACC_SELF_P_Z_SPEC_MAX = "SPEN_ACC_SELF_P_Z_SPEC_MAX";
        public static final String SPEN_ACC_SELF_P_Z_SPEC_MIN = "SPEN_ACC_SELF_P_Z_SPEC_MIN";
        public static final String SPEN_ACC_VECTOR_SUM_SPEC_MAX = "SPEN_ACC_VECTOR_SUM_SPEC_MAX";
        public static final String SPEN_ACC_VECTOR_SUM_SPEC_MIN = "SPEN_ACC_VECTOR_SUM_SPEC_MIN";
        public static final String SPEN_BATTERY_CHECK_DELAY_AFTER_DISCHARGING = "SPEN_BATTERY_CHECK_DELAY_AFTER_DISCHARGING";
        public static final String SPEN_BLE_BATT0_SPEC_MAX = "SPEN_BLE_BATT0_SPEC_MAX";
        public static final String SPEN_BLE_BATT0_SPEC_MIN = "SPEN_BLE_BATT0_SPEC_MIN";
        public static final String SPEN_BLE_BATT12_SPEC_MAX = "SPEN_BLE_BATT12_SPEC_MAX";
        public static final String SPEN_BLE_BATT12_SPEC_MIN = "SPEN_BLE_BATT12_SPEC_MIN";
        public static final String SPEN_BLE_BATT1_SPEC_MAX = "SPEN_BLE_BATT1_SPEC_MAX";
        public static final String SPEN_BLE_BATT1_SPEC_MIN = "SPEN_BLE_BATT1_SPEC_MIN";
        public static final String SPEN_BLE_BATT21_SPEC_MAX_FORMULA_COEFFICIENT_A = "SPEN_BLE_BATT21_SPEC_MAX_FORMULA_COEFFICIENT_A";
        public static final String SPEN_BLE_BATT21_SPEC_MAX_FORMULA_COEFFICIENT_B = "SPEN_BLE_BATT21_SPEC_MAX_FORMULA_COEFFICIENT_B";
        public static final String SPEN_BLE_BATT21_SPEC_MAX_FORMULA_COEFFICIENT_C = "SPEN_BLE_BATT21_SPEC_MAX_FORMULA_COEFFICIENT_C";
        public static final String SPEN_BLE_BATT21_SPEC_MAX_FORMULA_COEFFICIENT_D = "SPEN_BLE_BATT21_SPEC_MAX_FORMULA_COEFFICIENT_D";
        public static final String SPEN_BLE_BATT21_SPEC_MIN_FORMULA_COEFFICIENT_A = "SPEN_BLE_BATT21_SPEC_MIN_FORMULA_COEFFICIENT_A";
        public static final String SPEN_BLE_BATT21_SPEC_MIN_FORMULA_COEFFICIENT_B = "SPEN_BLE_BATT21_SPEC_MIN_FORMULA_COEFFICIENT_B";
        public static final String SPEN_BLE_BATT21_SPEC_MIN_FORMULA_COEFFICIENT_C = "SPEN_BLE_BATT21_SPEC_MIN_FORMULA_COEFFICIENT_C";
        public static final String SPEN_BLE_BATT21_SPEC_MIN_FORMULA_COEFFICIENT_D = "SPEN_BLE_BATT21_SPEC_MIN_FORMULA_COEFFICIENT_D";
        public static final String SPEN_BLE_BATT23_SPEC_MAX = "SPEN_BLE_BATT23_SPEC_MAX";
        public static final String SPEN_BLE_BATT23_SPEC_MIN = "SPEN_BLE_BATT23_SPEC_MIN";
        public static final String SPEN_BLE_BATT34_SPEC_MAX = "SPEN_BLE_BATT34_SPEC_MAX";
        public static final String SPEN_BLE_BATT34_SPEC_MAX_FORMULA_COEFFICIENT_A = "SPEN_BLE_BATT34_SPEC_MAX_FORMULA_COEFFICIENT_A";
        public static final String SPEN_BLE_BATT34_SPEC_MAX_FORMULA_COEFFICIENT_B = "SPEN_BLE_BATT34_SPEC_MAX_FORMULA_COEFFICIENT_B";
        public static final String SPEN_BLE_BATT34_SPEC_MAX_FORMULA_COEFFICIENT_C = "SPEN_BLE_BATT34_SPEC_MAX_FORMULA_COEFFICIENT_C";
        public static final String SPEN_BLE_BATT34_SPEC_MAX_FORMULA_COEFFICIENT_D = "SPEN_BLE_BATT34_SPEC_MAX_FORMULA_COEFFICIENT_D";
        public static final String SPEN_BLE_BATT34_SPEC_MIN = "SPEN_BLE_BATT34_SPEC_MIN";
        public static final String SPEN_BLE_BATT34_SPEC_MIN_FORMULA_COEFFICIENT_A = "SPEN_BLE_BATT34_SPEC_MIN_FORMULA_COEFFICIENT_A";
        public static final String SPEN_BLE_BATT34_SPEC_MIN_FORMULA_COEFFICIENT_B = "SPEN_BLE_BATT34_SPEC_MIN_FORMULA_COEFFICIENT_B";
        public static final String SPEN_BLE_BATT34_SPEC_MIN_FORMULA_COEFFICIENT_C = "SPEN_BLE_BATT34_SPEC_MIN_FORMULA_COEFFICIENT_C";
        public static final String SPEN_BLE_BATT34_SPEC_MIN_FORMULA_COEFFICIENT_D = "SPEN_BLE_BATT34_SPEC_MIN_FORMULA_COEFFICIENT_D";
        public static final String SPEN_BLE_BATT43_SPEC_MAX = "SPEN_BLE_BATT43_SPEC_MAX";
        public static final String SPEN_BLE_BATT43_SPEC_MIN = "SPEN_BLE_BATT43_SPEC_MIN";
        public static final String SPEN_BLE_FW_VER_SPEC_MIN = "SPEN_BLE_FW_VER_SPEC_MIN";
        public static final String SPEN_BLE_RSSI_SPEC_MAX = "SPEN_BLE_RSSI_SPEC_MAX";
        public static final String SPEN_BLE_RSSI_SPEC_MIN = "SPEN_BLE_RSSI_SPEC_MIN";
        public static final String SPEN_BLE_TEST_MINRSSI = "SPEN_BLE_TEST_MINRSSI";
        public static final String SPEN_BLE_TEST_MINRSSI_FINAL = "SPEN_BLE_TEST_MINRSSI_FINAL";
        public static final String SPEN_BLE_TEST_SCANDELAY = "SPEN_BLE_TEST_SCANDELAY";
        public static final String SPEN_BLE_TEST_SCAN_PERIOD = "SPEN_BLE_TEST_SCAN_PERIOD";
        public static final String SPEN_BLE_TEST_SCAN_PERIOD_RETRY = "SPEN_BLE_TEST_SCAN_PERIOD_RETRY";
        public static final String SPEN_COLOR_CODE_LIST = "SPEN_COLOR_CODE_LIST";
        public static final String SPEN_DISTANCE_ABS_SPEC = "SPEN_DISTANCE_ABS_SPEC";
        public static final String SPEN_GRAVITY_BLOCK_CHECK_FW_VER_SPEC_MIN = "SPEN_GRAVITY_BLOCK_CHECK_FW_VER_SPEC_MIN";
        public static final String SPEN_GYRO_SELF_DIFF_X_SPEC_MAX = "SPEN_GYRO_SELF_DIFF_X_SPEC_MAX";
        public static final String SPEN_GYRO_SELF_DIFF_X_SPEC_MIN = "SPEN_GYRO_SELF_DIFF_X_SPEC_MIN";
        public static final String SPEN_GYRO_SELF_DIFF_Y_SPEC_MAX = "SPEN_GYRO_SELF_DIFF_Y_SPEC_MAX";
        public static final String SPEN_GYRO_SELF_DIFF_Y_SPEC_MIN = "SPEN_GYRO_SELF_DIFF_Y_SPEC_MIN";
        public static final String SPEN_GYRO_SELF_DIFF_Z_SPEC_MAX = "SPEN_GYRO_SELF_DIFF_Z_SPEC_MAX";
        public static final String SPEN_GYRO_SELF_DIFF_Z_SPEC_MIN = "SPEN_GYRO_SELF_DIFF_Z_SPEC_MIN";
        public static final String SPEN_GYRO_SELF_X_SPEC_MAX = "SPEN_GYRO_SELF_X_SPEC_MAX";
        public static final String SPEN_GYRO_SELF_X_SPEC_MIN = "SPEN_GYRO_SELF_X_SPEC_MIN";
        public static final String SPEN_GYRO_SELF_Y_SPEC_MAX = "SPEN_GYRO_SELF_Y_SPEC_MAX";
        public static final String SPEN_GYRO_SELF_Y_SPEC_MIN = "SPEN_GYRO_SELF_Y_SPEC_MIN";
        public static final String SPEN_GYRO_SELF_Z_SPEC_MAX = "SPEN_GYRO_SELF_Z_SPEC_MAX";
        public static final String SPEN_GYRO_SELF_Z_SPEC_MIN = "SPEN_GYRO_SELF_Z_SPEC_MIN";
        public static final String SPEN_GYRO_ZRO_AVG_X_SPEC_MAX = "SPEN_GYRO_ZRO_AVG_X_SPEC_MAX";
        public static final String SPEN_GYRO_ZRO_AVG_X_SPEC_MIN = "SPEN_GYRO_ZRO_AVG_X_SPEC_MIN";
        public static final String SPEN_GYRO_ZRO_AVG_Y_SPEC_MAX = "SPEN_GYRO_ZRO_AVG_Y_SPEC_MAX";
        public static final String SPEN_GYRO_ZRO_AVG_Y_SPEC_MIN = "SPEN_GYRO_ZRO_AVG_Y_SPEC_MIN";
        public static final String SPEN_GYRO_ZRO_AVG_Z_SPEC_MAX = "SPEN_GYRO_ZRO_AVG_Z_SPEC_MAX";
        public static final String SPEN_GYRO_ZRO_AVG_Z_SPEC_MIN = "SPEN_GYRO_ZRO_AVG_Z_SPEC_MIN";
        public static final String SPEN_NODE_COUNT_HEIGHT = "SPEN_NODE_COUNT_HEIGHT";
        public static final String SPEN_NODE_COUNT_WIDTH = "SPEN_NODE_COUNT_WIDTH";
        public static final String SPEN_UNNECESSARY_NODE_COUNT = "SPEN_UNNECESSARY_NODE_COUNT";
        public static final String SPK_CAL_CIRRUS_REPT_LEFT_SPEC = "SPK_CAL_CIRRUS_REPT_LEFT_SPEC";
        public static final String SPK_CAL_CIRRUS_REPT_RIGHT_SPEC = "SPK_CAL_CIRRUS_REPT_RIGHT_SPEC";
        public static final String SPK_CAL_CIRRUS_REPT_SPEC = "SPK_CAL_CIRRUS_REPT_SPEC";
        public static final String SPK_CAL_CIRRUS_TEMPERATURE_SPEC = "SPK_CAL_CIRRUS_TEMPERATURE_SPEC";
        public static final String SPK_CAL_GOODIX_IMPEDANCE_SPEC = "SPK_CAL_GOODIX_IMPEDANCE_SPEC";
        public static final String SPK_CAL_GOODIX_TEMPERATURE_SPEC = "SPK_CAL_GOODIX_TEMPERATURE_SPEC";
        public static final String SPK_CAL_MAXIM_IMPEDANCE_SPEC = "SPK_CAL_MAXIM_IMPEDANCE_SPEC";
        public static final String SPK_CAL_MAXIM_TEMPERATURE_SPEC = "SPK_CAL_MAXIM_TEMPERATURE_SPEC";
        public static final String SPK_CAL_NXP_IMPEDANCE_SPEC = "SPK_CAL_NXP_IMPEDANCE_SPEC";
        public static final String SPK_CAL_NXP_TEMPERATURE_SPEC = "SPK_CAL_NXP_TEMPERATURE_SPEC";
        public static final String SPK_CAL_QUALCOMM_IMPEDANCE_SPEC = "SPK_CAL_QUALCOMM_IMPEDANCE_SPEC";
        public static final String SPK_CAL_QUALCOMM_TEMPERATURE_SPEC = "SPK_CAL_QUALCOMM_TEMPERATURE_SPEC";
        public static final String SPK_CAL_RICHTEK_IMPEDANCE_SPEC = "SPK_CAL_RICHTEK_IMPEDANCE_SPEC";
        public static final String SPK_CAL_RICHTEK_TEMPERATURE_SPEC = "SPK_CAL_RICHTEK_TEMPERATURE_SPEC";
        public static final String SPK_CAL_TI_IMPEDANCE_SPEC = "SPK_CAL_TI_IMPEDANCE_SPEC";
        public static final String SPK_CAL_TI_TEMPERATURE_SPEC = "SPK_CAL_TI_TEMPERATURE_SPEC";
        public static final String SYS_SCREEN_SAVER_SLEEP = "SYS_SCREEN_SAVER_SLEEP";
        public static final String TAG = "HardwareSpec";
        public static final String TOUCH_BACK_KEY_SPEC_MAX = "TOUCH_BACK_KEY_SPEC_MAX";
        public static final String TOUCH_BACK_KEY_SPEC_MIN = "TOUCH_BACK_KEY_SPEC_MIN";
        public static final String TOUCH_HIDDEN_KEY1_SPEC_MAX = "TOUCH_HIDDEN_KEY1_SPEC_MAX";
        public static final String TOUCH_HIDDEN_KEY1_SPEC_MIN = "TOUCH_HIDDEN_KEY1_SPEC_MIN";
        public static final String TOUCH_HIDDEN_KEY2_SPEC_MAX = "TOUCH_HIDDEN_KEY2_SPEC_MAX";
        public static final String TOUCH_HIDDEN_KEY2_SPEC_MIN = "TOUCH_HIDDEN_KEY2_SPEC_MIN";
        public static final String TOUCH_HIDDEN_KEY3_SPEC_MAX = "TOUCH_HIDDEN_KEY3_SPEC_MAX";
        public static final String TOUCH_HIDDEN_KEY3_SPEC_MIN = "TOUCH_HIDDEN_KEY3_SPEC_MIN";
        public static final String TOUCH_HIDDEN_KEY4_SPEC_MAX = "TOUCH_HIDDEN_KEY4_SPEC_MAX";
        public static final String TOUCH_HIDDEN_KEY4_SPEC_MIN = "TOUCH_HIDDEN_KEY4_SPEC_MIN";
        public static final String TOUCH_KEY_ABOV_SPEC_MAX = "TOUCH_KEY_ABOV_SPEC_MAX";
        public static final String TOUCH_KEY_ABOV_SPEC_MIN = "TOUCH_KEY_ABOV_SPEC_MIN";
        public static final String TOUCH_KEY_CYPRESS_SPEC_MAX = "TOUCH_KEY_CYPRESS_SPEC_MAX";
        public static final String TOUCH_KEY_CYPRESS_SPEC_MIN = "TOUCH_KEY_CYPRESS_SPEC_MIN";
        public static final String TOUCH_KEY_DEFAULT_SCALING = "TOUCH_KEY_DEFAULT_SCALING";
        public static final String TOUCH_KEY_GRAPH_REDUCTION = "TOUCH_KEY_GRAPH_REDUCTION";
        public static final String TOUCH_KEY_OUTER_SPEC_MAX = "TOUCH_KEY_OUTER_SPEC_MAX";
        public static final String TOUCH_KEY_OUTER_SPEC_MIN = "TOUCH_KEY_OUTER_SPEC_MIN";
        public static final String TOUCH_KEY_SPEC_MAX = "TOUCH_KEY_SPEC_MAX";
        public static final String TOUCH_KEY_SPEC_MIN = "TOUCH_KEY_SPEC_MIN";
        public static final String TOUCH_MENU_KEY_SPEC_MAX = "TOUCH_MENU_KEY_SPEC_MAX";
        public static final String TOUCH_MENU_KEY_SPEC_MIN = "TOUCH_MENU_KEY_SPEC_MIN";
        public static final String TOUCH_REF_KEY1_SPEC_MAX = "TOUCH_REF_KEY1_SPEC_MAX";
        public static final String TOUCH_REF_KEY1_SPEC_MIN = "TOUCH_REF_KEY1_SPEC_MIN";
        public static final String TOUCH_REF_KEY2_SPEC_MAX = "TOUCH_REF_KEY2_SPEC_MAX";
        public static final String TOUCH_REF_KEY2_SPEC_MIN = "TOUCH_REF_KEY2_SPEC_MIN";
        public static final String TOUCH_SWITCH_KEY_SPEC_MAX = "TOUCH_SWITCH_KEY_SPEC_MAX";
        public static final String TOUCH_SWITCH_KEY_SPEC_MIN = "TOUCH_SWITCH_KEY_SPEC_MIN";
        public static final String TSP_CONNECTION_MIN = "TSP_CONNECTION_MIN";
        public static final String TSP_DEADZONE_HEIGHT = "TSP_DEADZONE_HEIGHT";
        public static final String TSP_DEADZONE_WIDTH = "TSP_DEADZONE_WIDTH";
        public static final String TSP_HOVER_BLOCK_SIZE_HEIGHT_UM = "TSP_HOVER_BLOCK_SIZE_HEIGHT_UM";
        public static final String TSP_HOVER_BLOCK_SIZE_WIDTH_UM = "TSP_HOVER_BLOCK_SIZE_WIDTH_UM";
        public static final String TSP_HOVER_CIRCLE_INNER_MAGNIFIED = "TSP_HOVER_CIRCLE_INNER_MAGNIFIED";
        public static final String TSP_HOVER_CIRCLE_OUTER_MAGNIFIED = "TSP_HOVER_CIRCLE_OUTER_MAGNIFIED";
        public static final String TSP_NODE_COUNT_HEIGHT = "TSP_NODE_COUNT_HEIGHT";
        public static final String TSP_NODE_COUNT_WIDTH = "TSP_NODE_COUNT_WIDTH";
        public static final String TSP_SELFTEST_ABS_CAP_DATA_RX_MAX = "TSP_SELFTEST_ABS_CAP_DATA_RX_MAX";
        public static final String TSP_SELFTEST_ABS_CAP_DATA_RX_MIN = "TSP_SELFTEST_ABS_CAP_DATA_RX_MIN";
        public static final String TSP_SELFTEST_ABS_CAP_DATA_TX_MAX = "TSP_SELFTEST_ABS_CAP_DATA_TX_MAX";
        public static final String TSP_SELFTEST_ABS_CAP_DATA_TX_MIN = "TSP_SELFTEST_ABS_CAP_DATA_TX_MIN";
        public static final String TSP_SELFTEST_CM_OFFSET_GAP_CENTER_GREAT_SEC = "TSP_SELFTEST_CM_OFFSET_GAP_CENTER_GREAT_SEC";
        public static final String TSP_SELFTEST_CM_OFFSET_GAP_ONLY_CORNER_XY_SEC = "TSP_SELFTEST_CM_OFFSET_GAP_ONLY_CORNER_XY_SEC";
        public static final String TSP_SELFTEST_CM_OFFSET_GAP_ONLY_CORNER_XY_SEC_LOW_FREQ = "TSP_SELFTEST_CM_OFFSET_GAP_ONLY_CORNER_XY_SEC_LOW_FREQ";
        public static final String TSP_SELFTEST_CM_OFFSET_GAP_SIDE_X_GREAT_SEC = "TSP_SELFTEST_CM_OFFSET_GAP_SIDE_X_GREAT_SEC";
        public static final String TSP_SELFTEST_CM_OFFSET_GAP_SPLIT_CORNER_XY_SEC = "TSP_SELFTEST_CM_OFFSET_GAP_SPLIT_CORNER_XY_SEC";
        public static final String TSP_SELFTEST_CM_OFFSET_GAP_SPLIT_CORNER_XY_SEC_LOW_FREQ = "TSP_SELFTEST_CM_OFFSET_GAP_SPLIT_CORNER_XY_SEC_LOW_FREQ";
        public static final String TSP_SELFTEST_CM_OFFSET_GAP_Y1_GREAT_SEC = "TSP_SELFTEST_CM_OFFSET_GAP_Y1_GREAT_SEC";
        public static final String TSP_SELFTEST_CM_OFFSET_GAP_Y2_GREAT_SEC = "TSP_SELFTEST_CM_OFFSET_GAP_Y2_GREAT_SEC";
        public static final String TSP_SELFTEST_CM_OFFSET_GAP_Y3_GREAT_SEC = "TSP_SELFTEST_CM_OFFSET_GAP_Y3_GREAT_SEC";
        public static final String TSP_SELFTEST_CM_OFFSET_ONLY_CORNER_MAX_SEC = "TSP_SELFTEST_CM_OFFSET_ONLY_CORNER_MAX_SEC";
        public static final String TSP_SELFTEST_CM_OFFSET_ONLY_CORNER_MIN_SEC = "TSP_SELFTEST_CM_OFFSET_ONLY_CORNER_MIN_SEC";
        public static final String TSP_SELFTEST_CM_OFFSET_SPLIT_CORNER_GAP_SEC = "TSP_SELFTEST_CM_OFFSET_SPLIT_CORNER_GAP_SEC";
        public static final String TSP_SELFTEST_CM_OFFSET_SPLIT_CORNER_MAX_SEC = "TSP_SELFTEST_CM_OFFSET_SPLIT_CORNER_MAX_SEC";
        public static final String TSP_SELFTEST_CM_OFFSET_SPLIT_CORNER_MIN_SEC = "TSP_SELFTEST_CM_OFFSET_SPLIT_CORNER_MIN_SEC";
        public static final String TSP_SELFTEST_CM_PRE_DELTA_MAX_SEC = "TSP_SELFTEST_CM_PRE_DELTA_MAX_SEC";
        public static final String TSP_SELFTEST_CM_PRE_DELTA_MIN_SEC = "TSP_SELFTEST_CM_PRE_DELTA_MIN_SEC";
        public static final String TSP_SELFTEST_CM_UB_YCROSS_SEC = "TSP_SELFTEST_CM_UB_YCROSS_SEC";
        public static final String TSP_SELFTEST_CM_XY_SEC = "TSP_SELFTEST_CM_XY_SEC";
        public static final String TSP_SELFTEST_FORCE_CAL_MAX = "TSP_SELFTEST_FORCE_CAL_MAX";
        public static final String TSP_SELFTEST_FORCE_CAL_MIN = "TSP_SELFTEST_FORCE_CAL_MIN";
        public static final String TSP_SELFTEST_GAP_SEC = "TSP_SELFTEST_GAP_SEC";
        public static final String TSP_SELFTEST_HFDND_HGAP_KEY_MAX_ZINITIX = "TSP_SELFTEST_HFDND_HGAP_KEY_MAX_ZINITIX";
        public static final String TSP_SELFTEST_HFDND_HGAP_VIEW_MAX_ZINITIX = "TSP_SELFTEST_HFDND_HGAP_VIEW_MAX_ZINITIX";
        public static final String TSP_SELFTEST_HFDND_MAX_ZINITIX = "TSP_SELFTEST_HFDND_MAX_ZINITIX";
        public static final String TSP_SELFTEST_HFDND_MIN_ZINITIX = "TSP_SELFTEST_HFDND_MIN_ZINITIX";
        public static final String TSP_SELFTEST_HFDND_VGAP_KEY_MAX_ZINITIX = "TSP_SELFTEST_HFDND_VGAP_KEY_MAX_ZINITIX";
        public static final String TSP_SELFTEST_HFDND_VGAP_VIEW_MAX_ZINITIX = "TSP_SELFTEST_HFDND_VGAP_VIEW_MAX_ZINITIX";
        public static final String TSP_SELFTEST_HGAP_KEY_MAX_ZINITIX = "TSP_SELFTEST_HGAP_KEY_MAX_ZINITIX";
        public static final String TSP_SELFTEST_HGAP_VIEW_MAX_ZINITIX = "TSP_SELFTEST_HGAP_VIEW_MAX_ZINITIX";
        public static final String TSP_SELFTEST_KEY_CM_DATA_MAX_STM = "TSP_SELFTEST_KEY_CM_DATA_MAX_STM";
        public static final String TSP_SELFTEST_KEY_CM_DATA_MIN_STM = "TSP_SELFTEST_KEY_CM_DATA_MIN_STM";
        public static final String TSP_SELFTEST_MAX2 = "TSP_SELFTEST_MAX2";
        public static final String TSP_SELFTEST_MAX_SEC = "TSP_SELFTEST_MAX_SEC";
        public static final String TSP_SELFTEST_MIN2 = "TSP_SELFTEST_MIN2";
        public static final String TSP_SELFTEST_MIN_SEC = "TSP_SELFTEST_MIN_SEC";
        public static final String TSP_SELFTEST_REFERENCE_DIFF_H_MAX = "TSP_SELFTEST_REFERENCE_DIFF_H_MAX";
        public static final String TSP_SELFTEST_REFERENCE_DIFF_V_MAX = "TSP_SELFTEST_REFERENCE_DIFF_V_MAX";
        public static final String TSP_SELFTEST_RX_SHORT_KEY_MAX_ZINITIX = "TSP_SELFTEST_RX_SHORT_KEY_MAX_ZINITIX";
        public static final String TSP_SELFTEST_RX_SHORT_VIEW_MAX_ZINITIX = "TSP_SELFTEST_RX_SHORT_VIEW_MAX_ZINITIX";
        public static final String TSP_SELFTEST_SELF_DND_MAX_ZINITIX = "TSP_SELFTEST_SELF_DND_MAX_ZINITIX";
        public static final String TSP_SELFTEST_SELF_DND_MIN_ZINITIX = "TSP_SELFTEST_SELF_DND_MIN_ZINITIX";
        public static final String TSP_SELFTEST_SELF_HGAP_VIEW_MAX_ZINITIX = "TSP_SELFTEST_SELF_HGAP_VIEW_MAX_ZINITIX";
        public static final String TSP_SELFTEST_SELF_OFFSET_X_GAP = "TSP_SELFTEST_SELF_OFFSET_X_GAP";
        public static final String TSP_SELFTEST_SELF_OFFSET_X_MAX = "TSP_SELFTEST_SELF_OFFSET_X_MAX";
        public static final String TSP_SELFTEST_SELF_OFFSET_X_MIN = "TSP_SELFTEST_SELF_OFFSET_X_MIN";
        public static final String TSP_SELFTEST_SELF_OFFSET_Y_GAP = "TSP_SELFTEST_SELF_OFFSET_Y_GAP";
        public static final String TSP_SELFTEST_SELF_OFFSET_Y_MAX = "TSP_SELFTEST_SELF_OFFSET_Y_MAX";
        public static final String TSP_SELFTEST_SELF_OFFSET_Y_MIN = "TSP_SELFTEST_SELF_OFFSET_Y_MIN";
        public static final String TSP_SELFTEST_SELF_PRE_DELTA_GAP = "TSP_SELFTEST_SELF_PRE_DELTA_GAP";
        public static final String TSP_SELFTEST_SELF_PRE_DELTA_MAX = "TSP_SELFTEST_SELF_PRE_DELTA_MAX";
        public static final String TSP_SELFTEST_SELF_PRE_DELTA_MIN = "TSP_SELFTEST_SELF_PRE_DELTA_MIN";
        public static final String TSP_SELFTEST_SLOPE_MAX = "TSP_SELFTEST_SLOPE_MAX";
        public static final String TSP_SELFTEST_SLOPE_MIN = "TSP_SELFTEST_SLOPE_MIN";
        public static final String TSP_SELFTEST_SPEC_MAX_MINUS_MIN = "TSP_SELFTEST_SPEC_MAX_MINUS_MIN";
        public static final String TSP_SELFTEST_TX_SHORT_KEY_MAX_ZINITIX = "TSP_SELFTEST_TX_SHORT_KEY_MAX_ZINITIX";
        public static final String TSP_SELFTEST_TX_SHORT_VIEW_MAX_ZINITIX = "TSP_SELFTEST_TX_SHORT_VIEW_MAX_ZINITIX";
        public static final String TSP_SELFTEST_VGAP_KEY_MAX_ZINITIX = "TSP_SELFTEST_VGAP_KEY_MAX_ZINITIX";
        public static final String TSP_SELFTEST_VGAP_VIEW_MAX_ZINITIX = "TSP_SELFTEST_VGAP_VIEW_MAX_ZINITIX";
        public static final String TSP_SPEN_NODE_COUNT_HEIGHT = "TSP_SPEN_NODE_COUNT_HEIGHT";
        public static final String TSP_SPEN_NODE_COUNT_WIDTH = "TSP_SPEN_NODE_COUNT_WIDTH";
        public static final String TSP_X_AXIS_CHANNEL = "TSP_X_AXIS_CHANNEL";
        public static final String TSP_Y_AXIS_CHANNEL = "TSP_Y_AXIS_CHANNEL";
        public static final String VCONN_SPEC_MAX = "VCONN_SPEC_MAX";
        public static final String VCONN_SPEC_MIN = "VCONN_SPEC_MIN";
        public static final String WACOM_HEIGHT_BASIS = "WACOM_HEIGHT_BASIS";
        public static final String WACOM_WIDTH_BASIS = "WACOM_WIDTH_BASIS";
        public static final String WATERPROOF_IS_OPEN_SPEC = "WATERPROOF_IS_OPEN_SPEC";
        public static final String WATERPROOF_L_LEAK_MAIN = "WATERPROOF_L_LEAK_MAIN";
        public static final String WATERPROOF_L_LEAK_SUB = "WATERPROOF_L_LEAK_SUB";
        public static final String WATERPROOF_S_LEAK_MAIN = "WATERPROOF_S_LEAK_MAIN";
        public static final String WATERPROOF_S_LEAK_SUB = "WATERPROOF_S_LEAK_SUB";
        public static final String WHITELED_COUNT = "WHITELED_COUNT";
        public static final String WHITELED_OFF = "WHITELED_OFF";
        public static final String WHITELED_ON = "WHITELED_ON";
        public static final String WIRELESSS_AFC_VOLTAGE = "WIRELESSS_AFC_VOLTAGE";
        public static final String WIRELESS_AFC_CURRENT_SPEC_MAX = "WIRELESS_AFC_CURRENT_SPEC_MAX";
        public static final String WIRELESS_AFC_CURRENT_SPEC_MIN = "WIRELESS_AFC_CURRENT_SPEC_MIN";
        public static final String WIRELESS_AFC_CURRENT_TEMP_SPEC_MAX = "WIRELESS_AFC_CURRENT_TEMP_SPEC_MAX";
        public static final String WIRELESS_AFC_CURRENT_TEMP_SPEC_MIN = "WIRELESS_AFC_CURRENT_TEMP_SPEC_MIN";
        public static final String WIRELESS_CHARGING_TX_EFFICIENCY_MIN = "WIRELESS_CHARGING_TX_EFFICIENCY_MIN";
        public static final String WIRELESS_CHARGING_TX_IIN3_MAX = "WIRELESS_CHARGING_TX_IIN3_MAX";
        public static final String WIRELESS_CHARGING_TX_IIN3_MIN = "WIRELESS_CHARGING_TX_IIN3_MIN";
        public static final String WIRELESS_CHARGING_TX_IOUT_MAX = "WIRELESS_CHARGING_TX_IOUT_MAX";
        public static final String WIRELESS_CHARGING_TX_IOUT_MIN = "WIRELESS_CHARGING_TX_IOUT_MIN";
        public static final String WIRELESS_CHARGING_TX_VIN3_MAX = "WIRELESS_CHARGING_TX_VIN3_MAX";
        public static final String WIRELESS_CHARGING_TX_VIN3_MIN = "WIRELESS_CHARGING_TX_VIN3_MIN";
        public static final String WIRELESS_CHARGING_TX_VOUT_MAX = "WIRELESS_CHARGING_TX_VOUT_MAX";
        public static final String WIRELESS_CHARGING_TX_VOUT_MIN = "WIRELESS_CHARGING_TX_VOUT_MIN";
        public static final String WIRELESS_CURRENT_SPEC_MAX = "WIRELESS_CURRENT_SPEC_MAX";
        public static final String WIRELESS_CURRENT_SPEC_MIN = "WIRELESS_CURRENT_SPEC_MIN";
        public static final String WIRELESS_FAST_CHARGE_2_SPEC_MAX = "WIRELESS_FAST_CHARGE_2_SPEC_MAX";
        public static final String WIRELESS_FAST_CHARGE_2_SPEC_MIN = "WIRELESS_FAST_CHARGE_2_SPEC_MIN";
        public static final String WIRELESS_FAST_CHARGE_3_SPEC_MAX_DUAL = "WIRELESS_FAST_CHARGE_3_SPEC_MAX_DUAL";
        public static final String WIRELESS_FAST_CHARGE_3_SPEC_MAX_SLAVE = "WIRELESS_FAST_CHARGE_3_SPEC_MAX_SLAVE";
        public static final String WIRELESS_FAST_CHARGE_3_SPEC_MIN_DUAL = "WIRELESS_FAST_CHARGE_3_SPEC_MIN_DUAL";
        public static final String WIRELESS_FAST_CHARGE_3_SPEC_MIN_SLAVE = "WIRELESS_FAST_CHARGE_3_SPEC_MIN_SLAVE";
        public static final String WIRELESS_NORMAL_CHARGE_VOLTAGE = "WIRELESS_NORMAL_CHARGE_VOLTAGE";

        public static boolean getBoolean(String id) {
            return Values.getBoolean(id, "value");
        }

        public static boolean getBoolean(String id, int logLevel) {
            return Values.getBoolean(id, "value", logLevel);
        }

        public static byte getByte(String id) {
            return Values.getByte(id, "value");
        }

        public static String getString(String id) {
            return Values.getString(id, "value");
        }

        public static String getStringWithNoExceptionLog(String id) {
            return Values.getStringWithNoExceptionLog(id, "value");
        }

        public static int getInt(String id) {
            return Values.getInt(id, "value");
        }

        public static long getLong(String id) {
            return Values.getLong(id, "value");
        }

        public static float getFloat(String id) {
            return Values.getFloat(id, "value");
        }

        public static double getDouble(String id) {
            return Values.getDouble(id, "value");
        }

        public static boolean getInvisible(String id) {
            return Values.getBoolean(id, "invisible");
        }
    }

    public static class Properties {
        public static final String ABC_LOG_RUNNING = "ABC_LOG_RUNNING";
        public static final String ABC_LOG_TRIGGER = "ABC_LOG_TRIGGER";
        public static final String ABC_RESULT = "ABC_RESULT";
        public static final String AP_FUSING_DATA = "AP_FUSING_DATA";
        public static final String AP_FUSING_VALUE = "AP_FUSING_VALUE";
        public static final String AP_PCB_ID = "AP_PCB_ID";
        public static final String ASB_VERSION = "ASB_VERSION";
        public static final String ATD_TTY_VALUE = "ATD_TTY_VALUE";
        public static final String BACKUP_INTERNEL_MEMORY_SIZE = "BACKUP_INTERNEL_MEMORY_SIZE";
        public static final String BACK_COVER_TYPE = "BACK_COVER_TYPE";
        public static final String BINARY_TYPE = "BINARY_TYPE";
        public static final String BOOTLOADER_VERSION = "BOOTLOADER_VERSION";
        public static final String BOOT_AP_SERIAL = "BOOT_AP_SERIAL";
        public static final String BOOT_COMPLETED = "BOOT_COMPLETED";
        public static final String BOOT_VERSION = "BOOT_VERSION";
        public static final String BUCK_MODE = "BUCK_MODE";
        public static final String BUILD_CHARACTERISTICS = "BUILD_CHARACTERISTICS";
        public static final String BUILD_TYPE = "BUILD_TYPE";
        public static final String CONTENTS_VERSION = "CONTENTS_VERSION";
        public static final String CPNV_BACKUP_CMD = "CPNV_BACKUP_CMD";
        public static final String CP_RAM_LOGGING = "CP_RAM_LOGGING";
        public static final String CSC_SALES_CODE = "CSC_SALES_CODE";
        public static final String CSC_VERSION = "CSC_VERSION";
        public static final String DEVICETEST_STATUS = "DEVICETEST_STATUS";
        public static final String EMMC_CHECKSUM = "EMMC_CHECKSUM";
        public static final String ESE_SUPPORT = "ESE_SUPPORT";
        public static final String FACM_NFC_TEST = "FACM_NFC_TEST";
        public static final String FACM_SECURITY_MODE = "FACM_SECURITY_MODE";
        public static final String FACTORYAPP_FAILHIST = "FACTORYAPP_FAILHIST";
        public static final String FACTORYAPP_FAILHIST_FAILITEM = "FACTORYAPP_FAILHIST_FAILITEM";
        public static final String FACTORYAPP_FAILHIST_RDMKEY = "FACTORYAPP_FAILHIST_RDMKEY";
        public static final String FACTORYAPP_FAILHIST_TIME = "FACTORYAPP_FAILHIST_TIME";
        public static final String FLOG_FOLDER = "FLOG_FOLDER";
        public static final String FLS_FOLDER_NAME = "FLS_FOLDER_NAME";
        public static final String FTL_GADGET_MODE = "FTL_GADGET_MODE";
        public static final String HDCP_SN = "HDCP_SN";
        public static final String HW_REVISION = "HW_REVISION";
        public static final String HW_VERSION = "HW_VERSION";
        public static final String ISS_ENABLED_STATE = "ISS_ENABLED_STATE";
        public static final String MAIN_CHIP_NAME_AP = "MAIN_CHIP_NAME_AP";
        public static final String MAIN_CHIP_NAME_CP = "MAIN_CHIP_NAME_CP";
        public static final String MAIN_CHIP_NAME_CP2 = "MAIN_CHIP_NAME_CP2";
        public static final String NFC_SWP1_SUPPORT = "NFC_SWP1_SUPPORT";
        public static final String NFC_SWP2_SUPPORT = "NFC_SWP2_SUPPORT";
        public static final String OS_VERSION = "OS_VERSION";
        public static final String PDA_VERSION = "PDA_VERSION";
        public static final String PDP_ACTION = "PDP_ACTION";
        public static final String PDP_LAST_JOB = "PDP_LAST_JOB";
        public static final String PGM_STAGE = "PGM_STAGE";
        public static final String PHONE_VERSION = "PHONE_VERSION";
        public static final String PRETEST_BLUETOOTH_BACKGROUND_TEST_RESULT = "PRETEST_BLUETOOTH_BACKGROUND_TEST_RESULT";
        public static final String PRETEST_WIFI_BACKGROUND_TEST_RESULT = "PRETEST_WIFI_BACKGROUND_TEST_RESULT";
        public static final String PRODUCTION_DATE = "PRODUCTION_DATE";
        public static final String PRODUCT_NAME = "PRODUCT_NAME";
        public static final String PROPERTIES_DEFAULT_STRING = "Unknown";
        public static final String PROTOTYPE_SN = "PROTOTYPE_SN";
        public static final String ROOTING_CHECK = "ROOTING_CHECK";
        public static final String RP = "RP";
        public static final String SERIAL_NUMBER = "SERIAL_NUMBER";
        public static final String SLAVE_PCB_ID = "SLAVE_PCB_ID";
        public static final String SUB_PCB_ID = "SUB_PCB_ID";
        public static final String SW_VERSION = "SW_VERSION";
        public static final String TAG = "Properties";
        public static final String UART_1K_VALUE = "UART_1K_VALUE";
        public static final String WARRANTY_BIT_CHECK = "WARRANTY_BIT_CHECK";
        public static final String WARRANTY_BIT_CHECK_OLD = "WARRANTY_BIT_CHECK_OLD";

        public static String get(String id) {
            String property = Values.getString(id, "key");
            XmlUtil.log_d(Support.CLASS_NAME, "Properties.get", "property=" + property);
            return SystemProperties.get(property, PROPERTIES_DEFAULT_STRING);
        }

        public static String getProp(String key) {
            XmlUtil.log_d(Support.CLASS_NAME, "Properties.get", "property=" + key);
            return SystemProperties.get(key, PROPERTIES_DEFAULT_STRING);
        }

        public static void set(String id, String value) {
            String property = Values.getString(id, "key");
            XmlUtil.log_d(Support.CLASS_NAME, "Properties.set", "property=" + property + ", value=" + value);
            SystemProperties.set(property, value);
        }

        public static void setProp(String key, String value) {
            SystemProperties.set(key, value);
            XmlUtil.log_d(Support.CLASS_NAME, "Properties.set", "property=" + key + ", value=" + value);
        }
    }

    public static class Kernel {
        public static final String ABCD_RAW = "ABCD_RAW";
        public static final String ACCELEROMETER_SENSOR_TYPE = "ACCELEROMETER_SENSOR_TYPE";
        public static final String ACCEL_SENSOR_CAL = "ACCEL_SENSOR_CAL";
        public static final String ACCEL_SENSOR_INTPIN = "ACCEL_SENSOR_INTPIN";
        public static final String ACCEL_SENSOR_NAME = "ACCEL_SENSOR_NAME";
        public static final String ACCEL_SENSOR_RAW = "ACCEL_SENSOR_RAW";
        public static final String ACCEL_SENSOR_SELFTEST = "ACCEL_SENSOR_SELFTEST";
        public static final String ACCEL_SENSOR_VENDOR = "ACCEL_SENSOR_VENDOR";
        public static final String ACC_COVER_PWR_LSI = "ACC_COVER_PWR_LSI";
        public static final String ACC_COVER_PWR_QCOM = "ACC_COVER_PWR_QCOM";
        public static final String ACC_COVER_UART_LSI = "ACC_COVER_UART_LSI";
        public static final String ACC_COVER_UART_QCOM = "ACC_COVER_UART_QCOM";
        public static final String ACH_I2S_SYSFS = "ACH_I2S_SYSFS";
        public static final String ADC_ERR_CONTROL = "ADC_ERR_CONTROL";
        public static final String AFC_DISABLE = "AFC_DISABLE";
        public static final String AFC_SENSING_INT = "AFC_SENSING_INT";
        public static final String AFC_SET_VOLTAGE = "AFC_SET_VOLTAGE";
        public static final String AIR_COMMAND_WIFI = "AIR_COMMAND_WIFI";
        public static final String ANYWAY_JIG = "ANYWAY_JIG";
        public static final String APCHIP_HW_REV_NUM = "APCHIP_HW_REV_NUM";
        public static final String APCHIP_TEMP_ADC = "APCHIP_TEMP_ADC";
        public static final String APCHIP_TEMP_POWER_POLICY = "APCHIP_TEMP_POWER_POLICY";
        public static final String APCHIP_TEMP_THERMISTOR0 = "APCHIP_TEMP_THERMISTOR0";
        public static final String APCHIP_TEMP_THERMISTOR1 = "APCHIP_TEMP_THERMISTOR1";
        public static final String APCHIP_TEMP_THERMISTOR2 = "APCHIP_TEMP_THERMISTOR2";
        public static final String APCHIP_TEMP_THERMISTOR3 = "APCHIP_TEMP_THERMISTOR3";
        public static final String APCHIP_TEMP_THERMISTOR4 = "APCHIP_TEMP_THERMISTOR4";
        public static final String APCHIP_TEMP_THERMISTOR5 = "APCHIP_TEMP_THERMISTOR5";
        public static final String APCHIP_TEMP_THERMISTOR6 = "APCHIP_TEMP_THERMISTOR6";
        public static final String APCHIP_TEMP_THERMISTOR7 = "APCHIP_TEMP_THERMISTOR7";
        public static final String AP_CHIP_CHECK = "AP_CHIP_CHECK";
        public static final String AP_CHIP_DOU_FUSING_BINS = "AP_CHIP_DOU_FUSING_BINS";
        public static final String AP_CHIP_DOU_FUSING_REV = "AP_CHIP_DOU_FUSING_REV";
        public static final String AP_CHIP_EVT_REVISION = "AP_CHIP_EVT_REVISION";
        public static final String AP_CHIP_FUSING_BIT = "AP_CHIP_FUSING_BIT";
        public static final String AP_CHIP_ID = "AP_CHIP_ID";
        public static final String AP_CHIP_ID2 = "AP_CHIP_ID2";
        public static final String AP_CHIP_ID_REVISION = "AP_CHIP_ID_REVISION";
        public static final String AP_CHIP_LOT_ID = "AP_CHIP_LOT_ID";
        public static final String AP_GROUP = "AP_GROUP";
        public static final String AUDIO_AMP_VENDOR = "AUDIO_AMP_VENDOR";
        public static final String AUDIO_CODEC_IC_DRIVER = "AUDIO_CODEC_IC_DRIVER";
        public static final String AUDIO_CODEC_VA_WDSP_COUNT = "AUDIO_CODEC_VA_WDSP_COUNT";
        public static final String AUDIO_CODEC_VA_WDSP_DELAY = "AUDIO_CODEC_VA_WDSP_DELAY";
        public static final String AUDIO_CODEC_VA_WDSP_STATE = "AUDIO_CODEC_VA_WDSP_STATE";
        public static final String AVAILABLE_PIN_CHECK = "AVAILABLE_PIN_CHECK";
        public static final String BARCODE_EMUL_FIRMWARE_VERSION = "BARCODE_EMUL_FIRMWARE_VERSION";
        public static final String BAROMETER_SENSOR_NAME = "BAROMETER_SENSOR_NAME";
        public static final String BAROMETE_CALIBRATION = "BAROMETE_CALIBRATION";
        public static final String BAROMETE_DELTA = "BAROMETE_DELTA";
        public static final String BAROMETE_NAME = "BAROMETE_NAME";
        public static final String BAROMETE_SELFTEST = "BAROMETE_SELFTEST";
        public static final String BAROMETE_TEMPERATURE = "BAROMETE_TEMPERATURE";
        public static final String BAROMETE_VENDOR = "BAROMETE_VENDOR";
        public static final String BAROME_EEPROM = "BAROME_EEPROM";
        public static final String BATTERY_AP_LOCKUP = "BATTERY_AP_LOCKUP";
        public static final String BATTERY_CAPACITY = "BATTERY_CAPACITY";
        public static final String BATTERY_CISD_DATA = "BATTERY_CISD_DATA";
        public static final String BATTERY_CISD_MAXCAP_NOW = "BATTERY_CISD_MAXCAP_NOW";
        public static final String BATTERY_CISD_REMCAP = "BATTERY_CISD_REMCAP";
        public static final String BATTERY_CYCLE = "BATTERY_CYCLE";
        public static final String BATTERY_DISCHARGING_CHECK_ADC = "BATTERY_DISCHARGING_CHECK_ADC";
        public static final String BATTERY_DISCHARGING_FORCE_SWITCH = "BATTERY_DISCHARGING_FORCE_SWITCH";
        public static final String BATTERY_DISCHARGING_NTC_CHECK = "BATTERY_DISCHARGING_NTC_CHECK";
        public static final String BATTERY_DISCHARGING_SWITCH_CHECK = "BATTERY_DISCHARGING_SWITCH_CHECK";
        public static final String BATTERY_INBAT_VOLTAGE = "BATTERY_INBAT_VOLTAGE";
        public static final String BATTERY_INBAT_VOLTAGE_ADC = "BATTERY_INBAT_VOLTAGE_ADC";
        public static final String BATTERY_INBAT_VOLTAGE_OCV = "BATTERY_INBAT_VOLTAGE_OCV";
        public static final String BATTERY_MAIN_CURRENT = "BATTERY_MAIN_CURRENT";
        public static final String BATTERY_MAIN_ENB = "BATTERY_MAIN_ENB";
        public static final String BATTERY_MAIN_VOLTAGE = "BATTERY_MAIN_VOLTAGE";
        public static final String BATTERY_SAVE_SOC_DATA = "BATTERY_SAVE_SOC_DATA";
        public static final String BATTERY_SUB_CURRENT = "BATTERY_SUB_CURRENT";
        public static final String BATTERY_SUB_ENB = "BATTERY_SUB_ENB";
        public static final String BATTERY_SUB_TEMP = "BATTERY_SUB_TEMP";
        public static final String BATTERY_SUB_TEMP_ADC = "BATTERY_SUB_TEMP_ADC";
        public static final String BATTERY_SUB_VOLTAGE = "BATTERY_SUB_VOLTAGE";
        public static final String BATTERY_TEMP = "BATTERY_TEMP";
        public static final String BATTERY_TEMP_ADC = "BATTERY_TEMP_ADC";
        public static final String BATTERY_TEMP_ADC_AVER = "BATTERY_TEMP_ADC_AVER";
        @Deprecated
        public static final String BATTERY_TEMP_ADC_CAL = "BATTERY_TEMP_ADC_CAL";
        public static final String BATTERY_TEMP_AVER = "BATTERY_TEMP_AVER";
        public static final String BATTERY_TYPE = "BATTERY_TYPE";
        public static final String BATTERY_UPDATE_BEFORE_READ = "BATTERY_UPDATE_BEFORE_READ";
        public static final String BATTERY_VF_ADC = "BATTERY_VF_ADC";
        public static final String BATTERY_VF_OCV = "BATTERY_VF_OCV";
        public static final String BATTERY_VOLT = "BATTERY_VOLT";
        public static final String BATTERY_VOLT_ADC = "BATTERY_VOLT_ADC";
        public static final String BATTERY_VOLT_ADC_AVER = "BATTERY_VOLT_ADC_AVER";
        public static final String BATTERY_VOLT_ADC_CAL = "BATTERY_VOLT_ADC_CAL";
        public static final String BATTERY_VOLT_AVER = "BATTERY_VOLT_AVER";
        public static final String BATTERY_VOLT_DROP = "BATTERY_VOLT_DROP";
        public static final String BATTERY_WPC_CHARGE = "BATTERY_WPC_CHARGE";
        public static final String BATTERY_WPC_CTRL = "BATTERY_WPC_CTRL";
        public static final String BATTERY_WPC_TEMP = "BATTERY_WPC_TEMP";
        public static final String BATTERY_WPC_TEMP_ADC = "BATTERY_WPC_TEMP_ADC";
        public static final String BATTRY_FACTORYMODE = "BATTRY_FACTORYMODE";
        public static final String BATT_BATTERY_ID = "BATT_BATTERY_ID";
        public static final String BATT_FACTORY_MODE = "BATT_FACTORY_MODE";
        public static final String BATT_HV_WIRELESS_STATUS = "BATT_HV_WIRELESS_STATUS";
        public static final String BATT_SLATE_MODE = "BATT_SLATE_MODE";
        public static final String BATT_SUB_BATTERY_ID = "BATT_SUB_BATTERY_ID";
        public static final String BLANKET_THERMISTER_TEMPERATURE = "BLANKET_THERMISTER_TEMPERATURE";
        public static final String BPS_ENABLE_CHECKED = "BPS_ENABLE_CHECKED";
        public static final String BROME_SENSOR_SEAR_LEVEL_PRESSURE = "BROME_SENSOR_SEAR_LEVEL_PRESSURE";
        public static final String BUS_INPUT_DEVICE = "BUS_INPUT_DEVICE";
        public static final String BYPASS_MODE = "BYPASS_MODE";
        public static final String CABC_MODE = "CABC_MODE";
        public static final String CABLE_DETECT_CONN = "CABLE_DETECT_CONN";
        public static final String CABLE_DETECT_COUNT_CAMERA = "CABLE_DETECT_COUNT_CAMERA";
        public static final String CABLE_DETECT_COUNT_LOWERPBA = "CABLE_DETECT_COUNT_LOWERPBA";
        public static final String CABLE_DETECT_COUNT_MAINBATT = "CABLE_DETECT_COUNT_MAINBATT";
        public static final String CABLE_DETECT_COUNT_MAINDIGI = "CABLE_DETECT_COUNT_MAINDIGI";
        public static final String CABLE_DETECT_COUNT_OCTA = "CABLE_DETECT_COUNT_OCTA";
        public static final String CABLE_DETECT_COUNT_SUBBATT = "CABLE_DETECT_COUNT_SUBBATT";
        public static final String CABLE_DETECT_COUNT_SUBDIGI = "CABLE_DETECT_COUNT_SUBDIGI";
        public static final String CABLE_DETECT_COUNT_SUBPBA = "CABLE_DETECT_COUNT_SUBPBA";
        public static final String CABLE_DETECT_COUNT_SUBUB = "CABLE_DETECT_COUNT_SUBUB";
        public static final String CABLE_DETECT_COUNT_TOFCAM = "CABLE_DETECT_COUNT_TOFCAM";
        public static final String CABLE_DETECT_COUNT_TSP = "CABLE_DETECT_COUNT_TSP";
        public static final String CABLE_DETECT_COUNT_UPPERPBA = "CABLE_DETECT_COUNT_UPPERPBA";
        public static final String CABLE_DETECT_POPUP = "CABLE_DETECT_POPUP";
        public static final String CABLE_DETECT_SUB_UB = "CABLE_DETECT_SUB_UB";
        public static final String CABLE_DETECT_UB = "CABLE_DETECT_UB";
        public static final String CAL_DIGITAL_HALL = "CAL_DIGITAL_HALL";
        public static final String CAL_DIGITAL_REVERSE_HALL = "CAL_DIGITAL_REVERSE_HALL";
        public static final String CAMERA_ALL_FW_VER = "CAMERA_ALL_FW_VER";
        public static final String CAMERA_FLASH_TEMP_ADC = "CAMERA_FLASH_TEMP_ADC";
        public static final String CAMERA_FRONT2_FW_VER = "CAMERA_FRONT2_FW_VER";
        public static final String CAMERA_FRONT2_TILT = "CAMERA_FRONT2_TILT";
        public static final String CAMERA_FRONT_AF_CAL_CHECK = "CAMERA_FRONT_AF_CAL_CHECK";
        public static final String CAMERA_FRONT_DATA_DUMP = "CAMERA_FRONT_DATA_DUMP";
        public static final String CAMERA_FRONT_DATA_DUMP_SIZE = "CAMERA_FRONT_DATA_DUMP_SIZE";
        public static final String CAMERA_FRONT_DUAL_INFO = "CAMERA_FRONT_DUAL_INFO";
        public static final String CAMERA_FRONT_FW_VER = "CAMERA_FRONT_FW_VER";
        public static final String CAMERA_FRONT_TYPE = "CAMERA_FRONT_TYPE";
        public static final String CAMERA_OIS_AUTO = "CAMERA_OIS_AUTO";
        public static final String CAMERA_OIS_AUTO_2ND = "CAMERA_OIS_AUTO_2ND";
        public static final String CAMERA_REAR2_AF_CAL_CHECK = "CAMERA_REAR2_AF_CAL_CHECK";
        public static final String CAMERA_REAR2_FW_VER = "CAMERA_REAR2_FW_VER";
        public static final String CAMERA_REAR2_TILT = "CAMERA_REAR2_TILT";
        public static final String CAMERA_REAR4_TILT = "CAMERA_REAR4_TILT";
        public static final String CAMERA_REAR_AF_CAL_CHECK = "CAMERA_REAR_AF_CAL_CHECK";
        public static final String CAMERA_REAR_DATA_DUMP = "CAMERA_REAR_DATA_DUMP";
        public static final String CAMERA_REAR_DATA_DUMP_SIZE = "CAMERA_REAR_DATA_DUMP_SIZE";
        public static final String CAMERA_REAR_FW_VER = "CAMERA_REAR_FW_VER";
        public static final String CAMERA_REAR_OIS_FW_VER = "CAMERA_REAR_OIS_FW_VER";
        public static final String CAMERA_REAR_TYPE = "CAMERA_REAR_TYPE";
        public static final String CAMERA_SUPPORT_TYPE2 = "CAMERA_SUPPORT_TYPE2";
        public static final String CCD_STATUS_NODE = "CCD_STATUS_NODE";
        public static final String CCD_STATUS_NODE_2 = "CCD_STATUS_NODE_2";
        public static final String CCIC_CONTROL_OPTION = "CCIC_CONTROL_OPTION";
        public static final String CCIC_FIRMWARE_UPDATE = "CCIC_FIRMWARE_UPDATE";
        public static final String CCIC_FIRMWARE_UPDATE_STATUS = "CCIC_FIRMWARE_UPDATE_STATUS";
        public static final String CCIC_JIG_ON = "CCIC_JIG_ON";
        public static final String CCIC_LPM_MODE = "CCIC_LPM_MODE";
        public static final String CCIC_RID = "CCIC_RID";
        public static final String CCIC_STATUS = "CCIC_STATUS";
        public static final String CCIC_WATER_CHECK = "CCIC_WATER_CHECK";
        public static final String CHARGER_2ND_THERMISTER_TEMPERATURE = "CHARGER_2ND_THERMISTER_TEMPERATURE";
        public static final String CHARGING_STATE = "CHARGING_STATE";
        public static final String CHARGING_TYPE = "CHARGING_TYPE";
        public static final String CHECK_CHARGING_PORT = "CHECK_CHARGING_PORT";
        public static final String CHECK_KEY_PRESSED = "CHECK_KEY_PRESSED";
        public static final String CHECK_REQUESTED_GPIO = "CHECK_REQUESTED_GPIO";
        public static final String CHG_CURRENT_ADC = "CHG_CURRENT_ADC";
        public static final String CHG_TEMP = "CHG_TEMP";
        public static final String CHG_TEMP_ADC = "CHG_TEMP_ADC";
        public static final String COIL_TEMP = "COIL_TEMP";
        public static final String COIL_TEMP_ADC = "COIL_TEMP_ADC";
        public static final String COLOUR_BALANCE_EFS = "COLOUR_BALANCE_EFS";
        public static final String COLOUR_BALANCE_EFS_2 = "COLOUR_BALANCE_EFS_2";
        public static final String COLOUR_BALANCE_EFS_VER = "COLOUR_BALANCE_EFS_VER";
        public static final String COLOUR_BALANCE_KERNEL = "COLOUR_BALANCE_KERNEL";
        public static final String COLOUR_BALANCE_KERNEL_2 = "COLOUR_BALANCE_KERNEL_2";
        public static final String COMPANION_IC_CHECK = "COMPANION_IC_CHECK";
        public static final String COMPARE_HIDDEN_HOLE_OCTA_COLOR = "COMPARE_HIDDEN_HOLE_OCTA_COLOR";
        public static final String COMPARE_TSK_LIGHT_OCTA_COLOR = "COMPARE_TSK_LIGHT_OCTA_COLOR";
        public static final String CONTROL_NO = "CONTROL_NO";
        public static final String COUNTRY_PRODUCTION = "COUNTRY_PRODUCTION";
        public static final String CPU0_IDLE_COLLAPSE = "CPU0_IDLE_COLLAPSE";
        public static final String CPU0_MAX_FREQ = "CPU0_MAX_FREQ";
        public static final String CPU0_MIN_FREQ = "CPU0_MIN_FREQ";
        public static final String CPU0_STANDALONE_COLLAPSE = "CPU0_STANDALONE_COLLAPSE";
        public static final String CPU1_MAX_FREQ = "CPU1_MAX_FREQ";
        public static final String CPU1_MIN_FREQ = "CPU1_MIN_FREQ";
        public static final String CPU1_STANDALONE_COLLAPSE = "CPU1_STANDALONE_COLLAPSE";
        public static final String CPU4_MAX_FREQ = "CPU4_MAX_FREQ";
        public static final String CPU5_MAX_FREQ = "CPU5_MAX_FREQ";
        public static final String CPU6_MAX_FREQ = "CPU6_MAX_FREQ";
        public static final String CPU7_MAX_FREQ = "CPU7_MAX_FREQ";
        public static final String CPU_BIG_LITTLE_STATUS = "CPU_BIG_LITTLE_STATUS";
        public static final String CPU_CPU0_ONLINE = "CPU_CPU0_ONLINE";
        public static final String CPU_CPU1_ONLINE = "CPU_CPU1_ONLINE";
        public static final String CPU_CPU2_ONLINE = "CPU_CPU2_ONLINE";
        public static final String CPU_CPU3_ONLINE = "CPU_CPU3_ONLINE";
        public static final String CPU_CPU4_ONLINE = "CPU_CPU4_ONLINE";
        public static final String CPU_HOTPLUG_DISABLE = "CPU_HOTPLUG_DISABLE";
        public static final String CPU_MAX_FREQ_SET = "CPU_MAX_FREQ_SET";
        public static final String CPU_MIN_FREQ_SET = "CPU_MIN_FREQ_SET";
        public static final String CTRL_REQUESTED_GPIO = "CTRL_REQUESTED_GPIO";
        public static final String CURRENT_AVG = "CURRENT_AVG";
        public static final String CURRENT_MAX = "CURRENT_MAX";
        public static final String CURRENT_NOW = "CURRENT_NOW";
        public static final String D2D_ADC_CTRL = "D2D_ADC_CTRL";
        public static final String D2D_CHARGE_CTRL = "D2D_CHARGE_CTRL";
        public static final String D2D_VBUS_VOLTAGE = "D2D_VBUS_VOLTAGE";
        public static final String DDICHIP_ID = "DDICHIP_ID";
        public static final String DDICHIP_ID2 = "DDICHIP_ID2";
        public static final String DDI_MIPI_CONTROL = "DDI_MIPI_CONTROL";
        public static final String DIGITAL_HALL_IC_CAL = "DIGITAL_HALL_IC_CAL";
        public static final String DIGITAL_HALL_IC_CAMERA_CHIP_ID = "DIGITAL_HALL_IC_CAMERA_CHIP_ID";
        public static final String DIGITAL_HALL_IC_SELFTEST = "DIGITAL_HALL_IC_SELFTEST";
        public static final String DIGITAL_HALL_IC_STATUS = "DIGITAL_HALL_IC_STATUS";
        public static final String DIGITAL_HALL_IC_THD = "DIGITAL_HALL_IC_THD";
        public static final String DIRECT_CHARGER_THERMISTER_ADC = "DIRECT_CHARGER_THERMISTER_ADC";
        public static final String DIRECT_CHARGER_THERMISTER_MODE = "DIRECT_CHARGER_THERMISTER_MODE";
        public static final String DIRECT_CHARGER_THERMISTER_TEMPERATURE = "DIRECT_CHARGER_THERMISTER_TEMPERATURE";
        public static final String DIRECT_CHARGE_BATTERY_VOLT = "DIRECT_CHARGE_BATTERY_VOLT";
        public static final String DIRECT_CHARGE_I_IN = "DIRECT_CHARGE_I_IN";
        public static final String DIRECT_CHARGE_STATUS = "DIRECT_CHARGE_STATUS";
        public static final String DIRECT_CHARGE_STEP = "DIRECT_CHARGE_STEP";
        public static final String DIRECT_CHARGE_TOTAL_STEP = "DIRECT_CHARGE_TOTAL_STEP";
        public static final String DISPLAY_INPUT_CURRENT_EFS = "DISPLAY_INPUT_CURRENT_EFS";
        public static final String DISPLAY_INPUT_CURRENT_MODE = "DISPLAY_INPUT_CURRENT_MODE";
        public static final String DISPLAY_INPUT_CURRENT_VALIDITY = "DISPLAY_INPUT_CURRENT_VALIDITY";
        public static final String DISPLAY_INPUT_CURRENT_VALUE = "DISPLAY_INPUT_CURRENT_VALUE";
        public static final String DISPLAY_LINEAR_TEST_NODE = "DISPLAY_LINEAR_TEST_NODE";
        public static final String DISPLAY_LINEAR_TEST_NODE_2 = "DISPLAY_LINEAR_TEST_NODE_2";
        public static final String DISPLAY_PMIC = "DISPLAY_PMIC";
        public static final String DISPLAY_PMIC_POK_REGISTER = "DISPLAY_PMIC_POK_REGISTER";
        public static final String DISPLAY_POC_DATA_EFS = "DISPLAY_POC_DATA_EFS";
        public static final String DPSWITCH_CCIC_CONTROL = "DPSWITCH_CCIC_CONTROL";
        public static final String DPSWITCH_CCIC_SBU_ADC = "DPSWITCH_CCIC_SBU_ADC";
        public static final String DPSWITCH_CHECK_SBU_ADC = "DPSWITCH_CHECK_SBU_ADC";
        public static final String DPSWITCH_CHECK_SBU_DRY = "DPSWITCH_CHECK_SBU_DRY";
        public static final String DPSWITCH_SET_MODE = "DPSWITCH_SET_MODE";
        public static final String DPSWITCH_SET_MODE_CCIC = "DPSWITCH_SET_MODE_CCIC";
        public static final String DSC_DECODER_CRC_NODE = "DSC_DECODER_CRC_NODE";
        public static final String DSF_VERSION = "DSF_VERSION";
        public static final String DSM_AMP_STATUS = "DSM_AMP_STATUS";
        public static final String DSM_AMP_VALIDATION = "DSM_AMP_VALIDATION";
        public static final String DSM_AMP_VALIDATION_2 = "DSM_AMP_VALIDATION_2";
        public static final String DSM_AMP_VALIDATION_3 = "DSM_AMP_VALIDATION_3";
        public static final String DSM_AMP_VALIDATION_4 = "DSM_AMP_VALIDATION_4";
        public static final String DTV_CHECK = "DTV_CHECK";
        public static final String DUAL_CHARGER_SLAVE_ERDY = "DUAL_CHARGER_SLAVE_ERDY";
        public static final String DUAL_CHARGE_MODE = "DUAL_CHARGE_MODE";
        public static final String DVFS_PATH = "DVFS_PATH";
        public static final String DYNAMIC_HOTPLUG = "DYNAMIC_HOTPLUG";
        public static final String EARJACK_ANTENNA_STATE = "EARJACK_ANTENNA_STATE";
        public static final String EARJACK_PLUGGED = "EARJACK_PLUGGED";
        public static final String EARJACK_SWITCH_STATE = "EARJACK_SWITCH_STATE";
        public static final String EDTBO_FIRMWARE_UPDATE = "EDTBO_FIRMWARE_UPDATE";
        public static final String EDTBO_FIRMWARE_VERSION = "EDTBO_FIRMWARE_VERSION";
        public static final String EFS_CALDATE_PATH = "EFS_CALDATE_PATH";
        public static final String EFS_FACTORYAPP_ROOT_PATH = "EFS_FACTORYAPP_ROOT_PATH";
        public static final String EFS_FACTORY_ODE_PATH = "EFS_FACTORY_ODE_PATH";
        public static final String EFS_HW_PATH = "EFS_HW_PATH";
        public static final String EFS_MAGNETIC_DATA = "EFS_MAGNETIC_DATA";
        public static final String EFS_PRE_WATERPROOF_LEAK_PATH = "EFS_PRE_WATERPROOF_LEAK_PATH";
        public static final String EFS_PRE_WATERPROOF_LEAK_RESULT = "EFS_PRE_WATERPROOF_LEAK_RESULT";
        public static final String EFS_WATERPROOF_LLEAK_PATH = "EFS_WATERPROOF_LLEAK_PATH";
        public static final String EFS_WATERPROOF_SLEAK_PATH = "EFS_WATERPROOF_SLEAK_PATH";
        public static final String EMMC_CID = "EMMC_CID";
        public static final String EMMC_FIRMWARE_VERSION = "EMMC_FIRMWARE_VERSION";
        public static final String EMMC_FW_VERSION = "EMMC_FW_VERSION";
        public static final String EMMC_NAME = "EMMC_NAME";
        public static final String EMMC_TYPE = "EMMC_TYPE";
        public static final String EMMC_UN = "EMMC_UN";
        public static final String ENABLE_EARJACK_ANTENNA = "ENABLE_EARJACK_ANTENNA";
        public static final String ENABLE_HALL_DETECT = "ENABLE_HALL_DETECT";
        public static final String ENABLE_REVERSE_HALL_DETECT = "ENABLE_REVERSE_HALL_DETECT";
        public static final String ENABLE_SLIDING_MOTOR = "ENABLE_SLIDING_MOTOR";
        public static final String EPEN_BLE_CHARGING_MODE = "EPEN_BLE_CHARGING_MODE";
        public static final String EPEN_BLE_PAIRING_TIME = "EPEN_BLE_PAIRING_TIME";
        public static final String EPEN_CHECKSUM_CHECK = "EPEN_CHECKSUM_CHECK";
        public static final String EPEN_CHECKSUM_RESULT = "EPEN_CHECKSUM_RESULT";
        public static final String EPEN_CMD = "EPEN_CMD";
        public static final String EPEN_CMD_RESULT = "EPEN_CMD_RESULT";
        public static final String EPEN_CMD_STATUS = "EPEN_CMD_STATUS";
        public static final String EPEN_DIGITIZER_CHECK = "EPEN_DIGITIZER_CHECK";
        public static final String EPEN_DISABLE_MODE = "EPEN_DISABLE_MODE";
        public static final String EPEN_ENABLE = "EPEN_ENABLE";
        public static final String EPEN_FIRMWARE_UPDATE = "EPEN_FIRMWARE_UPDATE";
        public static final String EPEN_FIRMWARE_UPDATE_STATUS = "EPEN_FIRMWARE_UPDATE_STATUS";
        public static final String EPEN_FIRMWARE_VERSION = "EPEN_FIRMWARE_VERSION";
        public static final String EPEN_GARAGE_FIRMWARE_UPDATE = "EPEN_GARAGE_FIRMWARE_UPDATE";
        public static final String EPEN_GARAGE_FIRMWARE_UPDATE_STATUS = "EPEN_GARAGE_FIRMWARE_UPDATE_STATUS";
        public static final String EPEN_GARAGE_MODE = "EPEN_GARAGE_MODE";
        public static final String EPEN_GARAGE_RAWDATA = "EPEN_GARAGE_RAWDATA";
        public static final String EPEN_INSERT = "EPEN_INSERT";
        public static final String EPEN_SAVINGMODE = "EPEN_SAVINGMODE";
        public static final String EPEN_TUNING_VERSION = "EPEN_TUNING_VERSION";
        public static final String ETHERNET_CONNECTION = "ETHERNET_CONNECTION";
        public static final String ETHERNET_MAC_ADDRESS = "ETHERNET_MAC_ADDRESS";
        public static final String ETHERNET_MAC_ADDRESS_EFS = "ETHERNET_MAC_ADDRESS_EFS";
        public static final String EXTERNAL_MEMORY_INSERTED = "EXTERNAL_MEMORY_INSERTED";
        public static final String EXT_CSD_READ = "EXT_CSD_READ";
        public static final String EXT_SUB_THM = "EXT_SUB_THM";
        public static final String EXT_UP_THM = "EXT_UP_THM";
        public static final String FACTORYMODE_RELEASE_VBUS2BAT = "FACTORYMODE_RELEASE_VBUS2BAT";
        public static final String FACTORYMODE_SET_BYPASS = "FACTORYMODE_SET_BYPASS";
        public static final String FACTORY_BATT_TYPE = "FACTORY_BATT_TYPE";
        public static final String FACTORY_CHARGING_TEST = "FACTORY_CHARGING_TEST";
        public static final String FACTORY_FAILHIST = "FACTORY_FAILHIST";
        public static final String FACTORY_FAILHIST_FLS = "FACTORY_FAILHIST_FLS";
        public static final String FACTORY_MODE = "FACTORY_MODE";
        public static final String FAC_HW_PARAM_BATT_QR = "FAC_HW_PARAM_BATT_QR";
        public static final String FAC_HW_PARAM_DATA = "FAC_HW_PARAM_DATA";
        public static final String FAC_HW_PART_INFORM_DATA = "FAC_HW_PART_INFORM_DATA";
        public static final String FAC_HW_PART_PROTOTYPE_SERIAL_NO = "FAC_HW_PART_PROTOTYPE_SERIAL_NO";
        public static final String FAC_HW_PART_SMD_DATE = "FAC_HW_PART_SMD_DATE";
        public static final String FG_CYCLE = "FG_CYCLE";
        public static final String FG_FIRMWARE = "FG_FIRMWARE";
        public static final String FG_FULLCAPNOM = "FG_FULLCAPNOM";
        public static final String FINGERPRINT_CELL_ID_WHEN_CALIBRATION = "FINGERPRINT_CELL_ID_WHEN_CALIBRATION";
        public static final String FINGERPRINT_CHIP_NAME = "FINGERPRINT_CHIP_NAME";
        public static final String FINGERPRINT_HBM_STATUS = "FINGERPRINT_HBM_STATUS";
        public static final String FINGERPRINT_OPTICAL_CAL_PATH = "FINGERPRINT_OPTICAL_CAL_PATH";
        public static final String FINGERPRINT_TEST_TARGET_NIT = "FINGERPRINT_TEST_TARGET_NIT";
        public static final String FINGERPRINT_TYPE_CHECK = "FINGERPRINT_TYPE_CHECK";
        public static final String FINGERPRINT_VENDOR = "FINGERPRINT_VENDOR";
        public static final String FINGERPRINT_WOG_RETAIN = "FINGERPRINT_WOG_RETAIN";
        public static final String FINGERPRINT_WOG_SUPPORT = "FINGERPRINT_WOG_SUPPORT";
        public static final String FIVE_BUTTON = "FIVE_BUTTON";
        public static final String FLASH_LED_THERM = "FLASH_LED_THERM";
        public static final String FLICKER_DATA_FILE = "FLICKER_DATA_FILE";
        public static final String FLICKER_SENSOR_ALS_CLEAR = "FLICKER_SENSOR_ALS_CLEAR";
        public static final String FLICKER_SENSOR_ALS_WIDEBAND = "FLICKER_SENSOR_ALS_WIDEBAND";
        public static final String FLICKER_SENSOR_DATA = "FLICKER_SENSOR_DATA";
        public static final String FLICKER_SENSOR_EOL_MODE = "FLICKER_SENSOR_EOL_MODE";
        public static final String FLICKER_SENSOR_EOL_SPEC = "FLICKER_SENSOR_EOL_SPEC";
        public static final String FLICKER_SENSOR_FACTORY_TEST_RESULT = "FLICKER_SENSOR_FACTORY_TEST_RESULT";
        public static final String FLICKER_SENSOR_ID = "FLICKER_SENSOR_ID";
        public static final String FLICKER_SENSOR_POWER = "FLICKER_SENSOR_POWER";
        public static final String FLICKER_SENSOR_SELFTEST = "FLICKER_SENSOR_SELFTEST";
        public static final String FLICKER_SENSOR_TRIM_CHECK = "FLICKER_SENSOR_TRIM_CHECK";
        public static final String FLIP_COVER_DETECTOR_STATUS = "FLIP_COVER_DETECTOR_STATUS";
        public static final String FUEL_GAUGE_CURRENT_NOW = "FUEL_GAUGE_CURRENT_NOW";
        public static final String FUEL_GAUGE_INIT_CHECK = "FUEL_GAUGE_INIT_CHECK";
        public static final String FUEL_GAUGE_RESET = "FUEL_GAUGE_RESET";
        public static final String FUEL_GAUGE_VOLT_SLOPE = "FUEL_GAUGE_VOLT_SLOPE";
        public static final String FUEL_GAUGE_VOLT_SLOPE_DATA = "FUEL_GAUGE_VOLT_SLOPE_DATA";
        public static final String FULL_VOLTAGE = "FULL_VOLTAGE";
        public static final String FW_DIGITAL_HALL = "FW_DIGITAL_HALL";
        public static final String FW_DIGITAL_REVERSE_HALL = "FW_DIGITAL_REVERSE_HALL";
        public static final String FW_SELFTEST_HALL = "FW_SELFTEST_HALL";
        public static final String FW_SELFTEST_REVERSE_HALL = "FW_SELFTEST_REVERSE_HALL";
        public static final String GAMMA_CODE_FLASH = "GAMMA_CODE_FLASH";
        public static final String GEOMAGNETIC_SENSOR_ADC = "GEOMAGNETIC_SENSOR_ADC";
        public static final String GEOMAGNETIC_SENSOR_DAC = "GEOMAGNETIC_SENSOR_DAC";
        public static final String GEOMAGNETIC_SENSOR_NAME = "GEOMAGNETIC_SENSOR_NAME";
        @Deprecated
        public static final String GEOMAGNETIC_SENSOR_POWER = "GEOMAGNETIC_SENSOR_POWER";
        public static final String GEOMAGNETIC_SENSOR_SELFTEST = "GEOMAGNETIC_SENSOR_SELFTEST";
        public static final String GEOMAGNETIC_SENSOR_STATUS = "GEOMAGNETIC_SENSOR_STATUS";
        @Deprecated
        public static final String GEOMAGNETIC_SENSOR_TEMP = "GEOMAGNETIC_SENSOR_TEMP";
        public static final String GEOMAGNETIC_SENSOR_VENDOR = "GEOMAGNETIC_SENSOR_VENDOR";
        public static final String GESTURE_SENSOR_VENDOR = "GESTURE_SENSOR_VENDOR";
        public static final String GRIP_ADC_FILT = "GRIP_ADC_FILT";
        public static final String GRIP_ADC_FILT_2 = "GRIP_ADC_FILT_2";
        public static final String GRIP_ADC_FILT_3 = "GRIP_ADC_FILT_3";
        public static final String GRIP_ADC_FILT_4 = "GRIP_ADC_FILT_4";
        public static final String GRIP_ADC_FILT_5 = "GRIP_ADC_FILT_5";
        public static final String GRIP_ADC_FILT_6 = "GRIP_ADC_FILT_6";
        public static final String GRIP_ANALOG_GAIN = "GRIP_ANALOG_GAIN";
        public static final String GRIP_ANALOG_GAIN_2 = "GRIP_ANALOG_GAIN_2";
        public static final String GRIP_ANALOG_GAIN_3 = "GRIP_ANALOG_GAIN_3";
        public static final String GRIP_ANALOG_GAIN_4 = "GRIP_ANALOG_GAIN_4";
        public static final String GRIP_ANALOG_GAIN_5 = "GRIP_ANALOG_GAIN_5";
        public static final String GRIP_ANALOG_GAIN_6 = "GRIP_ANALOG_GAIN_6";
        public static final String GRIP_AVG_NEGFILT = "GRIP_AVG_NEGFILT";
        public static final String GRIP_AVG_NEGFILT_2 = "GRIP_AVG_NEGFILT_2";
        public static final String GRIP_AVG_NEGFILT_3 = "GRIP_AVG_NEGFILT_3";
        public static final String GRIP_AVG_NEGFILT_4 = "GRIP_AVG_NEGFILT_4";
        public static final String GRIP_AVG_NEGFILT_5 = "GRIP_AVG_NEGFILT_5";
        public static final String GRIP_AVG_NEGFILT_6 = "GRIP_AVG_NEGFILT_6";
        public static final String GRIP_AVG_POSFILT = "GRIP_AVG_POSFILT";
        public static final String GRIP_AVG_POSFILT_2 = "GRIP_AVG_POSFILT_2";
        public static final String GRIP_AVG_POSFILT_3 = "GRIP_AVG_POSFILT_3";
        public static final String GRIP_AVG_POSFILT_4 = "GRIP_AVG_POSFILT_4";
        public static final String GRIP_AVG_POSFILT_5 = "GRIP_AVG_POSFILT_5";
        public static final String GRIP_AVG_POSFILT_6 = "GRIP_AVG_POSFILT_6";
        public static final String GRIP_AVG_THRESH = "GRIP_AVG_THRESH";
        public static final String GRIP_AVG_THRESH_2 = "GRIP_AVG_THRESH_2";
        public static final String GRIP_AVG_THRESH_3 = "GRIP_AVG_THRESH_3";
        public static final String GRIP_AVG_THRESH_4 = "GRIP_AVG_THRESH_4";
        public static final String GRIP_AVG_THRESH_5 = "GRIP_AVG_THRESH_5";
        public static final String GRIP_AVG_THRESH_6 = "GRIP_AVG_THRESH_6";
        public static final String GRIP_CDC_DOWN = "GRIP_CDC_DOWN";
        public static final String GRIP_CDC_DOWN_2 = "GRIP_CDC_DOWN_2";
        public static final String GRIP_CDC_DOWN_3 = "GRIP_CDC_DOWN_3";
        public static final String GRIP_CDC_DOWN_4 = "GRIP_CDC_DOWN_4";
        public static final String GRIP_CDC_DOWN_5 = "GRIP_CDC_DOWN_5";
        public static final String GRIP_CDC_DOWN_6 = "GRIP_CDC_DOWN_6";
        public static final String GRIP_CDC_UP = "GRIP_CDC_UP";
        public static final String GRIP_CDC_UP_2 = "GRIP_CDC_UP_2";
        public static final String GRIP_CDC_UP_3 = "GRIP_CDC_UP_3";
        public static final String GRIP_CDC_UP_4 = "GRIP_CDC_UP_4";
        public static final String GRIP_CDC_UP_5 = "GRIP_CDC_UP_5";
        public static final String GRIP_CDC_UP_6 = "GRIP_CDC_UP_6";
        public static final String GRIP_CHECK_BODY_THD = "GRIP_CHECK_BODY_THD";
        public static final String GRIP_CML_BIAS = "GRIP_CML_BIAS";
        public static final String GRIP_CML_BIAS_2 = "GRIP_CML_BIAS_2";
        public static final String GRIP_CML_BIAS_3 = "GRIP_CML_BIAS_3";
        public static final String GRIP_CML_BIAS_4 = "GRIP_CML_BIAS_4";
        public static final String GRIP_CML_BIAS_5 = "GRIP_CML_BIAS_5";
        public static final String GRIP_CML_BIAS_6 = "GRIP_CML_BIAS_6";
        public static final String GRIP_DEBOUNCE_CLOSE = "GRIP_DEBOUNCE_CLOSE";
        public static final String GRIP_DEBOUNCE_CLOSE_2 = "GRIP_DEBOUNCE_CLOSE_2";
        public static final String GRIP_DEBOUNCE_CLOSE_3 = "GRIP_DEBOUNCE_CLOSE_3";
        public static final String GRIP_DEBOUNCE_CLOSE_4 = "GRIP_DEBOUNCE_CLOSE_4";
        public static final String GRIP_DEBOUNCE_CLOSE_5 = "GRIP_DEBOUNCE_CLOSE_5";
        public static final String GRIP_DEBOUNCE_CLOSE_6 = "GRIP_DEBOUNCE_CLOSE_6";
        public static final String GRIP_DEBOUNCE_FAR = "GRIP_DEBOUNCE_FAR";
        public static final String GRIP_DEBOUNCE_FAR_2 = "GRIP_DEBOUNCE_FAR_2";
        public static final String GRIP_DEBOUNCE_FAR_3 = "GRIP_DEBOUNCE_FAR_3";
        public static final String GRIP_DEBOUNCE_FAR_4 = "GRIP_DEBOUNCE_FAR_4";
        public static final String GRIP_DEBOUNCE_FAR_5 = "GRIP_DEBOUNCE_FAR_5";
        public static final String GRIP_DEBOUNCE_FAR_6 = "GRIP_DEBOUNCE_FAR_6";
        public static final String GRIP_HYSTERESIS = "GRIP_HYSTERESIS";
        public static final String GRIP_HYSTERESIS_2 = "GRIP_HYSTERESIS_2";
        public static final String GRIP_HYSTERESIS_3 = "GRIP_HYSTERESIS_3";
        public static final String GRIP_HYSTERESIS_4 = "GRIP_HYSTERESIS_4";
        public static final String GRIP_HYSTERESIS_5 = "GRIP_HYSTERESIS_5";
        public static final String GRIP_HYSTERESIS_6 = "GRIP_HYSTERESIS_6";
        public static final String GRIP_IRQ_COUNT = "GRIP_IRQ_COUNT";
        public static final String GRIP_IRQ_COUNT2 = "GRIP_IRQ_COUNT2";
        public static final String GRIP_IRQ_COUNT3 = "GRIP_IRQ_COUNT3";
        public static final String GRIP_IRQ_COUNT4 = "GRIP_IRQ_COUNT4";
        public static final String GRIP_IRQ_COUNT5 = "GRIP_IRQ_COUNT5";
        public static final String GRIP_IRQ_COUNT6 = "GRIP_IRQ_COUNT6";
        public static final String GRIP_ISUM = "GRIP_ISUM";
        public static final String GRIP_ISUM_2 = "GRIP_ISUM_2";
        public static final String GRIP_ISUM_3 = "GRIP_ISUM_3";
        public static final String GRIP_ISUM_4 = "GRIP_ISUM_4";
        public static final String GRIP_ISUM_5 = "GRIP_ISUM_5";
        public static final String GRIP_ISUM_6 = "GRIP_ISUM_6";
        public static final String GRIP_PHASE = "GRIP_PHASE";
        public static final String GRIP_PHASE_2 = "GRIP_PHASE_2";
        public static final String GRIP_PHASE_3 = "GRIP_PHASE_3";
        public static final String GRIP_PHASE_4 = "GRIP_PHASE_4";
        public static final String GRIP_PHASE_5 = "GRIP_PHASE_5";
        public static final String GRIP_PHASE_6 = "GRIP_PHASE_6";
        public static final String GRIP_RAWFILT = "GRIP_RAWFILT";
        public static final String GRIP_RAWFILT_2 = "GRIP_RAWFILT_2";
        public static final String GRIP_RAWFILT_3 = "GRIP_RAWFILT_3";
        public static final String GRIP_RAWFILT_4 = "GRIP_RAWFILT_4";
        public static final String GRIP_RAWFILT_5 = "GRIP_RAWFILT_5";
        public static final String GRIP_RAWFILT_6 = "GRIP_RAWFILT_6";
        public static final String GRIP_RAWFILT_CH2 = "GRIP_RAWFILT_CH2";
        public static final String GRIP_REFERENCE_CAP = "GRIP_REFERENCE_CAP";
        public static final String GRIP_RESET_READY = "GRIP_RESET_READY";
        public static final String GRIP_RESISTOR_FILTER_INPUT = "GRIP_RESISTOR_FILTER_INPUT";
        public static final String GRIP_RESISTOR_FILTER_INPUT_2 = "GRIP_RESISTOR_FILTER_INPUT_2";
        public static final String GRIP_RESISTOR_FILTER_INPUT_3 = "GRIP_RESISTOR_FILTER_INPUT_3";
        public static final String GRIP_RESISTOR_FILTER_INPUT_4 = "GRIP_RESISTOR_FILTER_INPUT_4";
        public static final String GRIP_RESISTOR_FILTER_INPUT_5 = "GRIP_RESISTOR_FILTER_INPUT_5";
        public static final String GRIP_RESISTOR_FILTER_INPUT_6 = "GRIP_RESISTOR_FILTER_INPUT_6";
        public static final String GRIP_RESOLUTION = "GRIP_RESOLUTION";
        public static final String GRIP_RESOLUTION_2 = "GRIP_RESOLUTION_2";
        public static final String GRIP_RESOLUTION_3 = "GRIP_RESOLUTION_3";
        public static final String GRIP_RESOLUTION_4 = "GRIP_RESOLUTION_4";
        public static final String GRIP_RESOLUTION_5 = "GRIP_RESOLUTION_5";
        public static final String GRIP_RESOLUTION_6 = "GRIP_RESOLUTION_6";
        public static final String GRIP_SAMPLING_FREQ = "GRIP_SAMPLING_FREQ";
        public static final String GRIP_SAMPLING_FREQ_2 = "GRIP_SAMPLING_FREQ_2";
        public static final String GRIP_SAMPLING_FREQ_3 = "GRIP_SAMPLING_FREQ_3";
        public static final String GRIP_SAMPLING_FREQ_4 = "GRIP_SAMPLING_FREQ_4";
        public static final String GRIP_SAMPLING_FREQ_5 = "GRIP_SAMPLING_FREQ_5";
        public static final String GRIP_SAMPLING_FREQ_6 = "GRIP_SAMPLING_FREQ_6";
        public static final String GRIP_SAMPLING_FREQ_CH2 = "GRIP_SAMPLING_FREQ_CH2";
        public static final String GRIP_SCAN_PERIOD = "GRIP_SCAN_PERIOD";
        public static final String GRIP_SCAN_PERIOD_2 = "GRIP_SCAN_PERIOD_2";
        public static final String GRIP_SCAN_PERIOD_3 = "GRIP_SCAN_PERIOD_3";
        public static final String GRIP_SCAN_PERIOD_4 = "GRIP_SCAN_PERIOD_4";
        public static final String GRIP_SCAN_PERIOD_5 = "GRIP_SCAN_PERIOD_5";
        public static final String GRIP_SCAN_PERIOD_6 = "GRIP_SCAN_PERIOD_6";
        public static final String GRIP_SENSOR_CALIBRATION = "GRIP_SENSOR_CALIBRATION";
        public static final String GRIP_SENSOR_CALIBRATION_2 = "GRIP_SENSOR_CALIBRATION_2";
        public static final String GRIP_SENSOR_CALIBRATION_3 = "GRIP_SENSOR_CALIBRATION_3";
        public static final String GRIP_SENSOR_CALIBRATION_4 = "GRIP_SENSOR_CALIBRATION_4";
        public static final String GRIP_SENSOR_CALIBRATION_5 = "GRIP_SENSOR_CALIBRATION_5";
        public static final String GRIP_SENSOR_CALIBRATION_6 = "GRIP_SENSOR_CALIBRATION_6";
        public static final String GRIP_SENSOR_CALIBRATION_SLOPE = "GRIP_SENSOR_CALIBRATION_SLOPE";
        public static final String GRIP_SENSOR_CAPMAIN = "GRIP_SENSOR_CAPMAIN";
        public static final String GRIP_SENSOR_CH_COUNT = "GRIP_SENSOR_CH_COUNT";
        public static final String GRIP_SENSOR_CH_COUNT_2 = "GRIP_SENSOR_CH_COUNT_2";
        public static final String GRIP_SENSOR_CH_COUNT_3 = "GRIP_SENSOR_CH_COUNT_3";
        public static final String GRIP_SENSOR_CH_COUNT_4 = "GRIP_SENSOR_CH_COUNT_4";
        public static final String GRIP_SENSOR_CH_COUNT_5 = "GRIP_SENSOR_CH_COUNT_5";
        public static final String GRIP_SENSOR_CH_COUNT_6 = "GRIP_SENSOR_CH_COUNT_6";
        public static final String GRIP_SENSOR_CH_STATE = "GRIP_SENSOR_CH_STATE";
        public static final String GRIP_SENSOR_CH_STATE_2 = "GRIP_SENSOR_CH_STATE_2";
        public static final String GRIP_SENSOR_CH_STATE_3 = "GRIP_SENSOR_CH_STATE_3";
        public static final String GRIP_SENSOR_CH_STATE_4 = "GRIP_SENSOR_CH_STATE_4";
        public static final String GRIP_SENSOR_CH_STATE_5 = "GRIP_SENSOR_CH_STATE_5";
        public static final String GRIP_SENSOR_CH_STATE_6 = "GRIP_SENSOR_CH_STATE_6";
        public static final String GRIP_SENSOR_DIFF_AVG = "GRIP_SENSOR_DIFF_AVG";
        public static final String GRIP_SENSOR_DIFF_AVG_2 = "GRIP_SENSOR_DIFF_AVG_2";
        public static final String GRIP_SENSOR_DIFF_AVG_3 = "GRIP_SENSOR_DIFF_AVG_3";
        public static final String GRIP_SENSOR_DIFF_AVG_4 = "GRIP_SENSOR_DIFF_AVG_4";
        public static final String GRIP_SENSOR_DIFF_AVG_5 = "GRIP_SENSOR_DIFF_AVG_5";
        public static final String GRIP_SENSOR_DIFF_AVG_6 = "GRIP_SENSOR_DIFF_AVG_6";
        public static final String GRIP_SENSOR_DIFF_AVG_CH2 = "GRIP_SENSOR_DIFF_AVG_CH2";
        public static final String GRIP_SENSOR_ERASECAL = "GRIP_SENSOR_ERASECAL";
        public static final String GRIP_SENSOR_FIRMWARE_UPDATE = "GRIP_SENSOR_FIRMWARE_UPDATE";
        public static final String GRIP_SENSOR_FIRMWARE_UPDATE_2 = "GRIP_SENSOR_FIRMWARE_UPDATE_2";
        public static final String GRIP_SENSOR_FIRMWARE_UPDATE_3 = "GRIP_SENSOR_FIRMWARE_UPDATE_3";
        public static final String GRIP_SENSOR_FIRMWARE_UPDATE_4 = "GRIP_SENSOR_FIRMWARE_UPDATE_4";
        public static final String GRIP_SENSOR_FIRMWARE_UPDATE_5 = "GRIP_SENSOR_FIRMWARE_UPDATE_5";
        public static final String GRIP_SENSOR_FIRMWARE_UPDATE_6 = "GRIP_SENSOR_FIRMWARE_UPDATE_6";
        public static final String GRIP_SENSOR_FIRMWARE_UPDATE_STATUS = "GRIP_SENSOR_FIRMWARE_UPDATE_STATUS";
        public static final String GRIP_SENSOR_FIRMWARE_UPDATE_STATUS_2 = "GRIP_SENSOR_FIRMWARE_UPDATE_STATUS_2";
        public static final String GRIP_SENSOR_FIRMWARE_UPDATE_STATUS_3 = "GRIP_SENSOR_FIRMWARE_UPDATE_STATUS_3";
        public static final String GRIP_SENSOR_FIRMWARE_UPDATE_STATUS_4 = "GRIP_SENSOR_FIRMWARE_UPDATE_STATUS_4";
        public static final String GRIP_SENSOR_FIRMWARE_UPDATE_STATUS_5 = "GRIP_SENSOR_FIRMWARE_UPDATE_STATUS_5";
        public static final String GRIP_SENSOR_FIRMWARE_UPDATE_STATUS_6 = "GRIP_SENSOR_FIRMWARE_UPDATE_STATUS_6";
        public static final String GRIP_SENSOR_FIRMWARE_VERSION_PANEL = "GRIP_SENSOR_FIRMWARE_VERSION_PANEL";
        public static final String GRIP_SENSOR_FIRMWARE_VERSION_PANEL_2 = "GRIP_SENSOR_FIRMWARE_VERSION_PANEL_2";
        public static final String GRIP_SENSOR_FIRMWARE_VERSION_PANEL_3 = "GRIP_SENSOR_FIRMWARE_VERSION_PANEL_3";
        public static final String GRIP_SENSOR_FIRMWARE_VERSION_PANEL_4 = "GRIP_SENSOR_FIRMWARE_VERSION_PANEL_4";
        public static final String GRIP_SENSOR_FIRMWARE_VERSION_PANEL_5 = "GRIP_SENSOR_FIRMWARE_VERSION_PANEL_5";
        public static final String GRIP_SENSOR_FIRMWARE_VERSION_PANEL_6 = "GRIP_SENSOR_FIRMWARE_VERSION_PANEL_6";
        public static final String GRIP_SENSOR_FIRMWARE_VERSION_PHONE = "GRIP_SENSOR_FIRMWARE_VERSION_PHONE";
        public static final String GRIP_SENSOR_FIRMWARE_VERSION_PHONE_2 = "GRIP_SENSOR_FIRMWARE_VERSION_PHONE_2";
        public static final String GRIP_SENSOR_FIRMWARE_VERSION_PHONE_3 = "GRIP_SENSOR_FIRMWARE_VERSION_PHONE_3";
        public static final String GRIP_SENSOR_FIRMWARE_VERSION_PHONE_4 = "GRIP_SENSOR_FIRMWARE_VERSION_PHONE_4";
        public static final String GRIP_SENSOR_FIRMWARE_VERSION_PHONE_5 = "GRIP_SENSOR_FIRMWARE_VERSION_PHONE_5";
        public static final String GRIP_SENSOR_FIRMWARE_VERSION_PHONE_6 = "GRIP_SENSOR_FIRMWARE_VERSION_PHONE_6";
        public static final String GRIP_SENSOR_GAIN = "GRIP_SENSOR_GAIN";
        public static final String GRIP_SENSOR_GAIN_2 = "GRIP_SENSOR_GAIN_2";
        public static final String GRIP_SENSOR_GAIN_3 = "GRIP_SENSOR_GAIN_3";
        public static final String GRIP_SENSOR_GAIN_4 = "GRIP_SENSOR_GAIN_4";
        public static final String GRIP_SENSOR_GAIN_5 = "GRIP_SENSOR_GAIN_5";
        public static final String GRIP_SENSOR_GAIN_6 = "GRIP_SENSOR_GAIN_6";
        public static final String GRIP_SENSOR_GAIN_CH2 = "GRIP_SENSOR_GAIN_CH2";
        public static final String GRIP_SENSOR_MODE = "GRIP_SENSOR_MODE";
        public static final String GRIP_SENSOR_MODE_2 = "GRIP_SENSOR_MODE_2";
        public static final String GRIP_SENSOR_MODE_3 = "GRIP_SENSOR_MODE_3";
        public static final String GRIP_SENSOR_MODE_4 = "GRIP_SENSOR_MODE_4";
        public static final String GRIP_SENSOR_MODE_5 = "GRIP_SENSOR_MODE_5";
        public static final String GRIP_SENSOR_MODE_6 = "GRIP_SENSOR_MODE_6";
        public static final String GRIP_SENSOR_NAME = "GRIP_SENSOR_NAME";
        public static final String GRIP_SENSOR_NAME_2ND = "GRIP_SENSOR_NAME_2ND";
        public static final String GRIP_SENSOR_NAME_3RD = "GRIP_SENSOR_NAME_3RD";
        public static final String GRIP_SENSOR_NAME_4TH = "GRIP_SENSOR_NAME_4TH";
        public static final String GRIP_SENSOR_NAME_5TH = "GRIP_SENSOR_NAME_5TH";
        public static final String GRIP_SENSOR_NAME_6TH = "GRIP_SENSOR_NAME_6TH";
        public static final String GRIP_SENSOR_NORMAL_THD = "GRIP_SENSOR_NORMAL_THD";
        public static final String GRIP_SENSOR_NORMAL_THD_2 = "GRIP_SENSOR_NORMAL_THD_2";
        public static final String GRIP_SENSOR_NORMAL_THD_3 = "GRIP_SENSOR_NORMAL_THD_3";
        public static final String GRIP_SENSOR_NORMAL_THD_4 = "GRIP_SENSOR_NORMAL_THD_4";
        public static final String GRIP_SENSOR_NORMAL_THD_5 = "GRIP_SENSOR_NORMAL_THD_5";
        public static final String GRIP_SENSOR_NORMAL_THD_6 = "GRIP_SENSOR_NORMAL_THD_6";
        public static final String GRIP_SENSOR_NORMAL_THD_CH2 = "GRIP_SENSOR_NORMAL_THD_CH2";
        public static final String GRIP_SENSOR_ONOFF = "GRIP_SENSOR_ONOFF";
        public static final String GRIP_SENSOR_ONOFF_2 = "GRIP_SENSOR_ONOFF_2";
        public static final String GRIP_SENSOR_ONOFF_3 = "GRIP_SENSOR_ONOFF_3";
        public static final String GRIP_SENSOR_ONOFF_4 = "GRIP_SENSOR_ONOFF_4";
        public static final String GRIP_SENSOR_ONOFF_5 = "GRIP_SENSOR_ONOFF_5";
        public static final String GRIP_SENSOR_ONOFF_6 = "GRIP_SENSOR_ONOFF_6";
        public static final String GRIP_SENSOR_RANGE = "GRIP_SENSOR_RANGE";
        public static final String GRIP_SENSOR_RANGE_2 = "GRIP_SENSOR_RANGE_2";
        public static final String GRIP_SENSOR_RANGE_3 = "GRIP_SENSOR_RANGE_3";
        public static final String GRIP_SENSOR_RANGE_4 = "GRIP_SENSOR_RANGE_4";
        public static final String GRIP_SENSOR_RANGE_5 = "GRIP_SENSOR_RANGE_5";
        public static final String GRIP_SENSOR_RANGE_6 = "GRIP_SENSOR_RANGE_6";
        public static final String GRIP_SENSOR_RAWDATA = "GRIP_SENSOR_RAWDATA";
        public static final String GRIP_SENSOR_RAWDATA_2 = "GRIP_SENSOR_RAWDATA_2";
        public static final String GRIP_SENSOR_RAWDATA_3 = "GRIP_SENSOR_RAWDATA_3";
        public static final String GRIP_SENSOR_RAWDATA_4 = "GRIP_SENSOR_RAWDATA_4";
        public static final String GRIP_SENSOR_RAWDATA_5 = "GRIP_SENSOR_RAWDATA_5";
        public static final String GRIP_SENSOR_RAWDATA_6 = "GRIP_SENSOR_RAWDATA_6";
        public static final String GRIP_SENSOR_RAWDATA_CH2 = "GRIP_SENSOR_RAWDATA_CH2";
        public static final String GRIP_SENSOR_RESET = "GRIP_SENSOR_RESET";
        public static final String GRIP_SENSOR_RESET_2 = "GRIP_SENSOR_RESET_2";
        public static final String GRIP_SENSOR_RESET_2ND = "GRIP_SENSOR_RESET_2ND";
        public static final String GRIP_SENSOR_RESET_3 = "GRIP_SENSOR_RESET_3";
        public static final String GRIP_SENSOR_RESET_3RD = "GRIP_SENSOR_RESET_3RD";
        public static final String GRIP_SENSOR_RESET_4 = "GRIP_SENSOR_RESET_4";
        public static final String GRIP_SENSOR_RESET_4TH = "GRIP_SENSOR_RESET_4TH";
        public static final String GRIP_SENSOR_RESET_5 = "GRIP_SENSOR_RESET_5";
        public static final String GRIP_SENSOR_RESET_5TH = "GRIP_SENSOR_RESET_5TH";
        public static final String GRIP_SENSOR_RESET_6 = "GRIP_SENSOR_RESET_6";
        public static final String GRIP_SENSOR_RESET_6TH = "GRIP_SENSOR_RESET_6TH";
        public static final String GRIP_SENSOR_TEMP_CAL = "GRIP_SENSOR_TEMP_CAL";
        public static final String GRIP_SENSOR_TEMP_CAL_2 = "GRIP_SENSOR_TEMP_CAL_2";
        public static final String GRIP_SENSOR_TEMP_CAL_5 = "GRIP_SENSOR_TEMP_CAL_5";
        public static final String GRIP_SENSOR_TEMP_CAL_6 = "GRIP_SENSOR_TEMP_CAL_6";
        public static final String GRIP_SENSOR_TEMP_REAL = "GRIP_SENSOR_TEMP_REAL";
        public static final String GRIP_SENSOR_TEMP_REAL_2 = "GRIP_SENSOR_TEMP_REAL_2";
        public static final String GRIP_SENSOR_TEMP_REAL_3 = "GRIP_SENSOR_TEMP_REAL_3";
        public static final String GRIP_SENSOR_TEMP_REAL_4 = "GRIP_SENSOR_TEMP_REAL_4";
        public static final String GRIP_SENSOR_TEMP_REAL_5 = "GRIP_SENSOR_TEMP_REAL_5";
        public static final String GRIP_SENSOR_TEMP_REAL_6 = "GRIP_SENSOR_TEMP_REAL_6";
        public static final String GRIP_SENSOR_THRESHOLD = "GRIP_SENSOR_THRESHOLD";
        public static final String GRIP_SENSOR_THRESHOLD_2 = "GRIP_SENSOR_THRESHOLD_2";
        public static final String GRIP_SENSOR_THRESHOLD_3 = "GRIP_SENSOR_THRESHOLD_3";
        public static final String GRIP_SENSOR_THRESHOLD_4 = "GRIP_SENSOR_THRESHOLD_4";
        public static final String GRIP_SENSOR_THRESHOLD_5 = "GRIP_SENSOR_THRESHOLD_5";
        public static final String GRIP_SENSOR_THRESHOLD_6 = "GRIP_SENSOR_THRESHOLD_6";
        public static final String GRIP_SENSOR_USEFUL_AVG = "GRIP_SENSOR_USEFUL_AVG";
        public static final String GRIP_SENSOR_USEFUL_AVG_2 = "GRIP_SENSOR_USEFUL_AVG_2";
        public static final String GRIP_SENSOR_USEFUL_AVG_3 = "GRIP_SENSOR_USEFUL_AVG_3";
        public static final String GRIP_SENSOR_USEFUL_AVG_4 = "GRIP_SENSOR_USEFUL_AVG_4";
        public static final String GRIP_SENSOR_USEFUL_AVG_5 = "GRIP_SENSOR_USEFUL_AVG_5";
        public static final String GRIP_SENSOR_USEFUL_AVG_6 = "GRIP_SENSOR_USEFUL_AVG_6";
        public static final String GRIP_SENSOR_USEFUL_AVG_CH2 = "GRIP_SENSOR_USEFUL_AVG_CH2";
        public static final String GRIP_SENSOR_VENDOR = "GRIP_SENSOR_VENDOR";
        public static final String GRIP_TEMP_ENABLE = "GRIP_TEMP_ENABLE";
        public static final String GRIP_TEMP_ENABLE_2 = "GRIP_TEMP_ENABLE_2";
        public static final String GRIP_TEMP_ENABLE_3 = "GRIP_TEMP_ENABLE_3";
        public static final String GRIP_TEMP_ENABLE_4 = "GRIP_TEMP_ENABLE_4";
        public static final String GRIP_TEMP_ENABLE_5 = "GRIP_TEMP_ENABLE_5";
        public static final String GRIP_TEMP_ENABLE_6 = "GRIP_TEMP_ENABLE_6";
        public static final String GRIP_TOUCH_SENSOR_BASELINE = "GRIP_TOUCH_SENSOR_BASELINE";
        public static final String GRIP_TOUCH_SENSOR_BASELINE_2 = "GRIP_TOUCH_SENSOR_BASELINE_2";
        public static final String GRIP_TOUCH_SENSOR_BASELINE_3 = "GRIP_TOUCH_SENSOR_BASELINE_3";
        public static final String GRIP_TOUCH_SENSOR_BASELINE_4 = "GRIP_TOUCH_SENSOR_BASELINE_4";
        public static final String GRIP_TOUCH_SENSOR_BASELINE_5 = "GRIP_TOUCH_SENSOR_BASELINE_5";
        public static final String GRIP_TOUCH_SENSOR_BASELINE_6 = "GRIP_TOUCH_SENSOR_BASELINE_6";
        public static final String GRIP_TOUCH_SENSOR_CHECK = "GRIP_TOUCH_SENSOR_CHECK";
        public static final String GRIP_TOUCH_SENSOR_CHECK_2 = "GRIP_TOUCH_SENSOR_CHECK_2";
        public static final String GRIP_TOUCH_SENSOR_CHECK_3 = "GRIP_TOUCH_SENSOR_CHECK_3";
        public static final String GRIP_TOUCH_SENSOR_CHECK_4 = "GRIP_TOUCH_SENSOR_CHECK_4";
        public static final String GRIP_TOUCH_SENSOR_CHECK_5 = "GRIP_TOUCH_SENSOR_CHECK_5";
        public static final String GRIP_TOUCH_SENSOR_CHECK_6 = "GRIP_TOUCH_SENSOR_CHECK_6";
        public static final String GRIP_TOUCH_SENSOR_CRC_CHECK = "GRIP_TOUCH_SENSOR_CRC_CHECK";
        public static final String GRIP_TOUCH_SENSOR_CRC_CHECK_2 = "GRIP_TOUCH_SENSOR_CRC_CHECK_2";
        public static final String GRIP_TOUCH_SENSOR_CRC_CHECK_3 = "GRIP_TOUCH_SENSOR_CRC_CHECK_3";
        public static final String GRIP_TOUCH_SENSOR_CRC_CHECK_4 = "GRIP_TOUCH_SENSOR_CRC_CHECK_4";
        public static final String GRIP_TOUCH_SENSOR_CRC_CHECK_5 = "GRIP_TOUCH_SENSOR_CRC_CHECK_5";
        public static final String GRIP_TOUCH_SENSOR_CRC_CHECK_6 = "GRIP_TOUCH_SENSOR_CRC_CHECK_6";
        public static final String GRIP_TOUCH_SENSOR_DIFF_DATA = "GRIP_TOUCH_SENSOR_DIFF_DATA";
        public static final String GRIP_TOUCH_SENSOR_DIFF_DATA_2 = "GRIP_TOUCH_SENSOR_DIFF_DATA_2";
        public static final String GRIP_TOUCH_SENSOR_DIFF_DATA_3 = "GRIP_TOUCH_SENSOR_DIFF_DATA_3";
        public static final String GRIP_TOUCH_SENSOR_DIFF_DATA_4 = "GRIP_TOUCH_SENSOR_DIFF_DATA_4";
        public static final String GRIP_TOUCH_SENSOR_DIFF_DATA_5 = "GRIP_TOUCH_SENSOR_DIFF_DATA_5";
        public static final String GRIP_TOUCH_SENSOR_DIFF_DATA_6 = "GRIP_TOUCH_SENSOR_DIFF_DATA_6";
        public static final String GRIP_TOUCH_SENSOR_ENABLE = "GRIP_TOUCH_SENSOR_ENABLE";
        public static final String GRIP_TOUCH_SENSOR_ENABLE_2 = "GRIP_TOUCH_SENSOR_ENABLE_2";
        public static final String GRIP_TOUCH_SENSOR_ENABLE_3 = "GRIP_TOUCH_SENSOR_ENABLE_3";
        public static final String GRIP_TOUCH_SENSOR_ENABLE_4 = "GRIP_TOUCH_SENSOR_ENABLE_4";
        public static final String GRIP_TOUCH_SENSOR_ENABLE_5 = "GRIP_TOUCH_SENSOR_ENABLE_5";
        public static final String GRIP_TOUCH_SENSOR_ENABLE_6 = "GRIP_TOUCH_SENSOR_ENABLE_6";
        public static final String GRIP_TOUCH_SENSOR_FW_VERSION = "GRIP_TOUCH_SENSOR_FW_VERSION";
        public static final String GRIP_TOUCH_SENSOR_FW_VERSION_2 = "GRIP_TOUCH_SENSOR_FW_VERSION_2";
        public static final String GRIP_TOUCH_SENSOR_FW_VERSION_3 = "GRIP_TOUCH_SENSOR_FW_VERSION_3";
        public static final String GRIP_TOUCH_SENSOR_FW_VERSION_4 = "GRIP_TOUCH_SENSOR_FW_VERSION_4";
        public static final String GRIP_TOUCH_SENSOR_FW_VERSION_5 = "GRIP_TOUCH_SENSOR_FW_VERSION_5";
        public static final String GRIP_TOUCH_SENSOR_FW_VERSION_6 = "GRIP_TOUCH_SENSOR_FW_VERSION_6";
        public static final String GRIP_TOUCH_SENSOR_GAIN = "GRIP_TOUCH_SENSOR_GAIN";
        public static final String GRIP_TOUCH_SENSOR_GAIN_2 = "GRIP_TOUCH_SENSOR_GAIN_2";
        public static final String GRIP_TOUCH_SENSOR_GAIN_3 = "GRIP_TOUCH_SENSOR_GAIN_3";
        public static final String GRIP_TOUCH_SENSOR_GAIN_4 = "GRIP_TOUCH_SENSOR_GAIN_4";
        public static final String GRIP_TOUCH_SENSOR_GAIN_5 = "GRIP_TOUCH_SENSOR_GAIN_5";
        public static final String GRIP_TOUCH_SENSOR_GAIN_6 = "GRIP_TOUCH_SENSOR_GAIN_6";
        public static final String GRIP_TOUCH_SENSOR_RAWDATA = "GRIP_TOUCH_SENSOR_RAWDATA";
        public static final String GRIP_TOUCH_SENSOR_RAWDATA_2 = "GRIP_TOUCH_SENSOR_RAWDATA_2";
        public static final String GRIP_TOUCH_SENSOR_RAWDATA_3 = "GRIP_TOUCH_SENSOR_RAWDATA_3";
        public static final String GRIP_TOUCH_SENSOR_RAWDATA_4 = "GRIP_TOUCH_SENSOR_RAWDATA_4";
        public static final String GRIP_TOUCH_SENSOR_RAWDATA_5 = "GRIP_TOUCH_SENSOR_RAWDATA_5";
        public static final String GRIP_TOUCH_SENSOR_RAWDATA_6 = "GRIP_TOUCH_SENSOR_RAWDATA_6";
        public static final String GRIP_TOUCH_SENSOR_REF_CAP = "GRIP_TOUCH_SENSOR_REF_CAP";
        public static final String GRIP_TOUCH_SENSOR_REF_CAP_2 = "GRIP_TOUCH_SENSOR_REF_CAP_2";
        public static final String GRIP_TOUCH_SENSOR_REF_CAP_3 = "GRIP_TOUCH_SENSOR_REF_CAP_3";
        public static final String GRIP_TOUCH_SENSOR_REF_CAP_4 = "GRIP_TOUCH_SENSOR_REF_CAP_4";
        public static final String GRIP_TOUCH_SENSOR_REF_CAP_5 = "GRIP_TOUCH_SENSOR_REF_CAP_5";
        public static final String GRIP_TOUCH_SENSOR_REF_CAP_6 = "GRIP_TOUCH_SENSOR_REF_CAP_6";
        public static final String GRIP_TOUCH_SENSOR_RESET = "GRIP_TOUCH_SENSOR_RESET";
        public static final String GRIP_TOUCH_SENSOR_RESET_2 = "GRIP_TOUCH_SENSOR_RESET_2";
        public static final String GRIP_TOUCH_SENSOR_RESET_3 = "GRIP_TOUCH_SENSOR_RESET_3";
        public static final String GRIP_TOUCH_SENSOR_RESET_4 = "GRIP_TOUCH_SENSOR_RESET_4";
        public static final String GRIP_TOUCH_SENSOR_RESET_5 = "GRIP_TOUCH_SENSOR_RESET_5";
        public static final String GRIP_TOUCH_SENSOR_RESET_6 = "GRIP_TOUCH_SENSOR_RESET_6";
        public static final String GRIP_TOUCH_SENSOR_RESET_READY = "GRIP_TOUCH_SENSOR_RESET_READY";
        public static final String GRIP_TOUCH_SENSOR_RESET_READY_2 = "GRIP_TOUCH_SENSOR_RESET_READY_2";
        public static final String GRIP_TOUCH_SENSOR_RESET_READY_3 = "GRIP_TOUCH_SENSOR_RESET_READY_3";
        public static final String GRIP_TOUCH_SENSOR_RESET_READY_4 = "GRIP_TOUCH_SENSOR_RESET_READY_4";
        public static final String GRIP_TOUCH_SENSOR_RESET_READY_5 = "GRIP_TOUCH_SENSOR_RESET_READY_5";
        public static final String GRIP_TOUCH_SENSOR_RESET_READY_6 = "GRIP_TOUCH_SENSOR_RESET_READY_6";
        public static final String GRIP_TOUCH_SENSOR_THD = "GRIP_TOUCH_SENSOR_THD";
        public static final String GRIP_TOUCH_SENSOR_THD_2 = "GRIP_TOUCH_SENSOR_THD_2";
        public static final String GRIP_TOUCH_SENSOR_THD_3 = "GRIP_TOUCH_SENSOR_THD_3";
        public static final String GRIP_TOUCH_SENSOR_THD_4 = "GRIP_TOUCH_SENSOR_THD_4";
        public static final String GRIP_TOUCH_SENSOR_THD_5 = "GRIP_TOUCH_SENSOR_THD_5";
        public static final String GRIP_TOUCH_SENSOR_THD_6 = "GRIP_TOUCH_SENSOR_THD_6";
        public static final String GRIP_TOUCH_SENSOR_TOTAL_CAP = "GRIP_TOUCH_SENSOR_TOTAL_CAP";
        public static final String GRIP_TOUCH_SENSOR_TOTAL_CAP_2 = "GRIP_TOUCH_SENSOR_TOTAL_CAP_2";
        public static final String GRIP_TOUCH_SENSOR_TOTAL_CAP_3 = "GRIP_TOUCH_SENSOR_TOTAL_CAP_3";
        public static final String GRIP_TOUCH_SENSOR_TOTAL_CAP_4 = "GRIP_TOUCH_SENSOR_TOTAL_CAP_4";
        public static final String GRIP_TOUCH_SENSOR_TOTAL_CAP_5 = "GRIP_TOUCH_SENSOR_TOTAL_CAP_5";
        public static final String GRIP_TOUCH_SENSOR_TOTAL_CAP_6 = "GRIP_TOUCH_SENSOR_TOTAL_CAP_6";
        public static final String GRIP_USEFUL_FILT = "GRIP_USEFUL_FILT";
        public static final String GRIP_USEFUL_FILT_2 = "GRIP_USEFUL_FILT_2";
        public static final String GRIP_USEFUL_FILT_3 = "GRIP_USEFUL_FILT_3";
        public static final String GRIP_USEFUL_FILT_4 = "GRIP_USEFUL_FILT_4";
        public static final String GRIP_USEFUL_FILT_5 = "GRIP_USEFUL_FILT_5";
        public static final String GRIP_USEFUL_FILT_6 = "GRIP_USEFUL_FILT_6";
        public static final String GYRO_OIS_CALTEST = "GYRO_OIS_CALTEST";
        public static final String GYRO_OIS_DIFF = "GYRO_OIS_DIFF";
        public static final String GYRO_OIS_POWER = "GYRO_OIS_POWER";
        public static final String GYRO_OIS_RAWDATA = "GYRO_OIS_RAWDATA";
        public static final String GYRO_OIS_RAWDATA_EFS = "GYRO_OIS_RAWDATA_EFS";
        public static final String GYRO_OIS_SELFTEST = "GYRO_OIS_SELFTEST";
        public static final String GYRO_SENSOR_DPS_SELECT = "GYRO_SENSOR_DPS_SELECT";
        public static final String GYRO_SENSOR_NAME = "GYRO_SENSOR_NAME";
        public static final String GYRO_SENSOR_REVISED = "GYRO_SENSOR_REVISED";
        public static final String GYRO_SENSOR_SELFTEST = "GYRO_SENSOR_SELFTEST";
        public static final String GYRO_SENSOR_TEMP = "GYRO_SENSOR_TEMP";
        public static final String GYRO_SENSOR_VENDOR = "GYRO_SENSOR_VENDOR";
        public static final String HC_COLORLED_BLINK = "HC_COLORLED_BLINK";
        public static final String HC_COLORLED_CONTROL = "HC_COLORLED_CONTROL";
        public static final String HC_WHITELED_CONTROL = "HC_WHITELED_CONTROL";
        public static final String HDCP_CHECK_2_0 = "HDCP_CHECK_2_0";
        public static final String HDCP_CHECK_WIDEVINE_KEYBOX = "HDCP_CHECK_WIDEVINE_KEYBOX";
        public static final String HDMI_FHD_MODE = "HDMI_FHD_MODE";
        public static final String HDMI_TEST_RESULT = "HDMI_TEST_RESULT";
        public static final String HIDDEN_HOLE_DATA = "HIDDEN_HOLE_DATA";
        public static final String HIDDEN_HOLE_VER = "HIDDEN_HOLE_VER";
        public static final String HIDDEN_HOLE_VER_SUB = "HIDDEN_HOLE_VER_SUB";
        public static final String HMAC_RESULT = "HMAC_RESULT";
        public static final String HOST_SPEED_MODE = "HOST_SPEED_MODE";
        public static final String HOT_PLUG_LOCK = "HOT_PLUG_LOCK";
        public static final String HRM_DEVICE_ID = "HRM_DEVICE_ID";
        public static final String HRM_DRIVER_VER = "HRM_DRIVER_VER";
        public static final String HRM_EOL_TEST = "HRM_EOL_TEST";
        public static final String HRM_EOL_TEST_RESULT = "HRM_EOL_TEST_RESULT";
        public static final String HRM_EOL_TEST_STATUS = "HRM_EOL_TEST_STATUS";
        public static final String HRM_FACTORY_CMD = "HRM_FACTORY_CMD";
        public static final String HRM_HR_RANGE = "HRM_HR_RANGE";
        public static final String HRM_HR_RANGE2 = "HRM_HR_RANGE2";
        public static final String HRM_IDAC_RANGE = "HRM_IDAC_RANGE";
        public static final String HRM_INT_PIN_CHECK = "HRM_INT_PIN_CHECK";
        public static final String HRM_LED_CURRENT = "HRM_LED_CURRENT";
        public static final String HRM_LED_CURRENT2 = "HRM_LED_CURRENT2";
        public static final String HRM_LIBRARY_ELF_VER = "HRM_LIBRARY_ELF_VER";
        public static final String HRM_LIBRARY_EOL_VER = "HRM_LIBRARY_EOL_VER";
        public static final String HRM_LIBRARY_VER = "HRM_LIBRARY_VER";
        public static final String HRM_MODE_IR = "HRM_MODE_IR";
        public static final String HRM_MODE_R = "HRM_MODE_R";
        public static final String HRM_PART_TYPE = "HRM_PART_TYPE";
        public static final String HRM_SELFTEST_RESULT = "HRM_SELFTEST_RESULT";
        public static final String HRM_SENSOR_NAME = "HRM_SENSOR_NAME";
        public static final String HRM_THD = "HRM_THD";
        public static final String HRM_VENDOR = "HRM_VENDOR";
        public static final String HRM_XTALK_CODE = "HRM_XTALK_CODE";
        public static final String HUMITEMP_THERMISTER_BATT = "HUMITEMP_THERMISTER_BATT";
        public static final String HUMITEMP_THERMISTER_BATT_CELCIUS = "HUMITEMP_THERMISTER_BATT_CELCIUS";
        public static final String HUMITEMP_THERMISTER_PAM = "HUMITEMP_THERMISTER_PAM";
        public static final String HUMITEMP_THERMISTER_S_HUB_BATT = "HUMITEMP_THERMISTER_S_HUB_BATT";
        public static final String HUMITEMP_THERMISTER_S_HUB_BATT_CELCIUS = "HUMITEMP_THERMISTER_S_HUB_BATT_CELCIUS";
        public static final String HUMI_TEMP_SENSOR_CAL = "HUMI_TEMP_SENSOR_CAL";
        public static final String HUMI_TEMP_SENSOR_RESET = "HUMI_TEMP_SENSOR_RESET";
        public static final String HV_CHARGE_CHIP = "HV_CHARGE_CHIP";
        public static final String HV_CHARGE_CURRENT = "HV_CHARGE_CURRENT";
        public static final String HV_CHARGE_STATUS = "HV_CHARGE_STATUS";
        public static final String HV_CHARGE_TYPE = "HV_CHARGE_TYPE";
        public static final String HV_POGO_INPUT = "HV_POGO_INPUT";
        public static final String HV_WC_CHARGER_STATUS = "HV_WC_CHARGER_STATUS";
        public static final String HWPARAM_PCB_INFO_PATH = "HWPARAM_PCB_INFO_PATH";
        public static final String HWPARAM_SMD_DATE_PATH = "HWPARAM_SMD_DATE_PATH";
        public static final String IDT_IC_GRADE = "IDT_IC_GRADE";
        public static final String IDT_MST_SWITCH = "IDT_MST_SWITCH";
        public static final String IDT_OTP_FIRMWARE_UPDATE = "IDT_OTP_FIRMWARE_UPDATE";
        public static final String IDT_OTP_FIRMWARE_UPDATE_STATUS = "IDT_OTP_FIRMWARE_UPDATE_STATUS";
        public static final String IDT_OTP_FIRMWARE_VERSION = "IDT_OTP_FIRMWARE_VERSION";
        public static final String IDT_OTP_ON_OFF = "IDT_OTP_ON_OFF";
        public static final String IDT_PACKAGING_FIRMWARE_VERSION = "IDT_PACKAGING_FIRMWARE_VERSION";
        public static final String IDT_TX_FIRMWARE_OFF = "IDT_TX_FIRMWARE_OFF";
        public static final String IDT_TX_FIRMWARE_ON = "IDT_TX_FIRMWARE_ON";
        public static final String IDT_TX_FIRMWARE_UPDATE_STATUS = "IDT_TX_FIRMWARE_UPDATE_STATUS";
        public static final String IDT_TX_FIRMWARE_VERSION = "IDT_TX_FIRMWARE_VERSION";
        public static final String ID_CHIP_VERIFY = "ID_CHIP_VERIFY";
        public static final String ID_DETECT_TEST = "ID_DETECT_TEST";
        public static final String IMEM_DEVICE_SIZE = "IMEM_DEVICE_SIZE";
        public static final String IRIS_CAMERA_FW_VER = "IRIS_CAMERA_FW_VER";
        public static final String IRIS_CHECK_FW_FACTORY = "IRIS_CHECK_FW_FACTORY";
        public static final String IRIS_PROXI_SENSOR_ADC = "IRIS_PROXI_SENSOR_ADC";
        public static final String IRIS_PROXI_SENSOR_DEFAULT_TRIM = "IRIS_PROXI_SENSOR_DEFAULT_TRIM";
        public static final String IRIS_PROXI_SENSOR_DETECT_HIGH_THRESHOLD = "IRIS_PROXI_SENSOR_DETECT_HIGH_THRESHOLD";
        public static final String IRIS_PROXI_SENSOR_DETECT_LOW_THRESHOLD = "IRIS_PROXI_SENSOR_DETECT_LOW_THRESHOLD";
        public static final String IRIS_PROXI_SENSOR_OFFSET = "IRIS_PROXI_SENSOR_OFFSET";
        public static final String IRIS_PROXI_SENSOR_SET_HIGH_THRESHOLD = "IRIS_PROXI_SENSOR_SET_HIGH_THRESHOLD";
        public static final String IRIS_PROXI_SENSOR_SET_LOW_THRESHOLD = "IRIS_PROXI_SENSOR_SET_LOW_THRESHOLD";
        public static final String IR_CURRENT = "IR_CURRENT";
        public static final String IR_LED_RESULT_TX = "IR_LED_RESULT_TX";
        public static final String IR_LED_SEND = "IR_LED_SEND";
        public static final String IR_LED_SEND_TEST = "IR_LED_SEND_TEST";
        public static final String JIG_B_SIGNAL = "JIG_B_SIGNAL";
        public static final String JIG_CONNECTION_CHECK = "JIG_CONNECTION_CHECK";
        public static final String JIG_CONNECTION_CHECK_ADC = "JIG_CONNECTION_CHECK_ADC";
        public static final String JIG_CONNECTION_CHECK_ADC_RAW = "JIG_CONNECTION_CHECK_ADC_RAW";
        public static final String JIG_INFO = "JIG_INFO";
        public static final String JIG_RID_ADC = "JIG_RID_ADC";
        public static final String KEYBOARD_CONNECTED = "KEYBOARD_CONNECTED";
        public static final String KEYPAD_BACKLIGHT_FAC = "KEYPAD_BACKLIGHT_FAC";
        public static final String KEYSTRING_BLOCK = "KEYSTRING_BLOCK";
        public static final String KEY_PRESSED = "KEY_PRESSED";
        public static final String KEY_PRESSED_3X4 = "KEY_PRESSED_3X4";
        public static final String KEY_PRESSED_POWER = "KEY_PRESSED_POWER";
        public static final String LCD_ALPM = "LCD_ALPM";
        public static final String LCD_ALPM_2 = "LCD_ALPM_2";
        public static final String LCD_AUTO_BRIGHTNESS = "LCD_AUTO_BRIGHTNESS";
        public static final String LCD_BACKLIGHT_BRIGHTNESS_LSI = "LCD_BACKLIGHT_BRIGHTNESS_LSI";
        public static final String LCD_BACKLIGHT_BRIGHTNESS_LSI_MAX = "LCD_BACKLIGHT_BRIGHTNESS_LSI_MAX";
        public static final String LCD_BACKLIGHT_BRIGHTNESS_QUALCOMM = "LCD_BACKLIGHT_BRIGHTNESS_QUALCOMM";
        public static final String LCD_BACKLIGHT_BRIGHTNESS_QUALCOMM_MAX = "LCD_BACKLIGHT_BRIGHTNESS_QUALCOMM_MAX";
        public static final String LCD_BRIGHTDOT = "LCD_BRIGHTDOT";
        public static final String LCD_DDI_TEST = "LCD_DDI_TEST";
        public static final String LCD_FAST_DISCHARGE = "LCD_FAST_DISCHARGE";
        public static final String LCD_FAST_DISCHARGE_2ND = "LCD_FAST_DISCHARGE_2ND";
        public static final String LCD_ID = "LCD_ID";
        public static final String LCD_PANEL_ELVSS = "LCD_PANEL_ELVSS";
        public static final String LCD_PMIC_POWER_CONTROL = "LCD_PMIC_POWER_CONTROL";
        public static final String LCD_TE_SIGNAL_CHECK_MAIN = "LCD_TE_SIGNAL_CHECK_MAIN";
        public static final String LCD_TE_SIGNAL_CHECK_SUB = "LCD_TE_SIGNAL_CHECK_SUB";
        public static final String LCD_TYPE_PATH = "LCD_TYPE_PATH";
        public static final String LCD_VARIABLE_RATE = "LCD_VARIABLE_RATE";
        public static final String LCD_VARIABLE_RATE_LFD = "LCD_VARIABLE_RATE_LFD";
        public static final String LED_BLINK = "LED_BLINK";
        public static final String LED_BLUE = "LED_BLUE";
        public static final String LED_CONTROL = "LED_CONTROL";
        public static final String LED_GREEN = "LED_GREEN";
        public static final String LED_LOWPOWER = "LED_LOWPOWER";
        public static final String LED_RED = "LED_RED";
        public static final String LIGHT_SENSOR_ADC = "LIGHT_SENSOR_ADC";
        public static final String LIGHT_SENSOR_CAL = "LIGHT_SENSOR_CAL";
        public static final String LIGHT_SENSOR_CIRCLE = "LIGHT_SENSOR_CIRCLE";
        public static final String LIGHT_SENSOR_DEBUG = "LIGHT_SENSOR_DEBUG";
        public static final String LIGHT_SENSOR_IMAGE_TEST_RESULT = "LIGHT_SENSOR_IMAGE_TEST_RESULT";
        public static final String LIGHT_SENSOR_LUX = "LIGHT_SENSOR_LUX";
        public static final String LIGHT_SENSOR_NAME = "LIGHT_SENSOR_NAME";
        public static final String LIGHT_SENSOR_RAW = "LIGHT_SENSOR_RAW";
        public static final String LINE_SPEC = "LINE_SPEC";
        public static final String LOGO_LIGHT_TEST_LED_PATTERN = "LOGO_LIGHT_TEST_LED_PATTERN";
        public static final int LOG_LEVEL_NEVER_SHOW = 0;
        public static final String LPA_MODE_SET = "LPA_MODE_SET";
        public static final String LPM_MODE_SET = "LPM_MODE_SET";
        public static final String LRP_THERMISTER_TEMPERATURE = "LRP_THERMISTER_TEMPERATURE";
        public static final String MAGNT_SENSOR_RAW = "MAGNT_SENSOR_RAW";
        public static final String MAIN_PMIC_DET = "MAIN_PMIC_DET";
        public static final String MASKING_HBM_STATUS = "MASKING_HBM_STATUS";
        public static final String MCD_STATUS_NODE = "MCD_STATUS_NODE";
        public static final String MCD_STATUS_NODE_2 = "MCD_STATUS_NODE_2";
        public static final String MD05_REGISTER_PATH = "MD05_REGISTER_PATH";
        public static final String MDNIE_BYPASS_NODE = "MDNIE_BYPASS_NODE";
        public static final String MICRO_CRACK_NODE = "MICRO_CRACK_NODE";
        public static final String MMCBLK_DEVICE_CSD = "MMCBLK_DEVICE_CSD";
        public static final String MMC_DATA = "MMC_DATA";
        public static final String MOOD_LED1 = "MOOD_LED1";
        public static final String MOOD_LED2 = "MOOD_LED2";
        public static final String MOOD_LED3 = "MOOD_LED3";
        public static final String MOOD_LED4 = "MOOD_LED4";
        public static final String MOOD_LED_NODE = "MOOD_LED_NODE";
        public static final String MOTOR_LPF = "MOTOR_LPF";
        public static final String MST_DATA_TRANSMIT_PATH = "MST_DATA_TRANSMIT_PATH";
        public static final String MTK_HPS_CONTROL = "MTK_HPS_CONTROL";
        public static final String MUIC_JIG_ON = "MUIC_JIG_ON";
        public static final String NAD_LOOP_TEST_RESULT = "NAD_LOOP_TEST_RESULT";
        public static final String NEW_FACTORY_MODE_DISABLE = "NEW_FACTORY_MODE_DISABLE";
        public static final String NFC_COVER_STATUS = "NFC_COVER_STATUS";
        public static final String NR_SIOP_THERMISTER_ADC = "NR_SIOP_THERMISTER_ADC";
        public static final String NR_SIOP_THERMISTER_TEMPERATURE = "NR_SIOP_THERMISTER_TEMPERATURE";
        public static final String NR_THERMISTER = "NR_THERMISTER";
        public static final String NR_THERMISTER_ADC = "NR_THERMISTER_ADC";
        public static final String OCTA_CONNECTION_CHECK = "OCTA_CONNECTION_CHECK";
        public static final String OCTA_DDI_SELF_MASK_CHECK = "OCTA_DDI_SELF_MASK_CHECK";
        public static final String OCTA_ERROR_CORRECTION = "OCTA_ERROR_CORRECTION";
        public static final String OCTA_ID = "OCTA_ID";
        public static final String OCTA_MAFPC_CHECK = "OCTA_MAFPC_CHECK";
        public static final String OCTA_MANUFACTURE_CODE = "OCTA_MANUFACTURE_CODE";
        public static final String OCTA_SOURCE_SELF_REPAIR = "OCTA_SOURCE_SELF_REPAIR";
        public static final String OCTA_SPI_SELF_MASK_NODE = "OCTA_SPI_SELF_MASK_NODE";
        public static final String OTG_MUIC_SET = "OTG_MUIC_SET";
        public static final String OTG_ONLINE = "OTG_ONLINE";
        public static final String OTG_TEST_MODE = "OTG_TEST_MODE";
        public static final String PA0_THERMISTER_ADC = "PA0_THERMISTER_ADC";
        public static final String PA0_THERMISTER_CELCIUS = "PA0_THERMISTER_CELCIUS";
        public static final String PA1_THERMISTER_ADC = "PA1_THERMISTER_ADC";
        public static final String PA1_THERMISTER_CELCIUS = "PA1_THERMISTER_CELCIUS";
        public static final String PAN_PAF_OFFSET = "PAN_PAF_OFFSET";
        public static final String PAN_PAF_OFFSET_MID = "PAN_PAF_OFFSET_MID";
        public static final String PATH_AUTOCAL = "PATH_AUTOCAL";
        public static final String PATH_BACKLIGHT_ON_FOR_GREEN_LCD = "PATH_BACKLIGHT_ON_FOR_GREEN_LCD";
        public static final String PATH_BATTERY_ASOC = "PATH_BATTERY_ASOC";
        public static final String PATH_BATTERY_CHARGE_COUNT = "PATH_BATTERY_CHARGE_COUNT";
        public static final String PATH_BATTERY_DISCON_COUNT = "PATH_BATTERY_DISCON_COUNT";
        public static final String PATH_BLOCK_HALLIC = "PATH_BLOCK_HALLIC";
        public static final String PATH_EARPHONE_KEY_ADC = "PATH_EARPHONE_KEY_ADC";
        public static final String PATH_EARPHONE_KEY_CODE = "PATH_EARPHONE_KEY_CODE";
        public static final String PATH_FORCE_CAL_DATA_EFS = "PATH_FORCE_CAL_DATA_EFS";
        public static final String PATH_FORCE_CFOFFSET_STRENGTH = "PATH_FORCE_CFOFFSET_STRENGTH";
        public static final String PATH_FUEL_GAUGE_ASOC = "PATH_FUEL_GAUGE_ASOC";
        public static final String PATH_HALLIC_DETECT_STATE = "PATH_HALLIC_DETECT_STATE";
        public static final String PATH_HALLIC_DETECT_STATE2 = "PATH_HALLIC_DETECT_STATE2";
        public static final String PATH_HALLIC_DETECT_STATE3 = "PATH_HALLIC_DETECT_STATE3";
        public static final String PATH_HALLIC_DETECT_STATE4 = "PATH_HALLIC_DETECT_STATE4";
        public static final String PATH_HALLIC_NUMBER = "PATH_HALLIC_NUMBER";
        public static final String PATH_HALLIC_STATE3 = "PATH_HALLIC_STATE3";
        public static final String PATH_HALLIC_STATE4 = "PATH_HALLIC_STATE4";
        public static final String PATH_HIGH_SENSITIVITY_MODE = "PATH_HIGH_SENSITIVITY_MODE";
        public static final String PATH_IFPMIC_RAM_BIST = "PATH_IFPMIC_RAM_BIST";
        public static final String PATH_IFPMIC_VBUS_ADC = "PATH_IFPMIC_VBUS_ADC";
        public static final String PATH_MAIN_CHIP_FEATURE_ID = "PATH_MAIN_CHIP_FEATURE_ID";
        public static final String PATH_MIC_PARALLEL_SPEC = "PATH_MIC_PARALLEL_SPEC";
        public static final String PATH_NOISE_TSK_BACK_IDAC = "PATH_NOISE_TSK_BACK_IDAC";
        public static final String PATH_NOISE_TSK_BACK_IDAC_INNER = "PATH_NOISE_TSK_BACK_IDAC_INNER";
        public static final String PATH_NOISE_TSK_BACK_IDAC_OUTER = "PATH_NOISE_TSK_BACK_IDAC_OUTER";
        public static final String PATH_NOISE_TSK_BACK_RAWDATA = "PATH_NOISE_TSK_BACK_RAWDATA";
        public static final String PATH_NOISE_TSK_BACK_RAWDATA_INNER = "PATH_NOISE_TSK_BACK_RAWDATA_INNER";
        public static final String PATH_NOISE_TSK_BACK_RAWDATA_OUTER = "PATH_NOISE_TSK_BACK_RAWDATA_OUTER";
        public static final String PATH_NOISE_TSK_BACK_RAWDATA_REFERENCE = "PATH_NOISE_TSK_BACK_RAWDATA_REFERENCE";
        public static final String PATH_NOISE_TSK_DUMMY4 = "PATH_NOISE_TSK_DUMMY4";
        public static final String PATH_NOISE_TSK_HIDDEN1 = "PATH_NOISE_TSK_HIDDEN1";
        public static final String PATH_NOISE_TSK_HIDDEN1_RAWDATA = "PATH_NOISE_TSK_HIDDEN1_RAWDATA";
        public static final String PATH_NOISE_TSK_HIDDEN2 = "PATH_NOISE_TSK_HIDDEN2";
        public static final String PATH_NOISE_TSK_HIDDEN2_RAWDATA = "PATH_NOISE_TSK_HIDDEN2_RAWDATA";
        public static final String PATH_NOISE_TSK_HOME_IDAC = "PATH_NOISE_TSK_HOME_IDAC";
        public static final String PATH_NOISE_TSK_HOME_RAWDATA = "PATH_NOISE_TSK_HOME_RAWDATA";
        public static final String PATH_NOISE_TSK_MD_PANEL = "PATH_NOISE_TSK_MD_PANEL";
        public static final String PATH_NOISE_TSK_MD_PHONE = "PATH_NOISE_TSK_MD_PHONE";
        public static final String PATH_NOISE_TSK_MENU_IDAC = "PATH_NOISE_TSK_MENU_IDAC";
        public static final String PATH_NOISE_TSK_MENU_RAWDATA = "PATH_NOISE_TSK_MENU_RAWDATA";
        public static final String PATH_NOISE_TSK_RECENT_IDAC = "PATH_NOISE_TSK_RECENT_IDAC";
        public static final String PATH_NOISE_TSK_RECENT_IDAC_INNER = "PATH_NOISE_TSK_RECENT_IDAC_INNER";
        public static final String PATH_NOISE_TSK_RECENT_IDAC_OUTER = "PATH_NOISE_TSK_RECENT_IDAC_OUTER";
        public static final String PATH_NOISE_TSK_RECENT_RAWDATA = "PATH_NOISE_TSK_RECENT_RAWDATA";
        public static final String PATH_NOISE_TSK_RECENT_RAWDATA_INNER = "PATH_NOISE_TSK_RECENT_RAWDATA_INNER";
        public static final String PATH_NOISE_TSK_RECENT_RAWDATA_OUTER = "PATH_NOISE_TSK_RECENT_RAWDATA_OUTER";
        public static final String PATH_NOISE_TSK_RECENT_RAWDATA_REFERENCE = "PATH_NOISE_TSK_RECENT_RAWDATA_REFERENCE";
        public static final String PATH_NOISE_TSK_SUB_BACK_RAWDATA = "PATH_NOISE_TSK_SUB_BACK_RAWDATA";
        public static final String PATH_NOISE_TSK_SUB_RECENT_RAWDATA = "PATH_NOISE_TSK_SUB_RECENT_RAWDATA";
        public static final String PATH_TSP_ALL_NODE_SPEC = "PATH_TSP_ALL_NODE_SPEC";
        public static final String PATH_TSP_MAGNETIC_SPEC = "PATH_TSP_MAGNETIC_SPEC";
        public static final String PATH_TSP_OPENSHORT_CM2_MAIN = "PATH_TSP_OPENSHORT_CM2_MAIN";
        public static final String PATH_TSP_OPENSHORT_CM2_OUT = "PATH_TSP_OPENSHORT_CM2_OUT";
        public static final String PATH_TSP_OPENSHORT_CM2_SDC = "PATH_TSP_OPENSHORT_CM2_SDC";
        public static final String PATH_TSP_OPENSHORT_CM2_SUB = "PATH_TSP_OPENSHORT_CM2_SUB";
        public static final String PATH_TSP_OPENSHORT_CM3_MAIN = "PATH_TSP_OPENSHORT_CM3_MAIN";
        public static final String PATH_TSP_OPENSHORT_CM3_OUT = "PATH_TSP_OPENSHORT_CM3_OUT";
        public static final String PATH_TSP_OPENSHORT_CM3_SDC = "PATH_TSP_OPENSHORT_CM3_SDC";
        public static final String PATH_TSP_OPENSHORT_CM3_SUB = "PATH_TSP_OPENSHORT_CM3_SUB";
        public static final String PA_THERM1 = "PA_THERM1";
        public static final String PA_THERM2 = "PA_THERM2";
        public static final String PA_THERM3 = "PA_THERM3";
        public static final String PDIC_CHIP_NAME = "PDIC_CHIP_NAME";
        public static final String PDIC_FIRMWARE_UPDATE = "PDIC_FIRMWARE_UPDATE";
        public static final String PDIC_FIRMWARE_UPDATE_STATUS = "PDIC_FIRMWARE_UPDATE_STATUS";
        public static final String PDIC_FW_BINARY = "PDIC_FW_BINARY";
        public static final String PDIC_FW_MODULE = "PDIC_FW_MODULE";
        public static final String PDIC_KERNEL_FIRMWARE_VERSION = "PDIC_KERNEL_FIRMWARE_VERSION";
        public static final String PD_CHECK_PS_READY = "PD_CHECK_PS_READY";
        public static final String PLANT_PRODUCTION = "PLANT_PRODUCTION";
        public static final String POGO_CHARGING_MODE = "POGO_CHARGING_MODE";
        public static final String POGO_DOCK_INT_PIN1 = "POGO_DOCK_INT_PIN1";
        public static final String POGO_DOCK_INT_PIN2 = "POGO_DOCK_INT_PIN2";
        public static final String POGO_MCU_FIRMWARE_VERSION = "POGO_MCU_FIRMWARE_VERSION";
        public static final String POGO_PIN_ADC_READ = "POGO_PIN_ADC_READ";
        public static final String PRESSURE_TOUCH_STATUS = "PRESSURE_TOUCH_STATUS";
        public static final String PRETEST_CABLE_DETECT_COUNT_CAMERA = "PRETEST_CABLE_DETECT_COUNT_CAMERA";
        public static final String PRETEST_CABLE_DETECT_COUNT_LOWERPBA = "PRETEST_CABLE_DETECT_COUNT_LOWERPBA";
        public static final String PRETEST_CABLE_DETECT_COUNT_MAINBATT = "PRETEST_CABLE_DETECT_COUNT_MAINBATT";
        public static final String PRETEST_CABLE_DETECT_COUNT_MAINDIGI = "PRETEST_CABLE_DETECT_COUNT_MAINDIGI";
        public static final String PRETEST_CABLE_DETECT_COUNT_OCTA = "PRETEST_CABLE_DETECT_COUNT_OCTA";
        public static final String PRETEST_CABLE_DETECT_COUNT_SUBBATT = "PRETEST_CABLE_DETECT_COUNT_SUBBATT";
        public static final String PRETEST_CABLE_DETECT_COUNT_SUBDIGI = "PRETEST_CABLE_DETECT_COUNT_SUBDIGI";
        public static final String PRETEST_CABLE_DETECT_COUNT_SUBPBA = "PRETEST_CABLE_DETECT_COUNT_SUBPBA";
        public static final String PRETEST_CABLE_DETECT_COUNT_SUBUB = "PRETEST_CABLE_DETECT_COUNT_SUBUB";
        public static final String PRETEST_CABLE_DETECT_COUNT_TOFCAM = "PRETEST_CABLE_DETECT_COUNT_TOFCAM";
        public static final String PRETEST_CABLE_DETECT_COUNT_TSP = "PRETEST_CABLE_DETECT_COUNT_TSP";
        public static final String PRETEST_CABLE_DETECT_COUNT_UPPERPBA = "PRETEST_CABLE_DETECT_COUNT_UPPERPBA";
        public static final String PRE_PAY = "PRE_PAY";
        public static final String PROXI_LIGHT_SELECT_FLIP_STATE = "PROXI_LIGHT_SELECT_FLIP_STATE";
        public static final String PROXI_SENSOR_ADC = "PROXI_SENSOR_ADC";
        public static final String PROXI_SENSOR_ADC_AVG = "PROXI_SENSOR_ADC_AVG";
        public static final String PROXI_SENSOR_ALERT_THRESHOLD = "PROXI_SENSOR_ALERT_THRESHOLD";
        public static final String PROXI_SENSOR_DEFAULT_TRIM = "PROXI_SENSOR_DEFAULT_TRIM";
        public static final String PROXI_SENSOR_DETECT_HIGH_THRESHOLD = "PROXI_SENSOR_DETECT_HIGH_THRESHOLD";
        public static final String PROXI_SENSOR_DETECT_LOW_THRESHOLD = "PROXI_SENSOR_DETECT_LOW_THRESHOLD";
        public static final String PROXI_SENSOR_MODIFY_SETTING = "PROXI_SENSOR_MODIFY_SETTING";
        public static final String PROXI_SENSOR_NAME = "PROXI_SENSOR_NAME";
        public static final String PROXI_SENSOR_OFFSET = "PROXI_SENSOR_OFFSET";
        public static final String PROXI_SENSOR_OFFSET_PASS = "PROXI_SENSOR_OFFSET_PASS";
        public static final String PROXI_SENSOR_SETTINGS_THD_HIGH = "PROXI_SENSOR_SETTINGS_THD_HIGH";
        public static final String PROXI_SENSOR_SETTINGS_THD_LOW = "PROXI_SENSOR_SETTINGS_THD_LOW";
        public static final String PROXI_SENSOR_SET_HIGH_THRESHOLD = "PROXI_SENSOR_SET_HIGH_THRESHOLD";
        public static final String PROXI_SENSOR_SET_LOW_THRESHOLD = "PROXI_SENSOR_SET_LOW_THRESHOLD";
        public static final String PROXI_SENSOR_TRIM_CHECK = "PROXI_SENSOR_TRIM_CHECK";
        public static final String PROX_LED_TEST = "PROX_LED_TEST";
        public static final String PTT_STATE = "PTT_STATE";
        public static final String QUEST_SUPPORT = "QUEST_SUPPORT";
        public static final String RAM_VERSION = "RAM_VERSION";
        public static final String RANGE_SENSOR_AVG = "RANGE_SENSOR_AVG";
        public static final String RANGE_SENSOR_CALIBRATION = "RANGE_SENSOR_CALIBRATION";
        public static final String RANGE_SENSOR_CAL_DATA_ID = "RANGE_SENSOR_CAL_DATA_ID";
        public static final String RANGE_SENSOR_CHIP_ID = "RANGE_SENSOR_CHIP_ID";
        public static final String RANGE_SENSOR_ENABLE = "RANGE_SENSOR_ENABLE";
        public static final String RANGE_SENSOR_FW_VER = "RANGE_SENSOR_FW_VER";
        public static final String RANGE_SENSOR_RAWDATA = "RANGE_SENSOR_RAWDATA";
        public static final String RANGE_SENSOR_TEMP = "RANGE_SENSOR_TEMP";
        public static final String RANGE_SENSOR_TEST_CAL_ITEM_0 = "RANGE_SENSOR_TEST_CAL_ITEM_0";
        public static final String RANGE_SENSOR_TEST_ITEM = "RANGE_SENSOR_TEST_ITEM";
        public static final String RANGE_SENSOR_TEST_ITEM_0 = "RANGE_SENSOR_TEST_ITEM_0";
        public static final String RANGE_SENSOR_TEST_MODE = "RANGE_SENSOR_TEST_MODE";
        public static final String RANGE_SENSOR_ZONE = "RANGE_SENSOR_ZONE";
        public static final String RCV_AMP_REINIT = "RCV_AMP_REINIT";
        public static final String RCV_AMP_VALIDATION_CHECK = "RCV_AMP_VALIDATION_CHECK";
        public static final String RCV_AMP_VALIDATION_STATUS = "RCV_AMP_VALIDATION_STATUS";
        public static final String RDM_MODEL_INFO_PATH = "RDM_MODEL_INFO_PATH";
        public static final String READ_COPR_NODE = "READ_COPR_NODE";
        public static final String REGION_INFO = "REGION_INFO";
        public static final String RESET_ENABLED = "RESET_ENABLED";
        public static final String RFBACKOFF_STATUS_WIFI = "RFBACKOFF_STATUS_WIFI";
        public static final String RGB_PE_ONOFF = "RGB_PE_ONOFF";
        public static final String SD_SPEED_MODE = "SD_SPEED_MODE";
        public static final String SECEFS_BACK_COVER_COUNT_FILE = "SECEFS_BACK_COVER_COUNT_FILE";
        public static final String SECEFS_COVER_COUNT_FILE = "SECEFS_COVER_COUNT_FILE";
        public static final String SECEFS_CPLOG_DIRECTORY = "SECEFS_CPLOG_DIRECTORY";
        public static final String SECEFS_CTEICODE = "SECEFS_CTEICODE";
        public static final String SECEFS_DISPLAY_PMIC_CURRENT_FOR_BIGDATA = "SECEFS_DISPLAY_PMIC_CURRENT_FOR_BIGDATA";
        public static final String SECEFS_DISPLAY_PMIC_POWER_VALUE = "SECEFS_DISPLAY_PMIC_POWER_VALUE";
        public static final String SECEFS_ETH_DIRECTORY = "SECEFS_ETH_DIRECTORY";
        public static final String SECEFS_FLICKER_DATA_FILE = "SECEFS_FLICKER_DATA_FILE";
        public static final String SECEFS_GRIP_TEMP_CAL_FILE = "SECEFS_GRIP_TEMP_CAL_FILE";
        public static final String SECEFS_HRM_DATA_FILE = "SECEFS_HRM_DATA_FILE";
        public static final String SECEFS_IMS_SETTING_BACKUP_FILE = "SECEFS_IMS_SETTING_BACKUP_FILE";
        public static final String SECEFS_IMS_SETTING_FILE = "SECEFS_IMS_SETTING_FILE";
        public static final String SECEFS_MPS_CODE_FILE = "SECEFS_MPS_CODE_FILE";
        public static final String SECEFS_OQCSBFTT_DIRECTORY = "SECEFS_OQCSBFTT_DIRECTORY";
        public static final String SECEFS_PATH_ACT_NV = "SECEFS_PATH_ACT_NV";
        public static final String SECEFS_PATH_EARJACK_COUNTER = "SECEFS_PATH_EARJACK_COUNTER";
        public static final String SECEFS_PATH_EPEN_COUNTER = "SECEFS_PATH_EPEN_COUNTER";
        public static final String SECEFS_PATH_FLASHPOPUP_COUNTER = "SECEFS_PATH_FLASHPOPUP_COUNTER";
        public static final String SECEFS_PATH_QWERTY_COUNTER = "SECEFS_PATH_QWERTY_COUNTER";
        public static final String SECEFS_PATH_TA_COUNTER = "SECEFS_PATH_TA_COUNTER";
        public static final String SECEFS_PATH_TDMB_COUNTER = "SECEFS_PATH_TDMB_COUNTER";
        public static final String SECEFS_PATH_TEST_NV = "SECEFS_PATH_TEST_NV";
        public static final String SECEFS_RESET_FLAG_FILE = "SECEFS_RESET_FLAG_FILE";
        public static final String SECEFS_RFBKOFFC_GPIO = "SECEFS_RFBKOFFC_GPIO";
        public static final String SECEFS_SWITCHED_SIM_EID = "SECEFS_SWITCHED_SIM_EID";
        public static final String SECEFS_TDMBTEST_RSSI_FILE = "SECEFS_TDMBTEST_RSSI_FILE";
        public static final String SECEFS_TDMBTEST_RSSI_LOG_FILE = "SECEFS_TDMBTEST_RSSI_LOG_FILE";
        public static final String SECEFS_WINDOW_COLOR_GROUP_FILE = "SECEFS_WINDOW_COLOR_GROUP_FILE";
        public static final String SECOND_CAMERA_PMIC = "SECOND_CAMERA_PMIC";
        public static final String SEC_BLANKET_THERMISTER_ADC = "SEC_BLANKET_THERMISTER_ADC";
        public static final String SEC_BLANKET_THERMISTER_TEMP = "SEC_BLANKET_THERMISTER_TEMP";
        public static final String SEC_CAMERA_THERMISTER_ADC = "SEC_CAMERA_THERMISTER_ADC";
        public static final String SEC_CAMERA_THERMISTER_TEMP = "SEC_CAMERA_THERMISTER_TEMP";
        public static final String SEC_CHARGING_VOLTAGE = "SEC_CHARGING_VOLTAGE";
        public static final String SEC_CHARGING_VOLTAGE_PD = "SEC_CHARGING_VOLTAGE_PD";
        public static final String SEC_EXT_THERMISTER_ADC = "SEC_EXT_THERMISTER_ADC";
        public static final String SEC_EXT_THERMISTER_TEMP = "SEC_EXT_THERMISTER_TEMP";
        public static final String SEC_MULTI_CHARGER_MODE = "SEC_MULTI_CHARGER_MODE";
        public static final String SEC_QUICK_CHARGE_VOLTAGE = "SEC_QUICK_CHARGE_VOLTAGE";
        public static final String SENSORDEBUG_CHECK_SSC = "SENSORDEBUG_CHECK_SSC";
        public static final String SENSORDEBUG_FORCE_TURN_OVER_CRASH = "SENSORDEBUG_FORCE_TURN_OVER_CRASH";
        public static final String SENSORHUB_CRASHED_FIRMWARE_UPDATE = "SENSORHUB_CRASHED_FIRMWARE_UPDATE";
        public static final String SENSORHUB_DDI_SPI_CHECK = "SENSORHUB_DDI_SPI_CHECK";
        public static final String SENSORHUB_FIRMWARE_UPDATE = "SENSORHUB_FIRMWARE_UPDATE";
        public static final String SENSORHUB_FIRMWARE_UPDATE_SYSTEM = "SENSORHUB_FIRMWARE_UPDATE_SYSTEM";
        public static final String SENSORHUB_FIRMWARE_VERSION = "SENSORHUB_FIRMWARE_VERSION";
        public static final String SENSORHUB_MCU = "SENSORHUB_MCU";
        public static final String SENSORHUB_QCT_FIRMWARE_UPDATE = "SENSORHUB_QCT_FIRMWARE_UPDATE";
        public static final String SENSORHUB_QCT_IC_FIRMWARE_VERSION = "SENSORHUB_QCT_IC_FIRMWARE_VERSION";
        public static final String SENSORHUB_QCT_KERNEL_FIRMWARE_VERSION = "SENSORHUB_QCT_KERNEL_FIRMWARE_VERSION";
        public static final String SERIAL_NO = "SERIAL_NO";
        public static final String SET_IFPMIC_POWER = "SET_IFPMIC_POWER";
        public static final String SET_JIGB_NODE = "SET_JIGB_NODE";
        public static final String SET_PARAM_PATH = "SET_PARAM_PATH";
        public static final String SET_QUICK_CHARGE_MODE = "SET_QUICK_CHARGE_MODE";
        public static final String SHIP_MODE = "SHIP_MODE";
        public static final String SHOULD_SHUT_DOWN = "SHOULD_SHUT_DOWN";
        public static final String SIDEKEY_COMMAND_CMD = "SIDEKEY_COMMAND_CMD";
        public static final String SIDEKEY_COMMAND_RESULT = "SIDEKEY_COMMAND_RESULT";
        public static final String SIDEKEY_COMMAND_RESULT_ALL = "SIDEKEY_COMMAND_RESULT_ALL";
        public static final String SIDEKEY_COMMAND_STATUS = "SIDEKEY_COMMAND_STATUS";
        public static final String SIM_TRAY_COUNT = "SIM_TRAY_COUNT";
        public static final String SLIDING_DOWN_HALL_DETECT = "SLIDING_DOWN_HALL_DETECT";
        public static final String SLPI_RESET = "SLPI_RESET";
        public static final String SPK_AMP_REINIT = "SPK_AMP_REINIT";
        public static final String SPK_AMP_REINIT_2 = "SPK_AMP_REINIT_2";
        public static final String SPK_CAL_CIRRUS_CAL = "SPK_CAL_CIRRUS_CAL";
        public static final String SPK_CAL_CIRRUS_REREF = "SPK_CAL_CIRRUS_REREF";
        public static final String SPK_CAL_CIRRUS_REREF_LEFT = "SPK_CAL_CIRRUS_REREF_LEFT";
        public static final String SPK_CAL_CIRRUS_REREF_RIGHT = "SPK_CAL_CIRRUS_REREF_RIGHT";
        public static final String SPK_CAL_CIRRUS_TEMP = "SPK_CAL_CIRRUS_TEMP";
        public static final String SPK_CAL_GOODIX_CAL = "SPK_CAL_GOODIX_CAL";
        public static final String SPK_CAL_GOODIX_IMPEDANCE = "SPK_CAL_GOODIX_IMPEDANCE";
        public static final String SPK_CAL_GOODIX_IMPEDANCE_2 = "SPK_CAL_GOODIX_IMPEDANCE_2";
        public static final String SPK_CAL_GOODIX_TEMP = "SPK_CAL_GOODIX_TEMP";
        public static final String SPK_CAL_GOODIX_TEMP_2 = "SPK_CAL_GOODIX_TEMP_2";
        public static final String SPK_CAL_MAXIM_CAL = "SPK_CAL_MAXIM_CAL";
        public static final String SPK_CAL_MAXIM_IMPEDANCE = "SPK_CAL_MAXIM_IMPEDANCE";
        public static final String SPK_CAL_MAXIM_IMPEDANCE_2 = "SPK_CAL_MAXIM_IMPEDANCE_2";
        public static final String SPK_CAL_MAXIM_TEMP = "SPK_CAL_MAXIM_TEMP";
        public static final String SPK_CAL_NEW_NXP_CAL = "SPK_CAL_NEW_NXP_CAL";
        public static final String SPK_CAL_NEW_NXP_RDC = "SPK_CAL_NEW_NXP_RDC";
        public static final String SPK_CAL_NEW_NXP_TEMP = "SPK_CAL_NEW_NXP_TEMP";
        public static final String SPK_CAL_RICHTEK_CAL = "SPK_CAL_RICHTEK_CAL";
        public static final String SPK_CAL_RICHTEK_IMPEDANCE = "SPK_CAL_RICHTEK_IMPEDANCE";
        public static final String SPRD_HOT_PLUG_LOCK = "SPRD_HOT_PLUG_LOCK";
        public static final String SS_FACTORY = "SS_FACTORY";
        public static final String STATE_SENSOR_RESET = "STATE_SENSOR_RESET";
        public static final String SUBFPCB_TYPE = "SUBFPCB_TYPE";
        public static final String SUBLCD_TYPE_PATH = "SUBLCD_TYPE_PATH";
        public static final String SUBOCTA_ID = "SUBOCTA_ID";
        public static final String SUBOCTA_MANUFACTURE_CODE = "SUBOCTA_MANUFACTURE_CODE";
        public static final String SUB_ACCEL_SENSOR_CAL = "SUB_ACCEL_SENSOR_CAL";
        public static final String SUB_ACCEL_SENSOR_RAW = "SUB_ACCEL_SENSOR_RAW";
        public static final String SUB_ACCEL_SENSOR_SELFTEST = "SUB_ACCEL_SENSOR_SELFTEST";
        public static final String SUB_GYRO_SENSOR_REVISED = "SUB_GYRO_SENSOR_REVISED";
        public static final String SUB_GYRO_SENSOR_SELFTEST = "SUB_GYRO_SENSOR_SELFTEST";
        public static final String SUB_MOTOR_LPF = "SUB_MOTOR_LPF";
        public static final String SUB_TSK_FIRMWARE_UPDATE = "SUB_TSK_FIRMWARE_UPDATE";
        public static final String SUB_TSK_FIRMWARE_UPDATE_STATUS = "SUB_TSK_FIRMWARE_UPDATE_STATUS";
        public static final String SUPPORT_MST_GPIO = "SUPPORT_MST_GPIO";
        public static final String SVC_CAL_NV = "SVC_CAL_NV";
        public static final String SWITCH_FACTORY = "SWITCH_FACTORY";
        public static final String SWITCH_KERNEL_FTM = "SWITCH_KERNEL_FTM";
        public static final String SYSFS_IFWI_VERSION = "SYSFS_IFWI_VERSION";
        public static final String SYSFS_OCTA_X_TALK_MODE = "SYSFS_OCTA_X_TALK_MODE";
        public static final String SYSTEM_CURRENT = "SYSTEM_CURRENT";
        public static final String SYSTEM_CURRENT_AVG = "SYSTEM_CURRENT_AVG";
        public static final String SYS_POWER_FTM_SLEEP = "SYS_POWER_FTM_SLEEP";
        public static final String TAG = "Sysfs";
        public static final String TEMP_HUMID_ENGINE_VER = "TEMP_HUMID_ENGINE_VER";
        public static final String THE_DEVICE_MOTOR_TYPE = "THE_DEVICE_MOTOR_TYPE";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_CALDATA_X = "THREE_DIMENSION_DIGITAL_HALL_IC_CALDATA_X";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_CALDATA_Y = "THREE_DIMENSION_DIGITAL_HALL_IC_CALDATA_Y";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_CALDATA_Z = "THREE_DIMENSION_DIGITAL_HALL_IC_CALDATA_Z";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_CHECK_AUTO_CAL = "THREE_DIMENSION_DIGITAL_HALL_IC_CHECK_AUTO_CAL";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_FAC_CAL = "THREE_DIMENSION_DIGITAL_HALL_IC_FAC_CAL";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_NAME = "THREE_DIMENSION_DIGITAL_HALL_IC_NAME";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_READ_DATA = "THREE_DIMENSION_DIGITAL_HALL_IC_READ_DATA";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_REF_ANGLE = "THREE_DIMENSION_DIGITAL_HALL_IC_REF_ANGLE";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_RESET_AUTO_CAL = "THREE_DIMENSION_DIGITAL_HALL_IC_RESET_AUTO_CAL";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_RF_TEST = "THREE_DIMENSION_DIGITAL_HALL_IC_RF_TEST";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_SELFTEST = "THREE_DIMENSION_DIGITAL_HALL_IC_SELFTEST";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_SPEC = "THREE_DIMENSION_DIGITAL_HALL_IC_SPEC";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_TEST_READ = "THREE_DIMENSION_DIGITAL_HALL_IC_TEST_READ";
        public static final String THREE_DIMENSION_DIGITAL_HALL_IC_TEST_SPEC = "THREE_DIMENSION_DIGITAL_HALL_IC_TEST_SPEC";
        public static final String TORCH_MODE_FLASH_1 = "TORCH_MODE_FLASH_1";
        public static final String TORCH_MODE_FLASH_2 = "TORCH_MODE_FLASH_2";
        public static final String TORCH_MODE_FLASH_3 = "TORCH_MODE_FLASH_3";
        public static final String TORCH_MODE_FLASH_OLD = "TORCH_MODE_FLASH_OLD";
        public static final String TORCH_MODE_FRONT_FLASH = "TORCH_MODE_FRONT_FLASH";
        public static final String TOUCHKEY_HAPTIC_CONTROL = "TOUCHKEY_HAPTIC_CONTROL";
        public static final String TOUCH_FIRMWARE_UPDATE = "TOUCH_FIRMWARE_UPDATE";
        public static final String TOUCH_FIRMWARE_UPDATE_STATUS = "TOUCH_FIRMWARE_UPDATE_STATUS";
        public static final String TOUCH_FIRMWARE_VERSION = "TOUCH_FIRMWARE_VERSION";
        public static final String TOUCH_KEY_BACK_CP_DATA = "TOUCH_KEY_BACK_CP_DATA";
        public static final String TOUCH_KEY_BRIGHTNESS = "TOUCH_KEY_BRIGHTNESS";
        public static final String TOUCH_KEY_CRC_CHECK = "TOUCH_KEY_CRC_CHECK";
        public static final String TOUCH_KEY_ENABLED = "TOUCH_KEY_ENABLED";
        public static final String TOUCH_KEY_INT_CTRL = "TOUCH_KEY_INT_CTRL";
        public static final String TOUCH_KEY_IRQ_COUNT = "TOUCH_KEY_IRQ_COUNT";
        public static final String TOUCH_KEY_RECENT_CP_DATA = "TOUCH_KEY_RECENT_CP_DATA";
        public static final String TOUCH_KEY_SENSITIVITY_APP_SWITCH = "TOUCH_KEY_SENSITIVITY_APP_SWITCH";
        public static final String TOUCH_KEY_SENSITIVITY_BACK = "TOUCH_KEY_SENSITIVITY_BACK";
        public static final String TOUCH_KEY_SENSITIVITY_BACK_INNER = "TOUCH_KEY_SENSITIVITY_BACK_INNER";
        public static final String TOUCH_KEY_SENSITIVITY_BACK_OUTER = "TOUCH_KEY_SENSITIVITY_BACK_OUTER";
        public static final String TOUCH_KEY_SENSITIVITY_HIDDEN1 = "TOUCH_KEY_SENSITIVITY_HIDDEN1";
        public static final String TOUCH_KEY_SENSITIVITY_HIDDEN2 = "TOUCH_KEY_SENSITIVITY_HIDDEN2";
        public static final String TOUCH_KEY_SENSITIVITY_HIDDEN3 = "TOUCH_KEY_SENSITIVITY_HIDDEN3";
        public static final String TOUCH_KEY_SENSITIVITY_HIDDEN4 = "TOUCH_KEY_SENSITIVITY_HIDDEN4";
        public static final String TOUCH_KEY_SENSITIVITY_HOME = "TOUCH_KEY_SENSITIVITY_HOME";
        public static final String TOUCH_KEY_SENSITIVITY_MENU = "TOUCH_KEY_SENSITIVITY_MENU";
        public static final String TOUCH_KEY_SENSITIVITY_OK = "TOUCH_KEY_SENSITIVITY_OK";
        public static final String TOUCH_KEY_SENSITIVITY_POWER = "TOUCH_KEY_SENSITIVITY_POWER";
        public static final String TOUCH_KEY_SENSITIVITY_RECENT = "TOUCH_KEY_SENSITIVITY_RECENT";
        public static final String TOUCH_KEY_SENSITIVITY_RECENT_INNER = "TOUCH_KEY_SENSITIVITY_RECENT_INNER";
        public static final String TOUCH_KEY_SENSITIVITY_RECENT_OUTER = "TOUCH_KEY_SENSITIVITY_RECENT_OUTER";
        public static final String TOUCH_KEY_SENSITIVITY_REF1 = "TOUCH_KEY_SENSITIVITY_REF1";
        public static final String TOUCH_KEY_SENSITIVITY_REF2 = "TOUCH_KEY_SENSITIVITY_REF2";
        public static final String TOUCH_KEY_SENSITIVITY_SEARCH = "TOUCH_KEY_SENSITIVITY_SEARCH";
        public static final String TOUCH_KEY_SENSITIVITY_SUB_APP_SWITCH = "TOUCH_KEY_SENSITIVITY_SUB_APP_SWITCH";
        public static final String TOUCH_KEY_SENSITIVITY_SUB_BACK = "TOUCH_KEY_SENSITIVITY_SUB_BACK";
        public static final String TOUCH_KEY_THRESHOLD = "TOUCH_KEY_THRESHOLD";
        public static final String TOUCH_KEY_THRESHOLD_BACK_INNER = "TOUCH_KEY_THRESHOLD_BACK_INNER";
        public static final String TOUCH_KEY_THRESHOLD_BACK_OUTER = "TOUCH_KEY_THRESHOLD_BACK_OUTER";
        public static final String TOUCH_KEY_THRESHOLD_RECENT_INNER = "TOUCH_KEY_THRESHOLD_RECENT_INNER";
        public static final String TOUCH_KEY_THRESHOLD_RECENT_OUTER = "TOUCH_KEY_THRESHOLD_RECENT_OUTER";
        public static final String TSK_FACTORY_MODE = "TSK_FACTORY_MODE";
        public static final String TSK_FIRMWARE_UPDATE = "TSK_FIRMWARE_UPDATE";
        public static final String TSK_FIRMWARE_UPDATE_STATUS = "TSK_FIRMWARE_UPDATE_STATUS";
        public static final String TSK_FIRMWARE_VERSION_PANEL = "TSK_FIRMWARE_VERSION_PANEL";
        public static final String TSK_FIRMWARE_VERSION_PHONE = "TSK_FIRMWARE_VERSION_PHONE";
        public static final String TSK_FIRMWARE_VERSION_SUB_PANEL = "TSK_FIRMWARE_VERSION_SUB_PANEL";
        public static final String TSK_FIRMWARE_VERSION_SUB_PHONE = "TSK_FIRMWARE_VERSION_SUB_PHONE";
        public static final String TSK_LIGHT_DATA = "TSK_LIGHT_DATA";
        public static final String TSK_LIGHT_VER = "TSK_LIGHT_VER";
        public static final String TSK_LIGHT_WRITE_DATA = "TSK_LIGHT_WRITE_DATA";
        public static final String TSK_VENDOR_NAME = "TSK_VENDOR_NAME";
        public static final String TSP2_COMMAND_CMD = "TSP2_COMMAND_CMD";
        public static final String TSP2_COMMAND_RESULT = "TSP2_COMMAND_RESULT";
        public static final String TSP2_COMMAND_RESULT_ALL = "TSP2_COMMAND_RESULT_ALL";
        public static final String TSP2_COMMAND_STATUS = "TSP2_COMMAND_STATUS";
        public static final String TSP2_COMMAND_STATUS_ALL = "TSP2_COMMAND_STATUS_ALL";
        public static final String TSP2_ENABLE = "TSP2_ENABLE";
        public static final String TSP_BYPASS = "TSP_BYPASS";
        public static final String TSP_COMMAND_CMD = "TSP_COMMAND_CMD";
        public static final String TSP_COMMAND_CONNECTION = "TSP_COMMAND_CONNECTION";
        public static final String TSP_COMMAND_LIST = "TSP_COMMAND_LIST";
        public static final String TSP_COMMAND_RESULT = "TSP_COMMAND_RESULT";
        public static final String TSP_COMMAND_RESULT_ALL = "TSP_COMMAND_RESULT_ALL";
        public static final String TSP_COMMAND_STATUS = "TSP_COMMAND_STATUS";
        public static final String TSP_COMMAND_STATUS_ALL = "TSP_COMMAND_STATUS_ALL";
        public static final String TSP_EAR_DETECT_ENABLE = "TSP_EAR_DETECT_ENABLE";
        public static final String TSP_ENABLE = "TSP_ENABLE";
        public static final String TSP_PROXIMITY_ADC = "TSP_PROXIMITY_ADC";
        public static final String TSP_RAW_DATA = "TSP_RAW_DATA";
        public static final String TSP_REPORT_FREQUENCY_120HZ = "TSP_REPORT_FREQUENCY_120HZ";
        public static final String TSP_SENSITIVITY_MODE = "TSP_SENSITIVITY_MODE";
        public static final String TSP_SUPPORT_FEATURE = "TSP_SUPPORT_FEATURE";
        public static final String UART_ON_OFF = "UART_ON_OFF";
        public static final String UART_SELECT = "UART_SELECT";
        public static final String UEVENT_HALL_DETECT = "UEVENT_HALL_DETECT";
        public static final String UFS_DEVICE_SIZE = "UFS_DEVICE_SIZE";
        public static final String UFS_DEVICE_SIZE_A = "UFS_DEVICE_SIZE_A";
        public static final String UFS_DEVICE_SIZE_B = "UFS_DEVICE_SIZE_B";
        public static final String UFS_DEVICE_SIZE_C = "UFS_DEVICE_SIZE_C";
        public static final String UFS_DEVICE_SIZE_D = "UFS_DEVICE_SIZE_D";
        public static final String UFS_DEVICE_SIZE_E = "UFS_DEVICE_SIZE_E";
        public static final String UFS_DEVICE_SIZE_F = "UFS_DEVICE_SIZE_F";
        public static final String UFS_DEVICE_SIZE_G = "UFS_DEVICE_SIZE_G";
        public static final String UFS_DEVICE_SIZE_H = "UFS_DEVICE_SIZE_H";
        public static final String UFS_FIRMWARE_VERSION = "UFS_FIRMWARE_VERSION";
        public static final String UFS_FW_VERSION = "UFS_FW_VERSION";
        public static final String UFS_UN = "UFS_UN";
        public static final String UFS_UN_LEGACY = "UFS_UN_LEGACY";
        public static final String UICOMMANDER_SCENARIO = "UICOMMANDER_SCENARIO";
        public static final String ULTRASONIC_ADC_DISTANCE = "ULTRASONIC_ADC_DISTANCE";
        public static final String ULTRASONIC_BGE_CAL_RESULT_FILE_1 = "ULTRASONIC_BGE_CAL_RESULT_FILE_1";
        public static final String ULTRASONIC_BGE_CAL_RESULT_FILE_2 = "ULTRASONIC_BGE_CAL_RESULT_FILE_2";
        public static final String ULTRASONIC_BGE_CAL_RESULT_FILE_3 = "ULTRASONIC_BGE_CAL_RESULT_FILE_3";
        public static final String ULTRASONIC_BGE_CAL_RESULT_PATH = "ULTRASONIC_BGE_CAL_RESULT_PATH";
        public static final String ULTRASONIC_COMP_TEMP_REAL = "ULTRASONIC_COMP_TEMP_REAL";
        public static final String ULTRASONIC_FP_BGECAL_RESULT = "ULTRASONIC_FP_BGECAL_RESULT";
        public static final String ULTRASONIC_FP_DEAD_MASK_IMAGE = "ULTRASONIC_FP_DEAD_MASK_IMAGE";
        public static final String ULTRASONIC_FP_NRSC_RESULT = "ULTRASONIC_FP_NRSC_RESULT";
        public static final String ULTRASONIC_FP_POSITION = "ULTRASONIC_FP_POSITION";
        public static final String ULTRASONIC_FP_SNR_IMAGE = "ULTRASONIC_FP_SNR_IMAGE";
        public static final String ULTRASONIC_FP_SNR_IMAGE_COPY_PATH = "ULTRASONIC_FP_SNR_IMAGE_COPY_PATH";
        public static final String ULTRASONIC_FP_SNR_RESULT = "ULTRASONIC_FP_SNR_RESULT";
        public static final String ULTRASONIC_INT_CHECK_PATH = "ULTRASONIC_INT_CHECK_PATH";
        public static final String ULTRASONIC_RIGHT_START_BTN_POSITION_X_MM = "ULTRASONIC_RIGHT_START_BTN_POSITION_X_MM";
        public static final String ULTRASONIC_RIGHT_START_BTN_POSITION_Y_MM = "ULTRASONIC_RIGHT_START_BTN_POSITION_Y_MM";
        public static final String ULTRASONIC_RIGHT_START_BTN_SIZE_HEIGHT_MM = "ULTRASONIC_RIGHT_START_BTN_SIZE_HEIGHT_MM";
        public static final String ULTRASONIC_RIGHT_START_BTN_SIZE_WIDTH_MM = "ULTRASONIC_RIGHT_START_BTN_SIZE_WIDTH_MM";
        public static final String ULTRASONIC_SENSOR_ID_SAVE_PATH = "ULTRASONIC_SENSOR_ID_SAVE_PATH";
        public static final String ULTRASONIC_VER_CHECK = "ULTRASONIC_VER_CHECK";
        public static final String ULTRASONIC_WUHB_INT_CMD = "ULTRASONIC_WUHB_INT_CMD";
        public static final String ULTRASONIC_WUHB_INT_RESULT = "ULTRASONIC_WUHB_INT_RESULT";
        public static final String USB3_OTG_TYPE_CHECK = "USB3_OTG_TYPE_CHECK";
        public static final String USB3_TYPE_CHECK = "USB3_TYPE_CHECK";
        public static final String USB3_TYPE_CHECK_LEGACY = "USB3_TYPE_CHECK_LEGACY";
        public static final String USBGEN2_CONNECTION_CHECK = "USBGEN2_CONNECTION_CHECK";
        public static final String USB_1ST_PORT_CHECK = "USB_1ST_PORT_CHECK";
        public static final String USB_1ST_PORT_SUPER_CHECK = "USB_1ST_PORT_SUPER_CHECK";
        public static final String USB_2ST_PORT_CHECK = "USB_2ST_PORT_CHECK";
        public static final String USB_2ST_PORT_SUPER_CHECK = "USB_2ST_PORT_SUPER_CHECK";
        public static final String USB_CONFIG_CHECK = "USB_CONFIG_CHECK";
        public static final String USB_CONTROL = "USB_CONTROL";
        public static final String USB_CTRL = "USB_CTRL";
        public static final String USB_FACTORY_MODE = "USB_FACTORY_MODE";
        public static final String USB_LOGGING_ENABLE = "USB_LOGGING_ENABLE";
        public static final String USB_LOGGING_STATUS = "USB_LOGGING_STATUS";
        public static final String USB_SELECT = "USB_SELECT";
        public static final String USB_TEMP = "USB_TEMP";
        public static final String USB_TEMP_ADC = "USB_TEMP_ADC";
        public static final String USE_MST_MFC_IC = "USE_MST_MFC_IC";
        public static final String VENDOR_PATH_MIC_PARALLEL_SPEC = "VENDOR_PATH_MIC_PARALLEL_SPEC";
        public static final String VGL_TEST_MODE = "VGL_TEST_MODE";
        public static final String VPH_VOLT = "VPH_VOLT";
        public static final String VSAFE_REGISTER_STATUS = "VSAFE_REGISTER_STATUS";
        public static final String WATER_INT_DETECT = "WATER_INT_DETECT";
        public static final String WATER_TEST_TYPE = "WATER_TEST_TYPE";
        public static final String WC_AUTH_ADT_SENT = "WC_AUTH_ADT_SENT";
        public static final String WC_DUO_RX_POWER = "WC_DUO_RX_POWER";
        public static final String WIFI_TEMP_THERMISTOR = "WIFI_TEMP_THERMISTOR";
        public static final String WIFI_THERMISTER_ADC = "WIFI_THERMISTER_ADC";
        public static final String WIFI_THERMISTER_TEMP = "WIFI_THERMISTER_TEMP";
        public static final String WINDOW_TYPE = "WINDOW_TYPE";
        public static final String WINDOW_TYPE_2 = "WINDOW_TYPE_2";
        public static final String WIRELESS_BATTERY = "WIRELESS_BATTERY";
        public static final String WIRELESS_CHARGING_TX_CONNECTION = "WIRELESS_CHARGING_TX_CONNECTION";
        public static final String WIRELESS_CHARGING_TX_CURRENT = "WIRELESS_CHARGING_TX_CURRENT";
        public static final String WIRELESS_CHARGING_TX_ENABLE = "WIRELESS_CHARGING_TX_ENABLE";
        public static final String WIRELESS_CHARGING_TX_IN_DATA = "WIRELESS_CHARGING_TX_IN_DATA";
        public static final String WIRELESS_CHARGING_TX_OUT_DATA = "WIRELESS_CHARGING_TX_OUT_DATA";
        public static final String WIRELESS_CHARGING_TX_RESULT = "WIRELESS_CHARGING_TX_RESULT";
        public static final String WIRELESS_CHARGING_TX_VOLTAGE = "WIRELESS_CHARGING_TX_VOLTAGE";
        public static final String WIRELESS_CHARGING_TX_VOUT = "WIRELESS_CHARGING_TX_VOUT";
        public static final String WIRELESS_CMD_INFO = "WIRELESS_CMD_INFO";
        public static final String WIRELESS_FAST_CHARGE_MULTI_CHARGER_MODE = "WIRELESS_FAST_CHARGE_MULTI_CHARGER_MODE";
        public static final String WIRELESS_OP_FREQ = "WIRELESS_OP_FREQ";
        public static final String WIRELESS_VOUT = "WIRELESS_VOUT";
        public static final String WIRELESS_VRECT = "WIRELESS_VRECT";
        public static final String XO_OSC_THERMISTER_TEMP = "XO_OSC_THERMISTER_TEMP";

        public static String getFilePath(String id) {
            return Values.getString(id, "path");
        }

        public static String getMatchKey(String id) {
            return Values.getString(id, "match");
        }

        public static byte getByte(String id) {
            String path = Values.getString(id, "path");
            byte value = 0;
            BufferedReader reader = null;
            try {
                reader = new BufferedReader(new FileReader(path));
                value = (byte) reader.read();
                try {
                    reader.close();
                } catch (IOException e) {
                    XmlUtil.log_e(e);
                }
            } catch (Exception e2) {
                XmlUtil.log_e(e2);
                if (reader != null) {
                    reader.close();
                }
            } catch (Throwable th) {
                if (reader != null) {
                    try {
                        reader.close();
                    } catch (IOException e3) {
                        XmlUtil.log_e(e3);
                    }
                }
                throw th;
            }
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.read", "path=" + path + ", value=" + ((int) value));
            return value;
        }

        public static String getAccSensorVendor() {
            return read(ACCEL_SENSOR_VENDOR);
        }

        public static String getGyroSensorName() {
            return Feature.getString(Feature.SENSOR_NAME_GYROSCOPE);
        }

        public static String getGeoMagneticSensorName() {
            return Feature.getString(Feature.SENSOR_NAME_MAGNETIC);
        }

        public static String readAllLine(String id, boolean isLog) {
            String path;
            if (isLog) {
                path = Values.getString(id, "path");
            } else {
                path = Values.getString(id, "path", false);
            }
            String value = "";
            BufferedReader reader = null;
            if (path == null || Properties.PROPERTIES_DEFAULT_STRING.equalsIgnoreCase(path)) {
                return value;
            }
            try {
                BufferedReader reader2 = new BufferedReader(new FileReader(path));
                while (true) {
                    String temp_value = reader2.readLine();
                    if (temp_value == null) {
                        break;
                    }
                    value = value + " " + temp_value;
                }
                if (value != null) {
                    value = value.trim();
                }
                try {
                    reader2.close();
                } catch (IOException e) {
                    XmlUtil.log_e(e);
                }
            } catch (Exception e2) {
                XmlUtil.log_e(e2);
                if (0 != 0) {
                    reader.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        reader.close();
                    } catch (IOException e3) {
                        XmlUtil.log_e(e3);
                    }
                }
                throw th;
            }
            if (isLog) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.readAllLine", "path=" + path + ", value=" + value);
            }
            return value;
        }

        public static String readNsyncContinuous(String id, boolean isLog) {
            String path;
            if (isLog) {
                path = Values.getString(id, "path");
            } else {
                path = Values.getString(id, "path", false);
            }
            String value = "";
            BufferedReader reader = null;
            if (path == null || Properties.PROPERTIES_DEFAULT_STRING.equalsIgnoreCase(path)) {
                return value;
            }
            try {
                BufferedReader reader2 = new BufferedReader(new FileReader(path));
                while (true) {
                    String temp_value = reader2.readLine();
                    if (temp_value == null) {
                        break;
                    }
                    value = value + "\n" + temp_value;
                }
                if (value != null) {
                    value = value.trim();
                }
                try {
                    reader2.close();
                } catch (IOException e) {
                    XmlUtil.log_e(e);
                }
            } catch (Exception e2) {
                XmlUtil.log_e(e2);
                if (0 != 0) {
                    reader.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        reader.close();
                    } catch (IOException e3) {
                        XmlUtil.log_e(e3);
                    }
                }
                throw th;
            }
            if (isLog) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.readAllLine", "path=" + path + ", value=" + value);
            }
            return value;
        }

        public static String read(String id, boolean isLog, boolean isTrim) {
            String path;
            if (isLog) {
                path = Values.getString(id, "path");
            } else {
                path = Values.getString(id, "path", false);
            }
            String value = null;
            BufferedReader reader = null;
            if (path == null || Properties.PROPERTIES_DEFAULT_STRING.equalsIgnoreCase(path)) {
                return null;
            }
            try {
                BufferedReader reader2 = new BufferedReader(new FileReader(path));
                value = reader2.readLine();
                if (value != null && isTrim) {
                    value = value.trim();
                }
                try {
                    reader2.close();
                } catch (IOException e) {
                    XmlUtil.log_e(e);
                }
            } catch (Exception e2) {
                XmlUtil.log_e(e2);
                if (0 != 0) {
                    reader.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        reader.close();
                    } catch (IOException e3) {
                        XmlUtil.log_e(e3);
                    }
                }
                throw th;
            }
            if (isLog) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.read", "path=" + path + ", value=" + value);
            }
            return value;
        }

        public static String read(String id, int logLevel) {
            String path = Values.getString(id, "path", logLevel);
            String value = null;
            BufferedReader reader = null;
            try {
                BufferedReader reader2 = new BufferedReader(new FileReader(path));
                value = reader2.readLine();
                if (value != null) {
                    value = value.trim();
                }
                try {
                    reader2.close();
                } catch (IOException e) {
                    XmlUtil.log_e(e);
                }
            } catch (Exception e2) {
                XmlUtil.log_e(e2);
                if (0 != 0) {
                    reader.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        reader.close();
                    } catch (IOException e3) {
                        XmlUtil.log_e(e3);
                    }
                }
                throw th;
            }
            if (logLevel > 0) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.read", "path=" + path + ", value=" + value);
            }
            return value;
        }

        public static String readFromFile(String id) {
            String path = Values.getString(id, "path");
            if (path == null || Properties.PROPERTIES_DEFAULT_STRING.equalsIgnoreCase(path)) {
                return null;
            }
            StringBuilder sb = new StringBuilder();
            BufferedReader reader = null;
            try {
                System.currentTimeMillis();
                long nStart = System.currentTimeMillis();
                BufferedReader reader2 = new BufferedReader(new FileReader(path));
                XmlUtil.log_d(Support.CLASS_NAME, "readFromFile", "start, path: " + path);
                while (true) {
                    String line = reader2.readLine();
                    if (line == null) {
                        break;
                    }
                    sb.append(line);
                    sb.append("\n");
                }
                long nEnd = System.currentTimeMillis();
                XmlUtil.log_d(Support.CLASS_NAME, "readFromFile", "finish, time: " + (nEnd - nStart) + ", path: " + path + ", value: " + sb.toString().trim());
                try {
                    reader2.close();
                } catch (IOException e) {
                    XmlUtil.log_e(Support.CLASS_NAME, "readFromFile", e.toString());
                }
            } catch (IOException e2) {
                XmlUtil.log_e(Support.CLASS_NAME, "readFromFile", e2.toString());
                if (0 != 0) {
                    reader.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        reader.close();
                    } catch (IOException e3) {
                        XmlUtil.log_e(Support.CLASS_NAME, "readFromFile", e3.toString());
                    }
                }
                throw th;
            }
            return sb.toString().trim();
        }

        public static int readFromFile(String id, long offset) {
            int result = -1;
            RandomAccessFile randomAccessFile = null;
            String path = Values.getString(id, "path");
            File file = new File(path);
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.readFromFile start", "path=" + path + ", offset=" + offset);
            if (!file.exists()) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.readFromFile", "path=[" + path + "] is not found");
                return -1;
            }
            try {
                randomAccessFile = new RandomAccessFile(new File(path), "r");
                randomAccessFile.seek(offset);
                result = randomAccessFile.read();
                try {
                    randomAccessFile.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            } catch (FileNotFoundException e2) {
                e2.printStackTrace();
                if (randomAccessFile != null) {
                    randomAccessFile.close();
                }
            } catch (IOException e3) {
                e3.printStackTrace();
                if (randomAccessFile != null) {
                    randomAccessFile.close();
                }
            } catch (Throwable th) {
                if (randomAccessFile != null) {
                    try {
                        randomAccessFile.close();
                    } catch (IOException e4) {
                        e4.printStackTrace();
                    }
                }
                throw th;
            }
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.readFromFile end", "path=" + path + ", offset=" + offset + ", result=" + result);
            return result;
        }

        public static String readFromPath(String path, boolean isLog) {
            String value = null;
            BufferedReader reader = null;
            if (path == null || Properties.PROPERTIES_DEFAULT_STRING.equalsIgnoreCase(path)) {
                return null;
            }
            try {
                BufferedReader reader2 = new BufferedReader(new FileReader(path));
                value = reader2.readLine();
                if (value != null) {
                    value = value.trim();
                }
                try {
                    reader2.close();
                } catch (IOException e) {
                    XmlUtil.log_e(e);
                }
            } catch (Exception e2) {
                XmlUtil.log_e(e2);
                if (0 != 0) {
                    reader.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        reader.close();
                    } catch (IOException e3) {
                        XmlUtil.log_e(e3);
                    }
                }
                throw th;
            }
            if (isLog) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.read", "path=" + path + ", value=" + value);
            }
            return value;
        }

        public static String readAllFromPath(String path, boolean isLog) {
            String value = "";
            BufferedReader reader = null;
            if (path == null || Properties.PROPERTIES_DEFAULT_STRING.equalsIgnoreCase(path)) {
                return value;
            }
            try {
                BufferedReader reader2 = new BufferedReader(new FileReader(path));
                while (true) {
                    String temp_value = reader2.readLine();
                    if (temp_value == null) {
                        break;
                    }
                    value = value + " " + temp_value;
                }
                if (value != null) {
                    value = value.trim();
                }
                try {
                    reader2.close();
                } catch (IOException e) {
                    XmlUtil.log_e(e);
                }
            } catch (Exception e2) {
                XmlUtil.log_e(e2);
                if (0 != 0) {
                    reader.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        reader.close();
                    } catch (IOException e3) {
                        XmlUtil.log_e(e3);
                    }
                }
                throw th;
            }
            if (isLog) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.readAllLine", "path=" + path + ", value=" + value);
            }
            return value;
        }

        public static String readEnterFromPath(String path, boolean isLog) {
            String value = "";
            BufferedReader reader = null;
            if (path == null || Properties.PROPERTIES_DEFAULT_STRING.equalsIgnoreCase(path)) {
                return value;
            }
            try {
                BufferedReader reader2 = new BufferedReader(new FileReader(path));
                while (true) {
                    String temp_value = reader2.readLine();
                    if (temp_value == null) {
                        try {
                            break;
                        } catch (IOException e) {
                            XmlUtil.log_e(e);
                        }
                    } else {
                        value = value + temp_value + "\n";
                    }
                }
                reader2.close();
            } catch (Exception e2) {
                XmlUtil.log_e(e2);
                if (0 != 0) {
                    reader.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        reader.close();
                    } catch (IOException e3) {
                        XmlUtil.log_e(e3);
                    }
                }
                throw th;
            }
            if (isLog) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.readEnterFromPath", "path=" + path + ", value=" + value);
            }
            return value;
        }

        public static String readAllFromID(String id, boolean isLog) {
            return readAllFromPath(Values.getString(id, "path"), isLog);
        }

        public static String readAllFromID(String id) {
            return readAllFromID(id, true);
        }

        public static String read(String id) {
            return read(id, true);
        }

        public static String read(String id, boolean isLog) {
            return read(id, isLog, true);
        }

        public static int readVal(String id) {
            String path = Values.getString(id, "path");
            int retVal = 0;
            BufferedReader reader = null;
            try {
                BufferedReader reader2 = new BufferedReader(new FileReader(path));
                String value = reader2.readLine();
                if (value != null) {
                    retVal = Integer.parseInt(value.trim());
                }
                try {
                    reader2.close();
                } catch (IOException e) {
                    XmlUtil.log_e(e);
                }
            } catch (Exception e2) {
                XmlUtil.log_e(e2);
                if (0 != 0) {
                    reader.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        reader.close();
                    } catch (IOException e3) {
                        XmlUtil.log_e(e3);
                    }
                }
                throw th;
            }
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.readVal", "path=" + path + ", retVal=" + retVal);
            return retVal;
        }

        public static byte[] readByte(String id, int size, boolean isLog) {
            return readByteFromPath(Values.getString(id, "path"), size, isLog);
        }

        public static byte[] readByte(String id, boolean isLog) {
            return readByteFromPath(Values.getString(id, "path"), -1, isLog);
        }

        public static byte[] readByteFromPath(String path, int size, boolean isLog) {
            int mSize;
            File f = new File(path);
            FileInputStream fis = null;
            if (size < 0) {
                mSize = (int) f.length();
            } else {
                mSize = size;
            }
            byte[] result = new byte[mSize];
            try {
                FileInputStream fis2 = new FileInputStream(path);
                int pos = 0;
                int bufferSize = 10;
                while (true) {
                    int read = fis2.read(result, pos, bufferSize);
                    bufferSize = read;
                    if (read <= 0) {
                        break;
                    }
                    pos += bufferSize;
                    int temp = result.length - pos;
                    if (temp < 10) {
                        bufferSize = temp;
                    }
                }
                fis2.close();
                try {
                    fis2.close();
                } catch (IOException e) {
                    XmlUtil.log_e(e);
                }
            } catch (Exception e2) {
                XmlUtil.log_e(e2);
                if (0 != 0) {
                    fis.close();
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        fis.close();
                    } catch (IOException e3) {
                        XmlUtil.log_e(e3);
                    }
                }
                throw th;
            }
            return result;
        }

        public static boolean write(String id, String value) {
            String path = Values.getString(id, "path");
            boolean res = true;
            FileWriter writer = null;
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.write start", "path=" + path + ", value=" + value);
            try {
                writer = new FileWriter(path);
                writer.write(value);
                try {
                    writer.close();
                } catch (IOException e) {
                    XmlUtil.log_e(e);
                    res = false;
                }
            } catch (FileNotFoundException e2) {
                XmlUtil.log_e(e2);
                XmlUtil.printPermission(path);
                res = false;
                if (writer != null) {
                    writer.close();
                }
            } catch (Exception e3) {
                XmlUtil.log_e(e3);
                res = false;
                if (writer != null) {
                    writer.close();
                }
            } catch (Throwable th) {
                if (writer != null) {
                    try {
                        writer.close();
                    } catch (IOException e4) {
                        XmlUtil.log_e(e4);
                    }
                }
                throw th;
            }
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.write end", "path=" + path + ", value=" + value);
            return res;
        }

        public static boolean write(String id, byte[] value) {
            String path = Values.getString(id, "path");
            boolean res = true;
            FileOutputStream out = null;
            String valueString = value != null ? Arrays.toString(value) : "null";
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.write start", "path=" + path + ", value=" + valueString);
            if (value != null) {
                try {
                    out = new FileOutputStream(path);
                    out.write(value);
                    out.flush();
                    try {
                        out.close();
                    } catch (IOException e) {
                        XmlUtil.log_e(e);
                        res = false;
                    }
                } catch (FileNotFoundException e2) {
                    XmlUtil.log_e(e2);
                    XmlUtil.printPermission(path);
                    res = false;
                    if (out != null) {
                        out.close();
                    }
                } catch (Exception e3) {
                    XmlUtil.log_e(e3);
                    res = false;
                    if (out != null) {
                        out.close();
                    }
                } catch (Throwable th) {
                    if (out != null) {
                        try {
                            out.close();
                        } catch (IOException e4) {
                            XmlUtil.log_e(e4);
                        }
                    }
                    throw th;
                }
            } else {
                res = false;
            }
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.write end", "path=" + path + ", value=" + valueString);
            return res;
        }

        public static boolean writeToPath(String path, byte[] value) {
            return writeToPath(path, value, true);
        }

        public static boolean writeToPath(String path, byte[] value, boolean isLog) {
            if (value == null) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeToPath", "value is null, return false");
                return false;
            }
            boolean res = true;
            FileOutputStream out = null;
            if (isLog) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeToPath start", "path=" + path + ", value=" + Arrays.toString(value));
            }
            try {
                out = new FileOutputStream(path);
                out.write(value);
                out.flush();
                try {
                    out.close();
                } catch (FileNotFoundException e) {
                    XmlUtil.log_e(e);
                    XmlUtil.printPermission(path);
                    res = false;
                } catch (IOException e2) {
                    XmlUtil.log_e(e2);
                    res = false;
                }
            } catch (Exception e3) {
                XmlUtil.log_e(e3);
                res = false;
                if (out != null) {
                    out.close();
                }
            } catch (Throwable th) {
                if (out != null) {
                    try {
                        out.close();
                    } catch (FileNotFoundException e4) {
                        XmlUtil.log_e(e4);
                        XmlUtil.printPermission(path);
                    } catch (IOException e5) {
                        XmlUtil.log_e(e5);
                    }
                }
                throw th;
            }
            if (isLog) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeToPath end", "path=" + path + ", value=" + Arrays.toString(value) + ", res=" + res);
            }
            return res;
        }

        public static boolean writeToPath(String path, String value) {
            return writeToPath(path, value, true);
        }

        public static boolean writeToPath(String path, String value, boolean isLog) {
            boolean res = true;
            FileWriter writer = null;
            if (isLog) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeToPath start", "path=" + path + ", value=" + value);
            }
            try {
                writer = new FileWriter(path);
                writer.write(value);
                try {
                    writer.close();
                } catch (FileNotFoundException e) {
                    XmlUtil.log_e(e);
                    XmlUtil.printPermission(path);
                    res = false;
                } catch (IOException e2) {
                    XmlUtil.log_e(e2);
                    res = false;
                }
            } catch (Exception e3) {
                XmlUtil.log_e(e3);
                res = false;
                if (writer != null) {
                    writer.close();
                }
            } catch (Throwable th) {
                if (writer != null) {
                    try {
                        writer.close();
                    } catch (FileNotFoundException e4) {
                        XmlUtil.log_e(e4);
                        XmlUtil.printPermission(path);
                    } catch (IOException e5) {
                        XmlUtil.log_e(e5);
                    }
                }
                throw th;
            }
            if (isLog) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeToPath end", "path=" + path + ", value=" + value);
            }
            return res;
        }

        public static boolean writeToFile(String path, long offset, String value) {
            RandomAccessFile randomAccessFile = null;
            File file = new File(path);
            boolean result = false;
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeToFile start", "path=" + path + ", offset=" + offset + ", value=" + value);
            if (!file.exists()) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeToFile", "path=[" + path + "] is not found");
                return false;
            }
            try {
                randomAccessFile = new RandomAccessFile(new File(path), "rw");
                randomAccessFile.seek(offset);
                randomAccessFile.write(value.getBytes());
                result = true;
                try {
                    randomAccessFile.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            } catch (FileNotFoundException e2) {
                e2.printStackTrace();
                if (randomAccessFile != null) {
                    randomAccessFile.close();
                }
            } catch (IOException e3) {
                e3.printStackTrace();
                if (randomAccessFile != null) {
                    randomAccessFile.close();
                }
            } catch (Throwable th) {
                if (randomAccessFile != null) {
                    try {
                        randomAccessFile.close();
                    } catch (IOException e4) {
                        e4.printStackTrace();
                    }
                }
                throw th;
            }
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeToFile end", "path=" + path + ", offset=" + offset + ", value=" + value);
            return result;
        }

        public static boolean writeToPathNsync(String path, String value) {
            return writeToPathNsync(path, value.getBytes());
        }

        public static boolean writeToPathNsync(String path, byte[] value) {
            if (value == null) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeToPathNsync", "value is null, return false");
                return false;
            }
            boolean res = true;
            FileOutputStream out = null;
            try {
                out = new FileOutputStream(path);
                out.write(value);
                out.flush();
                out.getFD().sync();
                try {
                    out.close();
                } catch (IOException e) {
                    XmlUtil.log_e(e);
                    res = false;
                }
            } catch (Exception e2) {
                XmlUtil.log_e(e2);
                res = false;
                if (out != null) {
                    out.close();
                }
            } catch (Throwable th) {
                if (out != null) {
                    try {
                        out.close();
                    } catch (IOException e3) {
                        XmlUtil.log_e(e3);
                    }
                }
                throw th;
            }
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeToPathNsync", "path=" + path + ", value=" + Arrays.toString(value) + ", res=" + res);
            return res;
        }

        public static boolean writeToPathNsync(String path, String value, boolean writeType) {
            return writeToPathNsync(path, value.getBytes(), writeType);
        }

        public static boolean writeToPathNsync(String path, byte[] value, boolean writeType) {
            if (value == null) {
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeToPathNsync", "value is null, return false");
                return false;
            }
            boolean res = true;
            FileOutputStream out = null;
            try {
                out = new FileOutputStream(path, writeType);
                out.write(value);
                out.flush();
                out.getFD().sync();
                try {
                    out.close();
                } catch (IOException e) {
                    XmlUtil.log_e(e);
                    res = false;
                }
            } catch (Exception e2) {
                XmlUtil.log_e(e2);
                res = false;
                if (out != null) {
                    out.close();
                }
            } catch (Throwable th) {
                if (out != null) {
                    try {
                        out.close();
                    } catch (IOException e3) {
                        XmlUtil.log_e(e3);
                    }
                }
                throw th;
            }
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeToPathNsync", "path=" + path + ", value=" + Arrays.toString(value) + ", writeType=" + writeType + ", res=" + res);
            return res;
        }

        public static boolean writeNsync(String id, String value) {
            if (id == null) {
                XmlUtil.log_w(Support.CLASS_NAME, "Kernel.writeNsync", "id=null");
                return false;
            } else if (value == null) {
                XmlUtil.log_w(Support.CLASS_NAME, "Kernel.writeNsync", "value=null");
                return false;
            } else {
                String path = Values.getString(id, "path");
                boolean res = true;
                FileOutputStream out = null;
                byte[] bValue = value.getBytes();
                if (bValue == null) {
                    XmlUtil.log_w(Support.CLASS_NAME, "Kernel.writeNsync", "bValue=null");
                    return false;
                }
                try {
                    out = new FileOutputStream(path);
                    out.write(bValue);
                    out.flush();
                    out.getFD().sync();
                    try {
                        out.close();
                    } catch (IOException e) {
                        XmlUtil.log_e(e);
                        res = false;
                    }
                } catch (Exception e2) {
                    XmlUtil.log_e(e2);
                    res = false;
                    if (out != null) {
                        out.close();
                    }
                } catch (Throwable th) {
                    if (out != null) {
                        try {
                            out.close();
                        } catch (IOException e3) {
                            XmlUtil.log_e(e3);
                        }
                    }
                    throw th;
                }
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeNsync", "path=" + path + ", value=" + value + "res=" + res);
                return res;
            }
        }

        public static boolean writeNsyncContinuous(String id, String value) {
            if (id == null) {
                XmlUtil.log_w(Support.CLASS_NAME, "Kernel.writeNsyncContinuous", "id=null");
                return false;
            } else if (value == null) {
                XmlUtil.log_w(Support.CLASS_NAME, "Kernel.writeNsyncContinuous", "value=null");
                return false;
            } else {
                String path = Values.getString(id, "path");
                boolean res = true;
                FileOutputStream out = null;
                byte[] bValue = value.getBytes();
                if (bValue == null) {
                    XmlUtil.log_w(Support.CLASS_NAME, "Kernel.writeNsyncContinuous", "bValue=null");
                    return false;
                }
                try {
                    out = new FileOutputStream(path, true);
                    out.write(bValue);
                    out.flush();
                    out.getFD().sync();
                    try {
                        out.close();
                    } catch (IOException e) {
                        XmlUtil.log_e(e);
                        res = false;
                    }
                } catch (Exception e2) {
                    XmlUtil.log_e(e2);
                    res = false;
                    if (out != null) {
                        out.close();
                    }
                } catch (Throwable th) {
                    if (out != null) {
                        try {
                            out.close();
                        } catch (IOException e3) {
                            XmlUtil.log_e(e3);
                        }
                    }
                    throw th;
                }
                XmlUtil.log_d(Support.CLASS_NAME, "Kernel.writeNsyncContinuous", "path=" + path + ", value=" + value + "res=" + res);
                return res;
            }
        }

        public static boolean deleteFile(String id) {
            if (id != null) {
                return new File(getFilePath(id)).delete();
            }
            return false;
        }

        public static boolean isExistFile(String id) {
            if (id != null) {
                return new File(getFilePath(id)).exists();
            }
            return false;
        }

        public static boolean isExistFilePath(String path) {
            if (path != null) {
                return new File(path).exists();
            }
            return false;
        }

        public static boolean isExistFileID(String id) {
            return new File(Values.getString(id, "path")).exists();
        }

        public static boolean isReadableFile(String id) {
            if (id != null) {
                return new File(getFilePath(id)).canRead();
            }
            return false;
        }

        public static boolean isWritableFile(String id) {
            if (id != null) {
                return new File(getFilePath(id)).canWrite();
            }
            return false;
        }

        public static long getFileLength(String path) {
            return new File(path).length();
        }

        public static boolean mkDir(String path) {
            if (path == null || path.length() <= 0) {
                return false;
            }
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.mkDir", "path=" + path);
            int index = path.lastIndexOf("/");
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.mkDir", "index=" + index);
            String dir = path.substring(0, index);
            XmlUtil.log_d(Support.CLASS_NAME, "Kernel.mkDir", "dir=" + dir);
            File f = new File(dir);
            if (!f.exists()) {
                return f.mkdir();
            }
            return true;
        }

        public static boolean setPermission(String path, boolean excutable, boolean owneronlyE, boolean writable, boolean owneronlyW, boolean readable, boolean owneronlyR) {
            File f = new File(path);
            if (f.exists()) {
                f.setExecutable(excutable, owneronlyE);
                f.setWritable(writable, owneronlyW);
                f.setReadable(readable, owneronlyR);
                return true;
            }
            XmlUtil.log_e(Support.CLASS_NAME, "setPermission", "File not found : " + path);
            return false;
        }

        public static String findFLog(String _strRDMKey) {
            String strLogListPath = "NONE";
            File fileLogListFolder = new File(Environment.getExternalStorageDirectory().getAbsolutePath() + "/log/LogList");
            if (!fileLogListFolder.exists()) {
                XmlUtil.log_e(Support.CLASS_NAME, "findFLog", "not exist log list folder");
            } else {
                XmlUtil.log_e(Support.CLASS_NAME, "findFLog", "exist log list folder");
                File[] filesLogList = fileLogListFolder.listFiles();
                for (int i = 0; i < filesLogList.length; i++) {
                    if (filesLogList[i].getName().toLowerCase().contains(_strRDMKey.toLowerCase())) {
                        XmlUtil.log_e(Support.CLASS_NAME, "findFLog", "i find " + filesLogList[i].getName());
                        strLogListPath = filesLogList[i].getName();
                    }
                }
            }
            return strLogListPath;
        }

        public static String getUniqueNumber() {
            String strUN;
            XmlUtil.log_d(Support.CLASS_NAME, "getUniqueNumber");
            if (isExistFile(UFS_UN)) {
                strUN = read(UFS_UN);
            } else if (isExistFile(UFS_UN_LEGACY)) {
                strUN = read(UFS_UN_LEGACY);
            } else if (isExistFile(EMMC_UN)) {
                strUN = read(EMMC_UN);
            } else if (!isExistFile(EMMC_CID)) {
                return Properties.PROPERTIES_DEFAULT_STRING;
            } else {
                String cid = read(EMMC_CID);
                String memory_name = read(EMMC_NAME);
                String PNM = "";
                XmlUtil.log_d(Support.CLASS_NAME, "getUniqueNumber", "cid : \" + cid + \", memory_name : \" + memory_name");
                strUN = "" + "c";
                if (cid != null) {
                    String eMMC = cid.substring(0, 2);
                    if (memory_name != null) {
                        if (eMMC.equalsIgnoreCase(HwTestMenu.LCD_TEST_GRIP)) {
                            PNM = memory_name.substring(0, 2);
                        } else if (eMMC.equalsIgnoreCase("02") || eMMC.equalsIgnoreCase("45")) {
                            PNM = memory_name.substring(3, 5);
                        } else if (eMMC.equalsIgnoreCase("11") || eMMC.equalsIgnoreCase("90")) {
                            PNM = memory_name.substring(1, 3);
                        } else if (eMMC.equalsIgnoreCase("FE")) {
                            PNM = memory_name.substring(4, 6);
                        }
                    }
                    strUN = (((strUN + PNM) + cid.substring(18, 20)) + cid.substring(20, 28)) + cid.substring(28, 30);
                }
            }
            if (strUN != null) {
                strUN = strUN.toUpperCase();
            }
            XmlUtil.log_d(Support.CLASS_NAME, "getUniqueNumber, Unique Number : " + strUN);
            return strUN;
        }

        public static String readSysfs(String id) {
            String path = getFilePath(id);
            String match = getMatchKey(id);
            if ("#DEFAULT".equals(match) || Properties.PROPERTIES_DEFAULT_STRING.equals(match)) {
                return readFromPath(path, true);
            }
            return matchNreadSysfs(path, match);
        }

        public static String matchNreadSysfs(String regex, String match) {
            String str = regex;
            String[] key = match.split(",");
            if (key.length != 2) {
                XmlUtil.log_e(Support.CLASS_NAME, "Matching key is invalid - " + match);
                return "NULL";
            }
            String[] temp = str.split("\\[.+\\]");
            if (temp.length != 2) {
                XmlUtil.log_e(Support.CLASS_NAME, "matchNreadSysfs", "Regex path is invalid - " + str);
                return "NULL";
            }
            String prePath = temp[0].substring(0, temp[0].lastIndexOf("/"));
            String postPath = temp[1].substring(temp[1].indexOf("/") + 1, temp[1].length());
            XmlUtil.log_i(Support.CLASS_NAME, "matchNreadSysfs", "prePath - " + prePath);
            XmlUtil.log_i(Support.CLASS_NAME, "matchNreadSysfs", "postPath - " + postPath);
            File[] files = new File(prePath).listFiles();
            if (files != null) {
                int length = files.length;
                int i = 0;
                while (i < length) {
                    File f = files[i];
                    if (Pattern.matches(str, f.toString() + "/" + postPath)) {
                        if (isExistFilePath(f.toString() + "/" + key[0])) {
                            if (readFromPath(f.toString() + "/" + key[0], true).equals(key[1])) {
                                return readFromPath(f.toString() + "/" + postPath, true);
                            }
                        }
                    }
                    i++;
                    str = regex;
                }
            }
            XmlUtil.log_i(Support.CLASS_NAME, "matchNreadSysfs", "Cannot find matching file");
            return "NULL";
        }
    }

    public static class CommandFilter {
        public static final String TAG = "AtCommand";
        static ArrayList<String> filteredCommands = null;

        public static synchronized String[] getFilteredCommands() {
            synchronized (CommandFilter.class) {
                ArrayList<String> arrayList = filteredCommands;
                if (arrayList == null) {
                    filteredCommands = new ArrayList<>();
                    try {
                        Element[] items = XMLDataStorage.instance().getChildElementSet("CommandFilter");
                        if (items != null) {
                            for (Element item : items) {
                                boolean parent_Enable = Boolean.parseBoolean(item.getAttribute("enable"));
                                String parent_name = item.getAttribute("id");
                                if (parent_Enable && item.getNodeName().equals("item-group")) {
                                    NodeList childNodes = item.getChildNodes();
                                    for (int i = 0; i < childNodes.getLength(); i++) {
                                        Node child = childNodes.item(i);
                                        if (child.getNodeType() == 1) {
                                            String para = child.getAttributes().getNamedItem("para").getNodeValue();
                                            String count = child.getAttributes().getNamedItem("count").getNodeValue();
                                            filteredCommands.add(parent_name + "/" + para + "/" + count);
                                            XmlUtil.log_d(Support.CLASS_NAME, "CommandFilter", "filtername-" + parent_name + "/" + para + "/" + count);
                                        }
                                    }
                                }
                            }
                        }
                        if (filteredCommands.isEmpty()) {
                            return null;
                        }
                        return (String[]) filteredCommands.toArray(new String[0]);
                    } catch (Exception e) {
                        e.printStackTrace();
                        filteredCommands = null;
                        return null;
                    }
                } else if (arrayList.isEmpty()) {
                    return null;
                } else {
                    return (String[]) filteredCommands.toArray(new String[0]);
                }
            }
        }
    }

    public static class Values {
        /* access modifiers changed from: private */
        public static boolean getBoolean(String id, String resultField) {
            return getBoolean(id, resultField, false);
        }

        /* access modifiers changed from: private */
        public static boolean getBoolean(String id, String resultField, int logLevel) {
            return getBoolean(id, resultField, false, logLevel);
        }

        /* access modifiers changed from: private */
        public static boolean getBoolean(String id, String resultField, boolean defaultValue) {
            boolean value = defaultValue;
            try {
                value = Boolean.parseBoolean(XMLDataStorage.instance().getAttributeValueById(id, resultField));
                XmlUtil.log_d(Support.CLASS_NAME, "Values.getBoolean", "id=" + id + ", value=" + value);
                return value;
            } catch (Exception e) {
                XmlUtil.log_e(e);
                return value;
            }
        }

        private static boolean getBoolean(String id, String resultField, boolean defaultValue, int logLevel) {
            boolean value = defaultValue;
            try {
                value = Boolean.parseBoolean(XMLDataStorage.instance().getAttributeValueById(id, resultField));
                if (logLevel > 0) {
                    XmlUtil.log_d(Support.CLASS_NAME, "Values.getBoolean", "id=" + id + ", value=" + value);
                }
            } catch (Exception e) {
                XmlUtil.log_e(e);
            }
            return value;
        }

        /* access modifiers changed from: private */
        public static byte getByte(String id, String resultField) {
            byte value = 0;
            try {
                value = Byte.parseByte(XMLDataStorage.instance().getAttributeValueById(id, resultField));
                XmlUtil.log_d(Support.CLASS_NAME, "Values.getByte", "id=" + id + ", value=" + ((int) value));
                return value;
            } catch (Exception e) {
                XmlUtil.log_e(e);
                return value;
            }
        }

        /* access modifiers changed from: private */
        public static String getString(String id, String resultField, boolean isLog) {
            String value = Properties.PROPERTIES_DEFAULT_STRING;
            try {
                value = XMLDataStorage.instance().getAttributeValueById(id, resultField);
                if (isLog) {
                    XmlUtil.log_d(Support.CLASS_NAME, "Values.getString", "id=" + id + ", " + resultField + "=" + value);
                }
            } catch (Exception e) {
                XmlUtil.log_e(e);
            }
            if (value == null) {
                return Properties.PROPERTIES_DEFAULT_STRING;
            }
            return value;
        }

        /* access modifiers changed from: private */
        public static String getString(String id, String resultField) {
            return getString(id, resultField, true);
        }

        /* access modifiers changed from: private */
        public static String getString(String id, String resultField, int logLevel) {
            String value = Properties.PROPERTIES_DEFAULT_STRING;
            try {
                value = XMLDataStorage.instance().getAttributeValueById(id, resultField);
                if (logLevel > 0) {
                    XmlUtil.log_d(Support.CLASS_NAME, "Values.getString", "id=" + id + ", value=" + value);
                }
            } catch (Exception e) {
                XmlUtil.log_e(e);
            }
            if (value == null) {
                return Properties.PROPERTIES_DEFAULT_STRING;
            }
            return value;
        }

        /* access modifiers changed from: private */
        public static String getStringWithNoExceptionLog(String id, String resultField) {
            String value = Properties.PROPERTIES_DEFAULT_STRING;
            try {
                value = XMLDataStorage.instance().getAttributeValueById(id, resultField);
                XmlUtil.log_i(Support.CLASS_NAME, "Values.getStringWithNoExceptionLog", "id=" + id + ", value=" + value);
            } catch (Exception e) {
                XmlUtil.log_e(e);
            }
            if (value == null) {
                return Properties.PROPERTIES_DEFAULT_STRING;
            }
            return value;
        }

        /* access modifiers changed from: private */
        public static int getInt(String id, String resultField) {
            int value = 0;
            try {
                value = Integer.parseInt(XMLDataStorage.instance().getAttributeValueById(id, resultField));
                XmlUtil.log_d(Support.CLASS_NAME, "Values.getInt", "id=" + id + ", value=" + value);
                return value;
            } catch (Exception e) {
                XmlUtil.log_e(e);
                return value;
            }
        }

        /* access modifiers changed from: private */
        public static long getLong(String id, String resultField) {
            long value = 0;
            try {
                value = Long.parseLong(XMLDataStorage.instance().getAttributeValueById(id, resultField));
                XmlUtil.log_d(Support.CLASS_NAME, "Values.getFloat", "id=" + id + ", value=" + value);
                return value;
            } catch (Exception e) {
                XmlUtil.log_e(e);
                return value;
            }
        }

        /* access modifiers changed from: private */
        public static float getFloat(String id, String resultField) {
            float value = 0.0f;
            try {
                value = Float.parseFloat(XMLDataStorage.instance().getAttributeValueById(id, resultField));
                XmlUtil.log_d(Support.CLASS_NAME, "Values.getFloat", "id=" + id + ", value=" + value);
                return value;
            } catch (Exception e) {
                XmlUtil.log_e(e);
                return value;
            }
        }

        /* access modifiers changed from: private */
        public static double getDouble(String id, String resultField) {
            double value = 0.0d;
            try {
                value = Double.parseDouble(XMLDataStorage.instance().getAttributeValueById(id, resultField));
                XmlUtil.log_d(Support.CLASS_NAME, "Values.getDouble", "id=" + id + ", value=" + value);
                return value;
            } catch (Exception e) {
                XmlUtil.log_e(e);
                return value;
            }
        }

        public static boolean isExistAttrib(String id, String resultField) {
            try {
                XMLDataStorage.instance().getAttributeValueById(id, resultField);
                return true;
            } catch (Exception e) {
                XmlUtil.log_i(Support.CLASS_NAME, "Values.isExistAttrib", "Non-Existent - id=" + id + " ,resultField=" + resultField);
                return false;
            }
        }
    }
}
