package org.apache.poi.hssf.record;

import org.apache.poi.hssf.record.FormulaRecord;
import org.apache.poi.ss.formula.Formula;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.usermodel.CellType;

public final class OldFormulaRecord extends OldCellRecord {
    public static final short biff2_sid = 6;
    public static final short biff3_sid = 518;
    public static final short biff4_sid = 1030;
    public static final short biff5_sid = 6;
    private double field_4_value;
    private short field_5_options;
    private Formula field_6_parsed_expr;
    private FormulaRecord.SpecialCachedValue specialCachedValue;

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public OldFormulaRecord(RecordInputStream ris) {
        super(ris, ris.getSid() == 6);
        if (isBiff2()) {
            this.field_4_value = ris.readDouble();
        } else {
            long valueLongBits = ris.readLong();
            FormulaRecord.SpecialCachedValue create = FormulaRecord.SpecialCachedValue.create(valueLongBits);
            this.specialCachedValue = create;
            if (create == null) {
                this.field_4_value = Double.longBitsToDouble(valueLongBits);
            }
        }
        if (isBiff2()) {
            this.field_5_options = (short) ris.readUByte();
        } else {
            this.field_5_options = ris.readShort();
        }
        this.field_6_parsed_expr = Formula.read(ris.readShort(), ris, ris.available());
    }

    public int getCachedResultType() {
        FormulaRecord.SpecialCachedValue specialCachedValue2 = this.specialCachedValue;
        if (specialCachedValue2 == null) {
            return CellType.NUMERIC.getCode();
        }
        return specialCachedValue2.getValueType();
    }

    public boolean getCachedBooleanValue() {
        return this.specialCachedValue.getBooleanValue();
    }

    public int getCachedErrorValue() {
        return this.specialCachedValue.getErrorValue();
    }

    public double getValue() {
        return this.field_4_value;
    }

    public short getOptions() {
        return this.field_5_options;
    }

    public Ptg[] getParsedExpression() {
        return this.field_6_parsed_expr.getTokens();
    }

    public Formula getFormula() {
        return this.field_6_parsed_expr;
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.poi.hssf.record.OldCellRecord
    public void appendValueText(StringBuilder sb) {
        sb.append("    .value       = ");
        sb.append(getValue());
        sb.append("\n");
    }

    /* access modifiers changed from: protected */
    @Override // org.apache.poi.hssf.record.OldCellRecord
    public String getRecordName() {
        return "Old Formula";
    }
}
