package org.apache.poi.hssf.usermodel;

import org.apache.poi.common.usermodel.HyperlinkType;
import org.apache.poi.hssf.record.HyperlinkRecord;
import org.apache.poi.ss.usermodel.Hyperlink;
import org.apache.poi.util.Internal;

public class HSSFHyperlink implements Hyperlink {
    protected final HyperlinkType link_type;
    protected final HyperlinkRecord record;

    @Internal(since = "3.15 beta 3")
    protected HSSFHyperlink(int type) {
        this(HyperlinkType.forInt(type));
    }

    @Internal(since = "3.15 beta 3")
    protected HSSFHyperlink(HyperlinkType type) {
        this.link_type = type;
        HyperlinkRecord hyperlinkRecord = new HyperlinkRecord();
        this.record = hyperlinkRecord;
        switch (AnonymousClass1.$SwitchMap$org$apache$poi$common$usermodel$HyperlinkType[type.ordinal()]) {
            case 1:
            case 2:
                hyperlinkRecord.newUrlLink();
                return;
            case 3:
                hyperlinkRecord.newFileLink();
                return;
            case 4:
                hyperlinkRecord.newDocumentLink();
                return;
            default:
                throw new IllegalArgumentException("Invalid type: " + type);
        }
    }

    /* renamed from: org.apache.poi.hssf.usermodel.HSSFHyperlink$1  reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType;

        static {
            int[] iArr = new int[HyperlinkType.values().length];
            $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType = iArr;
            try {
                iArr[HyperlinkType.URL.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType[HyperlinkType.EMAIL.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType[HyperlinkType.FILE.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$org$apache$poi$common$usermodel$HyperlinkType[HyperlinkType.DOCUMENT.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    protected HSSFHyperlink(HyperlinkRecord record2) {
        this.record = record2;
        this.link_type = getType(record2);
    }

    private static HyperlinkType getType(HyperlinkRecord record2) {
        if (record2.isFileLink()) {
            return HyperlinkType.FILE;
        }
        if (record2.isDocumentLink()) {
            return HyperlinkType.DOCUMENT;
        }
        if (record2.getAddress() == null || !record2.getAddress().startsWith("mailto:")) {
            return HyperlinkType.URL;
        }
        return HyperlinkType.EMAIL;
    }

    protected HSSFHyperlink(Hyperlink other) {
        if (other instanceof HSSFHyperlink) {
            HyperlinkRecord clone = ((HSSFHyperlink) other).record.clone();
            this.record = clone;
            this.link_type = getType(clone);
            return;
        }
        this.link_type = other.getTypeEnum();
        this.record = new HyperlinkRecord();
        setFirstRow(other.getFirstRow());
        setFirstColumn(other.getFirstColumn());
        setLastRow(other.getLastRow());
        setLastColumn(other.getLastColumn());
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public int getFirstRow() {
        return this.record.getFirstRow();
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public void setFirstRow(int row) {
        this.record.setFirstRow(row);
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public int getLastRow() {
        return this.record.getLastRow();
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public void setLastRow(int row) {
        this.record.setLastRow(row);
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public int getFirstColumn() {
        return this.record.getFirstColumn();
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public void setFirstColumn(int col) {
        this.record.setFirstColumn((short) col);
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public int getLastColumn() {
        return this.record.getLastColumn();
    }

    @Override // org.apache.poi.ss.usermodel.Hyperlink
    public void setLastColumn(int col) {
        this.record.setLastColumn((short) col);
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public String getAddress() {
        return this.record.getAddress();
    }

    public String getTextMark() {
        return this.record.getTextMark();
    }

    public void setTextMark(String textMark) {
        this.record.setTextMark(textMark);
    }

    public String getShortFilename() {
        return this.record.getShortFilename();
    }

    public void setShortFilename(String shortFilename) {
        this.record.setShortFilename(shortFilename);
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public void setAddress(String address) {
        this.record.setAddress(address);
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public String getLabel() {
        return this.record.getLabel();
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public void setLabel(String label) {
        this.record.setLabel(label);
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public int getType() {
        return this.link_type.getCode();
    }

    @Override // org.apache.poi.common.usermodel.Hyperlink
    public HyperlinkType getTypeEnum() {
        return this.link_type;
    }

    public boolean equals(Object other) {
        if (this == other) {
            return true;
        }
        if (!(other instanceof HSSFHyperlink)) {
            return false;
        }
        if (this.record == ((HSSFHyperlink) other).record) {
            return true;
        }
        return false;
    }

    public int hashCode() {
        return this.record.hashCode();
    }
}
