package org.apache.poi.sl.draw.geom;

import java.io.InputStream;
import java.util.LinkedHashMap;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Unmarshaller;
import javax.xml.stream.EventFilter;
import javax.xml.stream.XMLEventReader;
import javax.xml.stream.XMLInputFactory;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.events.XMLEvent;
import org.apache.poi.sl.draw.binding.CTCustomGeometry2D;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class PresetGeometries extends LinkedHashMap<String, CustomGeometry> {
    protected static final String BINDING_PACKAGE = "org.apache.poi.sl.draw.binding";
    private static final POILogger LOG = POILogFactory.getLogger(PresetGeometries.class);
    protected static PresetGeometries _inst;

    protected PresetGeometries() {
    }

    public void init(InputStream is) throws XMLStreamException, JAXBException {
        XMLInputFactory staxFactory;
        EventFilter startElementFilter;
        EventFilter startElementFilter2 = new EventFilter() {
            /* class org.apache.poi.sl.draw.geom.PresetGeometries.AnonymousClass1 */

            public boolean accept(XMLEvent event) {
                return event.isStartElement();
            }
        };
        XMLInputFactory staxFactory2 = XMLInputFactory.newFactory();
        XMLEventReader staxReader = staxFactory2.createXMLEventReader(is);
        XMLEventReader staxFiltRd = staxFactory2.createFilteredReader(staxReader, startElementFilter2);
        staxFiltRd.nextEvent();
        Unmarshaller unmarshaller = JAXBContext.newInstance(BINDING_PACKAGE).createUnmarshaller();
        long cntElem = 0;
        while (staxFiltRd.peek() != null) {
            String name = staxFiltRd.peek().getName().getLocalPart();
            CTCustomGeometry2D cus = (CTCustomGeometry2D) unmarshaller.unmarshal(staxReader, CTCustomGeometry2D.class).getValue();
            cntElem++;
            if (containsKey(name)) {
                POILogger pOILogger = LOG;
                startElementFilter = startElementFilter2;
                StringBuilder sb = new StringBuilder();
                staxFactory = staxFactory2;
                sb.append("Duplicate definition of ");
                sb.append(name);
                pOILogger.log(5, sb.toString());
            } else {
                startElementFilter = startElementFilter2;
                staxFactory = staxFactory2;
            }
            put(name, new CustomGeometry(cus));
            startElementFilter2 = startElementFilter;
            staxFactory2 = staxFactory;
        }
    }

    public static CustomGeometry convertCustomGeometry(XMLStreamReader staxReader) {
        try {
            return new CustomGeometry((CTCustomGeometry2D) JAXBContext.newInstance(BINDING_PACKAGE).createUnmarshaller().unmarshal(staxReader, CTCustomGeometry2D.class).getValue());
        } catch (JAXBException e) {
            LOG.log(7, "Unable to parse single custom geometry", e);
            return null;
        }
    }

    /* JADX INFO: finally extract failed */
    public static synchronized PresetGeometries getInstance() {
        PresetGeometries lInst;
        synchronized (PresetGeometries.class) {
            if (_inst == null) {
                PresetGeometries lInst2 = new PresetGeometries();
                try {
                    InputStream is = PresetGeometries.class.getResourceAsStream("presetShapeDefinitions.xml");
                    try {
                        lInst2.init(is);
                        is.close();
                        _inst = lInst2;
                    } catch (Throwable th) {
                        is.close();
                        throw th;
                    }
                } catch (Exception e) {
                    throw new RuntimeException(e);
                }
            }
            lInst = _inst;
        }
        return lInst;
    }
}
