package org.apache.poi.ss.format;

import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.text.FieldPosition;
import java.util.ArrayList;
import java.util.BitSet;
import java.util.Collections;
import java.util.Formatter;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;
import java.util.Set;
import java.util.TreeSet;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class CellNumberFormatter extends CellFormatter {
    private static final POILogger LOG = POILogFactory.getLogger(CellNumberFormatter.class);
    private static final CellFormatter SIMPLE_FLOAT = new CellNumberFormatter("#.#");
    private static final CellFormatter SIMPLE_INT = new CellNumberFormatter("#");
    private static final CellFormatter SIMPLE_NUMBER = new GeneralNumberFormatter();
    private final Special afterFractional;
    private final Special afterInteger;
    private final DecimalFormat decimalFmt;
    private final Special decimalPoint;
    private final String denominatorFmt;
    private final List<Special> denominatorSpecials;
    private final String desc;
    private final Special exponent;
    private final List<Special> exponentDigitSpecials;
    private final List<Special> exponentSpecials;
    private final List<Special> fractionalSpecials;
    private final boolean improperFraction;
    private final boolean integerCommas;
    private final List<Special> integerSpecials;
    private final int maxDenominator;
    private final Special numerator;
    private final String numeratorFmt;
    private final List<Special> numeratorSpecials;
    private final String printfFmt;
    private final double scale;
    private final Special slash;
    private final List<Special> specials;

    private static class GeneralNumberFormatter extends CellFormatter {
        private GeneralNumberFormatter() {
            super("General");
        }

        @Override // org.apache.poi.ss.format.CellFormatter
        public void formatValue(StringBuffer toAppendTo, Object value) {
            CellFormatter cf;
            if (value != null) {
                if (value instanceof Number) {
                    cf = ((Number) value).doubleValue() % 1.0d == 0.0d ? CellNumberFormatter.SIMPLE_INT : CellNumberFormatter.SIMPLE_FLOAT;
                } else {
                    cf = CellTextFormatter.SIMPLE_TEXT;
                }
                cf.formatValue(toAppendTo, value);
            }
        }

        @Override // org.apache.poi.ss.format.CellFormatter
        public void simpleValue(StringBuffer toAppendTo, Object value) {
            formatValue(toAppendTo, value);
        }
    }

    /* access modifiers changed from: package-private */
    public static class Special {
        final char ch;
        int pos;

        Special(char ch2, int pos2) {
            this.ch = ch2;
            this.pos = pos2;
        }

        public String toString() {
            return "'" + this.ch + "' @ " + this.pos;
        }
    }

    /* JADX WARN: Type inference failed for: r4v3, types: [java.text.DecimalFormat, java.lang.String] */
    /* JADX WARN: Type inference failed for: r4v4 */
    /* JADX WARN: Type inference failed for: r4v11 */
    /* JADX WARN: Type inference failed for: r4v12 */
    /* JADX WARNING: Unknown variable types count: 1 */
    public CellNumberFormatter(String format) {
        super(format);
        int fractionPartWidth;
        int i;
        ?? r4;
        boolean first;
        ArrayList arrayList = new ArrayList();
        this.specials = arrayList;
        ArrayList arrayList2 = new ArrayList();
        this.integerSpecials = arrayList2;
        ArrayList arrayList3 = new ArrayList();
        this.fractionalSpecials = arrayList3;
        ArrayList arrayList4 = new ArrayList();
        this.numeratorSpecials = arrayList4;
        ArrayList arrayList5 = new ArrayList();
        this.denominatorSpecials = arrayList5;
        ArrayList arrayList6 = new ArrayList();
        this.exponentSpecials = arrayList6;
        ArrayList arrayList7 = new ArrayList();
        this.exponentDigitSpecials = arrayList7;
        CellNumberPartHandler ph = new CellNumberPartHandler();
        StringBuffer descBuf = CellFormatPart.parseFormat(format, CellFormatType.NUMBER, ph);
        Special exponent2 = ph.getExponent();
        this.exponent = exponent2;
        arrayList.addAll(ph.getSpecials());
        this.improperFraction = ph.isImproperFraction();
        if ((ph.getDecimalPoint() == null && ph.getExponent() == null) || ph.getSlash() == null) {
            this.slash = ph.getSlash();
            this.numerator = ph.getNumerator();
        } else {
            this.slash = null;
            this.numerator = null;
        }
        int precision = interpretPrecision(ph.getDecimalPoint(), arrayList);
        if (ph.getDecimalPoint() != null) {
            int fractionPartWidth2 = precision + 1;
            if (precision == 0) {
                arrayList.remove(ph.getDecimalPoint());
                this.decimalPoint = null;
            } else {
                this.decimalPoint = ph.getDecimalPoint();
            }
            fractionPartWidth = fractionPartWidth2;
        } else {
            this.decimalPoint = null;
            fractionPartWidth = 0;
        }
        Special special = this.decimalPoint;
        if (special != null) {
            this.afterInteger = special;
        } else if (exponent2 != null) {
            this.afterInteger = exponent2;
        } else {
            Special special2 = this.numerator;
            if (special2 != null) {
                this.afterInteger = special2;
            } else {
                this.afterInteger = null;
            }
        }
        if (exponent2 != null) {
            this.afterFractional = exponent2;
        } else {
            Special special3 = this.numerator;
            if (special3 != null) {
                this.afterFractional = special3;
            } else {
                this.afterFractional = null;
            }
        }
        double[] scaleByRef = {ph.getScale()};
        this.integerCommas = interpretIntegerCommas(descBuf, arrayList, this.decimalPoint, integerEnd(), fractionalEnd(), scaleByRef);
        if (exponent2 == null) {
            this.scale = scaleByRef[0];
        } else {
            this.scale = 1.0d;
        }
        if (precision != 0) {
            i = 1;
            arrayList3.addAll(arrayList.subList(arrayList.indexOf(this.decimalPoint) + 1, fractionalEnd()));
        } else {
            i = 1;
        }
        if (exponent2 != null) {
            int exponentPos = arrayList.indexOf(exponent2);
            arrayList6.addAll(specialsFor(exponentPos, 2));
            arrayList7.addAll(specialsFor(exponentPos + 2));
        }
        if (this.slash != null) {
            Special special4 = this.numerator;
            if (special4 != null) {
                arrayList4.addAll(specialsFor(arrayList.indexOf(special4)));
            }
            arrayList5.addAll(specialsFor(arrayList.indexOf(this.slash) + i));
            if (arrayList5.isEmpty()) {
                arrayList4.clear();
                this.maxDenominator = i;
                r4 = 0;
                this.numeratorFmt = null;
                this.denominatorFmt = null;
            } else {
                r4 = 0;
                this.maxDenominator = maxValue(arrayList5);
                this.numeratorFmt = singleNumberFormat(arrayList4);
                this.denominatorFmt = singleNumberFormat(arrayList5);
            }
        } else {
            r4 = 0;
            this.maxDenominator = i;
            this.numeratorFmt = null;
            this.denominatorFmt = null;
        }
        arrayList2.addAll(arrayList.subList(0, integerEnd()));
        if (exponent2 == null) {
            StringBuffer fmtBuf = new StringBuffer("%");
            fmtBuf.append('0');
            fmtBuf.append(calculateIntegerPartWidth() + fractionPartWidth);
            fmtBuf.append('.');
            fmtBuf.append(precision);
            fmtBuf.append("f");
            this.printfFmt = fmtBuf.toString();
            this.decimalFmt = r4;
        } else {
            StringBuffer fmtBuf2 = new StringBuffer();
            boolean first2 = true;
            List<Special> specialList = this.integerSpecials;
            if (arrayList2.size() == i) {
                fmtBuf2.append("0");
                first = false;
            } else {
                for (Special s : specialList) {
                    if (isDigitFmt(s)) {
                        fmtBuf2.append(first2 ? '#' : '0');
                        first2 = false;
                    }
                }
                first = first2;
            }
            if (this.fractionalSpecials.size() > 0) {
                fmtBuf2.append('.');
                for (Special s2 : this.fractionalSpecials) {
                    if (isDigitFmt(s2)) {
                        if (!first) {
                            fmtBuf2.append('0');
                        }
                        first = false;
                    }
                }
            }
            fmtBuf2.append('E');
            List<Special> list = this.exponentSpecials;
            placeZeros(fmtBuf2, list.subList(2, list.size()));
            this.decimalFmt = new DecimalFormat(fmtBuf2.toString(), DecimalFormatSymbols.getInstance(LocaleUtil.getUserLocale()));
            this.printfFmt = r4;
        }
        this.desc = descBuf.toString();
    }

    private static void placeZeros(StringBuffer sb, List<Special> specials2) {
        for (Special s : specials2) {
            if (isDigitFmt(s)) {
                sb.append('0');
            }
        }
    }

    private static CellNumberStringMod insertMod(Special special, CharSequence toAdd, int where) {
        return new CellNumberStringMod(special, toAdd, where);
    }

    private static CellNumberStringMod deleteMod(Special start, boolean startInclusive, Special end, boolean endInclusive) {
        return new CellNumberStringMod(start, startInclusive, end, endInclusive);
    }

    private static CellNumberStringMod replaceMod(Special start, boolean startInclusive, Special end, boolean endInclusive, char withChar) {
        return new CellNumberStringMod(start, startInclusive, end, endInclusive, withChar);
    }

    private static String singleNumberFormat(List<Special> numSpecials) {
        return "%0" + numSpecials.size() + "d";
    }

    private static int maxValue(List<Special> s) {
        return (int) Math.round(Math.pow(10.0d, (double) s.size()) - 1.0d);
    }

    private List<Special> specialsFor(int pos, int takeFirst) {
        if (pos >= this.specials.size()) {
            return Collections.emptyList();
        }
        ListIterator<Special> it = this.specials.listIterator(pos + takeFirst);
        Special last = it.next();
        int end = pos + takeFirst;
        while (it.hasNext()) {
            Special s = it.next();
            if (!isDigitFmt(s) || s.pos - last.pos > 1) {
                break;
            }
            end++;
            last = s;
        }
        return this.specials.subList(pos, end + 1);
    }

    private List<Special> specialsFor(int pos) {
        return specialsFor(pos, 0);
    }

    private static boolean isDigitFmt(Special s) {
        return s.ch == '0' || s.ch == '?' || s.ch == '#';
    }

    private int calculateIntegerPartWidth() {
        Special s;
        int digitCount = 0;
        Iterator i$ = this.specials.iterator();
        while (i$.hasNext() && (s = i$.next()) != this.afterInteger) {
            if (isDigitFmt(s)) {
                digitCount++;
            }
        }
        return digitCount;
    }

    private static int interpretPrecision(Special decimalPoint2, List<Special> specials2) {
        int idx = specials2.indexOf(decimalPoint2);
        int precision = 0;
        if (idx != -1) {
            ListIterator<Special> it = specials2.listIterator(idx + 1);
            while (it.hasNext() && isDigitFmt(it.next())) {
                precision++;
            }
        }
        return precision;
    }

    private static boolean interpretIntegerCommas(StringBuffer sb, List<Special> specials2, Special decimalPoint2, int integerEnd, int fractionalEnd, double[] scale2) {
        ListIterator<Special> it = specials2.listIterator(integerEnd);
        boolean stillScaling = true;
        boolean integerCommas2 = false;
        while (it.hasPrevious()) {
            if (it.previous().ch != ',') {
                stillScaling = false;
            } else if (stillScaling) {
                scale2[0] = scale2[0] / 1000.0d;
            } else {
                integerCommas2 = true;
            }
        }
        if (decimalPoint2 != null) {
            ListIterator<Special> it2 = specials2.listIterator(fractionalEnd);
            while (it2.hasPrevious() && it2.previous().ch == ',') {
                scale2[0] = scale2[0] / 1000.0d;
            }
        }
        ListIterator<Special> it3 = specials2.listIterator();
        int removed = 0;
        while (it3.hasNext()) {
            Special s = it3.next();
            s.pos -= removed;
            if (s.ch == ',') {
                removed++;
                it3.remove();
                sb.deleteCharAt(s.pos);
            }
        }
        return integerCommas2;
    }

    private int integerEnd() {
        Special special = this.afterInteger;
        return special == null ? this.specials.size() : this.specials.indexOf(special);
    }

    private int fractionalEnd() {
        Special special = this.afterFractional;
        return special == null ? this.specials.size() : this.specials.indexOf(special);
    }

    /* JADX INFO: finally extract failed */
    /* JADX INFO: Multiple debug info for r5v20 int: [D('i$' java.util.Iterator), D('delPos' int)] */
    @Override // org.apache.poi.ss.format.CellFormatter
    public void formatValue(StringBuffer toAppendTo, Object valueObject) {
        double fractional;
        double value;
        Set<CellNumberStringMod> mods;
        StringBuffer output;
        StringBuffer output2;
        double value2;
        int adjustedPos;
        Iterator i$;
        double value3 = ((Number) valueObject).doubleValue() * this.scale;
        boolean negative = value3 < 0.0d;
        if (negative) {
            value3 = -value3;
        }
        if (this.slash == null) {
            value = value3;
            fractional = 0.0d;
        } else if (this.improperFraction) {
            value = 0.0d;
            fractional = value3;
        } else {
            value = (double) ((long) value3);
            fractional = value3 % 1.0d;
        }
        Set<CellNumberStringMod> mods2 = new TreeSet<>();
        StringBuffer output3 = new StringBuffer(this.desc);
        if (this.exponent != null) {
            writeScientific(value, output3, mods2);
            output = output3;
            mods = mods2;
        } else if (this.improperFraction) {
            output = output3;
            mods = mods2;
            writeFraction(value, null, fractional, output3, mods2);
        } else {
            output = output3;
            mods = mods2;
            StringBuffer result = new StringBuffer();
            Formatter f = new Formatter(result, LocaleUtil.getUserLocale());
            try {
                f.format(LocaleUtil.getUserLocale(), this.printfFmt, Double.valueOf(value));
                f.close();
                if (this.numerator == null) {
                    writeFractional(result, output);
                    writeInteger(result, output, this.integerSpecials, mods, this.integerCommas);
                } else {
                    writeFraction(value, result, fractional, output, mods);
                }
            } catch (Throwable th) {
                f.close();
                throw th;
            }
        }
        Iterator<CellNumberStringMod> changes = mods.iterator();
        CellNumberStringMod nextChange = changes.hasNext() ? changes.next() : null;
        BitSet deletedChars = new BitSet();
        int adjust = 0;
        Iterator i$2 = this.specials.iterator();
        while (i$2.hasNext()) {
            Special s = i$2.next();
            int adjustedPos2 = s.pos + adjust;
            if (!deletedChars.get(s.pos)) {
                output2 = output;
                if (output2.charAt(adjustedPos2) == '#') {
                    output2.deleteCharAt(adjustedPos2);
                    adjust--;
                    deletedChars.set(s.pos);
                }
            } else {
                output2 = output;
            }
            while (nextChange != null && s == nextChange.getSpecial()) {
                int lenBefore = output2.length();
                int modPos = s.pos + adjust;
                switch (nextChange.getOp()) {
                    case 1:
                        i$ = i$2;
                        adjustedPos = adjustedPos2;
                        value2 = value;
                        output2.insert(modPos, nextChange.getToAdd());
                        break;
                    case 2:
                        i$ = i$2;
                        adjustedPos = adjustedPos2;
                        value2 = value;
                        if (!nextChange.getToAdd().equals(",") || !deletedChars.get(s.pos)) {
                            output2.insert(modPos + 1, nextChange.getToAdd());
                            break;
                        }
                    case 3:
                        i$ = i$2;
                        int delPos = s.pos;
                        if (!nextChange.isStartInclusive()) {
                            delPos++;
                            modPos++;
                        }
                        while (deletedChars.get(delPos)) {
                            delPos++;
                            modPos++;
                        }
                        adjustedPos = adjustedPos2;
                        int delEndPos = nextChange.getEnd().pos;
                        if (nextChange.isEndInclusive()) {
                            delEndPos++;
                        }
                        int modEndPos = delEndPos + adjust;
                        if (modPos < modEndPos) {
                            value2 = value;
                            if ("".equals(nextChange.getToAdd())) {
                                output2.delete(modPos, modEndPos);
                            } else {
                                char fillCh = nextChange.getToAdd().charAt(0);
                                for (int i = modPos; i < modEndPos; i++) {
                                    output2.setCharAt(i, fillCh);
                                }
                            }
                            deletedChars.set(delPos, delEndPos);
                            break;
                        } else {
                            value2 = value;
                            break;
                        }
                    default:
                        throw new IllegalStateException("Unknown op: " + nextChange.getOp());
                }
                adjust += output2.length() - lenBefore;
                nextChange = changes.hasNext() ? changes.next() : null;
                i$2 = i$;
                adjustedPos2 = adjustedPos;
                value = value2;
            }
            output = output2;
            i$2 = i$2;
            value = value;
        }
        if (negative) {
            toAppendTo.append('-');
        }
        toAppendTo.append(output);
    }

    private void writeScientific(double value, StringBuffer output, Set<CellNumberStringMod> mods) {
        char expSignRes;
        StringBuffer result = new StringBuffer();
        FieldPosition fractionPos = new FieldPosition(1);
        this.decimalFmt.format(value, result, fractionPos);
        writeInteger(result, output, this.integerSpecials, mods, this.integerCommas);
        writeFractional(result, output);
        int signPos = fractionPos.getEndIndex() + 1;
        char expSignRes2 = result.charAt(signPos);
        if (expSignRes2 != '-') {
            result.insert(signPos, '+');
            expSignRes = '+';
        } else {
            expSignRes = expSignRes2;
        }
        Special expSign = this.exponentSpecials.listIterator(1).next();
        char expSignFmt = expSign.ch;
        if (expSignRes == '-' || expSignFmt == '+') {
            mods.add(replaceMod(expSign, true, expSign, true, expSignRes));
        } else {
            mods.add(deleteMod(expSign, true, expSign, true));
        }
        writeInteger(new StringBuffer(result.substring(signPos + 1)), output, this.exponentDigitSpecials, mods, false);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:15:0x009f, code lost:
        if (hasChar('#', r21.integerSpecials) != false) goto L_0x00a4;
     */
    /* JADX WARNING: Removed duplicated region for block: B:51:0x0128 A[Catch:{ RuntimeException -> 0x0152 }] */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x0134 A[Catch:{ RuntimeException -> 0x0152 }] */
    private void writeFraction(double value, StringBuffer result, double fractional, StringBuffer output, Set<CellNumberStringMod> mods) {
        int n;
        int d;
        int n2;
        boolean intOnlyHash;
        if (!this.improperFraction) {
            if (fractional == 0.0d) {
                if (!hasChar('0', this.numeratorSpecials)) {
                    writeInteger(result, output, this.integerSpecials, mods, false);
                    Special start = lastSpecial(this.integerSpecials);
                    Special end = lastSpecial(this.denominatorSpecials);
                    if (hasChar('?', this.integerSpecials, this.numeratorSpecials, this.denominatorSpecials)) {
                        mods.add(replaceMod(start, false, end, true, ' '));
                        return;
                    } else {
                        mods.add(deleteMod(start, false, end, true));
                        return;
                    }
                }
            }
            boolean numNoZero = !hasChar('0', this.numeratorSpecials);
            boolean intNoZero = !hasChar('0', this.integerSpecials);
            if (!this.integerSpecials.isEmpty()) {
                if (this.integerSpecials.size() == 1) {
                }
                intOnlyHash = false;
                boolean removeBecauseZero = fractional != 0.0d && (intOnlyHash || numNoZero);
                boolean removeBecauseFraction = fractional == 0.0d && intNoZero;
                if (value == 0.0d || (!removeBecauseZero && !removeBecauseFraction)) {
                    writeInteger(result, output, this.integerSpecials, mods, false);
                } else {
                    Special start2 = lastSpecial(this.integerSpecials);
                    mods.add(hasChar('?', new List[]{this.integerSpecials, this.numeratorSpecials}) ? replaceMod(start2, true, this.numerator, false, ' ') : deleteMod(start2, true, this.numerator, false));
                }
            }
            intOnlyHash = true;
            if (fractional != 0.0d) {
            }
            if (fractional == 0.0d) {
            }
            if (value == 0.0d) {
            }
            writeInteger(result, output, this.integerSpecials, mods, false);
        }
        if (fractional != 0.0d) {
            try {
                if (!this.improperFraction || fractional % 1.0d != 0.0d) {
                    SimpleFraction frac = SimpleFraction.buildFractionMaxDenominator(fractional, this.maxDenominator);
                    n = frac.getNumerator();
                    d = frac.getDenominator();
                    if (!this.improperFraction) {
                        n2 = (int) (((long) n) + Math.round(((double) d) * value));
                    } else {
                        n2 = n;
                    }
                    writeSingleInteger(this.numeratorFmt, n2, output, this.numeratorSpecials, mods);
                    writeSingleInteger(this.denominatorFmt, d, output, this.denominatorSpecials, mods);
                }
            } catch (RuntimeException ignored) {
                LOG.log(7, "error while fraction evaluation", ignored);
                return;
            }
        }
        n = (int) Math.round(fractional);
        d = 1;
        if (!this.improperFraction) {
        }
        writeSingleInteger(this.numeratorFmt, n2, output, this.numeratorSpecials, mods);
        writeSingleInteger(this.denominatorFmt, d, output, this.denominatorSpecials, mods);
    }

    private static boolean hasChar(char ch, List<Special>... numSpecials) {
        for (List<Special> specials2 : numSpecials) {
            for (Special s : specials2) {
                if (s.ch == ch) {
                    return true;
                }
            }
        }
        return false;
    }

    /* JADX INFO: finally extract failed */
    private void writeSingleInteger(String fmt, int num, StringBuffer output, List<Special> numSpecials, Set<CellNumberStringMod> mods) {
        StringBuffer sb = new StringBuffer();
        Formatter formatter = new Formatter(sb, LocaleUtil.getUserLocale());
        try {
            formatter.format(LocaleUtil.getUserLocale(), fmt, Integer.valueOf(num));
            formatter.close();
            writeInteger(sb, output, numSpecials, mods, false);
        } catch (Throwable th) {
            formatter.close();
            throw th;
        }
    }

    private void writeInteger(StringBuffer result, StringBuffer output, List<Special> numSpecials, Set<CellNumberStringMod> mods, boolean showCommas) {
        char resultCh;
        boolean z = true;
        int pos = result.indexOf(".") - 1;
        if (pos < 0) {
            if (this.exponent == null || numSpecials != this.integerSpecials) {
                pos = result.length() - 1;
            } else {
                pos = result.indexOf("E") - 1;
            }
        }
        int strip = 0;
        while (strip < pos && ((resultCh = result.charAt(strip)) == '0' || resultCh == ',')) {
            strip++;
        }
        ListIterator<Special> it = numSpecials.listIterator(numSpecials.size());
        Special lastOutputIntegerDigit = null;
        int digit = 0;
        while (true) {
            boolean z2 = false;
            if (!it.hasPrevious()) {
                break;
            }
            if (pos >= 0) {
                resultCh = result.charAt(pos);
            } else {
                resultCh = '0';
            }
            Special s = it.previous();
            boolean followWithComma = (!showCommas || digit <= 0 || digit % 3 != 0) ? false : z;
            boolean zeroStrip = false;
            if (resultCh != '0' || s.ch == '0' || s.ch == '?' || pos >= strip) {
                if (s.ch == '?' && pos < strip) {
                    z2 = true;
                }
                zeroStrip = z2;
                output.setCharAt(s.pos, zeroStrip ? ' ' : resultCh);
                lastOutputIntegerDigit = s;
            }
            if (followWithComma) {
                mods.add(insertMod(s, zeroStrip ? " " : ",", 2));
            }
            digit++;
            pos--;
            z = true;
        }
        new StringBuffer();
        if (pos >= 0) {
            int pos2 = pos + 1;
            StringBuffer extraLeadingDigits = new StringBuffer(result.substring(0, pos2));
            if (showCommas) {
                while (pos2 > 0) {
                    if (digit > 0 && digit % 3 == 0) {
                        extraLeadingDigits.insert(pos2, ',');
                    }
                    digit++;
                    pos2--;
                }
            }
            mods.add(insertMod(lastOutputIntegerDigit, extraLeadingDigits, 1));
        }
    }

    private void writeFractional(StringBuffer result, StringBuffer output) {
        int strip;
        if (this.fractionalSpecials.size() > 0) {
            int digit = result.indexOf(".") + 1;
            if (this.exponent != null) {
                strip = result.indexOf("e");
            } else {
                strip = result.length();
            }
            while (true) {
                strip--;
                if (strip <= digit || result.charAt(strip) != '0') {
                }
            }
            for (Special s : this.fractionalSpecials) {
                char resultCh = result.charAt(digit);
                if (resultCh != '0' || s.ch == '0' || digit < strip) {
                    output.setCharAt(s.pos, resultCh);
                } else if (s.ch == '?') {
                    output.setCharAt(s.pos, ' ');
                }
                digit++;
            }
        }
    }

    @Override // org.apache.poi.ss.format.CellFormatter
    public void simpleValue(StringBuffer toAppendTo, Object value) {
        SIMPLE_NUMBER.formatValue(toAppendTo, value);
    }

    private static Special lastSpecial(List<Special> s) {
        return s.get(s.size() - 1);
    }
}
