package org.apache.poi.ss.format;

import com.sec.factory.modules.ModuleDevice;

public class SimpleFraction {
    private final int denominator;
    private final int numerator;

    public static SimpleFraction buildFractionExactDenominator(double val, int exactDenom) {
        return new SimpleFraction((int) Math.round(((double) exactDenom) * val), exactDenom);
    }

    public static SimpleFraction buildFractionMaxDenominator(double value, int maxDenominator) {
        return buildFractionMaxDenominator(value, 0.0d, maxDenominator, 100);
    }

    /* JADX WARNING: Removed duplicated region for block: B:42:0x010d A[LOOP:0: B:7:0x0049->B:42:0x010d, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x00d2 A[SYNTHETIC] */
    private static SimpleFraction buildFractionMaxDenominator(double value, double epsilon, int maxDenominator, int maxIterations) {
        long p2;
        long a1;
        long q2;
        double d;
        long overflow = ModuleDevice.TIMELESS_VIBRATOR;
        long a0 = (long) Math.floor(value);
        String str = "Overflow trying to convert ";
        if (a0 <= ModuleDevice.TIMELESS_VIBRATOR) {
            double r0 = value;
            int i = 1;
            if (Math.abs(((double) a0) - value) < epsilon) {
                return new SimpleFraction((int) a0, 1);
            }
            long p0 = 1;
            long q0 = 0;
            int n = 0;
            boolean stop = false;
            long p1 = a0;
            long q1 = 1;
            while (true) {
                n += i;
                double r1 = 1.0d / (r0 - ((double) a0));
                long a12 = (long) Math.floor(r1);
                long a02 = a0;
                p2 = (a12 * p1) + p0;
                double r02 = r0;
                long q22 = (a12 * q1) + q0;
                if (epsilon != 0.0d || maxDenominator <= 0) {
                    a1 = a12;
                    q2 = q22;
                } else {
                    a1 = a12;
                    if (Math.abs(q22) > ((long) maxDenominator)) {
                        q2 = q22;
                        if (Math.abs(q1) < ((long) maxDenominator)) {
                            return new SimpleFraction((int) p1, (int) q1);
                        }
                    } else {
                        q2 = q22;
                    }
                }
                if (p2 > overflow || q2 > overflow) {
                } else {
                    double convergent = ((double) p2) / ((double) q2);
                    if (n < maxIterations) {
                        d = value;
                        if (Math.abs(convergent - d) > epsilon) {
                            if (q2 < ((long) maxDenominator)) {
                                q1 = q2;
                                r02 = r1;
                                p1 = p2;
                                a02 = a1;
                                q0 = q1;
                                p0 = p1;
                                if (!stop) {
                                    overflow = overflow;
                                    a0 = a02;
                                    str = str;
                                    r0 = r02;
                                    i = 1;
                                } else if (n >= maxIterations) {
                                    throw new RuntimeException("Unable to convert " + d + " to fraction after " + maxIterations + " iterations");
                                } else if (q2 < ((long) maxDenominator)) {
                                    return new SimpleFraction((int) p2, (int) q2);
                                } else {
                                    return new SimpleFraction((int) p1, (int) q1);
                                }
                            }
                            stop = true;
                            if (!stop) {
                            }
                        }
                    } else {
                        d = value;
                    }
                    stop = true;
                    if (!stop) {
                    }
                }
            }
            throw new RuntimeException(str + value + " to fraction (" + p2 + "/" + q2 + ")");
        }
        throw new IllegalArgumentException(str + value + " to fraction (" + a0 + "/" + 1L + ")");
    }

    public SimpleFraction(int numerator2, int denominator2) {
        this.numerator = numerator2;
        this.denominator = denominator2;
    }

    public int getDenominator() {
        return this.denominator;
    }

    public int getNumerator() {
        return this.numerator;
    }
}
