package org.apache.poi.ss.formula;

import org.apache.poi.ss.formula.ptg.AbstractFunctionPtg;
import org.apache.poi.ss.formula.ptg.AttrPtg;
import org.apache.poi.ss.formula.ptg.ControlPtg;
import org.apache.poi.ss.formula.ptg.FuncVarPtg;
import org.apache.poi.ss.formula.ptg.IntersectionPtg;
import org.apache.poi.ss.formula.ptg.MemAreaPtg;
import org.apache.poi.ss.formula.ptg.MemFuncPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.formula.ptg.RangePtg;
import org.apache.poi.ss.formula.ptg.UnionPtg;
import org.apache.poi.ss.formula.ptg.ValueOperatorPtg;
import org.apache.poi.util.Removal;

/* access modifiers changed from: package-private */
public final class OperandClassTransformer {
    private final FormulaType _formulaType;

    @Removal(version = "3.17")
    public OperandClassTransformer(int formulaType) {
        this(FormulaType.forInt(formulaType));
    }

    public OperandClassTransformer(FormulaType formulaType) {
        this._formulaType = formulaType;
    }

    /* access modifiers changed from: package-private */
    /* renamed from: org.apache.poi.ss.formula.OperandClassTransformer$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$org$apache$poi$ss$formula$FormulaType;

        static {
            int[] iArr = new int[FormulaType.values().length];
            $SwitchMap$org$apache$poi$ss$formula$FormulaType = iArr;
            try {
                iArr[FormulaType.CELL.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$org$apache$poi$ss$formula$FormulaType[FormulaType.ARRAY.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$org$apache$poi$ss$formula$FormulaType[FormulaType.NAMEDRANGE.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$org$apache$poi$ss$formula$FormulaType[FormulaType.DATAVALIDATION_LIST.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    public void transformFormula(ParseNode rootNode) {
        byte rootNodeOperandClass;
        switch (AnonymousClass1.$SwitchMap$org$apache$poi$ss$formula$FormulaType[this._formulaType.ordinal()]) {
            case 1:
                rootNodeOperandClass = 32;
                break;
            case 2:
                rootNodeOperandClass = 64;
                break;
            case 3:
            case 4:
                rootNodeOperandClass = 0;
                break;
            default:
                throw new RuntimeException("Incomplete code - formula type (" + this._formulaType + ") not supported yet");
        }
        transformNode(rootNode, rootNodeOperandClass, false);
    }

    private void transformNode(ParseNode node, byte desiredOperandClass, boolean callerForceArrayFlag) {
        Ptg token = node.getToken();
        ParseNode[] children = node.getChildren();
        if (isSimpleValueFunction(token)) {
            boolean localForceArray = desiredOperandClass == 64;
            for (ParseNode parseNode : children) {
                transformNode(parseNode, desiredOperandClass, localForceArray);
            }
            setSimpleValueFuncClass((AbstractFunctionPtg) token, desiredOperandClass, callerForceArrayFlag);
            return;
        }
        if (isSingleArgSum(token)) {
            token = FuncVarPtg.SUM;
        }
        if ((token instanceof ValueOperatorPtg) || (token instanceof ControlPtg) || (token instanceof MemFuncPtg) || (token instanceof MemAreaPtg) || (token instanceof UnionPtg) || (token instanceof IntersectionPtg)) {
            byte localDesiredOperandClass = desiredOperandClass == 0 ? 32 : desiredOperandClass;
            for (ParseNode parseNode2 : children) {
                transformNode(parseNode2, localDesiredOperandClass, callerForceArrayFlag);
            }
        } else if (token instanceof AbstractFunctionPtg) {
            transformFunctionNode((AbstractFunctionPtg) token, children, desiredOperandClass, callerForceArrayFlag);
        } else if (children.length > 0) {
            if (token != RangePtg.instance) {
                throw new IllegalStateException("Node should not have any children");
            }
        } else if (!token.isBaseToken()) {
            token.setClass(transformClass(token.getPtgClass(), desiredOperandClass, callerForceArrayFlag));
        }
    }

    private static boolean isSingleArgSum(Ptg token) {
        if (token instanceof AttrPtg) {
            return ((AttrPtg) token).isSum();
        }
        return false;
    }

    private static boolean isSimpleValueFunction(Ptg token) {
        if (!(token instanceof AbstractFunctionPtg)) {
            return false;
        }
        AbstractFunctionPtg aptg = (AbstractFunctionPtg) token;
        if (aptg.getDefaultOperandClass() != 32) {
            return false;
        }
        for (int i = aptg.getNumberOfOperands() - 1; i >= 0; i--) {
            if (aptg.getParameterClass(i) != 32) {
                return false;
            }
        }
        return true;
    }

    private byte transformClass(byte currentOperandClass, byte desiredOperandClass, boolean callerForceArrayFlag) {
        switch (desiredOperandClass) {
            case 0:
                if (!callerForceArrayFlag) {
                    return currentOperandClass;
                }
                return 0;
            case 32:
                if (!callerForceArrayFlag) {
                    return 32;
                }
                return 64;
            case 64:
                return 64;
            default:
                throw new IllegalStateException("Unexpected operand class (" + ((int) desiredOperandClass) + ")");
        }
    }

    private void transformFunctionNode(AbstractFunctionPtg afp, ParseNode[] children, byte desiredOperandClass, boolean callerForceArrayFlag) {
        byte defaultReturnOperandClass = afp.getDefaultOperandClass();
        boolean localForceArrayFlag = false;
        if (callerForceArrayFlag) {
            switch (defaultReturnOperandClass) {
                case 0:
                    if (desiredOperandClass == 0) {
                        afp.setClass((byte) 0);
                    } else {
                        afp.setClass((byte) 64);
                    }
                    localForceArrayFlag = false;
                    break;
                case 32:
                    afp.setClass((byte) 64);
                    localForceArrayFlag = true;
                    break;
                case 64:
                    afp.setClass((byte) 64);
                    localForceArrayFlag = false;
                    break;
                default:
                    throw new IllegalStateException("Unexpected operand class (" + ((int) defaultReturnOperandClass) + ")");
            }
        } else if (defaultReturnOperandClass == desiredOperandClass) {
            localForceArrayFlag = false;
            afp.setClass(defaultReturnOperandClass);
        } else {
            switch (desiredOperandClass) {
                case 0:
                    switch (defaultReturnOperandClass) {
                        case 32:
                            afp.setClass((byte) 32);
                            break;
                        case 64:
                            afp.setClass((byte) 64);
                            break;
                        default:
                            throw new IllegalStateException("Unexpected operand class (" + ((int) defaultReturnOperandClass) + ")");
                    }
                    localForceArrayFlag = false;
                    break;
                case 32:
                    afp.setClass((byte) 32);
                    localForceArrayFlag = false;
                    break;
                case 64:
                    switch (defaultReturnOperandClass) {
                        case 0:
                            afp.setClass((byte) 0);
                            break;
                        case 32:
                            afp.setClass((byte) 64);
                            break;
                        default:
                            throw new IllegalStateException("Unexpected operand class (" + ((int) defaultReturnOperandClass) + ")");
                    }
                    if (defaultReturnOperandClass == 32) {
                        localForceArrayFlag = true;
                        break;
                    }
                    break;
                default:
                    throw new IllegalStateException("Unexpected operand class (" + ((int) desiredOperandClass) + ")");
            }
        }
        for (int i = 0; i < children.length; i++) {
            transformNode(children[i], afp.getParameterClass(i), localForceArrayFlag);
        }
    }

    private void setSimpleValueFuncClass(AbstractFunctionPtg afp, byte desiredOperandClass, boolean callerForceArrayFlag) {
        if (callerForceArrayFlag || desiredOperandClass == 64) {
            afp.setClass((byte) 64);
        } else {
            afp.setClass((byte) 32);
        }
    }
}
