package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.ValueEval;

public final class Value extends Fixed1ArgFunction {
    private static final int MIN_DISTANCE_BETWEEN_THOUSANDS_SEPARATOR = 4;
    private static final Double ZERO = new Double(0.0d);

    @Override // org.apache.poi.ss.formula.functions.Function1Arg
    public ValueEval evaluate(int srcRowIndex, int srcColumnIndex, ValueEval arg0) {
        try {
            Double result = convertTextToNumber(OperandResolver.coerceValueToString(OperandResolver.getSingleValue(arg0, srcRowIndex, srcColumnIndex)));
            if (result == null) {
                return ErrorEval.VALUE_INVALID;
            }
            return new NumberEval(result.doubleValue());
        } catch (EvaluationException e) {
            return e.getErrorEval();
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:21:0x003a  */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x0045  */
    private static Double convertTextToNumber(String strText) {
        boolean foundCurrency = false;
        boolean foundUnaryPlus = false;
        boolean foundUnaryMinus = false;
        boolean foundPercentage = false;
        int len = strText.length();
        int i = 0;
        while (i < len) {
            char ch = strText.charAt(i);
            if (!Character.isDigit(ch) && ch != '.') {
                switch (ch) {
                    case ' ':
                        break;
                    case '$':
                        if (!foundCurrency) {
                            foundCurrency = true;
                            break;
                        } else {
                            return null;
                        }
                    case '+':
                        if (!foundUnaryMinus && !foundUnaryPlus) {
                            foundUnaryPlus = true;
                            break;
                        } else {
                            return null;
                        }
                    case '-':
                        if (!foundUnaryMinus && !foundUnaryPlus) {
                            foundUnaryMinus = true;
                            break;
                        } else {
                            return null;
                        }
                    default:
                        return null;
                }
                i++;
            }
            if (i >= len) {
                boolean foundDecimalPoint = false;
                int lastThousandsSeparatorIndex = -32768;
                StringBuffer sb = new StringBuffer(len);
                while (i < len) {
                    char ch2 = strText.charAt(i);
                    if (Character.isDigit(ch2)) {
                        sb.append(ch2);
                    } else {
                        switch (ch2) {
                            case ' ':
                                String remainingTextTrimmed = strText.substring(i).trim();
                                if (!remainingTextTrimmed.equals("%")) {
                                    if (remainingTextTrimmed.length() <= 0) {
                                        break;
                                    } else {
                                        return null;
                                    }
                                } else {
                                    foundPercentage = true;
                                    continue;
                                }
                            case '%':
                                foundPercentage = true;
                                continue;
                            case ',':
                                if (foundDecimalPoint || i - lastThousandsSeparatorIndex < 4) {
                                    return null;
                                }
                                lastThousandsSeparatorIndex = i;
                                continue;
                            case '.':
                                if (foundDecimalPoint || i - lastThousandsSeparatorIndex < 4) {
                                    return null;
                                }
                                foundDecimalPoint = true;
                                sb.append('.');
                                continue;
                            case 'E':
                            case 'e':
                                if (i - lastThousandsSeparatorIndex < 4) {
                                    return null;
                                }
                                sb.append(strText.substring(i));
                                i = len;
                                continue;
                            default:
                                return null;
                        }
                    }
                    i++;
                }
                if (!foundDecimalPoint && i - lastThousandsSeparatorIndex < 4) {
                    return null;
                }
                try {
                    double d = Double.parseDouble(sb.toString());
                    double result = foundUnaryMinus ? -d : d;
                    return Double.valueOf(foundPercentage ? result / 100.0d : result);
                } catch (NumberFormatException e) {
                    return null;
                }
            } else if (foundCurrency || foundUnaryMinus || foundUnaryPlus) {
                return null;
            } else {
                return ZERO;
            }
        }
        if (i >= len) {
        }
    }
}
